/**
 * 
 */
package com.ejie.ab63.adaptadores.service;

import java.net.URL;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import javax.xml.namespace.QName;
import javax.xml.ws.BindingProvider;
import javax.xml.ws.handler.HandlerResolver;
import javax.xml.ws.handler.PortInfo;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import com.ejie.ab63.clientesWS.ab61WebService.Ab61Exception;
import com.ejie.ab63.clientesWS.ab61WebService.Ab61WebService;
import com.ejie.ab63.clientesWS.ab61WebService.BusquedasWS;
import com.ejie.ab63.clientesWS.ab61WebService.DatosInicioOficio;
import com.ejie.ab63.clientesWS.ab61WebService.InicioOficioWS;
import com.ejie.ab63.clientesWS.ab61WebService.WebServiceImpl;
import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.comun.utilidades.config.Config;

/**
 *  
 * 
 */
@Service(value = "ab61WebServiceServiceImpl")
public class ab61WebServiceServiceImpl implements ab61WebServiceService {

	private static final Logger logger = LoggerFactory.getLogger(ab61WebServiceServiceImpl.class);

	private Ab61WebService service;

	private static final QName qname = new QName("http://com.ejie.ab61.serviciosWeb", "ab61WebService");

	private WebServiceImpl getab61WebServiceServiceImplServicePort() {
		return this.getab61WebServiceServiceImplServicePort(true);
	}

	private WebServiceImpl getab61WebServiceServiceImplServicePort(boolean getPort) {
		try {

			Properties prop = Config.loadProperties(Constantes.FICHERO_CONFIGURACION);

			if (this.service == null) {
				logger.info("INICIANDO SERVICE ab61WebServiceService");
				// Creamos el servicio

				logger.info("URL: " + prop.getProperty("Ab61WebService_URL"));

				service = new Ab61WebService(new URL(prop.getProperty("Ab61WebService_URL")), qname);

				// definimos un handler cliente
				service.setHandlerResolver(new HandlerResolver() {
					public List getHandlerChain(PortInfo portInfo) {
						return Collections.singletonList(new ab61WebServiceServiceHandler());
					}
				});
				logger.info("INICIADO SERVICE ab61WebServiceService");
			}
			if (getPort) {
				logger.info("get SERVICE PORT ab61WebServiceService inicia llamada WS");
				WebServiceImpl proxy = this.service.getAb61WebServicePort();

				Map<String, Object> ctxt = ((BindingProvider) proxy).getRequestContext();
				ctxt.put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, prop.getProperty("Ab61WebService_URL"));

				return proxy;
			}
		} catch (Exception e) {
			this.service = null;
		}
		return null;
	}

	public String generarExcelListados(int idListado, List<BusquedasWS> listaBusquedas, String codAplic)
			throws Ab61Exception {

		return getab61WebServiceServiceImplServicePort().generarExcelListados(idListado, listaBusquedas, codAplic);
	}

	public String descargarDocumento(Integer idPlantilla, String procedureId, String foderId, String codAplic)
			throws Ab61Exception {

		return getab61WebServiceServiceImplServicePort().descargarDocumento(idPlantilla, procedureId, foderId,
				codAplic);

	}

	public String generarDocumento(Integer idPlantilla, String procedureId, String foderId, String usuario)
			throws Ab61Exception {

		return getab61WebServiceServiceImplServicePort().generarDocumento(idPlantilla, procedureId, foderId, usuario);

	}

	public String modificarDocumento(Integer idPlantilla, String procedureId, String foderId, String usuario)
			throws Ab61Exception {

		return getab61WebServiceServiceImplServicePort().modificarDocumento(idPlantilla, procedureId, foderId, usuario);
	}

	/**
	 * Llama al webService que realiza la tarea indicada
	 * 
	 * @param idPlantilla
	 *            Integer
	 * @param procedureId
	 *            String
	 * @param folderId
	 *            String
	 * @param n38Login
	 *            String
	 * @return String
	 * @throws Ab61Exception
	 */
	public String aportarDocumento(Integer idPlantilla, String procedureId, String folderId, String n38Login,
			String usuario) throws Ab61Exception {

		return getab61WebServiceServiceImplServicePort().aportarDocumento(idPlantilla, procedureId, folderId, n38Login,
				usuario);
	}

	public String eliminarDocumento(Integer idPlantilla, String folderId, String procedureId) throws Ab61Exception {
		return getab61WebServiceServiceImplServicePort().eliminarDocumento(idPlantilla, folderId, procedureId);

	}

	public DatosInicioOficio generarInicioOficio(InicioOficioWS inicioOficioWS) throws Ab61Exception {
		return getab61WebServiceServiceImplServicePort().generarInicioOficio(inicioOficioWS);

	}
}
