package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Ab6343s00;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6343s00DaoImpl  
 *  
 */

@Repository
@Transactional
public class Ab6343s00DaoImpl implements Ab6343s00Dao {


    public static final String[] ORDER_BY_WHITE_LIST = new String[] {"IDRELESTEXPNB29", "IDESTABLECIMIENTO", "NUMEXPEDIENTE", "TITULOEXP", "ESTADO", "FECHAAPERTURA", "FOLDERID", "NOMBREPROC", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION"};

    private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Ab6343s00> rwMap = new RowMapper<Ab6343s00>() {
		public Ab6343s00 mapRow(ResultSet resultSet, int rowNum) throws SQLException {
           return new Ab6343s00(
               resultSet.getInt("IDRELESTEXPNB29"), resultSet.getInt("IDESTABLECIMIENTO"), resultSet.getString("NUMEXPEDIENTE"), resultSet.getString("TITULOEXP"), resultSet.getString("ESTADO"), resultSet.getDate("FECHAAPERTURA"), resultSet.getString("FOLDERID"), resultSet.getString("NOMBREPROC"), resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"), resultSet.getBigDecimal("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION")
           ); } } ;

	private RowMapper<Ab6343s00> rwMapPK = new RowMapper<Ab6343s00>() {
		public Ab6343s00 mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Ab6343s00(
				resultSet.getInt("IDRELESTEXPNB29")
           ); } } ;

	/**
     * Rowmapper para Jerarquía
     *
     * @param dataSource DataSource
     * @return
     */
	private RowMapper<JerarquiaDto< Ab6343s00>> rwMapJerarquia = new RowMapper<JerarquiaDto<Ab6343s00>>() {
		public JerarquiaDto<Ab6343s00> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Ab6343s00 ab6343s00 = new Ab6343s00(resultSet.getInt("IDRELESTEXPNB29"), resultSet.getInt("IDESTABLECIMIENTO"), resultSet.getString("NUMEXPEDIENTE"), resultSet.getString("TITULOEXP"), resultSet.getString("ESTADO"), resultSet.getDate("FECHAAPERTURA"), resultSet.getString("FOLDERID"), resultSet.getString("NOMBREPROC"), resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"), resultSet.getBigDecimal("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<Ab6343s00> jerarquia = new JerarquiaDto<Ab6343s00>();
			jerarquia.setModel(ab6343s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};


	/**
     * Method use to set the datasource.
     *
     * @param dataSource DataSource
     * @return
     */
    @Resource
    public void setDataSource(DataSource dataSource) {
    	this.jdbcTemplate = new JdbcTemplate(dataSource);
    }

	/*
	 * OPERACIONES CRUD
	 */

    /**
     * Inserts a single row in the Ab6343s00 table.
     *
     * @param ab6343s00 Ab6343s00
     * @return Ab6343s00
     */
	public Ab6343s00 add(Ab6343s00 ab6343s00) {
    	String query = "INSERT INTO AB6343S00 (ID_REL_EST_EXPNB29, ID_ESTABLECIMIENTO, NUM_EXPEDIENTE, TITULO_EXP, ESTADO, FECHA_APERTURA, FOLDER_ID, NOMBRE_PROC, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, ab6343s00.getIdRelEstExpnb29(), ab6343s00.getIdEstablecimiento(), ab6343s00.getNumExpediente(), ab6343s00.getTituloExp(), ab6343s00.getEstado(), ab6343s00.getFechaApertura(), ab6343s00.getFolderId(), ab6343s00.getNombreProc(), ab6343s00.getFechaRegistro(), ab6343s00.getUsuarioRegistro(), ab6343s00.getFechaUltmodificacion(), ab6343s00.getUsuarioUltmodificacion());
		return ab6343s00;
	}

    /**
     * Updates a single row in the Ab6343s00 table.
     *
     * @param ab6343s00 Ab6343s00
     * @return Ab6343s00
     */
    public Ab6343s00 update(Ab6343s00 ab6343s00) {
		String query = "UPDATE AB6343S00 SET ID_ESTABLECIMIENTO=?, NUM_EXPEDIENTE=?, TITULO_EXP=?, ESTADO=?, FECHA_APERTURA=?, FOLDER_ID=?, NOMBRE_PROC=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_REL_EST_EXPNB29=?";
		this.jdbcTemplate.update(query, ab6343s00.getIdEstablecimiento(), ab6343s00.getNumExpediente(), ab6343s00.getTituloExp(), ab6343s00.getEstado(), ab6343s00.getFechaApertura(), ab6343s00.getFolderId(), ab6343s00.getNombreProc(), ab6343s00.getFechaRegistro(), ab6343s00.getUsuarioRegistro(), ab6343s00.getFechaUltmodificacion(), ab6343s00.getUsuarioUltmodificacion(), ab6343s00.getIdRelEstExpnb29());
		return ab6343s00;
	}

    /**
     * Finds a single row in the Ab6343s00 table.
     *
     * @param ab6343s00 Ab6343s00
     * @return Ab6343s00
     */
    @Transactional (readOnly = true)
    public Ab6343s00 find(Ab6343s00 ab6343s00) {
		String query = "SELECT t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29, t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO, t1.NUM_EXPEDIENTE NUMEXPEDIENTE, t1.TITULO_EXP TITULOEXP, t1.ESTADO ESTADO, t1.FECHA_APERTURA FECHAAPERTURA, t1.FOLDER_ID FOLDERID, t1.NOMBRE_PROC NOMBREPROC, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6343S00 t1  WHERE t1.ID_REL_EST_EXPNB29 = ?  ";

		List<Ab6343s00> ab6343s00List = this.jdbcTemplate.query(query, this.rwMap, ab6343s00.getIdRelEstExpnb29());
		return (Ab6343s00) DataAccessUtils.uniqueResult(ab6343s00List);
    }

    /**
     * Removes a single row in the Ab6343s00 table.
     *
     * @param ab6343s00 Ab6343s00
     * @return
     */
    public void remove(Ab6343s00 ab6343s00) {
		String query = "DELETE FROM AB6343S00 WHERE ID_REL_EST_EXPNB29=?";
		this.jdbcTemplate.update(query, ab6343s00.getIdRelEstExpnb29());
    }
    
    /**
    * Exporta Datos al clipBoard
    *
    */
    public List<Ab6343s00> getMultiple(Ab6343s00 filterAb6343s00, TableRequestDto tableRequestDto,  Boolean startsWith){
    	
    	//Where clause & Params
    	Map<String, Object> mapaWhere = this.getWhereLikeMap(filterAb6343s00, startsWith);
    	StringBuilder where = new StringBuilder(" WHERE 1=1 ");
    	where.append(mapaWhere.get("query"));
    	
    	@SuppressWarnings("unchecked")
    	List<Object> params = (List<Object>) mapaWhere.get("params");
    	
    	StringBuilder sbMultipleSQL = TableManager.getSelectMultipleQuery(tableRequestDto, Ab6343s00.class, params, "ID_REL_EST_EXPNB29" );
    	
    	return this.jdbcTemplate.query(sbMultipleSQL.toString(), this.rwMap, params.toArray());
    }

   /**
    * Finds a list of rows in the Ab6343s00 table.
    *
    * @param ab6343s00 Ab6343s00
    * @param tableRequestDto TableRequestDto
    * @return List<Ab6343s00>
    */
	@Transactional (readOnly = true)
    public List<Ab6343s00> findAll(Ab6343s00 ab6343s00, TableRequestDto tableRequestDto) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6343S00 t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6343s00); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, Ab6343s00DaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Ab6343s00>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6343s00 table using like.
     *
     * @param ab6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @param startsWith Boolean
     * @return List<Ab6343s00>
     */
	@Transactional (readOnly = true)
    public List<Ab6343s00> findAllLike(Ab6343s00 ab6343s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT  t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
        query.append("FROM AB6343S00 t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6343s00,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, Ab6343s00DaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Ab6343s00>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

    /**
     * Counts rows in the Ab6343s00 table.
     *
     * @param ab6343s00 Ab6343s00
     * @return Long
     */
    @Transactional (readOnly = true)
    public Long findAllCount(Ab6343s00 ab6343s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6343S00 t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6343s00); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), params.toArray(), Long.class);
	}

	/**
	 * Counts rows in the Ab6343s00 table using like.
     *
     * @param ab6343s00 Ab6343s00
     * @param startsWith Boolean
     * @return Long
     */
	@Transactional (readOnly = true)
    public Long findAllLikeCount(Ab6343s00 ab6343s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6343S00 t1 ");

		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6343s00,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), params.toArray(), Long.class);
	}

	/**
	 * Reorder the data list of Ab6343s00 selected for rup_table
     *
     * @param ab6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @param startsWith Boolean
     * @return List<TableRowDto<Ab6343s00>>
     */
	@Override
	public List<TableRowDto<Ab6343s00>> reorderSelection(Ab6343s00 ab6343s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
        query.append("FROM AB6343S00 t1 ");
		// FILTRADO
		//Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6343s00,startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL =  TableManager.getReorderQuery(query, tableRequestDto, Ab6343s00.class, filterParamList, "IDRELESTEXPNB29" );

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(), new RowNumResultSetExtractor<Ab6343s00>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
     *
     * @param filterParams Ab6343s00
     * @param searchParams Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @param startsWith Boolean
     * @return List<TableRowDto<Ab6343s00>>
     */
	@Override
	public List<TableRowDto<Ab6343s00>> search(Ab6343s00 filterParams, Ab6343s00 searchParams, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
        query.append("FROM AB6343S00 t1 ");
        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith); 
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, tableRequestDto, Ab6343s00.class, filterParamList, searchSQL, searchParamList, from_alias, "IDRELESTEXPNB29");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(), new RowNumResultSetExtractor<Ab6343s00>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
     *
     * @param filterab6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @param startsWith Boolean
     */
	@Override
	public void removeMultiple(Ab6343s00 filterab6343s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder("SELECT t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
        query.append("FROM AB6343S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6343s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(tableRequestDto, Ab6343s00.class, query, params, "IDRELESTEXPNB29");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6343s00 table.
     *
     * @param filterAb6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @return List<JerarquiaDto<Ab6343s00>>
     */
	@Override
	public List<JerarquiaDto<Ab6343s00>> findAllLikeJerarquia(Ab6343s00 filterAb6343s00, TableRequestDto tableRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder("SELECT t1.ID_REL_EST_EXPNB29 IDRELESTEXPNB29,t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.NUM_EXPEDIENTE NUMEXPEDIENTE,t1.TITULO_EXP TITULOEXP,t1.ESTADO ESTADO,t1.FECHA_APERTURA FECHAAPERTURA,t1.FOLDER_ID FOLDERID,t1.NOMBRE_PROC NOMBREPROC,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
        //StringBuilder from = new StringBuilder("FROM AB6343S00 t1 ");
        List<String> from = new ArrayList<String>();
        from.add("AB6343S00");
        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6343s00, false);

		//JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		query = TableManagerJerarquia.getQuery(tableRequestDto, query, mapaWhere, "IDRELESTEXPNB29", "ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		query = TableManagerJerarquia.getQuery(tableRequestDto, query, mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins, businessFilters, businessParams);

		//PAGINACION
		if (tableRequestDto != null) {
			query = TableManagerJerarquia.getPaginationQuery(tableRequestDto, query, Ab6343s00DaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
     *
     * @param filterAb6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @return Long
     */
	@Override
	public Long findAllLikeCountJerarquia(Ab6343s00 filterAb6343s00, TableRequestDto tableRequestDto) {
		// FROM
        //StringBuilder from = new StringBuilder("FROM AB6343S00 t1 ");
        List<String> from = new ArrayList<String>();
        from.add("AB6343S00");

        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6343s00, false);

		//JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere, "IDRELESTEXPNB29", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		StringBuilder query = TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere, "ID", "ID_PADRE", from, from_alias, joins, businessFilters, businessParams);


		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForObject(query.toString(), params.toArray(), Long.class);
	}

	/**
	 * Find dependent hierarchical rows
     *
     * @param filterAb6343s00 Ab6343s00
     * @param tableRequestDto TableRequestDto
     * @return List<TableRowDto<Ab6343s00>>
     */
	@Override
	public List<TableRowDto<Ab6343s00>> findAllChild(Ab6343s00 filterAb6343s00, TableRequestDto tableRequestDto) {

		// FROM
        //StringBuilder from = new StringBuilder("FROM AB6343S00 t1 ");
        List<String> from = new ArrayList<String>();
        from.add("AB6343S00");

        //TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		//FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6343s00, false);

		//MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "IDRELESTEXPNB29", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y condiciones de negocio
		 */
//		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "ID", "ID_PADRE", from, from_alias, joins, businessFilters, businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(), new RowNumResultSetExtractor<Ab6343s00>(this.rwMapPK, "IDRELESTEXPNB29"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6343s00 entity
	 *
	 * @param ab6343s00 Ab6343s00
	 *            Bean with the criteria values to filter by.
	 * @return Map created with two keys
	 *         key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap (Ab6343s00 ab6343s00){

		StringBuilder where = new StringBuilder(Ab6343s00DaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6343s00  != null  && ab6343s00.getIdRelEstExpnb29() != null ) {
			where.append(" AND t1.ID_REL_EST_EXPNB29 = ?");
			params.add(ab6343s00.getIdRelEstExpnb29());
		}
		if (ab6343s00  != null  && ab6343s00.getIdEstablecimiento() != null ) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6343s00.getIdEstablecimiento());
		}
		if (ab6343s00  != null  && ab6343s00.getNumExpediente() != null ) {
			where.append(" AND t1.NUM_EXPEDIENTE = ?");
			params.add(ab6343s00.getNumExpediente());
		}
		if (ab6343s00  != null  && ab6343s00.getTituloExp() != null ) {
			where.append(" AND t1.TITULO_EXP = ?");
			params.add(ab6343s00.getTituloExp());
		}
		if (ab6343s00  != null  && ab6343s00.getEstado() != null ) {
			where.append(" AND t1.ESTADO = ?");
			params.add(ab6343s00.getEstado());
		}
		if (ab6343s00  != null  && ab6343s00.getFechaApertura() != null ) {
			where.append(" AND t1.FECHA_APERTURA = ?");
			params.add(ab6343s00.getFechaApertura());
		}
		if (ab6343s00  != null  && ab6343s00.getFolderId() != null ) {
			where.append(" AND t1.FOLDER_ID = ?");
			params.add(ab6343s00.getFolderId());
		}
		if (ab6343s00  != null  && ab6343s00.getNombreProc() != null ) {
			where.append(" AND t1.NOMBRE_PROC = ?");
			params.add(ab6343s00.getNombreProc());
		}
		if (ab6343s00  != null  && ab6343s00.getFechaRegistro() != null ) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6343s00.getFechaRegistro());
		}
		if (ab6343s00  != null  && ab6343s00.getUsuarioRegistro() != null ) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6343s00.getUsuarioRegistro());
		}
		if (ab6343s00  != null  && ab6343s00.getFechaUltmodificacion() != null ) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6343s00.getFechaUltmodificacion());
		}
		if (ab6343s00  != null  && ab6343s00.getUsuarioUltmodificacion() != null ) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6343s00.getUsuarioUltmodificacion());
		}

		Map<String,Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6343s00 entity
	 *
	 * @param ab6343s00 Ab6343s00
	 *            Bean with the criteria values to filter by.
     * @param startsWith Boolean
	 * @return Map created with two keys
	 *         key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap (Ab6343s00 ab6343s00, Boolean startsWith){

		StringBuilder where = new StringBuilder(Ab6343s00DaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6343s00  != null  && ab6343s00.getIdRelEstExpnb29() != null ) {
			where.append(" AND t1.ID_REL_EST_EXPNB29 = ?");
			params.add(ab6343s00.getIdRelEstExpnb29());
	     }
		if (ab6343s00  != null  && ab6343s00.getIdEstablecimiento() != null ) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6343s00.getIdEstablecimiento());
	     }
		if (ab6343s00  != null  && ab6343s00.getNumExpediente() != null ) {
			where.append(" AND UPPER(t1.NUM_EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getNumExpediente().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getNumExpediente().toUpperCase() +"%");
			}
			where.append(" AND t1.NUM_EXPEDIENTE IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getTituloExp() != null ) {
			where.append(" AND UPPER(t1.TITULO_EXP) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getTituloExp().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getTituloExp().toUpperCase() +"%");
			}
			where.append(" AND t1.TITULO_EXP IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getEstado() != null ) {
			where.append(" AND UPPER(t1.ESTADO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getEstado().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getEstado().toUpperCase() +"%");
			}
			where.append(" AND t1.ESTADO IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getFechaApertura() != null ) {
			where.append(" AND t1.FECHA_APERTURA = ?");
			params.add(ab6343s00.getFechaApertura());
	     }
		if (ab6343s00  != null  && ab6343s00.getFolderId() != null ) {
			where.append(" AND UPPER(t1.FOLDER_ID) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getFolderId().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getFolderId().toUpperCase() +"%");
			}
			where.append(" AND t1.FOLDER_ID IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getNombreProc() != null ) {
			where.append(" AND UPPER(t1.NOMBRE_PROC) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getNombreProc().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getNombreProc().toUpperCase() +"%");
			}
			where.append(" AND t1.NOMBRE_PROC IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getFechaRegistro() != null ) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6343s00.getFechaRegistro());
	     }
		if (ab6343s00  != null  && ab6343s00.getUsuarioRegistro() != null ) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getUsuarioRegistro().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getUsuarioRegistro().toUpperCase() +"%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
	     }
		if (ab6343s00  != null  && ab6343s00.getFechaUltmodificacion() != null ) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6343s00.getFechaUltmodificacion());
	     }
		if (ab6343s00  != null  && ab6343s00.getUsuarioUltmodificacion() != null ) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith){
				params.add(ab6343s00.getUsuarioUltmodificacion().toUpperCase() +"%");
			}else{
				params.add("%"+ab6343s00.getUsuarioUltmodificacion().toUpperCase() +"%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
	     }

		Map<String,Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	 public static final int STRING_BUILDER_INIT = 4096;}

