package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.model.AgenciaData;
import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.TipoFranquicia;
import com.ejie.ab63.model.terceros.DatosDirecciones;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6335s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AgenciaDataDaoImpl implements AgenciaDataDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDESTABLECIMIENTO", "FRANQUICIA",
			"AB6336S00IDFRANQUICIA", "AB6336S00DESCFRANQUICIAES", "AB6336S00DESCFRANQUICIAEU", "AB6336S00BAJA",
			"INDONLINE", "IDINSTALOFIPRINCIPAL", "IDORIGENOFIPRINCIPAL", "IDTIPOCIE", "ETIQUETACIE", "REGISTROFIANZA",
			"OBSERVFIANZA", "OBSERVSRC", "IDPRIMERASUCURSAL", "NUMCIE", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AgenciaData> rwMap = new RowMapper<AgenciaData>() {
		public AgenciaData mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AgenciaData(resultSet.getInt("IDESTABLECIMIENTO"), resultSet.getInt("FRANQUICIA"),
					new TipoFranquicia(resultSet.getLong("AB6336S00IDFRANQUICIA"),
							resultSet.getString("AB6336S00DESCFRANQUICIAES"),
							resultSet.getString("AB6336S00DESCFRANQUICIAEU"), resultSet.getInt("AB6336S00BAJA"), null,
							null, null, null),
					resultSet.getInt("INDONLINE"), resultSet.getString("IDINSTALOFIPRINCIPAL"),
					resultSet.getString("IDORIGENOFIPRINCIPAL"), resultSet.getString("IDTIPOCIE"),
					resultSet.getString("ETIQUETACIE"), resultSet.getString("REGISTROFIANZA"),
					resultSet.getString("OBSERVFIANZA"), resultSet.getString("OBSERVSRC"),
					resultSet.getString("IDPRIMERASUCURSAL"), resultSet.getString("NUMCIE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<AgenciaData> rwMapPK = new RowMapper<AgenciaData>() {
		public AgenciaData mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AgenciaData(resultSet.getInt("IDESTABLECIMIENTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AgenciaData>> rwMapJerarquia = new RowMapper<JerarquiaDto<AgenciaData>>() {
		public JerarquiaDto<AgenciaData> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AgenciaData ab6335s00 = new AgenciaData(resultSet.getInt("IDESTABLECIMIENTO"),
					resultSet.getInt("FRANQUICIA"),
					new TipoFranquicia(resultSet.getLong("AB6336S00IDFRANQUICIA"),
							resultSet.getString("AB6336S00DESCFRANQUICIAES"),
							resultSet.getString("AB6336S00DESCFRANQUICIAEU"), resultSet.getInt("AB6336S00BAJA"), null,
							null, null, null),
					resultSet.getInt("INDONLINE"), resultSet.getString("IDINSTALOFIPRINCIPAL"),
					resultSet.getString("IDORIGENOFIPRINCIPAL"), resultSet.getString("IDTIPOCIE"),
					resultSet.getString("ETIQUETACIE"), resultSet.getString("REGISTROFIANZA"),
					resultSet.getString("OBSERVFIANZA"), resultSet.getString("OBSERVSRC"),
					resultSet.getString("IDPRIMERASUCURSAL"), resultSet.getString("NUMCIE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<AgenciaData> jerarquia = new JerarquiaDto<AgenciaData>();
			jerarquia.setModel(ab6335s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	private RowMapper<DatosDirecciones> rwMapDireccionExtranjeraOficinaPpalAAVV = new RowMapper<DatosDirecciones>() {
		public DatosDirecciones mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			DatosDirecciones datosDirecciones = new DatosDirecciones();

			datosDirecciones.setIdDireccion(resultSet.getInt("ID_DIRECCION"));
			datosDirecciones.setDireccion(resultSet.getString("DIRECCION"));
			datosDirecciones.setNumero(resultSet.getString("NUMERO"));
			datosDirecciones.setPiso(resultSet.getString("PISO"));
			datosDirecciones.setLetra(resultSet.getString("LETRA"));
			datosDirecciones.setCodigoPostal(resultSet.getString("CODIGO_POSTAL"));
			datosDirecciones.setDescCiudadExtranjera(resultSet.getString("DESCRIPCION_CIUDAD"));
			datosDirecciones.setDescProvinciaExtranjera(resultSet.getString("DESCRIPCION_PROVINCIA"));
			datosDirecciones.setIdPais(resultSet.getLong("ID_PAIS"));

			return datosDirecciones;

		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6335s00 table.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @return Ab6335s00
	 */
	public AgenciaData add(AgenciaData ab6335s00) {
		String query = "INSERT INTO AB6335S00 (ID_ESTABLECIMIENTO, FRANQUICIA, ID_FRANQUICIA, INDONLINE, ID_INSTAL_OFI_PRINCIPAL, ID_ORIGEN_OFI_PRINCIPAL, ID_TIPO_CIE, ETIQUETA_CIE, REGISTRO_FIANZA, OBSERV_FIANZA, OBSERV_SRC, ID_PRIMERA_SUCURSAL, NUM_CIE, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";

		Long idFranquicia = null;
		if (ab6335s00.getTipoFranquicia() != null && ab6335s00.getTipoFranquicia().getIdFranquicia() != null) {
			idFranquicia = ab6335s00.getTipoFranquicia().getIdFranquicia();
		}
		this.jdbcTemplate.update(query, ab6335s00.getIdEstablecimiento(), ab6335s00.getFranquicia(), idFranquicia,
				ab6335s00.getIndonline(), ab6335s00.getIdInstalOfiPrincipal(), ab6335s00.getIdOrigenOfiPrincipal(),
				ab6335s00.getIdTipoCie(), ab6335s00.getEtiquetaCie(), ab6335s00.getRegistroFianza(),
				ab6335s00.getObservFianza(), ab6335s00.getObservSrc(), ab6335s00.getIdPrimeraSucursal(),
				ab6335s00.getNumCie(), ab6335s00.getFechaRegistro(), ab6335s00.getUsuarioRegistro(),
				ab6335s00.getFechaUltmodificacion(), ab6335s00.getUsuarioUltmodificacion());
		return ab6335s00;
	}

	/**
	 * Updates a single row in the Ab6335s00 table.
	 *
	 * @param agenciaData
	 *            Ab6335s00
	 * @return Ab6335s00
	 */
	public AgenciaData update(AgenciaData agenciaData) {
		String query = "UPDATE AB6335S00 SET FRANQUICIA=?, ID_FRANQUICIA=?, INDONLINE=?, ID_INSTAL_OFI_PRINCIPAL=?, ID_ORIGEN_OFI_PRINCIPAL=?, ID_TIPO_CIE=?, REGISTRO_FIANZA=?, OBSERV_FIANZA=?, OBSERV_SRC=?, ID_PRIMERA_SUCURSAL=?, NUM_CIE=?,  FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";

		Long idFranquicia = null;
		if (agenciaData.getTipoFranquicia() != null && agenciaData.getTipoFranquicia().getIdFranquicia() != null
				&& agenciaData.getTipoFranquicia().getIdFranquicia() != 0) {
			idFranquicia = agenciaData.getTipoFranquicia().getIdFranquicia();
		}
		this.jdbcTemplate.update(query, agenciaData.getFranquicia(), idFranquicia, agenciaData.getIndonline(),
				agenciaData.getIdInstalOfiPrincipal(), agenciaData.getIdOrigenOfiPrincipal(),
				agenciaData.getIdTipoCie(), agenciaData.getRegistroFianza(), agenciaData.getObservFianza(),
				agenciaData.getObservSrc(), agenciaData.getIdPrimeraSucursal(), agenciaData.getNumCie(),
				PermisosXLNETS.getUserConnected(), agenciaData.getIdEstablecimiento());
		return agenciaData;
	}

	/**
	 * Finds a single row in the Ab6335s00 table.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @return Ab6335s00
	 */
	@Transactional(readOnly = true)
	public AgenciaData find(AgenciaData ab6335s00) {
		String query = "SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO, t1.FRANQUICIA FRANQUICIA, t2.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t2.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t2.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t2.BAJA AB6336S00BAJA, t1.INDONLINE INDONLINE, t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL, t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL, t1.ID_TIPO_CIE IDTIPOCIE, t1.ETIQUETA_CIE ETIQUETACIE, t1.REGISTRO_FIANZA REGISTROFIANZA, t1.OBSERV_FIANZA OBSERVFIANZA, t1.OBSERV_SRC OBSERVSRC, t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL, t1.NUM_CIE NUMCIE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6335S00 t1, AB6336S00 t2  WHERE t1.ID_FRANQUICIA = t2.ID_FRANQUICIA AND t1.ID_ESTABLECIMIENTO = ?  ";

		List<AgenciaData> ab6335s00List = this.jdbcTemplate.query(query, this.rwMap, ab6335s00.getIdEstablecimiento());
		return (AgenciaData) DataAccessUtils.uniqueResult(ab6335s00List);
	}

	/**
	 * Removes a single row in the Ab6335s00 table.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @return
	 */
	public void remove(AgenciaData ab6335s00) {
		String query = "DELETE FROM AB6335S00 WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6335s00.getIdEstablecimiento());
	}

	/**
	 * Finds a list of rows in the Ab6335s00 table.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6335s00>
	 */
	@Transactional(readOnly = true)
	public List<AgenciaData> findAll(AgenciaData ab6335s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t2.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t2.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t2.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t2.BAJA AB6336S00BAJA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6335S00 t1, AB6336T t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6335s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_FRANQUICIA = t2.ID_FRANQUICIA ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, AgenciaDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AgenciaData>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6335s00 table using like.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6335s00>
	 */
	@Transactional(readOnly = true)
	public List<AgenciaData> findAllLike(AgenciaData ab6335s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t2.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t2.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t2.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t2.BAJA AB6336S00BAJA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6335S00 t1, AB6336T t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6335s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_FRANQUICIA = t2.ID_FRANQUICIA ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, AgenciaDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AgenciaData>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6335s00 table.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AgenciaData ab6335s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6335S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6335s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6335s00 table using like.
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AgenciaData ab6335s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6335S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6335s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6335s00 selected for rup_table
	 *
	 * @param ab6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6335s00>>
	 */
	@Override
	public List<TableRowDto<AgenciaData>> reorderSelection(AgenciaData ab6335s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t1.ID_FRANQUICIA IDFRANQUICIA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6335S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6335s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, AgenciaData.class,
				filterParamList, "ID_ESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AgenciaData>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6335s00
	 * @param searchParams
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6335s00>>
	 */
	@Override
	public List<TableRowDto<AgenciaData>> search(AgenciaData filterParams, AgenciaData searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t1.ID_FRANQUICIA IDFRANQUICIA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6335S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, AgenciaData.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_ESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AgenciaData>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AgenciaData filterab6335s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t1.ID_FRANQUICIA IDFRANQUICIA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6335S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6335s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, AgenciaData.class,
				query, params, "ID_ESTABLECIMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6335s00 table.
	 *
	 * @param filterAb6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6335s00>>
	 */
	@Override
	public List<JerarquiaDto<AgenciaData>> findAllLikeJerarquia(AgenciaData filterAb6335s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FRANQUICIA FRANQUICIA,t1.ID_FRANQUICIA IDFRANQUICIA,t1.INDONLINE INDONLINE,t1.ID_INSTAL_OFI_PRINCIPAL IDINSTALOFIPRINCIPAL,t1.ID_ORIGEN_OFI_PRINCIPAL IDORIGENOFIPRINCIPAL,t1.ID_TIPO_CIE IDTIPOCIE,t1.ETIQUETA_CIE ETIQUETACIE,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.OBSERV_SRC OBSERVSRC,t1.ID_PRIMERA_SUCURSAL IDPRIMERASUCURSAL,t1.NUM_CIE NUMCIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6335S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6335S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6335s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ESTABLECIMIENTO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AgenciaDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AgenciaData filterAb6335s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6335S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6335S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6335s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ESTABLECIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6335s00
	 *            Ab6335s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6335s00>>
	 */
	@Override
	public List<TableRowDto<AgenciaData>> findAllChild(AgenciaData filterAb6335s00, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6335S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6335S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6335s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ESTABLECIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AgenciaData>(this.rwMapPK, "ID_ESTABLECIMIENTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6335s00 entity
	 *
	 * @param ab6335s00
	 *            Ab6335s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AgenciaData ab6335s00) {

		StringBuilder where = new StringBuilder(AgenciaDataDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6335s00 != null && ab6335s00.getIdEstablecimiento() != null) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6335s00.getIdEstablecimiento());
		}
		if (ab6335s00 != null && ab6335s00.getFranquicia() != null) {
			where.append(" AND t1.FRANQUICIA = ?");
			params.add(ab6335s00.getFranquicia());
		}
		if (ab6335s00 != null && ab6335s00.getTipoFranquicia() != null
				&& ab6335s00.getTipoFranquicia().getIdFranquicia() != null) {
			where.append(" AND t2.ID_FRANQUICIA = ?");
			params.add(ab6335s00.getTipoFranquicia().getIdFranquicia());
		}
		if (ab6335s00 != null && ab6335s00.getIndonline() != null) {
			where.append(" AND t1.INDONLINE = ?");
			params.add(ab6335s00.getIndonline());
		}
		if (ab6335s00 != null && ab6335s00.getIdInstalOfiPrincipal() != null) {
			where.append(" AND t1.ID_INSTAL_OFI_PRINCIPAL = ?");
			params.add(ab6335s00.getIdInstalOfiPrincipal());
		}
		if (ab6335s00 != null && ab6335s00.getIdOrigenOfiPrincipal() != null) {
			where.append(" AND t1.ID_ORIGEN_OFI_PRINCIPAL = ?");
			params.add(ab6335s00.getIdOrigenOfiPrincipal());
		}
		if (ab6335s00 != null && ab6335s00.getIdTipoCie() != null) {
			where.append(" AND t1.ID_TIPO_CIE = ?");
			params.add(ab6335s00.getIdTipoCie());
		}
		if (ab6335s00 != null && ab6335s00.getEtiquetaCie() != null) {
			where.append(" AND t1.ETIQUETA_CIE = ?");
			params.add(ab6335s00.getEtiquetaCie());
		}
		if (ab6335s00 != null && ab6335s00.getRegistroFianza() != null) {
			where.append(" AND t1.REGISTRO_FIANZA = ?");
			params.add(ab6335s00.getRegistroFianza());
		}
		if (ab6335s00 != null && ab6335s00.getObservFianza() != null) {
			where.append(" AND t1.OBSERV_FIANZA = ?");
			params.add(ab6335s00.getObservFianza());
		}
		if (ab6335s00 != null && ab6335s00.getObservSrc() != null) {
			where.append(" AND t1.OBSERV_SRC = ?");
			params.add(ab6335s00.getObservSrc());
		}
		if (ab6335s00 != null && ab6335s00.getIdPrimeraSucursal() != null) {
			where.append(" AND t1.ID_PRIMERA_SUCURSAL = ?");
			params.add(ab6335s00.getIdPrimeraSucursal());
		}
		if (ab6335s00 != null && ab6335s00.getNumCie() != null) {
			where.append(" AND t1.NUM_CIE = ?");
			params.add(ab6335s00.getNumCie());
		}
		if (ab6335s00 != null && ab6335s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6335s00.getFechaRegistro());
		}
		if (ab6335s00 != null && ab6335s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6335s00.getUsuarioRegistro());
		}
		if (ab6335s00 != null && ab6335s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6335s00.getFechaUltmodificacion());
		}
		if (ab6335s00 != null && ab6335s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6335s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6335s00 entity
	 *
	 * @param ab6335s00
	 *            Ab6335s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AgenciaData ab6335s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AgenciaDataDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6335s00 != null && ab6335s00.getIdEstablecimiento() != null) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6335s00.getIdEstablecimiento());
		}
		if (ab6335s00 != null && ab6335s00.getFranquicia() != null) {
			where.append(" AND t1.FRANQUICIA = ?");
			params.add(ab6335s00.getFranquicia());
		}
		if (ab6335s00 != null && ab6335s00.getTipoFranquicia() != null
				&& ab6335s00.getTipoFranquicia().getIdFranquicia() != null) {
			where.append(" AND t2.ID_FRANQUICIA = ?");
			params.add(ab6335s00.getTipoFranquicia().getIdFranquicia());
		}
		if (ab6335s00 != null && ab6335s00.getIndonline() != null) {
			where.append(" AND t1.INDONLINE = ?");
			params.add(ab6335s00.getIndonline());
		}
		if (ab6335s00 != null && ab6335s00.getIdInstalOfiPrincipal() != null) {
			where.append(" AND UPPER(t1.ID_INSTAL_OFI_PRINCIPAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getIdInstalOfiPrincipal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getIdInstalOfiPrincipal().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_INSTAL_OFI_PRINCIPAL IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getIdOrigenOfiPrincipal() != null) {
			where.append(" AND UPPER(t1.ID_ORIGEN_OFI_PRINCIPAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getIdOrigenOfiPrincipal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getIdOrigenOfiPrincipal().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_ORIGEN_OFI_PRINCIPAL IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getIdTipoCie() != null) {
			where.append(" AND UPPER(t1.ID_TIPO_CIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getIdTipoCie().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getIdTipoCie().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_TIPO_CIE IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getEtiquetaCie() != null) {
			where.append(" AND UPPER(t1.ETIQUETA_CIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getEtiquetaCie().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getEtiquetaCie().toUpperCase() + "%");
			}
			where.append(" AND t1.ETIQUETA_CIE IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getRegistroFianza() != null) {
			where.append(" AND UPPER(t1.REGISTRO_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getRegistroFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getRegistroFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.REGISTRO_FIANZA IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getObservFianza() != null) {
			where.append(" AND UPPER(t1.OBSERV_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getObservFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getObservFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERV_FIANZA IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getObservSrc() != null) {
			where.append(" AND UPPER(t1.OBSERV_SRC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getObservSrc().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getObservSrc().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERV_SRC IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getIdPrimeraSucursal() != null) {
			where.append(" AND UPPER(t1.ID_PRIMERA_SUCURSAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getIdPrimeraSucursal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getIdPrimeraSucursal().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_PRIMERA_SUCURSAL IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getNumCie() != null) {
			where.append(" AND UPPER(t1.NUM_CIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getNumCie().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getNumCie().toUpperCase() + "%");
			}
			where.append(" AND t1.NUM_CIE IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6335s00.getFechaRegistro());
		}
		if (ab6335s00 != null && ab6335s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6335s00 != null && ab6335s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6335s00.getFechaUltmodificacion());
		}
		if (ab6335s00 != null && ab6335s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6335s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6335s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public Establecimiento addDatosEmpresaDireccionExtranjeraOficinaPpalAAVV(Establecimiento establecimiento) {
		String query = "INSERT INTO AB61.AB6136T00(ID_DIRECCION, ID_TERCERO, ID_TIPO_DIRECCION, ID_PAIS, DESCRIPCION_PROVINCIA, DESCRIPCION_CIUDAD, DIRECCION, NUMERO, PISO, LETRA, CODIGO_POSTAL, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB61.S_AB6136T00.NEXTVAL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, SYSDATE, ?) ";
		this.jdbcTemplate.update(query, establecimiento.getDatosTerceros().getIdTercero(),
				Constantes.ID_DIRECCION_OFICINA_PRINCIPAL,
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getIdPais(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDescProvinciaExtranjera(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDescCiudadExtranjera(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDireccion(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getNumero(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getPiso(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getLetra(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getCodigoPostal(),
				PermisosXLNETS.getUserConnected());
		return establecimiento;
	}

	@Override
	public Establecimiento updateDatosEmpresaDireccionExtranjeraOficinaPpalAAVV(Establecimiento establecimiento) {
		String query = "UPDATE DATOS_DIRECCIONES SET ID_PAIS=?, DESCRIPCION_PROVINCIA=?, DESCRIPCION_CIUDAD=?, DIRECCION=?, NUMERO=?, PISO=?, LETRA=?, CODIGO_POSTAL=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_DIRECCION=?";
		this.jdbcTemplate.update(query, establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getIdPais(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDescProvinciaExtranjera(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDescCiudadExtranjera(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getDireccion(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getNumero(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getPiso(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getLetra(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getCodigoPostal(),
				PermisosXLNETS.getUserConnected(),
				establecimiento.getFranquicia().getDireccionOficinaPpalExtranjera().getIdDireccion());
		return establecimiento;
	}

	@Override
	public DatosDirecciones getDireccionExtranjeraOficinaPpalAAVV(Integer idTercero) {
		String query = "SELECT t136.ID_DIRECCION, t136.DIRECCION, t136.NUMERO, t136.PISO, t136.LETRA, t136.CODIGO_POSTAL, t136.DESCRIPCION_CIUDAD, t136.DESCRIPCION_PROVINCIA, t136.ID_PAIS FROM AB61.AB6136T00 t136 WHERE ID_TIPO_DIRECCION = 5 AND ID_TERCERO = ? ";

		List<DatosDirecciones> datosDirecciones = this.jdbcTemplate.query(query,
				this.rwMapDireccionExtranjeraOficinaPpalAAVV, idTercero);
		return (DatosDirecciones) DataAccessUtils.uniqueResult(datosDirecciones);
	}

	@Override
	public Integer deleteDireccionExtranjeraOfiPpal(Integer idDireccionExt) {
		String query = "DELETE FROM DATOS_DIRECCIONES WHERE ID_DIRECCION=?";
		return this.jdbcTemplate.update(query, idDireccionExt);
	}

	@Override
	public String getNextNumCie() {

		String query = "SELECT CONCAT('CIE', MAX(TO_NUMBER(SUBSTR(NUM_CIE,4,LENGTH(NUM_CIE)))) + 1) AS GENERATED_CIE FROM AB6335T00 WHERE ID_ORIGEN_OFI_PRINCIPAL IN ('C') AND NUM_CIE LIKE 'CIE%'";

		return this.jdbcTemplate.queryForObject(query, String.class);
	}

	@Override
	public int updateNumCieAgenciaData(AgenciaData agenciaData, String numCie) {
		String query = "UPDATE AB6335T00 SET NUM_CIE = ? WHERE ID_ESTABLECIMIENTO = ?";
		return this.jdbcTemplate.update(query, numCie, agenciaData.getIdEstablecimiento());
	}

	@Override
	public String getOrigenOficinaPpal(String idInstalOficinaPpal) {
		String query = "SELECT ID_ORIGEN_OFI_PRINCIPAL FROM AB6335T00 WHERE ID_ESTABLECIMIENTO = ?";
		return this.jdbcTemplate.queryForObject(query, String.class, idInstalOficinaPpal);
	}

	@Override
	public Integer comprobarPrimeraSucursal(Integer idOficinaPpal, Integer idEstablecimiento) {
		String query = "SELECT COUNT(1) FROM AB6335T00 WHERE ID_PRIMERA_SUCURSAL = 'S' AND ID_INSTAL_OFI_PRINCIPAL = ? AND ID_ESTABLECIMIENTO NOT IN (?)";
		return this.jdbcTemplate.queryForInt(query, idOficinaPpal, idEstablecimiento);
	}
}
