package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Alojamiento;
import com.ejie.ab63.model.AseoAlojamiento;
import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.model.TipoAseo;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6326s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class AseoAlojamientoDaoImpl implements AseoAlojamientoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDASEOALO", "NUMSUPERFICIE", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "AB6323S00IDALOJAMIENTO",
			"AB6323S00DESCNOMBREALOJAMIENTO", "AB6323S00TIPOALOJAMIENTO", "AB6323S00CAPACIDAD",
			"AB6323S00NUMPLAZASDORMITORIO", "AB6323S00NUMPLAZASCONVERTIBLES", "AB6323S00NUMUNIDADES",
			"AB6323S00NUMSUPCOCINA", "AB6323S00NUMSUPCOMEDOR", "AB6323S00NUMSUPSALON", "AB6323S00NUMSUPSALONCOMEDOR",
			"AB6323S00NUMSUPSALONCOCINACOM", "AB6323S00NUMSUPCOCINACOMEDOR", "AB6323S00NUMSUPESTUDIO",
			"AB6323S00FECHAREGISTRO", "AB6323S00USUARIOREGISTRO", "AB6323S00FECHAULTMODIFICACION",
			"AB6323S00USUARIOULTMODIF", "AB6316S00IDTIPOASEO", "AB6316S00DESCTIPOES", "AB6316S00FECHAMODIFICACION",
			"AB6316S00NOMUSUARIO", "AB6316S00BAJA", "AB6316S00DESCTIPOEU", "AB6316S00FECHAREGISTRO",
			"AB6316S00USUARIOREGISTRO", "AB6316S00FECHAULTMODIFICACION", "AB6316S00USUARIOULTMODIF",
			"AB6323S00IDESTABLECIMIENTO", "TIPOREGISTRO", "NUMALOJAMIENTO", "NUMSUPTOTAL", "CAPACIDADTOTAL",
			"CAPACIDADDORM", "CAPACIDADSUPLETORIAS", "ACCESIBILIDAD", "OTRASCARACTERISTICAS" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<AseoAlojamiento> rwMap = new RowMapper<AseoAlojamiento>() {
		public AseoAlojamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AseoAlojamiento(resultSet.getInt("IDASEOALO"), resultSet.getBigDecimal("NUMSUPERFICIE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getLong("NUM_ASEO"),
					new Alojamiento(resultSet.getInt("Ab6323s00IDALOJAMIENTO"),
							resultSet.getString("Ab6323s00DESCNOMBREALOJAMIENTO"),
							resultSet.getString("Ab6323s00TIPOALOJAMIENTO"), resultSet.getString("Ab6323s00CAPACIDAD"),
							resultSet.getLong("Ab6323s00NUMPLAZASDORMITORIO"),
							resultSet.getLong("Ab6323s00NUMPLAZASCONVERTIBLES"),
							resultSet.getLong("Ab6323s00NUMUNIDADES"), resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINA"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALON"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOCINACOM"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINACOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPESTUDIO"),
							resultSet.getDate("Ab6323s00FECHAREGISTRO"),
							resultSet.getString("Ab6323s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6323s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6323S00USUARIOULTMODIF"),
							new EstablecimientoData(resultSet.getInt("Ab6323s00IDESTABLECIMIENTO"), null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null),
							resultSet.getInt("TIPOREGISTRO"), resultSet.getLong("NUMALOJAMIENTO"),
							resultSet.getBigDecimal("NUMSUPTOTAL"), resultSet.getLong("CAPACIDADTOTAL"),
							resultSet.getInt("ACCESIBILIDAD"), resultSet.getString("OTRASCARACTERISTICAS")),
					new TipoAseo(resultSet.getString("Ab6316s00IDTIPOASEO"), resultSet.getString("Ab6316s00DESCTIPOES"),
							resultSet.getDate("Ab6316s00FECHAMODIFICACION"), resultSet.getString("Ab6316s00NOMUSUARIO"),
							resultSet.getInt("Ab6316s00BAJA"), resultSet.getString("Ab6316s00DESCTIPOEU"),
							resultSet.getDate("Ab6316s00FECHAREGISTRO"),
							resultSet.getString("Ab6316s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6316s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6316S00USUARIOULTMODIF")));
		}
	};

	private RowMapper<AseoAlojamiento> rwMapPK = new RowMapper<AseoAlojamiento>() {
		public AseoAlojamiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new AseoAlojamiento(resultSet.getInt("IDASEOALO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<AseoAlojamiento>> rwMapJerarquia = new RowMapper<JerarquiaDto<AseoAlojamiento>>() {
		public JerarquiaDto<AseoAlojamiento> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			AseoAlojamiento ab6326s00 = new AseoAlojamiento(resultSet.getInt("IDASEOALO"),
					resultSet.getBigDecimal("NUMSUPERFICIE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getLong("NUM_ASEO"),
					new Alojamiento(resultSet.getInt("Ab6323s00IDALOJAMIENTO"),
							resultSet.getString("Ab6323s00DESCNOMBREALOJAMIENTO"),
							resultSet.getString("Ab6323s00TIPOALOJAMIENTO"), resultSet.getString("Ab6323s00CAPACIDAD"),
							resultSet.getLong("Ab6323s00NUMPLAZASDORMITORIO"),
							resultSet.getLong("Ab6323s00NUMPLAZASCONVERTIBLES"),
							resultSet.getLong("Ab6323s00NUMUNIDADES"), resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINA"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALON"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOCINACOM"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINACOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPESTUDIO"),
							resultSet.getDate("Ab6323s00FECHAREGISTRO"),
							resultSet.getString("Ab6323s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6323s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6323S00USUARIOULTMODIF"),
							new EstablecimientoData(resultSet.getInt("Ab6323s00IDESTABLECIMIENTO"), null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null),
							null, null, null, null, null, null),
					new TipoAseo(resultSet.getString("Ab6316s00IDTIPOASEO"), resultSet.getString("Ab6316s00DESCTIPOES"),
							resultSet.getDate("Ab6316s00FECHAMODIFICACION"), resultSet.getString("Ab6316s00NOMUSUARIO"),
							resultSet.getInt("Ab6316s00BAJA"), resultSet.getString("Ab6316s00DESCTIPOEU"),
							resultSet.getDate("Ab6316s00FECHAREGISTRO"),
							resultSet.getString("Ab6316s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6316s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6316S00USUARIOULTMODIF")));

			JerarquiaDto<AseoAlojamiento> jerarquia = new JerarquiaDto<AseoAlojamiento>();
			jerarquia.setModel(ab6326s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @return Ab6326s00
	 */
	public AseoAlojamiento add(AseoAlojamiento ab6326s00) {
		String query = "INSERT INTO AB6326S00 (ID_ASEO_ALO, ID_ALOJAMIENTO, ID_TIPO_ASEO, NUM_SUPERFICIE,NUM_ASEO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB6326Q00.NEXTVAL,?,?,?,?,SYSDATE,?)";
		Object getAb6323s00IdAlojamientoAux = null;
		if (ab6326s00.getAlojamiento() != null && ab6326s00.getAlojamiento().getIdAlojamiento() != null) {
			getAb6323s00IdAlojamientoAux = ab6326s00.getAlojamiento().getIdAlojamiento();
		}
		Object getAb6316s00IdTipoAseoAux = null;
		if (ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getIdTipoAseo() != null) {
			getAb6316s00IdTipoAseoAux = ab6326s00.getTipoAseo().getIdTipoAseo();
		}
		this.jdbcTemplate.update(query, getAb6323s00IdAlojamientoAux, getAb6316s00IdTipoAseoAux,
				ab6326s00.getNumSuperficie(), ab6326s00.getNumAseoAlojamiento(), PermisosXLNETS.getUserConnected());
		return ab6326s00;
	}

	/**
	 * Updates a single row in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @return Ab6326s00
	 */
	public AseoAlojamiento update(AseoAlojamiento ab6326s00) {
		String query = "UPDATE AB6326S00 SET ID_ALOJAMIENTO=?, ID_TIPO_ASEO=?, NUM_SUPERFICIE=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ASEO_ALO=?";
		Object getAb6323s00IdAlojamientoAux = null;
		if (ab6326s00.getAlojamiento() != null && ab6326s00.getAlojamiento().getIdAlojamiento() != null) {
			getAb6323s00IdAlojamientoAux = ab6326s00.getAlojamiento().getIdAlojamiento();
		}
		Object getAb6316s00IdTipoAseoAux = null;
		if (ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getIdTipoAseo() != null) {
			getAb6316s00IdTipoAseoAux = ab6326s00.getTipoAseo().getIdTipoAseo();
		}
		this.jdbcTemplate.update(query, getAb6323s00IdAlojamientoAux, getAb6316s00IdTipoAseoAux,
				ab6326s00.getNumSuperficie(), PermisosXLNETS.getUserConnected(), ab6326s00.getIdAseoAlo());
		return ab6326s00;
	}

	/**
	 * Finds a single row in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @return Ab6326s00
	 */
	@Transactional(readOnly = true)
	public AseoAlojamiento find(AseoAlojamiento ab6326s00) {
		String query = "SELECT t1.ID_ASEO_ALO IDASEOALO,t1.NUM_ASEO NUM_ASEO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO, t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO, t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO, t2.CAPACIDAD AB6323S00CAPACIDAD, t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO, t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES, t2.NUM_UNIDADES AB6323S00NUMUNIDADES, t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA, t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR, t2.NUM_SUP_SALON AB6323S00NUMSUPSALON, t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR, t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM, t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR, t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO, t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF, t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO, t3.DESC_TIPO_ES AB6316S00DESCTIPOES, t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION, t3.NOM_USUARIO AB6316S00NOMUSUARIO, t3.BAJA AB6316S00BAJA, t3.DESC_TIPO_EU AB6316S00DESCTIPOEU, t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO, t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO, t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION, t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF, t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO, t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS FROM AB6326S00 t1 , AB6323S00 t2 , AB6316S00 t3  WHERE t1.ID_ASEO_ALO = ?   AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+)";

		List<AseoAlojamiento> ab6326s00List = this.jdbcTemplate.query(query, this.rwMap, ab6326s00.getIdAseoAlo());
		return (AseoAlojamiento) DataAccessUtils.uniqueResult(ab6326s00List);
	}

	/**
	 * Removes a single row in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @return
	 */
	public void remove(AseoAlojamiento ab6326s00) {
		String query = "DELETE FROM AB6326S00 WHERE ID_ASEO_ALO=?";
		this.jdbcTemplate.update(query, ab6326s00.getIdAseoAlo());
	}

	/**
	 * Finds a list of rows in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6326s00>
	 */
	@Transactional(readOnly = true)
	public List<AseoAlojamiento> findAll(AseoAlojamiento ab6326s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASEO_ALO IDASEOALO,t1.NUM_ASEO NUM_ASEO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO,t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS ");
		query.append("FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6326s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AseoAlojamientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AseoAlojamiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6326s00 table using like.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6326s00>
	 */
	@Transactional(readOnly = true)
	public List<AseoAlojamiento> findAllLike(AseoAlojamiento ab6326s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ASEO_ALO IDASEOALO,t1.NUM_ASEO NUM_ASEO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO, t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS ");
		query.append("FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6326s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					AseoAlojamientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<AseoAlojamiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6326s00 table.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(AseoAlojamiento ab6326s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6326S00 t1 , AB6323S00 t2 , AB6316S00 t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6326s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6326s00 table using like.
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(AseoAlojamiento ab6326s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6326s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6326s00 selected for rup_table
	 *
	 * @param ab6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6326s00>>
	 */
	@Override
	public List<TableRowDto<AseoAlojamiento>> reorderSelection(AseoAlojamiento ab6326s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASEO_ALO IDASEOALO,t1.NUM_ASEO NUM_ASEO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6326s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				AseoAlojamiento.class, filterParamList, "ID_ASEO_ALO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AseoAlojamiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6326s00
	 * @param searchParams
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6326s00>>
	 */
	@Override
	public List<TableRowDto<AseoAlojamiento>> search(AseoAlojamiento filterParams, AseoAlojamiento searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASEO_ALO IDASEOALO,t1.NUM_ASEO NUM_ASEO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) AND t1.ID_TIPO_ASEO= t3.ID_TIPO_ASEO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				AseoAlojamiento.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_ASEO_ALO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<AseoAlojamiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(AseoAlojamiento filterab6326s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASEO_ALO IDASEOALO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6326S00 t1 ,AB6323S00 t2 ,AB6316S00 t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6326s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				AseoAlojamiento.class, query, params, "ID_ASEO_ALO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6326s00 table.
	 *
	 * @param filterAb6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6326s00>>
	 */
	@Override
	public List<JerarquiaDto<AseoAlojamiento>> findAllLikeJerarquia(AseoAlojamiento filterAb6326s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ASEO_ALO IDASEOALO,t1.NUM_SUPERFICIE NUMSUPERFICIE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIF,t3.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t3.DESC_TIPO_ES AB6316S00DESCTIPOES,t3.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t3.NOM_USUARIO AB6316S00NOMUSUARIO,t3.BAJA AB6316S00BAJA,t3.DESC_TIPO_EU AB6316S00DESCTIPOEU,t3.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6316S00USUARIOULTMODIF,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6326S00 t1 ,AB6323S00
		// t2 ,AB6316S00 t3 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6326S00");
		from.add("AB6323S00");
		from.add("AB6316S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6326s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ASEO_ALO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					AseoAlojamientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(AseoAlojamiento filterAb6326s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6326S00 t1 ,AB6323S00
		// t2 ,AB6316S00 t3 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6326S00");
		from.add("AB6323S00");
		from.add("AB6316S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6326s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ASEO_ALO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6326s00
	 *            Ab6326s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6326s00>>
	 */
	@Override
	public List<TableRowDto<AseoAlojamiento>> findAllChild(AseoAlojamiento filterAb6326s00,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6326S00 t1 ,AB6323S00
		// t2 ,AB6316S00 t3 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6326S00");
		from.add("AB6323S00");
		from.add("AB6316S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6326s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ASEO_ALO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<AseoAlojamiento>(this.rwMapPK, "ID_ASEO_ALO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6326s00 entity
	 *
	 * @param ab6326s00
	 *            Ab6326s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(AseoAlojamiento ab6326s00) {

		StringBuilder where = new StringBuilder(AseoAlojamientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6326s00 != null && ab6326s00.getIdAseoAlo() != null) {
			where.append(" AND t1.ID_ASEO_ALO = ?");
			params.add(ab6326s00.getIdAseoAlo());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getIdAlojamiento() != null) {
			where.append(" AND t2.ID_ALOJAMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getIdAlojamiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getEstablecimientoData() != null
				&& ab6326s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getDescNombreAlojamiento() != null) {
			where.append(" AND t2.DESC_NOMBRE_ALOJAMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getDescNombreAlojamiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getTipoAlojamiento() != null) {
			where.append(" AND t2.TIPO_ALOJAMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getTipoAlojamiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getCapacidad() != null) {
			where.append(" AND t2.CAPACIDAD = ?");
			params.add(ab6326s00.getAlojamiento().getCapacidad());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumPlazasDormitorio() != null) {
			where.append(" AND t2.NUM_PLAZAS_DORMITORIO = ?");
			params.add(ab6326s00.getAlojamiento().getNumPlazasDormitorio());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumPlazasConvertibles() != null) {
			where.append(" AND t2.NUM_PLAZAS_CONVERTIBLES = ?");
			params.add(ab6326s00.getAlojamiento().getNumPlazasConvertibles());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumUnidades() != null) {
			where.append(" AND t2.NUM_UNIDADES = ?");
			params.add(ab6326s00.getAlojamiento().getNumUnidades());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupCocina() != null) {
			where.append(" AND t2.NUM_SUP_COCINA = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupCocina());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupComedor() != null) {
			where.append(" AND t2.NUM_SUP_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalon() != null) {
			where.append(" AND t2.NUM_SUP_SALON = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalon());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalonComedor() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalonComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalonCocinaCom() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COCINA_COM = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalonCocinaCom());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupCocinaComedor() != null) {
			where.append(" AND t2.NUM_SUP_COCINA_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupCocinaComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupEstudio() != null) {
			where.append(" AND t2.NUM_SUP_ESTUDIO = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupEstudio());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getAlojamiento().getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6326s00.getAlojamiento().getUsuarioRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getAlojamiento().getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6326s00.getAlojamiento().getUsuarioUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getIdTipoAseo() != null) {
			where.append(" AND t3.ID_TIPO_ASEO = ?");
			params.add(ab6326s00.getTipoAseo().getIdTipoAseo());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getDescTipoEs() != null) {
			where.append(" AND t3.DESC_TIPO_ES = ?");
			params.add(ab6326s00.getTipoAseo().getDescTipoEs());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaModificacion() != null) {
			where.append(" AND t3.FECHA_MODIFICACION = ?");
			params.add(ab6326s00.getTipoAseo().getFechaModificacion());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getNomUsuario() != null) {
			where.append(" AND t3.NOM_USUARIO = ?");
			params.add(ab6326s00.getTipoAseo().getNomUsuario());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getBaja() != null) {
			where.append(" AND t3.BAJA = ?");
			params.add(ab6326s00.getTipoAseo().getBaja());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getDescTipoEu() != null) {
			where.append(" AND t3.DESC_TIPO_EU = ?");
			params.add(ab6326s00.getTipoAseo().getDescTipoEu());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getTipoAseo().getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(ab6326s00.getTipoAseo().getUsuarioRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getTipoAseo().getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getUsuarioUltmodificacion() != null) {
			where.append(" AND t3.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6326s00.getTipoAseo().getUsuarioUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getNumSuperficie() != null) {
			where.append(" AND t1.NUM_SUPERFICIE = ?");
			params.add(ab6326s00.getNumSuperficie());
		}
		if (ab6326s00 != null && ab6326s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6326s00.getUsuarioRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6326s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6326s00 entity
	 *
	 * @param ab6326s00
	 *            Ab6326s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(AseoAlojamiento ab6326s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(AseoAlojamientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6326s00 != null && ab6326s00.getIdAseoAlo() != null) {
			where.append(" AND t1.ID_ASEO_ALO = ?");
			params.add(ab6326s00.getIdAseoAlo());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getIdAlojamiento() != null) {
			where.append(" AND t2.ID_ALOJAMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getIdAlojamiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getEstablecimientoData() != null
				&& ab6326s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getDescNombreAlojamiento() != null) {
			where.append(" AND UPPER(t2.DESC_NOMBRE_ALOJAMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getAlojamiento().getDescNombreAlojamiento().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getAlojamiento().getDescNombreAlojamiento().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_NOMBRE_ALOJAMIENTO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getTipoAlojamiento() != null) {
			where.append(" AND UPPER(t2.TIPO_ALOJAMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getAlojamiento().getTipoAlojamiento().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getAlojamiento().getTipoAlojamiento().toUpperCase() + "%");
			}
			where.append(" AND t2.TIPO_ALOJAMIENTO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getCapacidad() != null) {
			where.append(" AND UPPER(t2.CAPACIDAD) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getAlojamiento().getCapacidad().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getAlojamiento().getCapacidad().toUpperCase() + "%");
			}
			where.append(" AND t2.CAPACIDAD IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumPlazasDormitorio() != null) {
			where.append(" AND t2.NUM_PLAZAS_DORMITORIO = ?");
			params.add(ab6326s00.getAlojamiento().getNumPlazasDormitorio());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumPlazasConvertibles() != null) {
			where.append(" AND t2.NUM_PLAZAS_CONVERTIBLES = ?");
			params.add(ab6326s00.getAlojamiento().getNumPlazasConvertibles());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumUnidades() != null) {
			where.append(" AND t2.NUM_UNIDADES = ?");
			params.add(ab6326s00.getAlojamiento().getNumUnidades());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupCocina() != null) {
			where.append(" AND t2.NUM_SUP_COCINA = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupCocina());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupComedor() != null) {
			where.append(" AND t2.NUM_SUP_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalon() != null) {
			where.append(" AND t2.NUM_SUP_SALON = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalon());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalonComedor() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalonComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupSalonCocinaCom() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COCINA_COM = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupSalonCocinaCom());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupCocinaComedor() != null) {
			where.append(" AND t2.NUM_SUP_COCINA_COMEDOR = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupCocinaComedor());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumSupEstudio() != null) {
			where.append(" AND t2.NUM_SUP_ESTUDIO = ?");
			params.add(ab6326s00.getAlojamiento().getNumSupEstudio());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getAlojamiento().getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getAlojamiento().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getAlojamiento().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getAlojamiento().getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getAlojamiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getAlojamiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getIdTipoAseo() != null) {
			where.append(" AND t3.ID_TIPO_ASEO = ?");
			params.add(ab6326s00.getTipoAseo().getIdTipoAseo());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getDescTipoEs() != null) {
			where.append(" AND UPPER(t3.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getTipoAseo().getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getTipoAseo().getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t3.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaModificacion() != null) {
			where.append(" AND t3.FECHA_MODIFICACION = ?");
			params.add(ab6326s00.getTipoAseo().getFechaModificacion());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getNomUsuario() != null) {
			where.append(" AND UPPER(t3.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getTipoAseo().getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getTipoAseo().getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t3.NOM_USUARIO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getBaja() != null) {
			where.append(" AND t3.BAJA = ?");
			params.add(ab6326s00.getTipoAseo().getBaja());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null && ab6326s00.getTipoAseo().getDescTipoEu() != null) {
			where.append(" AND UPPER(t3.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getTipoAseo().getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getTipoAseo().getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t3.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getTipoAseo().getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getTipoAseo().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getTipoAseo().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getTipoAseo().getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getTipoAseo() != null
				&& ab6326s00.getTipoAseo().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t3.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getTipoAseo().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getTipoAseo().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getNumSuperficie() != null) {
			where.append(" AND t1.NUM_SUPERFICIE = ?");
			params.add(ab6326s00.getNumSuperficie());
		}
		if (ab6326s00 != null && ab6326s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6326s00.getFechaRegistro());
		}
		if (ab6326s00 != null && ab6326s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6326s00.getFechaUltmodificacion());
		}
		if (ab6326s00 != null && ab6326s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6326s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6326s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6326s00 != null && ab6326s00.getAlojamiento() != null
				&& ab6326s00.getAlojamiento().getNumAlojamiento() != null) {
			where.append(" AND t2.NUM_ALOJAMIENTO = ?");
			params.add(ab6326s00.getAlojamiento().getNumAlojamiento());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public void deleteByIdAlojamiento(Integer idAlojamiento) {
		String query = "DELETE FROM AB6326S00 WHERE ID_ALOJAMIENTO=?";
		this.jdbcTemplate.update(query, idAlojamiento);

	}
}
