package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Alojamiento;
import com.ejie.ab63.model.Direccion;
import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6328s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class DireccionDaoImpl implements DireccionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDDIRECCION", "NUMCANTIDAD", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "AB6323S00IDALOJAMIENTO",
			"AB6323S00DESCNOMBREALOJAMIENTO", "AB6323S00TIPOALOJAMIENTO", "AB6323S00CAPACIDAD",
			"AB6323S00NUMPLAZASDORMITORIO", "AB6323S00NUMPLAZASCONVERTIBLES", "AB6323S00NUMUNIDADES",
			"AB6323S00NUMSUPCOCINA", "AB6323S00NUMSUPCOMEDOR", "AB6323S00NUMSUPSALON", "AB6323S00NUMSUPSALONCOMEDOR",
			"AB6323S00NUMSUPSALONCOCINACOM", "AB6323S00NUMSUPCOCINACOMEDOR", "AB6323S00NUMSUPESTUDIO",
			"AB6323S00FECHAREGISTRO", "AB6323S00USUARIOREGISTRO", "AB6323S00FECHAULTMODIFICACION",
			"AB6323S00USUARIOULTMODIFICACION", "AB6323S00IDESTABLECIMIENTO", "TIPOREGISTRO", "NUMALOJAMIENTO",
			"NUMSUPTOTAL", "CAPACIDADTOTAL", "CAPACIDADDORM", "CAPACIDADSUPLETORIAS", "ACCESIBILIDAD",
			"OTRASCARACTERISTICAS" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Direccion> rwMap = new RowMapper<Direccion>() {
		public Direccion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Direccion(resultSet.getInt("IDDIRECCION"), resultSet.getLong("NUMCANTIDAD"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new Alojamiento(resultSet.getInt("Ab6323s00IDALOJAMIENTO"),
							resultSet.getString("Ab6323s00DESCNOMBREALOJAMIENTO"),
							resultSet.getString("Ab6323s00TIPOALOJAMIENTO"), resultSet.getString("Ab6323s00CAPACIDAD"),
							resultSet.getLong("Ab6323s00NUMPLAZASDORMITORIO"),
							resultSet.getLong("Ab6323s00NUMPLAZASCONVERTIBLES"),
							resultSet.getLong("Ab6323s00NUMUNIDADES"), resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINA"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALON"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOCINACOM"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINACOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPESTUDIO"),
							resultSet.getDate("Ab6323s00FECHAREGISTRO"),
							resultSet.getString("Ab6323s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6323s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6323s00USUARIOULTMODIFICACION"),
							new EstablecimientoData(resultSet.getInt("Ab6323s00IDESTABLECIMIENTO"), null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null),
							resultSet.getInt("TIPOREGISTRO"), resultSet.getLong("NUMALOJAMIENTO"),
							resultSet.getBigDecimal("NUMSUPTOTAL"), resultSet.getLong("CAPACIDADTOTAL"),
							resultSet.getInt("ACCESIBILIDAD"), resultSet.getString("OTRASCARACTERISTICAS")));
		}
	};

	private RowMapper<Direccion> rwMapPK = new RowMapper<Direccion>() {
		public Direccion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Direccion(resultSet.getInt("IDDIRECCION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Direccion>> rwMapJerarquia = new RowMapper<JerarquiaDto<Direccion>>() {
		public JerarquiaDto<Direccion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Direccion ab6328s00 = new Direccion(resultSet.getInt("IDDIRECCION"), resultSet.getLong("NUMCANTIDAD"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					new Alojamiento(resultSet.getInt("Ab6323s00IDALOJAMIENTO"),
							resultSet.getString("Ab6323s00DESCNOMBREALOJAMIENTO"),
							resultSet.getString("Ab6323s00TIPOALOJAMIENTO"), resultSet.getString("Ab6323s00CAPACIDAD"),
							resultSet.getLong("Ab6323s00NUMPLAZASDORMITORIO"),
							resultSet.getLong("Ab6323s00NUMPLAZASCONVERTIBLES"),
							resultSet.getLong("Ab6323s00NUMUNIDADES"), resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINA"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALON"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPSALONCOCINACOM"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPCOCINACOMEDOR"),
							resultSet.getBigDecimal("Ab6323s00NUMSUPESTUDIO"),
							resultSet.getDate("Ab6323s00FECHAREGISTRO"),
							resultSet.getString("Ab6323s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6323s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6323s00USUARIOULTMODIFICACION"),
							new EstablecimientoData(resultSet.getInt("Ab6323s00IDESTABLECIMIENTO"), null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null, null, null, null, null, null, null,
									null, null, null, null, null, null, null, null),
							null, null, null, null, null, null));

			JerarquiaDto<Direccion> jerarquia = new JerarquiaDto<Direccion>();
			jerarquia.setModel(ab6328s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @return Ab6328s00
	 */
	public Direccion add(Direccion ab6328s00) {
		String query = "INSERT INTO AB6328S00 (ID_DIRECCION, ID_ALOJAMIENTO, NUM_CANTIDAD, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?)";
		Object getAb6323s00IdAlojamientoAux = null;
		if (ab6328s00.getAlojamiento() != null && ab6328s00.getAlojamiento().getIdAlojamiento() != null) {
			getAb6323s00IdAlojamientoAux = ab6328s00.getAlojamiento().getIdAlojamiento();
		}
		this.jdbcTemplate.update(query, ab6328s00.getIdDireccion(), getAb6323s00IdAlojamientoAux,
				ab6328s00.getNumCantidad(), ab6328s00.getFechaRegistro(), ab6328s00.getUsuarioRegistro(),
				ab6328s00.getFechaUltmodificacion(), ab6328s00.getUsuarioUltmodificacion());
		return ab6328s00;
	}

	/**
	 * Updates a single row in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @return Ab6328s00
	 */
	public Direccion update(Direccion ab6328s00) {
		String query = "UPDATE AB6328S00 SET ID_ALOJAMIENTO=?, NUM_CANTIDAD=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_DIRECCION=?";
		Object getAb6323s00IdAlojamientoAux = null;
		if (ab6328s00.getAlojamiento() != null && ab6328s00.getAlojamiento().getIdAlojamiento() != null) {
			getAb6323s00IdAlojamientoAux = ab6328s00.getAlojamiento().getIdAlojamiento();
		}
		this.jdbcTemplate.update(query, getAb6323s00IdAlojamientoAux, ab6328s00.getNumCantidad(),
				ab6328s00.getFechaRegistro(), ab6328s00.getUsuarioRegistro(), ab6328s00.getFechaUltmodificacion(),
				ab6328s00.getUsuarioUltmodificacion(), ab6328s00.getIdDireccion());
		return ab6328s00;
	}

	/**
	 * Finds a single row in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @return Ab6328s00
	 */
	@Transactional(readOnly = true)
	public Direccion find(Direccion ab6328s00) {
		String query = "SELECT t1.ID_DIRECCION IDDIRECCION, t1.NUM_CANTIDAD NUMCANTIDAD, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO, t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO, t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO, t2.CAPACIDAD AB6323S00CAPACIDAD, t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO, t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES, t2.NUM_UNIDADES AB6323S00NUMUNIDADES, t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA, t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR, t2.NUM_SUP_SALON AB6323S00NUMSUPSALON, t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR, t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM, t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR, t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO, t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION, t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO, t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS FROM AB6328S00 t1 , AB6323S00 t2  WHERE t1.ID_DIRECCION = ?   AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+)";

		List<Direccion> ab6328s00List = this.jdbcTemplate.query(query, this.rwMap, ab6328s00.getIdDireccion());
		return (Direccion) DataAccessUtils.uniqueResult(ab6328s00List);
	}

	/**
	 * Removes a single row in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @return
	 */
	public void remove(Direccion ab6328s00) {
		String query = "DELETE FROM AB6328S00 WHERE ID_DIRECCION=?";
		this.jdbcTemplate.update(query, ab6328s00.getIdDireccion());
	}

	/**
	 * Finds a list of rows in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6328s00>
	 */
	@Transactional(readOnly = true)
	public List<Direccion> findAll(Direccion ab6328s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO, t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS ");
		query.append("FROM AB6328S00 t1 ,AB6323S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6328s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, DireccionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Direccion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6328s00 table using like.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6328s00>
	 */
	@Transactional(readOnly = true)
	public List<Direccion> findAllLike(Direccion ab6328s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO, t2.TIPO_REGISTRO TIPOREGISTRO, t2.NUM_ALOJAMIENTO NUMALOJAMIENTO, t2.NUM_SUP_TOTAL NUMSUPTOTAL, t2.CAPACIDAD_TOTAL CAPACIDADTOTAL, t2.ACCESIBILIDAD ACCESIBILIDAD, t2.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS ");
		query.append("FROM AB6328S00 t1 ,AB6323S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6328s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, DireccionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Direccion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6328s00 table.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Direccion ab6328s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6328S00 t1 , AB6323S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6328s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6328s00 table using like.
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Direccion ab6328s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6328S00 t1 ,AB6323S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6328s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6328s00 selected for rup_table
	 *
	 * @param ab6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6328s00>>
	 */
	@Override
	public List<TableRowDto<Direccion>> reorderSelection(Direccion ab6328s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6328S00 t1 ,AB6323S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6328s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Direccion.class,
				filterParamList, "ID_DIRECCION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Direccion>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6328s00
	 * @param searchParams
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6328s00>>
	 */
	@Override
	public List<TableRowDto<Direccion>> search(Direccion filterParams, Direccion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6328S00 t1 ,AB6323S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ALOJAMIENTO= t2.ID_ALOJAMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Direccion.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_DIRECCION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Direccion>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Direccion filterab6328s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		query.append("FROM AB6328S00 t1 ,AB6323S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6328s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Direccion.class,
				query, params, "ID_DIRECCION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6328s00 table.
	 *
	 * @param filterAb6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6328s00>>
	 */
	@Override
	public List<JerarquiaDto<Direccion>> findAllLikeJerarquia(Direccion filterAb6328s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_DIRECCION IDDIRECCION,t1.NUM_CANTIDAD NUMCANTIDAD,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ALOJAMIENTO AB6323S00IDALOJAMIENTO,t2.DESC_NOMBRE_ALOJAMIENTO AB6323S00DESCNOMBREALOJAMIENTO,t2.TIPO_ALOJAMIENTO AB6323S00TIPOALOJAMIENTO,t2.CAPACIDAD AB6323S00CAPACIDAD,t2.NUM_PLAZAS_DORMITORIO AB6323S00NUMPLAZASDORMITORIO,t2.NUM_PLAZAS_CONVERTIBLES AB6323S00NUMPLAZASCONVERTIBLES,t2.NUM_UNIDADES AB6323S00NUMUNIDADES,t2.NUM_SUP_COCINA AB6323S00NUMSUPCOCINA,t2.NUM_SUP_COMEDOR AB6323S00NUMSUPCOMEDOR,t2.NUM_SUP_SALON AB6323S00NUMSUPSALON,t2.NUM_SUP_SALON_COMEDOR AB6323S00NUMSUPSALONCOMEDOR,t2.NUM_SUP_SALON_COCINA_COM AB6323S00NUMSUPSALONCOCINACOM,t2.NUM_SUP_COCINA_COMEDOR AB6323S00NUMSUPCOCINACOMEDOR,t2.NUM_SUP_ESTUDIO AB6323S00NUMSUPESTUDIO,t2.FECHA_REGISTRO AB6323S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6323S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6323S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6323S00USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6323S00IDESTABLECIMIENTO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6328S00 t1 ,AB6323S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6328S00");
		from.add("AB6323S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6328s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_DIRECCION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					DireccionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Direccion filterAb6328s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6328S00 t1 ,AB6323S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6328S00");
		from.add("AB6323S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6328s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_DIRECCION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6328s00
	 *            Ab6328s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6328s00>>
	 */
	@Override
	public List<TableRowDto<Direccion>> findAllChild(Direccion filterAb6328s00, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6328S00 t1 ,AB6323S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6328S00");
		from.add("AB6323S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6328s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_DIRECCION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Direccion>(this.rwMapPK, "ID_DIRECCION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6328s00 entity
	 *
	 * @param ab6328s00
	 *            Ab6328s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Direccion ab6328s00) {

		StringBuilder where = new StringBuilder(DireccionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6328s00 != null && ab6328s00.getIdDireccion() != null) {
			where.append(" AND t1.ID_DIRECCION = ?");
			params.add(ab6328s00.getIdDireccion());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getIdAlojamiento() != null) {
			where.append(" AND t2.ID_ALOJAMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getIdAlojamiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getEstablecimientoData() != null
				&& ab6328s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getDescNombreAlojamiento() != null) {
			where.append(" AND t2.DESC_NOMBRE_ALOJAMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getDescNombreAlojamiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getTipoAlojamiento() != null) {
			where.append(" AND t2.TIPO_ALOJAMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getTipoAlojamiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getCapacidad() != null) {
			where.append(" AND t2.CAPACIDAD = ?");
			params.add(ab6328s00.getAlojamiento().getCapacidad());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumPlazasDormitorio() != null) {
			where.append(" AND t2.NUM_PLAZAS_DORMITORIO = ?");
			params.add(ab6328s00.getAlojamiento().getNumPlazasDormitorio());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumPlazasConvertibles() != null) {
			where.append(" AND t2.NUM_PLAZAS_CONVERTIBLES = ?");
			params.add(ab6328s00.getAlojamiento().getNumPlazasConvertibles());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumUnidades() != null) {
			where.append(" AND t2.NUM_UNIDADES = ?");
			params.add(ab6328s00.getAlojamiento().getNumUnidades());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupCocina() != null) {
			where.append(" AND t2.NUM_SUP_COCINA = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupCocina());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupComedor() != null) {
			where.append(" AND t2.NUM_SUP_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalon() != null) {
			where.append(" AND t2.NUM_SUP_SALON = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalon());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalonComedor() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalonComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalonCocinaCom() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COCINA_COM = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalonCocinaCom());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupCocinaComedor() != null) {
			where.append(" AND t2.NUM_SUP_COCINA_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupCocinaComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupEstudio() != null) {
			where.append(" AND t2.NUM_SUP_ESTUDIO = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupEstudio());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6328s00.getAlojamiento().getFechaRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6328s00.getAlojamiento().getUsuarioRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6328s00.getAlojamiento().getFechaUltmodificacion());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6328s00.getAlojamiento().getUsuarioUltmodificacion());
		}
		if (ab6328s00 != null && ab6328s00.getNumCantidad() != null) {
			where.append(" AND t1.NUM_CANTIDAD = ?");
			params.add(ab6328s00.getNumCantidad());
		}
		if (ab6328s00 != null && ab6328s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6328s00.getFechaRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6328s00.getUsuarioRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6328s00.getFechaUltmodificacion());
		}
		if (ab6328s00 != null && ab6328s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6328s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6328s00 entity
	 *
	 * @param ab6328s00
	 *            Ab6328s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Direccion ab6328s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(DireccionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6328s00 != null && ab6328s00.getIdDireccion() != null) {
			where.append(" AND t1.ID_DIRECCION = ?");
			params.add(ab6328s00.getIdDireccion());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getIdAlojamiento() != null) {
			where.append(" AND t2.ID_ALOJAMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getIdAlojamiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getEstablecimientoData() != null
				&& ab6328s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6328s00.getAlojamiento().getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getDescNombreAlojamiento() != null) {
			where.append(" AND UPPER(t2.DESC_NOMBRE_ALOJAMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getAlojamiento().getDescNombreAlojamiento().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getAlojamiento().getDescNombreAlojamiento().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_NOMBRE_ALOJAMIENTO IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getTipoAlojamiento() != null) {
			where.append(" AND UPPER(t2.TIPO_ALOJAMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getAlojamiento().getTipoAlojamiento().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getAlojamiento().getTipoAlojamiento().toUpperCase() + "%");
			}
			where.append(" AND t2.TIPO_ALOJAMIENTO IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getCapacidad() != null) {
			where.append(" AND UPPER(t2.CAPACIDAD) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getAlojamiento().getCapacidad().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getAlojamiento().getCapacidad().toUpperCase() + "%");
			}
			where.append(" AND t2.CAPACIDAD IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumPlazasDormitorio() != null) {
			where.append(" AND t2.NUM_PLAZAS_DORMITORIO = ?");
			params.add(ab6328s00.getAlojamiento().getNumPlazasDormitorio());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumPlazasConvertibles() != null) {
			where.append(" AND t2.NUM_PLAZAS_CONVERTIBLES = ?");
			params.add(ab6328s00.getAlojamiento().getNumPlazasConvertibles());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumUnidades() != null) {
			where.append(" AND t2.NUM_UNIDADES = ?");
			params.add(ab6328s00.getAlojamiento().getNumUnidades());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupCocina() != null) {
			where.append(" AND t2.NUM_SUP_COCINA = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupCocina());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupComedor() != null) {
			where.append(" AND t2.NUM_SUP_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalon() != null) {
			where.append(" AND t2.NUM_SUP_SALON = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalon());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalonComedor() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalonComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupSalonCocinaCom() != null) {
			where.append(" AND t2.NUM_SUP_SALON_COCINA_COM = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupSalonCocinaCom());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupCocinaComedor() != null) {
			where.append(" AND t2.NUM_SUP_COCINA_COMEDOR = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupCocinaComedor());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getNumSupEstudio() != null) {
			where.append(" AND t2.NUM_SUP_ESTUDIO = ?");
			params.add(ab6328s00.getAlojamiento().getNumSupEstudio());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6328s00.getAlojamiento().getFechaRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getAlojamiento().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getAlojamiento().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6328s00.getAlojamiento().getFechaUltmodificacion());
		}
		if (ab6328s00 != null && ab6328s00.getAlojamiento() != null
				&& ab6328s00.getAlojamiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getAlojamiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getAlojamiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getNumCantidad() != null) {
			where.append(" AND t1.NUM_CANTIDAD = ?");
			params.add(ab6328s00.getNumCantidad());
		}
		if (ab6328s00 != null && ab6328s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6328s00.getFechaRegistro());
		}
		if (ab6328s00 != null && ab6328s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6328s00 != null && ab6328s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6328s00.getFechaUltmodificacion());
		}
		if (ab6328s00 != null && ab6328s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6328s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6328s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
