package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6321s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class EstablecimientoDataDaoImpl implements EstablecimientoDataDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDESTABLECIMIENTO", "FECHAANOCONSTRUCCION",
			"FECHAANORENOVACION", "DERECHOCOCINA", "SERVICIOCOMEDOR", "NUMSALONES", "NUMSALONESCOMEDOR", "NUMCOMEDORES",
			"NUMBAOSGENERALES", "NUMCONJUNTOS", "NUMESTUDIOS", "NUMHABDOBLE", "NUMHABINDIVIDUALES",
			"NUMMAXIMOSUPLETORIAS", "NUMPLAZAS", "EDIFICIOCATALOGADO", "NUMHABMAS4", "NUMHABMENOS4",
			"COMPARTEVIVIENDAS", "NUMHABDOBLECS", "NUMAPARTAMENTOS", "NUMSUITES", "COMPARTEINSTAL", "NUMINSTALCOMPARTE",
			"NUMSUPACAMPADA", "SUPERFICIETOTAL", "BAR", "RESTAURANTE", "PISCINA", "NUMTOTPARCELAS", "NUMPARCELASANF",
			"NUMPARCELASAF", "NUMPARCELASSA", "INDICADORIA", "FECHACONTROLIA", "REQUISITOS", "NUMCONTROL",
			"FECHAANTCONTROL", "NUMHABITACIONES", "NUMRESIDENTESPERM", "SUPTOTHABITAC", "SUPRESTODEPEN",
			"FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "NUMSUPCOCINA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<EstablecimientoData> rwMap = new RowMapper<EstablecimientoData>() {
		public EstablecimientoData mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstablecimientoData(resultSet.getInt("IDESTABLECIMIENTO"),
					resultSet.getLong("FECHAANOCONSTRUCCION"), resultSet.getLong("FECHAANORENOVACION"),
					resultSet.getInt("DERECHOCOCINA"), resultSet.getInt("SERVICIOCOMEDOR"),
					resultSet.getLong("NUMSALONES"), resultSet.getLong("NUMSALONESCOMEDOR"),
					resultSet.getLong("NUMCOMEDORES"), resultSet.getLong("NUMBAOSGENERALES"),
					resultSet.getLong("NUMCONJUNTOS"), resultSet.getLong("NUMESTUDIOS"),
					resultSet.getLong("NUMHABDOBLE"), resultSet.getLong("NUMHABINDIVIDUALES"),
					resultSet.getLong("NUMMAXIMOSUPLETORIAS"), resultSet.getLong("NUMPLAZAS"),
					resultSet.getInt("EDIFICIOCATALOGADO"), resultSet.getLong("NUMHABMAS4"),
					resultSet.getLong("NUMHABMENOS4"), resultSet.getInt("COMPARTEVIVIENDAS"),
					resultSet.getLong("NUMHABDOBLECS"), resultSet.getLong("NUMAPARTAMENTOS"),
					resultSet.getLong("NUMSUITES"), resultSet.getInt("COMPARTEINSTAL"),
					resultSet.getString("NUMINSTALCOMPARTE"), resultSet.getBigDecimal("NUMSUPACAMPADA"),
					resultSet.getInt("BAR"), resultSet.getInt("RESTAURANTE"), resultSet.getInt("PISCINA"),
					resultSet.getLong("NUMTOTPARCELAS"), resultSet.getLong("NUMPARCELASANF"),
					resultSet.getLong("NUMPARCELASAF"), resultSet.getLong("NUMPARCELASSA"),
					resultSet.getInt("INDICADORIA"), resultSet.getDate("FECHACONTROLIA"),
					resultSet.getString("REQUISITOS"), resultSet.getLong("NUMCONTROL"),
					resultSet.getDate("FECHAANTCONTROL"), resultSet.getString("NUMHABITACIONES"),
					resultSet.getString("NUMRESIDENTESPERM"), resultSet.getString("SUPTOTHABITAC"),
					resultSet.getBigDecimal("SUPRESTODEPEN"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), null, null, resultSet.getString("NUMDORMRESID"),
					resultSet.getString("NUMDORMUSUARIO"), null, null, resultSet.getBigDecimal("NUMSUPCOCINA"));
		}
	};

	private RowMapper<EstablecimientoData> rwMapPK = new RowMapper<EstablecimientoData>() {
		public EstablecimientoData mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new EstablecimientoData(resultSet.getInt("IDESTABLECIMIENTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<EstablecimientoData>> rwMapJerarquia = new RowMapper<JerarquiaDto<EstablecimientoData>>() {
		public JerarquiaDto<EstablecimientoData> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			EstablecimientoData ab6321s00 = new EstablecimientoData(resultSet.getInt("IDESTABLECIMIENTO"),
					resultSet.getLong("FECHAANOCONSTRUCCION"), resultSet.getLong("FECHAANORENOVACION"),
					resultSet.getInt("DERECHOCOCINA"), resultSet.getInt("SERVICIOCOMEDOR"),
					resultSet.getLong("NUMSALONES"), resultSet.getLong("NUMSALONESCOMEDOR"),
					resultSet.getLong("NUMCOMEDORES"), resultSet.getLong("NUMBAOSGENERALES"),
					resultSet.getLong("NUMCONJUNTOS"), resultSet.getLong("NUMESTUDIOS"),
					resultSet.getLong("NUMHABDOBLE"), resultSet.getLong("NUMHABINDIVIDUALES"),
					resultSet.getLong("NUMMAXIMOSUPLETORIAS"), resultSet.getLong("NUMPLAZAS"),
					resultSet.getInt("EDIFICIOCATALOGADO"), resultSet.getLong("NUMHABMAS4"),
					resultSet.getLong("NUMHABMENOS4"), resultSet.getInt("COMPARTEVIVIENDAS"),
					resultSet.getLong("NUMHABDOBLECS"), resultSet.getLong("NUMAPARTAMENTOS"),
					resultSet.getLong("NUMSUITES"), resultSet.getInt("COMPARTEINSTAL"),
					resultSet.getString("NUMINSTALCOMPARTE"), resultSet.getBigDecimal("NUMSUPACAMPADA"),
					resultSet.getInt("BAR"), resultSet.getInt("RESTAURANTE"), resultSet.getInt("PISCINA"),
					resultSet.getLong("NUMTOTPARCELAS"), resultSet.getLong("NUMPARCELASANF"),
					resultSet.getLong("NUMPARCELASAF"), resultSet.getLong("NUMPARCELASSA"),
					resultSet.getInt("INDICADORIA"), resultSet.getDate("FECHACONTROLIA"),
					resultSet.getString("REQUISITOS"), resultSet.getLong("NUMCONTROL"),
					resultSet.getDate("FECHAANTCONTROL"), resultSet.getString("NUMHABITACIONES"),
					resultSet.getString("NUMRESIDENTESPERM"), resultSet.getString("SUPTOTHABITAC"),
					resultSet.getBigDecimal("SUPRESTODEPEN"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), null, null, resultSet.getString("NUMDORMRESID"),
					resultSet.getString("NUMDORMUSUARIO"), null, null, resultSet.getBigDecimal("NUMSUPCOCINA"));

			JerarquiaDto<EstablecimientoData> jerarquia = new JerarquiaDto<EstablecimientoData>();
			jerarquia.setModel(ab6321s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6321s00 table.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @return Ab6321s00
	 */
	public EstablecimientoData add(EstablecimientoData ab6321s00) {
		String query = "INSERT INTO AB6321S00 (ID_ESTABLECIMIENTO, FECHA_ANO_CONSTRUCCION, FECHA_ANO_RENOVACION, DERECHO_COCINA, SERVICIO_COMEDOR, NUM_SALONES, NUM_SALONES_COMEDOR, NUM_COMEDORES, NUM_BAOS_GENERALES, NUM_CONJUNTOS, NUM_ESTUDIOS, NUM_HAB_DOBLE, NUM_HAB_INDIVIDUALES, NUM_MAXIMO_SUPLETORIAS, NUM_PLAZAS, EDIFICIO_CATALOGADO, NUM_HAB_MAS_4, NUM_HAB_MENOS_4, COMPARTE_VIVIENDAS, NUM_HAB_DOBLE_CS, NUM_APARTAMENTOS, NUM_SUITES, COMPARTE_INSTAL, NUM_INSTAL_COMPARTE, NUM_SUP_ACAMPADA, BAR, RESTAURANTE, PISCINA, NUM_TOT_PARCELAS, NUM_PARCELAS_ANF, NUM_PARCELAS_AF, NUM_PARCELAS_SA, INDICADOR_IA, FECHA_CONTROL_IA, REQUISITOS, NUM_CONTROL, FECHA_ANT_CONTROL, NUM_HABITACIONES, NUM_RESIDENTES_PERM, SUP_TOT_HABITAC, SUP_RESTO_DEPEN, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, ab6321s00.getIdEstablecimiento(), ab6321s00.getFechaAnoConstruccion(),
				ab6321s00.getFechaAnoRenovacion(), ab6321s00.getDerechoCocina(), ab6321s00.getServicioComedor(),
				ab6321s00.getNumSalones(), ab6321s00.getNumSalonesComedor(), ab6321s00.getNumComedores(),
				ab6321s00.getNumBanosGenerales(), ab6321s00.getNumConjuntos(), ab6321s00.getNumEstudios(),
				ab6321s00.getNumHabDoble(), ab6321s00.getNumHabIndividuales(), ab6321s00.getNumMaximoSupletorias(),
				ab6321s00.getNumPlazas(), ab6321s00.getEdificioCatalogado(), ab6321s00.getNumHabMas4(),
				ab6321s00.getNumHabMenos4(), ab6321s00.getComparteViviendas(), ab6321s00.getNumHabDobleCs(),
				ab6321s00.getNumApartamentos(), ab6321s00.getNumSuites(), ab6321s00.getComparteInstal(),
				ab6321s00.getNumInstalComparte(), ab6321s00.getNumSupAcampada(), ab6321s00.getBar(),
				ab6321s00.getRestaurante(), ab6321s00.getPiscina(), ab6321s00.getNumTotParcelas(),
				ab6321s00.getNumParcelasAnf(), ab6321s00.getNumParcelasAf(), ab6321s00.getNumParcelasSa(),
				ab6321s00.getIndicadorIa(), ab6321s00.getFechaControlIa(), ab6321s00.getRequisitos(),
				ab6321s00.getNumControl(), ab6321s00.getFechaAntControl(), ab6321s00.getNumHabitaciones(),
				ab6321s00.getNumResidentesPerm(), ab6321s00.getSupTotHabitac(), ab6321s00.getSupRestoDepen(),
				ab6321s00.getFechaRegistro(), ab6321s00.getUsuarioRegistro(), ab6321s00.getFechaUltmodificacion(),
				ab6321s00.getUsuarioUltmodificacion());
		return ab6321s00;
	}

	/**
	 * Updates a single row in the Ab6321s00 table.
	 *
	 * @param establecimientoData
	 *            Ab6321s00
	 * @return Ab6321s00
	 */
	public EstablecimientoData update(EstablecimientoData establecimientoData) {
		String query = "UPDATE AB6321S00 SET FECHA_ANO_CONSTRUCCION=?, FECHA_ANO_RENOVACION=?, DERECHO_COCINA=?, SERVICIO_COMEDOR=?, NUM_SALONES=?, NUM_SALONES_COMEDOR=?, NUM_COMEDORES=?, NUM_BAOS_GENERALES=?, NUM_CONJUNTOS=?, NUM_ESTUDIOS=?, NUM_HAB_DOBLE=?, NUM_HAB_INDIVIDUALES=?, NUM_MAXIMO_SUPLETORIAS=?, NUM_PLAZAS=?, EDIFICIO_CATALOGADO=?, NUM_HAB_MAS_4=?, NUM_HAB_MENOS_4=?, COMPARTE_VIVIENDAS=?, NUM_HAB_DOBLE_CS=?, NUM_APARTAMENTOS=?, NUM_SUITES=?, COMPARTE_INSTAL=?, NUM_INSTAL_COMPARTE=?, NUM_SUP_ACAMPADA=?, BAR=?, RESTAURANTE=?, PISCINA=?, NUM_TOT_PARCELAS=?, NUM_PARCELAS_ANF=?, NUM_PARCELAS_AF=?, NUM_PARCELAS_SA=?, INDICADOR_IA=?, FECHA_CONTROL_IA=?, REQUISITOS=?, NUM_CONTROL=?, FECHA_ANT_CONTROL=?, NUM_HABITACIONES=?, NUM_RESIDENTES_PERM=?, SUP_TOT_HABITAC=?, SUP_RESTO_DEPEN=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, DISPONE_COCINA=? , DISPONE_SALON=?, SUPERFICIE_TOTAL=?,NUM_DORM_RESID=?, NUM_DORM_USUARIO=?, NUM_SUP_COCINA=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, establecimientoData.getFechaAnoConstruccion(), establecimientoData.getFechaAnoRenovacion(),
				establecimientoData.getDerechoCocina(), establecimientoData.getServicioComedor(), establecimientoData.getNumSalones(),
				establecimientoData.getNumSalonesComedor(), establecimientoData.getNumComedores(), establecimientoData.getNumBanosGenerales(),
				establecimientoData.getNumConjuntos(), establecimientoData.getNumEstudios(), establecimientoData.getNumHabDoble(),
				establecimientoData.getNumHabIndividuales(), establecimientoData.getNumMaximoSupletorias(), establecimientoData.getNumPlazas(),
				establecimientoData.getEdificioCatalogado(), establecimientoData.getNumHabMas4(), establecimientoData.getNumHabMenos4(),
				establecimientoData.getComparteViviendas(), establecimientoData.getNumHabDobleCs(), establecimientoData.getNumApartamentos(),
				establecimientoData.getNumSuites(), establecimientoData.getComparteInstal(), establecimientoData.getNumInstalComparte(),
				establecimientoData.getNumSupAcampada(), establecimientoData.getBar(), establecimientoData.getRestaurante(), establecimientoData.getPiscina(),
				establecimientoData.getNumTotParcelas(), establecimientoData.getNumParcelasAnf(), establecimientoData.getNumParcelasAf(),
				establecimientoData.getNumParcelasSa(), establecimientoData.getIndicadorIa(), establecimientoData.getFechaControlIa(),
				establecimientoData.getRequisitos(), establecimientoData.getNumControl(), establecimientoData.getFechaAntControl(),
				establecimientoData.getNumHabitaciones(), establecimientoData.getNumResidentesPerm(), establecimientoData.getSupTotHabitac(),
				establecimientoData.getSupRestoDepen(), establecimientoData.getFechaRegistro(), establecimientoData.getUsuarioRegistro(),
				establecimientoData.getFechaUltmodificacion(), establecimientoData.getUsuarioUltmodificacion(),
				establecimientoData.getDisponeCocina(), establecimientoData.getDisponeSalon(), establecimientoData.getSuperficieTotal(),
				establecimientoData.getNumDormitoriosResidentes(), establecimientoData.getNumDormitoriosUsuarios(),
				establecimientoData.getNumSupCocina(), establecimientoData.getIdEstablecimiento());
		return establecimientoData;
	}

	/**
	 * Finds a single row in the Ab6321s00 table.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @return Ab6321s00
	 */
	@Transactional(readOnly = true)
	public EstablecimientoData find(EstablecimientoData ab6321s00) {
		String query = "SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO, t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION, t1.FECHA_ANO_RENOVACION FECHAANORENOVACION, t1.DERECHO_COCINA DERECHOCOCINA, t1.SERVICIO_COMEDOR SERVICIOCOMEDOR, t1.NUM_SALONES NUMSALONES, t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR, t1.NUM_COMEDORES NUMCOMEDORES, t1.NUM_BAOS_GENERALES NUMBAOSGENERALES, t1.NUM_CONJUNTOS NUMCONJUNTOS, t1.NUM_ESTUDIOS NUMESTUDIOS, t1.NUM_HAB_DOBLE NUMHABDOBLE, t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES, t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS, t1.NUM_PLAZAS NUMPLAZAS, t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO, t1.NUM_HAB_MAS_4 NUMHABMAS4, t1.NUM_HAB_MENOS_4 NUMHABMENOS4, t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS, t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS, t1.NUM_APARTAMENTOS NUMAPARTAMENTOS, t1.NUM_SUITES NUMSUITES, t1.COMPARTE_INSTAL COMPARTEINSTAL, t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE, t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA, t1.BAR BAR, t1.RESTAURANTE RESTAURANTE, t1.PISCINA PISCINA, t1.NUM_TOT_PARCELAS NUMTOTPARCELAS, t1.NUM_PARCELAS_ANF NUMPARCELASANF, t1.NUM_PARCELAS_AF NUMPARCELASAF, t1.NUM_PARCELAS_SA NUMPARCELASSA, t1.INDICADOR_IA INDICADORIA, t1.FECHA_CONTROL_IA FECHACONTROLIA, t1.REQUISITOS REQUISITOS, t1.NUM_CONTROL NUMCONTROL, t1.FECHA_ANT_CONTROL FECHAANTCONTROL, t1.NUM_HABITACIONES NUMHABITACIONES, t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM, t1.SUP_TOT_HABITAC SUPTOTHABITAC, t1.SUP_RESTO_DEPEN SUPRESTODEPEN, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO, t1.NUM_SUP_COCINA NUMSUPCOCINA FROM AB6321S00 t1  WHERE t1.ID_ESTABLECIMIENTO = ?  ";

		List<EstablecimientoData> ab6321s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6321s00.getIdEstablecimiento());
		return (EstablecimientoData) DataAccessUtils.uniqueResult(ab6321s00List);
	}

	/**
	 * Removes a single row in the Ab6321s00 table.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @return
	 */
	public void remove(EstablecimientoData ab6321s00) {
		String query = "DELETE FROM AB6321S00 WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getIdEstablecimiento());
	}

	/**
	 * Finds a list of rows in the Ab6321s00 table.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6321s00>
	 */
	@Transactional(readOnly = true)
	public List<EstablecimientoData> findAll(EstablecimientoData ab6321s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO,t1.NUM_SUP_COCINA NUMSUPCOCINA ");
		query.append("FROM AB6321S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6321s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EstablecimientoDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EstablecimientoData>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6321s00 table using like.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6321s00>
	 */
	@Transactional(readOnly = true)
	public List<EstablecimientoData> findAllLike(EstablecimientoData ab6321s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO,t1.NUM_SUP_COCINA NUMSUPCOCINA  ");
		query.append("FROM AB6321S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6321s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					EstablecimientoDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<EstablecimientoData>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6321s00 table.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(EstablecimientoData ab6321s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6321S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6321s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), Long.class, params.toArray());
	}

	/**
	 * Counts rows in the Ab6321s00 table using like.
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(EstablecimientoData ab6321s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6321S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6321s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), Long.class, params.toArray());
	}

	/**
	 * Reorder the data list of Ab6321s00 selected for rup_table
	 *
	 * @param ab6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6321s00>>
	 */
	@Override
	public List<TableRowDto<EstablecimientoData>> reorderSelection(EstablecimientoData ab6321s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO  ");
		// FROM
		query.append("FROM AB6321S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6321s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				EstablecimientoData.class, filterParamList, "ID_ESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EstablecimientoData>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6321s00
	 * @param searchParams
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6321s00>>
	 */
	@Override
	public List<TableRowDto<EstablecimientoData>> search(EstablecimientoData filterParams,
			EstablecimientoData searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO  ");
		// FROM
		query.append("FROM AB6321S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				EstablecimientoData.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_ESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<EstablecimientoData>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(EstablecimientoData filterab6321s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO  ");
		// FROM
		query.append("FROM AB6321S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6321s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				EstablecimientoData.class, query, params, "ID_ESTABLECIMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6321s00 table.
	 *
	 * @param filterAb6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6321s00>>
	 */
	@Override
	public List<JerarquiaDto<EstablecimientoData>> findAllLikeJerarquia(EstablecimientoData filterAb6321s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ESTABLECIMIENTO IDESTABLECIMIENTO,t1.FECHA_ANO_CONSTRUCCION FECHAANOCONSTRUCCION,t1.FECHA_ANO_RENOVACION FECHAANORENOVACION,t1.DERECHO_COCINA DERECHOCOCINA,t1.SERVICIO_COMEDOR SERVICIOCOMEDOR,t1.NUM_SALONES NUMSALONES,t1.NUM_SALONES_COMEDOR NUMSALONESCOMEDOR,t1.NUM_COMEDORES NUMCOMEDORES,t1.NUM_BAOS_GENERALES NUMBAOSGENERALES,t1.NUM_CONJUNTOS NUMCONJUNTOS,t1.NUM_ESTUDIOS NUMESTUDIOS,t1.NUM_HAB_DOBLE NUMHABDOBLE,t1.NUM_HAB_INDIVIDUALES NUMHABINDIVIDUALES,t1.NUM_MAXIMO_SUPLETORIAS NUMMAXIMOSUPLETORIAS,t1.NUM_PLAZAS NUMPLAZAS,t1.EDIFICIO_CATALOGADO EDIFICIOCATALOGADO,t1.NUM_HAB_MAS_4 NUMHABMAS4,t1.NUM_HAB_MENOS_4 NUMHABMENOS4,t1.COMPARTE_VIVIENDAS COMPARTEVIVIENDAS,t1.NUM_HAB_DOBLE_CS NUMHABDOBLECS,t1.NUM_APARTAMENTOS NUMAPARTAMENTOS,t1.NUM_SUITES NUMSUITES,t1.COMPARTE_INSTAL COMPARTEINSTAL,t1.NUM_INSTAL_COMPARTE NUMINSTALCOMPARTE,t1.NUM_SUP_ACAMPADA NUMSUPACAMPADA,t1.BAR BAR,t1.RESTAURANTE RESTAURANTE,t1.PISCINA PISCINA,t1.NUM_TOT_PARCELAS NUMTOTPARCELAS,t1.NUM_PARCELAS_ANF NUMPARCELASANF,t1.NUM_PARCELAS_AF NUMPARCELASAF,t1.NUM_PARCELAS_SA NUMPARCELASSA,t1.INDICADOR_IA INDICADORIA,t1.FECHA_CONTROL_IA FECHACONTROLIA,t1.REQUISITOS REQUISITOS,t1.NUM_CONTROL NUMCONTROL,t1.FECHA_ANT_CONTROL FECHAANTCONTROL,t1.NUM_HABITACIONES NUMHABITACIONES,t1.NUM_RESIDENTES_PERM NUMRESIDENTESPERM,t1.SUP_TOT_HABITAC SUPTOTHABITAC,t1.SUP_RESTO_DEPEN SUPRESTODEPEN,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.SUPERFICIE_TOTAL SUPERFICIETOTAL,t1.NUM_DORM_RESID NUMDORMRESID, t1.NUM_DORM_USUARIO NUMDORMUSUARIO  ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6321S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6321S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6321s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_ESTABLECIMIENTO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					EstablecimientoDataDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(EstablecimientoData filterAb6321s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6321S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6321S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6321s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_ESTABLECIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForObject(query.toString(), Long.class, params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6321s00
	 *            Ab6321s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6321s00>>
	 */
	@Override
	public List<TableRowDto<EstablecimientoData>> findAllChild(EstablecimientoData filterAb6321s00,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6321S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6321S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6321s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_ESTABLECIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<EstablecimientoData>(this.rwMapPK, "ID_ESTABLECIMIENTO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6321s00 entity
	 *
	 * @param ab6321s00
	 *            Ab6321s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(EstablecimientoData ab6321s00) {

		StringBuilder where = new StringBuilder(EstablecimientoDataDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6321s00 != null && ab6321s00.getIdEstablecimiento() != null) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6321s00.getIdEstablecimiento());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAnoConstruccion() != null) {
			where.append(" AND t1.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6321s00.getFechaAnoConstruccion());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAnoRenovacion() != null) {
			where.append(" AND t1.FECHA_ANO_RENOVACION = ?");
			params.add(ab6321s00.getFechaAnoRenovacion());
		}
		if (ab6321s00 != null && ab6321s00.getDerechoCocina() != null) {
			where.append(" AND t1.DERECHO_COCINA = ?");
			params.add(ab6321s00.getDerechoCocina());
		}
		if (ab6321s00 != null && ab6321s00.getServicioComedor() != null) {
			where.append(" AND t1.SERVICIO_COMEDOR = ?");
			params.add(ab6321s00.getServicioComedor());
		}
		if (ab6321s00 != null && ab6321s00.getNumSalones() != null) {
			where.append(" AND t1.NUM_SALONES = ?");
			params.add(ab6321s00.getNumSalones());
		}
		if (ab6321s00 != null && ab6321s00.getNumSalonesComedor() != null) {
			where.append(" AND t1.NUM_SALONES_COMEDOR = ?");
			params.add(ab6321s00.getNumSalonesComedor());
		}
		if (ab6321s00 != null && ab6321s00.getNumComedores() != null) {
			where.append(" AND t1.NUM_COMEDORES = ?");
			params.add(ab6321s00.getNumComedores());
		}
		if (ab6321s00 != null && ab6321s00.getNumBanosGenerales() != null) {
			where.append(" AND t1.NUM_BAOS_GENERALES = ?");
			params.add(ab6321s00.getNumBanosGenerales());
		}
		if (ab6321s00 != null && ab6321s00.getNumConjuntos() != null) {
			where.append(" AND t1.NUM_CONJUNTOS = ?");
			params.add(ab6321s00.getNumConjuntos());
		}
		if (ab6321s00 != null && ab6321s00.getNumEstudios() != null) {
			where.append(" AND t1.NUM_ESTUDIOS = ?");
			params.add(ab6321s00.getNumEstudios());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabDoble() != null) {
			where.append(" AND t1.NUM_HAB_DOBLE = ?");
			params.add(ab6321s00.getNumHabDoble());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabIndividuales() != null) {
			where.append(" AND t1.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6321s00.getNumHabIndividuales());
		}
		if (ab6321s00 != null && ab6321s00.getNumMaximoSupletorias() != null) {
			where.append(" AND t1.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6321s00.getNumMaximoSupletorias());
		}
		if (ab6321s00 != null && ab6321s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6321s00.getNumPlazas());
		}
		if (ab6321s00 != null && ab6321s00.getEdificioCatalogado() != null) {
			where.append(" AND t1.EDIFICIO_CATALOGADO = ?");
			params.add(ab6321s00.getEdificioCatalogado());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabMas4() != null) {
			where.append(" AND t1.NUM_HAB_MAS_4 = ?");
			params.add(ab6321s00.getNumHabMas4());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabMenos4() != null) {
			where.append(" AND t1.NUM_HAB_MENOS_4 = ?");
			params.add(ab6321s00.getNumHabMenos4());
		}
		if (ab6321s00 != null && ab6321s00.getComparteViviendas() != null) {
			where.append(" AND t1.COMPARTE_VIVIENDAS = ?");
			params.add(ab6321s00.getComparteViviendas());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabDobleCs() != null) {
			where.append(" AND t1.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6321s00.getNumHabDobleCs());
		}
		if (ab6321s00 != null && ab6321s00.getNumApartamentos() != null) {
			where.append(" AND t1.NUM_APARTAMENTOS = ?");
			params.add(ab6321s00.getNumApartamentos());
		}
		if (ab6321s00 != null && ab6321s00.getNumSuites() != null) {
			where.append(" AND t1.NUM_SUITES = ?");
			params.add(ab6321s00.getNumSuites());
		}
		if (ab6321s00 != null && ab6321s00.getComparteInstal() != null) {
			where.append(" AND t1.COMPARTE_INSTAL = ?");
			params.add(ab6321s00.getComparteInstal());
		}
		if (ab6321s00 != null && ab6321s00.getNumInstalComparte() != null) {
			where.append(" AND t1.NUM_INSTAL_COMPARTE = ?");
			params.add(ab6321s00.getNumInstalComparte());
		}
		if (ab6321s00 != null && ab6321s00.getNumSupAcampada() != null) {
			where.append(" AND t1.NUM_SUP_ACAMPADA = ?");
			params.add(ab6321s00.getNumSupAcampada());
		}
		if (ab6321s00 != null && ab6321s00.getBar() != null) {
			where.append(" AND t1.BAR = ?");
			params.add(ab6321s00.getBar());
		}
		if (ab6321s00 != null && ab6321s00.getRestaurante() != null) {
			where.append(" AND t1.RESTAURANTE = ?");
			params.add(ab6321s00.getRestaurante());
		}
		if (ab6321s00 != null && ab6321s00.getPiscina() != null) {
			where.append(" AND t1.PISCINA = ?");
			params.add(ab6321s00.getPiscina());
		}
		if (ab6321s00 != null && ab6321s00.getNumTotParcelas() != null) {
			where.append(" AND t1.NUM_TOT_PARCELAS = ?");
			params.add(ab6321s00.getNumTotParcelas());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasAnf() != null) {
			where.append(" AND t1.NUM_PARCELAS_ANF = ?");
			params.add(ab6321s00.getNumParcelasAnf());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasAf() != null) {
			where.append(" AND t1.NUM_PARCELAS_AF = ?");
			params.add(ab6321s00.getNumParcelasAf());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasSa() != null) {
			where.append(" AND t1.NUM_PARCELAS_SA = ?");
			params.add(ab6321s00.getNumParcelasSa());
		}
		if (ab6321s00 != null && ab6321s00.getIndicadorIa() != null) {
			where.append(" AND t1.INDICADOR_IA = ?");
			params.add(ab6321s00.getIndicadorIa());
		}
		if (ab6321s00 != null && ab6321s00.getFechaControlIa() != null) {
			where.append(" AND t1.FECHA_CONTROL_IA = ?");
			params.add(ab6321s00.getFechaControlIa());
		}
		if (ab6321s00 != null && ab6321s00.getRequisitos() != null) {
			where.append(" AND t1.REQUISITOS = ?");
			params.add(ab6321s00.getRequisitos());
		}
		if (ab6321s00 != null && ab6321s00.getNumControl() != null) {
			where.append(" AND t1.NUM_CONTROL = ?");
			params.add(ab6321s00.getNumControl());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAntControl() != null) {
			where.append(" AND t1.FECHA_ANT_CONTROL = ?");
			params.add(ab6321s00.getFechaAntControl());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabitaciones() != null) {
			where.append(" AND t1.NUM_HABITACIONES = ?");
			params.add(ab6321s00.getNumHabitaciones());
		}
		if (ab6321s00 != null && ab6321s00.getNumResidentesPerm() != null) {
			where.append(" AND t1.NUM_RESIDENTES_PERM = ?");
			params.add(ab6321s00.getNumResidentesPerm());
		}
		if (ab6321s00 != null && ab6321s00.getSupTotHabitac() != null) {
			where.append(" AND t1.SUP_TOT_HABITAC = ?");
			params.add(ab6321s00.getSupTotHabitac());
		}
		if (ab6321s00 != null && ab6321s00.getSupRestoDepen() != null) {
			where.append(" AND t1.SUP_RESTO_DEPEN = ?");
			params.add(ab6321s00.getSupRestoDepen());
		}
		if (ab6321s00 != null && ab6321s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6321s00.getFechaRegistro());
		}
		if (ab6321s00 != null && ab6321s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6321s00.getUsuarioRegistro());
		}
		if (ab6321s00 != null && ab6321s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6321s00.getFechaUltmodificacion());
		}
		if (ab6321s00 != null && ab6321s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6321s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6321s00 entity
	 *
	 * @param ab6321s00
	 *            Ab6321s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(EstablecimientoData ab6321s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(EstablecimientoDataDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6321s00 != null && ab6321s00.getIdEstablecimiento() != null) {
			where.append(" AND t1.ID_ESTABLECIMIENTO = ?");
			params.add(ab6321s00.getIdEstablecimiento());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAnoConstruccion() != null) {
			where.append(" AND t1.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6321s00.getFechaAnoConstruccion());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAnoRenovacion() != null) {
			where.append(" AND t1.FECHA_ANO_RENOVACION = ?");
			params.add(ab6321s00.getFechaAnoRenovacion());
		}
		if (ab6321s00 != null && ab6321s00.getDerechoCocina() != null) {
			where.append(" AND t1.DERECHO_COCINA = ?");
			params.add(ab6321s00.getDerechoCocina());
		}
		if (ab6321s00 != null && ab6321s00.getServicioComedor() != null) {
			where.append(" AND t1.SERVICIO_COMEDOR = ?");
			params.add(ab6321s00.getServicioComedor());
		}
		if (ab6321s00 != null && ab6321s00.getNumSalones() != null) {
			where.append(" AND t1.NUM_SALONES = ?");
			params.add(ab6321s00.getNumSalones());
		}
		if (ab6321s00 != null && ab6321s00.getNumSalonesComedor() != null) {
			where.append(" AND t1.NUM_SALONES_COMEDOR = ?");
			params.add(ab6321s00.getNumSalonesComedor());
		}
		if (ab6321s00 != null && ab6321s00.getNumComedores() != null) {
			where.append(" AND t1.NUM_COMEDORES = ?");
			params.add(ab6321s00.getNumComedores());
		}
		if (ab6321s00 != null && ab6321s00.getNumBanosGenerales() != null) {
			where.append(" AND t1.NUM_BAOS_GENERALES = ?");
			params.add(ab6321s00.getNumBanosGenerales());
		}
		if (ab6321s00 != null && ab6321s00.getNumConjuntos() != null) {
			where.append(" AND t1.NUM_CONJUNTOS = ?");
			params.add(ab6321s00.getNumConjuntos());
		}
		if (ab6321s00 != null && ab6321s00.getNumEstudios() != null) {
			where.append(" AND t1.NUM_ESTUDIOS = ?");
			params.add(ab6321s00.getNumEstudios());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabDoble() != null) {
			where.append(" AND t1.NUM_HAB_DOBLE = ?");
			params.add(ab6321s00.getNumHabDoble());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabIndividuales() != null) {
			where.append(" AND t1.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6321s00.getNumHabIndividuales());
		}
		if (ab6321s00 != null && ab6321s00.getNumMaximoSupletorias() != null) {
			where.append(" AND t1.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6321s00.getNumMaximoSupletorias());
		}
		if (ab6321s00 != null && ab6321s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6321s00.getNumPlazas());
		}
		if (ab6321s00 != null && ab6321s00.getEdificioCatalogado() != null) {
			where.append(" AND t1.EDIFICIO_CATALOGADO = ?");
			params.add(ab6321s00.getEdificioCatalogado());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabMas4() != null) {
			where.append(" AND t1.NUM_HAB_MAS_4 = ?");
			params.add(ab6321s00.getNumHabMas4());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabMenos4() != null) {
			where.append(" AND t1.NUM_HAB_MENOS_4 = ?");
			params.add(ab6321s00.getNumHabMenos4());
		}
		if (ab6321s00 != null && ab6321s00.getComparteViviendas() != null) {
			where.append(" AND t1.COMPARTE_VIVIENDAS = ?");
			params.add(ab6321s00.getComparteViviendas());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabDobleCs() != null) {
			where.append(" AND t1.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6321s00.getNumHabDobleCs());
		}
		if (ab6321s00 != null && ab6321s00.getNumApartamentos() != null) {
			where.append(" AND t1.NUM_APARTAMENTOS = ?");
			params.add(ab6321s00.getNumApartamentos());
		}
		if (ab6321s00 != null && ab6321s00.getNumSuites() != null) {
			where.append(" AND t1.NUM_SUITES = ?");
			params.add(ab6321s00.getNumSuites());
		}
		if (ab6321s00 != null && ab6321s00.getComparteInstal() != null) {
			where.append(" AND t1.COMPARTE_INSTAL = ?");
			params.add(ab6321s00.getComparteInstal());
		}
		if (ab6321s00 != null && ab6321s00.getNumInstalComparte() != null) {
			where.append(" AND UPPER(t1.NUM_INSTAL_COMPARTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getNumInstalComparte().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getNumInstalComparte().toUpperCase() + "%");
			}
			where.append(" AND t1.NUM_INSTAL_COMPARTE IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getNumSupAcampada() != null) {
			where.append(" AND t1.NUM_SUP_ACAMPADA = ?");
			params.add(ab6321s00.getNumSupAcampada());
		}
		if (ab6321s00 != null && ab6321s00.getBar() != null) {
			where.append(" AND t1.BAR = ?");
			params.add(ab6321s00.getBar());
		}
		if (ab6321s00 != null && ab6321s00.getRestaurante() != null) {
			where.append(" AND t1.RESTAURANTE = ?");
			params.add(ab6321s00.getRestaurante());
		}
		if (ab6321s00 != null && ab6321s00.getPiscina() != null) {
			where.append(" AND t1.PISCINA = ?");
			params.add(ab6321s00.getPiscina());
		}
		if (ab6321s00 != null && ab6321s00.getNumTotParcelas() != null) {
			where.append(" AND t1.NUM_TOT_PARCELAS = ?");
			params.add(ab6321s00.getNumTotParcelas());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasAnf() != null) {
			where.append(" AND t1.NUM_PARCELAS_ANF = ?");
			params.add(ab6321s00.getNumParcelasAnf());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasAf() != null) {
			where.append(" AND t1.NUM_PARCELAS_AF = ?");
			params.add(ab6321s00.getNumParcelasAf());
		}
		if (ab6321s00 != null && ab6321s00.getNumParcelasSa() != null) {
			where.append(" AND t1.NUM_PARCELAS_SA = ?");
			params.add(ab6321s00.getNumParcelasSa());
		}
		if (ab6321s00 != null && ab6321s00.getIndicadorIa() != null) {
			where.append(" AND t1.INDICADOR_IA = ?");
			params.add(ab6321s00.getIndicadorIa());
		}
		if (ab6321s00 != null && ab6321s00.getFechaControlIa() != null) {
			where.append(" AND t1.FECHA_CONTROL_IA = ?");
			params.add(ab6321s00.getFechaControlIa());
		}
		if (ab6321s00 != null && ab6321s00.getRequisitos() != null) {
			where.append(" AND UPPER(t1.REQUISITOS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getRequisitos().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getRequisitos().toUpperCase() + "%");
			}
			where.append(" AND t1.REQUISITOS IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getNumControl() != null) {
			where.append(" AND t1.NUM_CONTROL = ?");
			params.add(ab6321s00.getNumControl());
		}
		if (ab6321s00 != null && ab6321s00.getFechaAntControl() != null) {
			where.append(" AND t1.FECHA_ANT_CONTROL = ?");
			params.add(ab6321s00.getFechaAntControl());
		}
		if (ab6321s00 != null && ab6321s00.getNumHabitaciones() != null) {
			where.append(" AND UPPER(t1.NUM_HABITACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getNumHabitaciones().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getNumHabitaciones().toUpperCase() + "%");
			}
			where.append(" AND t1.NUM_HABITACIONES IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getNumResidentesPerm() != null) {
			where.append(" AND UPPER(t1.NUM_RESIDENTES_PERM) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getNumResidentesPerm().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getNumResidentesPerm().toUpperCase() + "%");
			}
			where.append(" AND t1.NUM_RESIDENTES_PERM IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getSupTotHabitac() != null) {
			where.append(" AND UPPER(t1.SUP_TOT_HABITAC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getSupTotHabitac().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getSupTotHabitac().toUpperCase() + "%");
			}
			where.append(" AND t1.SUP_TOT_HABITAC IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getSupRestoDepen() != null) {
			where.append(" AND t1.SUP_RESTO_DEPEN = ? ");
			params.add(ab6321s00.getSupRestoDepen());
		}
		if (ab6321s00 != null && ab6321s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6321s00.getFechaRegistro());
		}
		if (ab6321s00 != null && ab6321s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6321s00 != null && ab6321s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6321s00.getFechaUltmodificacion());
		}
		if (ab6321s00 != null && ab6321s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6321s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6321s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public EstablecimientoData updateEstDataNumApartamentos(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_APARTAMENTOS=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumApartamentos(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumEstudios(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_ESTUDIOS=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumEstudios(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumConjuntos(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_CONJUNTOS=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumConjuntos(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumSuites(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_SUITES=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumSuites(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumHabDobles(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_HAB_DOBLE=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumHabDoble(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumHabDoblesCs(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_HAB_DOBLE_CS=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumHabDobleCs(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumHabInd(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_HAB_INDIVIDUALES=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumHabIndividuales(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataNumHabMultiples(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_HAB_MAS_4=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumHabMas4(), PermisosXLNETS.getUserConnected(),
				ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}

	@Override
	public EstablecimientoData updateEstDataTotalHoteles(EstablecimientoData ab6321s00) {
		String query = "UPDATE AB6321S00 SET NUM_SALONES=?, NUM_SALONES_COMEDOR=?, NUM_COMEDORES=?, NUM_APARTAMENTOS=?, NUM_ESTUDIOS=?, NUM_CONJUNTOS=?, NUM_SUITES=?, NUM_HAB_DOBLE=?, NUM_HAB_DOBLE_CS=?, NUM_HAB_INDIVIDUALES=?, NUM_HAB_MAS_4=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6321s00.getNumSalones(), ab6321s00.getNumSalonesComedor(),
				ab6321s00.getNumComedores(), ab6321s00.getNumApartamentos(), ab6321s00.getNumEstudios(),
				ab6321s00.getNumConjuntos(), ab6321s00.getNumSuites(), ab6321s00.getNumHabDoble(),
				ab6321s00.getNumHabDobleCs(), ab6321s00.getNumHabIndividuales(), ab6321s00.getNumHabMas4(),
				PermisosXLNETS.getUserConnected(), ab6321s00.getIdEstablecimiento());
		return ab6321s00;
	}
}
