package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.FactorCompensatorio;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6319s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class FactorCompensatorioDaoImpl implements FactorCompensatorioDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDFACTORCOMP", "IDESTABLECIMIENTO",
			"DESCRIPCION", "DESCRIPCIONEU", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<FactorCompensatorio> rwMap = new RowMapper<FactorCompensatorio>() {
		public FactorCompensatorio mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FactorCompensatorio(resultSet.getInt("IDFACTORCOMP"), resultSet.getString("DESCRIPCION"),
					resultSet.getString("DESCRIPCIONEU"),
					new Establecimiento(resultSet.getInt("Ab6301s00IDESTABLECIMIENTO")),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<FactorCompensatorio> rwMapPK = new RowMapper<FactorCompensatorio>() {
		public FactorCompensatorio mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FactorCompensatorio(resultSet.getInt("IDFACTORCOMP"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<FactorCompensatorio>> rwMapJerarquia = new RowMapper<JerarquiaDto<FactorCompensatorio>>() {
		public JerarquiaDto<FactorCompensatorio> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			FactorCompensatorio ab6319s00 = new FactorCompensatorio(resultSet.getInt("IDFACTORCOMP"),
					resultSet.getString("DESCRIPCION"), resultSet.getString("DESCRIPCIONEU"),
					new Establecimiento(resultSet.getInt("Ab6301s00IDESTABLECIMIENTO")),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<FactorCompensatorio> jerarquia = new JerarquiaDto<FactorCompensatorio>();
			jerarquia.setModel(ab6319s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @return Ab6319s00
	 */
	public FactorCompensatorio add(FactorCompensatorio ab6319s00) {
		String query = "INSERT INTO AB6319S00 (ID_FACTOR_COMP, ID_ESTABLECIMIENTO, DESCRIPCION, DESCRIPCION_EU, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB6319Q00.NEXTVAL,?,?,?,SYSDATE,?)";
		Object getAb6301s00IdEstablecimientoAux = null;
		if (ab6319s00.getEstablecimiento() != null && ab6319s00.getEstablecimiento().getIdEstablecimiento() != null) {
			getAb6301s00IdEstablecimientoAux = ab6319s00.getEstablecimiento().getIdEstablecimiento();
		}

		this.jdbcTemplate.update(query, getAb6301s00IdEstablecimientoAux, ab6319s00.getDescripcion(),
				ab6319s00.getDescripcionEu(), PermisosXLNETS.getUserConnected());
		return ab6319s00;
	}

	/**
	 * Updates a single row in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @return Ab6319s00
	 */
	public FactorCompensatorio update(FactorCompensatorio ab6319s00) {
		String query = "UPDATE AB6319S00 SET ID_ESTABLECIMIENTO=?, DESCRIPCION=?, DESCRIPCION_EU=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_FACTOR_COMP=?";
		Object getAb6301s00IdEstablecimientoAux = null;
		if (ab6319s00.getEstablecimiento() != null && ab6319s00.getEstablecimiento().getIdEstablecimiento() != null) {
			getAb6301s00IdEstablecimientoAux = ab6319s00.getEstablecimiento().getIdEstablecimiento();
		}

		this.jdbcTemplate.update(query, getAb6301s00IdEstablecimientoAux, ab6319s00.getDescripcion(),
				ab6319s00.getDescripcionEu(), PermisosXLNETS.getUserConnected(), ab6319s00.getIdFactorComp());
		return ab6319s00;
	}

	/**
	 * Finds a single row in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @return Ab6319s00
	 */
	@Transactional(readOnly = true)
	public FactorCompensatorio find(FactorCompensatorio ab6319s00) {
		String query = "SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t1.DESCRIPCION_EU DESCRIPCIONEU, t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6319S00 t1 , AB6301S00 t2 WHERE t1.ID_FACTOR_COMP = ?   AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+)";

		List<FactorCompensatorio> ab6319s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6319s00.getIdFactorComp());
		return (FactorCompensatorio) DataAccessUtils.uniqueResult(ab6319s00List);
	}

	/**
	 * Removes a single row in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @return
	 */
	public void remove(FactorCompensatorio ab6319s00) {
		String query = "DELETE FROM AB6319S00 WHERE ID_FACTOR_COMP=?";
		this.jdbcTemplate.update(query, ab6319s00.getIdFactorComp());
	}

	/**
	 * Finds a list of rows in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6319s00>
	 */
	@Transactional(readOnly = true)
	public List<FactorCompensatorio> findAll(FactorCompensatorio ab6319s00, TableRequestDto tableRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t1.DESCRIPCION_EU DESCRIPCIONEU,t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6319S00 t1 ,AB6301S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6319s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query,
					FactorCompensatorioDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FactorCompensatorio>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6319s00 table using like.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6319s00>
	 */
	@Transactional(readOnly = true)
	public List<FactorCompensatorio> findAllLike(FactorCompensatorio ab6319s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t1.DESCRIPCION_EU DESCRIPCIONEU, t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6319S00 t1 ,AB6301S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6319s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query,
					FactorCompensatorioDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FactorCompensatorio>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6319s00 table.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(FactorCompensatorio ab6319s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6319S00 t1 , AB6301S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6319s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6319s00 table using like.
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(FactorCompensatorio ab6319s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6319S00 t1 ,AB6301S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6319s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6319s00 selected for rup_table
	 *
	 * @param ab6319s00
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6319s00>>
	 */

	public List<TableRowDto<FactorCompensatorio>> reorderSelection(FactorCompensatorio ab6319s00,
			TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6319S00 t1 ,AB6301S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6319s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, tableRequestDto,
				FactorCompensatorio.class, filterParamList, "ID_FACTOR_COMP");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FactorCompensatorio>(this.rwMapPK, tableRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6319s00
	 * @param searchParams
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6319s00>>
	 */
	public List<TableRowDto<FactorCompensatorio>> search(FactorCompensatorio filterParams,
			FactorCompensatorio searchParams, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6319S00 t1 ,AB6301S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, tableRequestDto,
				FactorCompensatorio.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_FACTOR_COMP");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FactorCompensatorio>(this.rwMapPK, tableRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6319s00
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(FactorCompensatorio filterab6319s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FACTOR_COMP IDFACTORCOMP, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6301S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6319S00 t1 ,AB6301S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6319s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(tableRequestDto,
				FactorCompensatorio.class, query, params, "ID_FACTOR_COMP");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6319s00
	 *            Ab6319s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6319s00>>
	 */
	public List<TableRowDto<FactorCompensatorio>> findAllChild(FactorCompensatorio filterAb6319s00,
			TableRequestDto tableRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6319S00 t1 ,AB6301S00
		// t2 ,AB6316S00 t3 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6319S00");
		from.add("AB6301S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6319s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "ID_FACTOR_COMP",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<FactorCompensatorio>(this.rwMapPK, "ID_FACTOR_COMP"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6319s00 entity
	 *
	 * @param ab6319s00
	 *            Ab6319s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(FactorCompensatorio ab6319s00) {

		StringBuilder where = new StringBuilder(FactorCompensatorioDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6319s00 != null && ab6319s00.getIdFactorComp() != null) {
			where.append(" AND t1.ID_FACTOR_COMP = ?");
			params.add(ab6319s00.getIdFactorComp());
		}
		if (ab6319s00 != null && ab6319s00.getEstablecimiento() != null
				&& ab6319s00.getEstablecimiento().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6319s00.getEstablecimiento().getIdEstablecimiento());
		}
		if (ab6319s00 != null && ab6319s00.getDescripcion() != null) {
			where.append(" AND t3.DESCRIPCION = ?");
			params.add(ab6319s00.getDescripcion());
		}
		if (ab6319s00 != null && ab6319s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6319s00.getFechaRegistro());
		}
		if (ab6319s00 != null && ab6319s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6319s00.getUsuarioRegistro());
		}
		if (ab6319s00 != null && ab6319s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6319s00.getFechaUltmodificacion());
		}
		if (ab6319s00 != null && ab6319s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6319s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6319s00 entity
	 *
	 * @param ab6319s00
	 *            Ab6319s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(FactorCompensatorio ab6319s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(FactorCompensatorioDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6319s00 != null && ab6319s00.getIdFactorComp() != null) {
			where.append(" AND t1.ID_FACTOR_COMP = ?");
			params.add(ab6319s00.getIdFactorComp());
		}
		if (ab6319s00 != null && ab6319s00.getEstablecimiento() != null
				&& ab6319s00.getEstablecimiento().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6319s00.getEstablecimiento().getIdEstablecimiento());
		}
		if (ab6319s00 != null && ab6319s00.getDescripcion() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6319s00.getDescripcion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6319s00.getDescripcion().toUpperCase() + "%");
			}
			where.append(" AND t3.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6319s00 != null && ab6319s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6319s00.getFechaRegistro());
		}
		if (ab6319s00 != null && ab6319s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6319s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6319s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6319s00 != null && ab6319s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6319s00.getFechaUltmodificacion());
		}
		if (ab6319s00 != null && ab6319s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6319s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6319s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
