package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.AgenciaData;
import com.ejie.ab63.model.FianzaEstablecimiento;
import com.ejie.ab63.model.TipoFranquicia;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6337s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class FianzaEstablecimientoDaoImpl implements FianzaEstablecimientoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDFIANZASESTAB", "NUMIMPORTEFIANZA",
			"REGISTROFIANZA", "FECHAFIANZA", "IDTIPOFIANZA", "ASOCIACIONFIANZA", "ADMONFIANZA", "OBSERVFIANZA",
			"FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION",
			"AB6335S00IDESTABLECIMIENTO", "AB6335S00FRANQUICIA", "AB6336S00IDFRANQUICIA", "AB6336S00DESCFRANQUICIAES",
			"AB6336S00DESCFRANQUICIAEU", "AB6336S00BAJA", "AB6335S00INDONLINE", "AB6335S00IDINSTALOFIPRINCIPAL",
			"AB6335S00IDORIGENOFIPRINCIPAL", "AB6335S00IDTIPOCIE", "AB6335S00ETIQUETACIE", "AB6335S00REGISTROFIANZA",
			"AB6335S00OBSERVFIANZA", "AB6335S00OBSERVSRC", "AB6335S00IDPRIMERASUCURSAL", "AB6335S00NUMCIE",
			"AB6335S00FECHAREGISTRO", "AB6335S00USUARIOREGISTRO", "AB6335S00FECHAULTMODIFICACION",
			"AB6335S00USUARIOULTMODIF" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<FianzaEstablecimiento> rwMap = new RowMapper<FianzaEstablecimiento>() {
		public FianzaEstablecimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FianzaEstablecimiento(resultSet.getInt("IDFIANZASESTAB"),
					resultSet.getBigDecimal("NUMIMPORTEFIANZA"), resultSet.getString("REGISTROFIANZA"),
					resultSet.getDate("FECHAFIANZA"), resultSet.getString("IDTIPOFIANZA"),
					resultSet.getString("ASOCIACIONFIANZA"), resultSet.getString("ADMONFIANZA"),
					resultSet.getString("OBSERVFIANZA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new AgenciaData(resultSet.getInt("Ab6335s00IDESTABLECIMIENTO"),
							resultSet.getInt("Ab6335s00FRANQUICIA"),
							new TipoFranquicia(resultSet.getLong("AB6336S00IDFRANQUICIA"),
									resultSet.getString("AB6336S00DESCFRANQUICIAES"),
									resultSet.getString("AB6336S00DESCFRANQUICIAEU"), resultSet.getInt("AB6336S00BAJA"),
									null, null, null, null),
							resultSet.getInt("Ab6335s00INDONLINE"),
							resultSet.getString("Ab6335s00IDINSTALOFIPRINCIPAL"),
							resultSet.getString("Ab6335s00IDORIGENOFIPRINCIPAL"),
							resultSet.getString("Ab6335s00IDTIPOCIE"), resultSet.getString("Ab6335s00ETIQUETACIE"),
							resultSet.getString("Ab6335s00REGISTROFIANZA"),
							resultSet.getString("Ab6335s00OBSERVFIANZA"), resultSet.getString("Ab6335s00OBSERVSRC"),
							resultSet.getString("Ab6335s00IDPRIMERASUCURSAL"), resultSet.getString("Ab6335s00NUMCIE"),
							resultSet.getDate("Ab6335s00FECHAREGISTRO"),
							resultSet.getString("Ab6335s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6335s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6335S00USUARIOULTMODIF")));
		}
	};

	private RowMapper<FianzaEstablecimiento> rwMapPK = new RowMapper<FianzaEstablecimiento>() {
		public FianzaEstablecimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new FianzaEstablecimiento(resultSet.getInt("IDFIANZASESTAB"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<FianzaEstablecimiento>> rwMapJerarquia = new RowMapper<JerarquiaDto<FianzaEstablecimiento>>() {
		public JerarquiaDto<FianzaEstablecimiento> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			FianzaEstablecimiento ab6337s00 = new FianzaEstablecimiento(resultSet.getInt("IDFIANZASESTAB"),
					resultSet.getBigDecimal("NUMIMPORTEFIANZA"), resultSet.getString("REGISTROFIANZA"),
					resultSet.getDate("FECHAFIANZA"), resultSet.getString("IDTIPOFIANZA"),
					resultSet.getString("ASOCIACIONFIANZA"), resultSet.getString("ADMONFIANZA"),
					resultSet.getString("OBSERVFIANZA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new AgenciaData(resultSet.getInt("Ab6335s00IDESTABLECIMIENTO"),
							resultSet.getInt("Ab6335s00FRANQUICIA"),
							new TipoFranquicia(resultSet.getLong("AB6336S00IDFRANQUICIA"),
									resultSet.getString("AB6336S00DESCFRANQUICIAES"),
									resultSet.getString("AB6336S00DESCFRANQUICIAEU"), resultSet.getInt("AB6336S00BAJA"),
									null, null, null, null),
							resultSet.getInt("Ab6335s00INDONLINE"),
							resultSet.getString("Ab6335s00IDINSTALOFIPRINCIPAL"),
							resultSet.getString("Ab6335s00IDORIGENOFIPRINCIPAL"),
							resultSet.getString("Ab6335s00IDTIPOCIE"), resultSet.getString("Ab6335s00ETIQUETACIE"),
							resultSet.getString("Ab6335s00REGISTROFIANZA"),
							resultSet.getString("Ab6335s00OBSERVFIANZA"), resultSet.getString("Ab6335s00OBSERVSRC"),
							resultSet.getString("Ab6335s00IDPRIMERASUCURSAL"), resultSet.getString("Ab6335s00NUMCIE"),
							resultSet.getDate("Ab6335s00FECHAREGISTRO"),
							resultSet.getString("Ab6335s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6335s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6335S00USUARIOULTMODIF")));

			JerarquiaDto<FianzaEstablecimiento> jerarquia = new JerarquiaDto<FianzaEstablecimiento>();
			jerarquia.setModel(ab6337s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @return Ab6337s00
	 */
	public FianzaEstablecimiento add(FianzaEstablecimiento ab6337s00) {
		String query = "INSERT INTO AB6337S00 (ID_FIANZAS_ESTAB, ID_ESTABLECIMIENTO, NUM_IMPORTE_FIANZA, REGISTRO_FIANZA, FECHA_FIANZA, ID_TIPO_FIANZA, ASOCIACION_FIANZA, ADMON_FIANZA, OBSERV_FIANZA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB6337Q00.NEXTVAL,?,?,?,?,?,?,?,?,SYSDATE,?)";
		Object getAb6335s00IdEstablecimientoAux = null;
		if (ab6337s00.getFranquicia() != null && ab6337s00.getFranquicia().getIdEstablecimiento() != null) {
			getAb6335s00IdEstablecimientoAux = ab6337s00.getFranquicia().getIdEstablecimiento();
		}
		this.jdbcTemplate.update(query, getAb6335s00IdEstablecimientoAux, ab6337s00.getNumImporteFianza(),
				ab6337s00.getRegistroFianza(), ab6337s00.getFechaFianza(), ab6337s00.getIdTipoFianza(),
				ab6337s00.getAsociacionFianza(), ab6337s00.getAdmonFianza(), ab6337s00.getObservFianza(),
				PermisosXLNETS.getUserConnected());
		return ab6337s00;
	}

	/**
	 * Updates a single row in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @return Ab6337s00
	 */
	public FianzaEstablecimiento update(FianzaEstablecimiento ab6337s00) {
		String query = "UPDATE AB6337S00 SET ID_ESTABLECIMIENTO=?, NUM_IMPORTE_FIANZA=?, REGISTRO_FIANZA=?, FECHA_FIANZA=?, ID_TIPO_FIANZA=?, ASOCIACION_FIANZA=?, ADMON_FIANZA=?, OBSERV_FIANZA=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_FIANZAS_ESTAB=?";
		Object getAb6335s00IdEstablecimientoAux = null;
		if (ab6337s00.getFranquicia() != null && ab6337s00.getFranquicia().getIdEstablecimiento() != null) {
			getAb6335s00IdEstablecimientoAux = ab6337s00.getFranquicia().getIdEstablecimiento();
		}
		// ab6337s00.setNumImporteFianza(new
		// BigDecimal(ab6337s00.getNumImporteFianza().toString().replace(",",
		// ".")));

		this.jdbcTemplate.update(query, getAb6335s00IdEstablecimientoAux, ab6337s00.getNumImporteFianza(),
				ab6337s00.getRegistroFianza(), ab6337s00.getFechaFianza(), ab6337s00.getIdTipoFianza(),
				ab6337s00.getAsociacionFianza(), ab6337s00.getAdmonFianza(), ab6337s00.getObservFianza(),
				PermisosXLNETS.getUserConnected(), ab6337s00.getIdFianzasEstab());
		return ab6337s00;
	}

	/**
	 * Finds a single row in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @return Ab6337s00
	 */
	@Transactional(readOnly = true)
	public FianzaEstablecimiento find(FianzaEstablecimiento ab6337s00) {
		String query = "SELECT t1.ID_FIANZAS_ESTAB IDFIANZASESTAB, t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA, t1.REGISTRO_FIANZA REGISTROFIANZA, t1.FECHA_FIANZA FECHAFIANZA, t1.ID_TIPO_FIANZA IDTIPOFIANZA, t1.ASOCIACION_FIANZA ASOCIACIONFIANZA, t1.ADMON_FIANZA ADMONFIANZA, t1.OBSERV_FIANZA OBSERVFIANZA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO, t2.FRANQUICIA AB6335S00FRANQUICIA, t3.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t3.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t3.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t3.BAJA AB6336S00BAJA, t2.INDONLINE AB6335S00INDONLINE, t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL, t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL, t2.ID_TIPO_CIE AB6335S00IDTIPOCIE, t2.ETIQUETA_CIE AB6335S00ETIQUETACIE, t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA, t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA, t2.OBSERV_SRC AB6335S00OBSERVSRC, t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL, t2.NUM_CIE AB6335S00NUMCIE, t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF FROM AB6337S00 t1 , AB6335S00 t2, AB6336S00 t3  WHERE t1.ID_FIANZAS_ESTAB = ?  AND t2.ID_FRANQUICIA = t3.ID_FRANQUICIA(+) AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+)";

		List<FianzaEstablecimiento> ab6337s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6337s00.getIdFianzasEstab());
		return (FianzaEstablecimiento) DataAccessUtils.uniqueResult(ab6337s00List);
	}

	/**
	 * Removes a single row in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @return
	 */
	public void remove(FianzaEstablecimiento ab6337s00) {
		String query = "DELETE FROM AB6337S00 WHERE ID_FIANZAS_ESTAB=?";
		this.jdbcTemplate.update(query, ab6337s00.getIdFianzasEstab());
	}

	/**
	 * Finds a list of rows in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @return List<Ab6337s00>
	 */
	@Transactional(readOnly = true)
	public List<FianzaEstablecimiento> findAll(FianzaEstablecimiento ab6337s00, TableRequestDto TableRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t3.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t3.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t3.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t3.BAJA AB6336S00BAJA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		query.append("FROM AB6337S00 t1 ,AB6335S00 t2 ,AB6336S00 t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6337s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t2.ID_FRANQUICIA = t3.ID_FRANQUICIA AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (TableRequestDto != null) {
			query = TableManager.getPaginationQuery(TableRequestDto, query,
					FianzaEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FianzaEstablecimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6337s00 table using like.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6337s00>
	 */
	@Transactional(readOnly = true)
	public List<FianzaEstablecimiento> findAllLike(FianzaEstablecimiento ab6337s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t3.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t3.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t3.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t3.BAJA AB6336S00BAJA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		query.append("FROM AB6337S00 t1 ,AB6335S00 t2, AB6336S00 t3, AB6301S00 t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6337s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t2.ID_FRANQUICIA = t3.ID_FRANQUICIA(+) AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) AND t1.ID_ESTABLECIMIENTO = t4.ID_ESTABLECIMIENTO AND t4.ID_MODALIDAD = 'P' ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query,
					FianzaEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<FianzaEstablecimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6337s00 table.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(FianzaEstablecimiento ab6337s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6337S00 t1 , AB6335S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6337s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6337s00 table using like.
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(FianzaEstablecimiento ab6337s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6337S00 t1 ,AB6335S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6337s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6337s00 selected for rup_table
	 *
	 * @param ab6337s00
	 *            Ab6337s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6337s00>>
	 */
	@Override
	public List<TableRowDto<FianzaEstablecimiento>> reorderSelection(FianzaEstablecimiento ab6337s00,
			TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t2.ID_FRANQUICIA AB6335S00IDFRANQUICIA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		// FROM
		query.append("FROM AB6337S00 t1 ,AB6335S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6337s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, tableRequestDto,
				FianzaEstablecimiento.class, filterParamList, "IDFIANZASESTAB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FianzaEstablecimiento>(this.rwMapPK, tableRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6337s00
	 * @param searchParams
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6337s00>>
	 */
	@Override
	public List<TableRowDto<FianzaEstablecimiento>> search(FianzaEstablecimiento filterParams,
			FianzaEstablecimiento searchParams, TableRequestDto TableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t2.ID_FRANQUICIA AB6335S00IDFRANQUICIA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		// FROM
		query.append("FROM AB6337S00 t1 ,AB6335S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, TableRequestDto,
				FianzaEstablecimiento.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_FIANZAS_ESTAB");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<FianzaEstablecimiento>(this.rwMapPK, TableRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6337s00
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(FianzaEstablecimiento filterab6337s00, TableRequestDto TableRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t2.ID_FRANQUICIA AB6335S00IDFRANQUICIA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		// FROM
		query.append("FROM AB6337S00 t1 ,AB6335S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6337s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(TableRequestDto,
				FianzaEstablecimiento.class, query, params, "ID_FIANZAS_ESTAB");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6337s00 table.
	 *
	 * @param filterAb6337s00
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @return List<JerarquiaDto<Ab6337s00>>
	 */
	@Override
	public List<JerarquiaDto<FianzaEstablecimiento>> findAllLikeJerarquia(FianzaEstablecimiento filterAb6337s00,
			TableRequestDto TableRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t2.ID_FRANQUICIA AB6335S00IDFRANQUICIA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6337S00 t1 ,AB6335S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6337S00");
		from.add("AB6335S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6337s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = TableManagerJerarquia.getQuery(TableRequestDto, query, mapaWhere, "ID_FIANZAS_ESTAB", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(TableRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (TableRequestDto != null) {
			query = TableManagerJerarquia.getPaginationQuery(TableRequestDto, query,
					FianzaEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6337s00
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(FianzaEstablecimiento filterAb6337s00, TableRequestDto TableRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6337S00 t1 ,AB6335S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6337S00");
		from.add("AB6335S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6337s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryCount(TableRequestDto, mapaWhere, "ID_FIANZAS_ESTAB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(TableRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6337s00
	 *            Ab6337s00
	 * @param TableRequestDto
	 *            TableRequestDto
	 * @return List<TableRowDto<Ab6337s00>>
	 */
	@Override
	public List<TableRowDto<FianzaEstablecimiento>> findAllChild(FianzaEstablecimiento filterAb6337s00,
			TableRequestDto TableRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6337S00 t1 ,AB6335S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6337S00");
		from.add("AB6335S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6337s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(TableRequestDto, mapaWhere, "ID_FIANZAS_ESTAB",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(TableRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<FianzaEstablecimiento>(this.rwMapPK, "ID_FIANZAS_ESTAB"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6337s00 entity
	 *
	 * @param ab6337s00
	 *            Ab6337s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(FianzaEstablecimiento ab6337s00) {

		StringBuilder where = new StringBuilder(FianzaEstablecimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6337s00 != null && ab6337s00.getIdFianzasEstab() != null) {
			where.append(" AND t1.ID_FIANZAS_ESTAB = ?");
			params.add(ab6337s00.getIdFianzasEstab());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6337s00.getFranquicia().getIdEstablecimiento());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFranquicia() != null) {
			where.append(" AND t2.FRANQUICIA = ?");
			params.add(ab6337s00.getFranquicia().getFranquicia());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getTipoFranquicia() != null
				&& ab6337s00.getFranquicia().getTipoFranquicia().getIdFranquicia() != null) {
			where.append(" AND t3.ID_FRANQUICIA = ?");
			params.add(ab6337s00.getFranquicia().getTipoFranquicia().getIdFranquicia());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIndonline() != null) {
			where.append(" AND t2.INDONLINE = ?");
			params.add(ab6337s00.getFranquicia().getIndonline());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdInstalOfiPrincipal() != null) {
			where.append(" AND t2.ID_INSTAL_OFI_PRINCIPAL = ?");
			params.add(ab6337s00.getFranquicia().getIdInstalOfiPrincipal());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdOrigenOfiPrincipal() != null) {
			where.append(" AND t2.ID_ORIGEN_OFI_PRINCIPAL = ?");
			params.add(ab6337s00.getFranquicia().getIdOrigenOfiPrincipal());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdTipoCie() != null) {
			where.append(" AND t2.ID_TIPO_CIE = ?");
			params.add(ab6337s00.getFranquicia().getIdTipoCie());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getEtiquetaCie() != null) {
			where.append(" AND t2.ETIQUETA_CIE = ?");
			params.add(ab6337s00.getFranquicia().getEtiquetaCie());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getRegistroFianza() != null) {
			where.append(" AND t2.REGISTRO_FIANZA = ?");
			params.add(ab6337s00.getFranquicia().getRegistroFianza());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getObservFianza() != null) {
			where.append(" AND t2.OBSERV_FIANZA = ?");
			params.add(ab6337s00.getFranquicia().getObservFianza());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getObservSrc() != null) {
			where.append(" AND t2.OBSERV_SRC = ?");
			params.add(ab6337s00.getFranquicia().getObservSrc());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdPrimeraSucursal() != null) {
			where.append(" AND t2.ID_PRIMERA_SUCURSAL = ?");
			params.add(ab6337s00.getFranquicia().getIdPrimeraSucursal());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null && ab6337s00.getFranquicia().getNumCie() != null) {
			where.append(" AND t2.NUM_CIE = ?");
			params.add(ab6337s00.getFranquicia().getNumCie());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6337s00.getFranquicia().getFechaRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6337s00.getFranquicia().getUsuarioRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6337s00.getFranquicia().getFechaUltmodificacion());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6337s00.getFranquicia().getUsuarioUltmodificacion());
		}
		if (ab6337s00 != null && ab6337s00.getNumImporteFianza() != null) {
			where.append(" AND t1.NUM_IMPORTE_FIANZA = ?");
			params.add(ab6337s00.getNumImporteFianza());
		}
		if (ab6337s00 != null && ab6337s00.getRegistroFianza() != null) {
			where.append(" AND t1.REGISTRO_FIANZA = ?");
			params.add(ab6337s00.getRegistroFianza());
		}
		if (ab6337s00 != null && ab6337s00.getFechaFianza() != null) {
			where.append(" AND t1.FECHA_FIANZA = ?");
			params.add(ab6337s00.getFechaFianza());
		}
		if (ab6337s00 != null && ab6337s00.getIdTipoFianza() != null) {
			where.append(" AND t1.ID_TIPO_FIANZA = ?");
			params.add(ab6337s00.getIdTipoFianza());
		}
		if (ab6337s00 != null && ab6337s00.getAsociacionFianza() != null) {
			where.append(" AND t1.ASOCIACION_FIANZA = ?");
			params.add(ab6337s00.getAsociacionFianza());
		}
		if (ab6337s00 != null && ab6337s00.getAdmonFianza() != null) {
			where.append(" AND t1.ADMON_FIANZA = ?");
			params.add(ab6337s00.getAdmonFianza());
		}
		if (ab6337s00 != null && ab6337s00.getObservFianza() != null) {
			where.append(" AND t1.OBSERV_FIANZA = ?");
			params.add(ab6337s00.getObservFianza());
		}
		if (ab6337s00 != null && ab6337s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6337s00.getFechaRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6337s00.getUsuarioRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6337s00.getFechaUltmodificacion());
		}
		if (ab6337s00 != null && ab6337s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6337s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6337s00 entity
	 *
	 * @param ab6337s00
	 *            Ab6337s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(FianzaEstablecimiento ab6337s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(FianzaEstablecimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6337s00 != null && ab6337s00.getIdFianzasEstab() != null) {
			where.append(" AND t1.ID_FIANZAS_ESTAB = ?");
			params.add(ab6337s00.getIdFianzasEstab());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6337s00.getFranquicia().getIdEstablecimiento());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFranquicia() != null) {
			where.append(" AND t2.FRANQUICIA = ?");
			params.add(ab6337s00.getFranquicia().getFranquicia());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getTipoFranquicia() != null
				&& ab6337s00.getFranquicia().getTipoFranquicia().getIdFranquicia() != null) {
			where.append(" AND t3.ID_FRANQUICIA = ?");
			params.add(ab6337s00.getFranquicia().getTipoFranquicia().getIdFranquicia());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIndonline() != null) {
			where.append(" AND t2.INDONLINE = ?");
			params.add(ab6337s00.getFranquicia().getIndonline());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdInstalOfiPrincipal() != null) {
			where.append(" AND UPPER(t2.ID_INSTAL_OFI_PRINCIPAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getIdInstalOfiPrincipal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getIdInstalOfiPrincipal().toUpperCase() + "%");
			}
			where.append(" AND t2.ID_INSTAL_OFI_PRINCIPAL IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdOrigenOfiPrincipal() != null) {
			where.append(" AND UPPER(t2.ID_ORIGEN_OFI_PRINCIPAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getIdOrigenOfiPrincipal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getIdOrigenOfiPrincipal().toUpperCase() + "%");
			}
			where.append(" AND t2.ID_ORIGEN_OFI_PRINCIPAL IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdTipoCie() != null) {
			where.append(" AND UPPER(t2.ID_TIPO_CIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getIdTipoCie().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getIdTipoCie().toUpperCase() + "%");
			}
			where.append(" AND t2.ID_TIPO_CIE IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getEtiquetaCie() != null) {
			where.append(" AND UPPER(t2.ETIQUETA_CIE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getEtiquetaCie().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getEtiquetaCie().toUpperCase() + "%");
			}
			where.append(" AND t2.ETIQUETA_CIE IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getRegistroFianza() != null) {
			where.append(" AND UPPER(t2.REGISTRO_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getRegistroFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getRegistroFianza().toUpperCase() + "%");
			}
			where.append(" AND t2.REGISTRO_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getObservFianza() != null) {
			where.append(" AND UPPER(t2.OBSERV_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getObservFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getObservFianza().toUpperCase() + "%");
			}
			where.append(" AND t2.OBSERV_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getObservSrc() != null) {
			where.append(" AND UPPER(t2.OBSERV_SRC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getObservSrc().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getObservSrc().toUpperCase() + "%");
			}
			where.append(" AND t2.OBSERV_SRC IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getIdPrimeraSucursal() != null) {
			where.append(" AND UPPER(t2.ID_PRIMERA_SUCURSAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getIdPrimeraSucursal().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getIdPrimeraSucursal().toUpperCase() + "%");
			}
			where.append(" AND t2.ID_PRIMERA_SUCURSAL IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null && ab6337s00.getFranquicia().getNumCie() != null) {
			where.append(" AND t2.NUM_CIE = ?");
			params.add(ab6337s00.getFranquicia().getNumCie());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6337s00.getFranquicia().getFechaRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6337s00.getFranquicia().getFechaUltmodificacion());
		}
		if (ab6337s00 != null && ab6337s00.getFranquicia() != null
				&& ab6337s00.getFranquicia().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getFranquicia().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getFranquicia().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getNumImporteFianza() != null) {
			where.append(" AND t1.NUM_IMPORTE_FIANZA = ?");
			params.add(ab6337s00.getNumImporteFianza());
		}
		if (ab6337s00 != null && ab6337s00.getRegistroFianza() != null) {
			where.append(" AND UPPER(t1.REGISTRO_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getRegistroFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getRegistroFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.REGISTRO_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFechaFianza() != null) {
			where.append(" AND t1.FECHA_FIANZA = ?");
			params.add(ab6337s00.getFechaFianza());
		}
		if (ab6337s00 != null && ab6337s00.getIdTipoFianza() != null) {
			where.append(" AND UPPER(t1.ID_TIPO_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getIdTipoFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getIdTipoFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_TIPO_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getAsociacionFianza() != null) {
			where.append(" AND UPPER(t1.ASOCIACION_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getAsociacionFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getAsociacionFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.ASOCIACION_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getAdmonFianza() != null) {
			where.append(" AND UPPER(t1.ADMON_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getAdmonFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getAdmonFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.ADMON_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getObservFianza() != null) {
			where.append(" AND UPPER(t1.OBSERV_FIANZA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getObservFianza().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getObservFianza().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERV_FIANZA IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6337s00.getFechaRegistro());
		}
		if (ab6337s00 != null && ab6337s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6337s00 != null && ab6337s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6337s00.getFechaUltmodificacion());
		}
		if (ab6337s00 != null && ab6337s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6337s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6337s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public List<FianzaEstablecimiento> getFianzasByEstablecimiento(FianzaEstablecimiento fianza) {
		/*
		 * StringBuilder query = new StringBuilder(
		 * "SELECT  t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA, t3.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t3.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t3.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t3.BAJA AB6336S00BAJA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF "
		 * ); query.append(
		 * "FROM AB6337S00 t1 ,AB6335S00 t2, AB6336S00 t3 WHERE 1=1 AND t2.ID_FRANQUICIA = t3.ID_FRANQUICIA AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) AND t2.ID_ESTABLECIMIENTO=? "
		 * );
		 * 
		 * List<Object> params = new ArrayList<Object>();
		 * params.add(fianza.getFranquicia().getIdEstablecimiento());
		 */

		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FIANZAS_ESTAB IDFIANZASESTAB,t1.NUM_IMPORTE_FIANZA NUMIMPORTEFIANZA,t1.REGISTRO_FIANZA REGISTROFIANZA,t1.FECHA_FIANZA FECHAFIANZA,t1.ID_TIPO_FIANZA IDTIPOFIANZA,t1.ASOCIACION_FIANZA ASOCIACIONFIANZA,t1.ADMON_FIANZA ADMONFIANZA,t1.OBSERV_FIANZA OBSERVFIANZA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6335S00IDESTABLECIMIENTO,t2.FRANQUICIA AB6335S00FRANQUICIA,t3.ID_FRANQUICIA AB6336S00IDFRANQUICIA, t3.DESC_FRANQUICIA_ES AB6336S00DESCFRANQUICIAES,t3.DESC_FRANQUICIA_EU AB6336S00DESCFRANQUICIAEU,t3.BAJA AB6336S00BAJA,t2.INDONLINE AB6335S00INDONLINE,t2.ID_INSTAL_OFI_PRINCIPAL AB6335S00IDINSTALOFIPRINCIPAL,t2.ID_ORIGEN_OFI_PRINCIPAL AB6335S00IDORIGENOFIPRINCIPAL,t2.ID_TIPO_CIE AB6335S00IDTIPOCIE,t2.ETIQUETA_CIE AB6335S00ETIQUETACIE,t2.REGISTRO_FIANZA AB6335S00REGISTROFIANZA,t2.OBSERV_FIANZA AB6335S00OBSERVFIANZA,t2.OBSERV_SRC AB6335S00OBSERVSRC,t2.ID_PRIMERA_SUCURSAL AB6335S00IDPRIMERASUCURSAL,t2.NUM_CIE AB6335S00NUMCIE,t2.FECHA_REGISTRO AB6335S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6335S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6335S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6335S00USUARIOULTMODIF ");
		query.append(
				"FROM AB6337S00 t1 ,AB6335S00 t2, AB6336S00 t3, AB6301S00 t4 WHERE t2.ID_FRANQUICIA = t3.ID_FRANQUICIA(+) AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) AND t1.ID_ESTABLECIMIENTO = t4.ID_ESTABLECIMIENTO AND t4.ID_MODALIDAD = 'P' AND t2.NUM_CIE=?  ");

		List<Object> params = new ArrayList<Object>();
		params.add(fianza.getFranquicia().getNumCie());

		return (List<FianzaEstablecimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}
}
