package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Grupo;
import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6312s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class GrupoDaoImpl implements GrupoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDGRUPO", "DESCGRUPOES", "FECHAMODIFICACION",
			"NOMUSUARIO", "BAJA", "DESCGRUPOEU", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "AB6311S00IDTIPOESTABLECIMIENTO", "AB6311S00DESCTIPOES",
			"AB6311S00FECHAMODIFICACION", "AB6311S00NOMUSUARIO", "AB6311S00BAJA", "AB6311S00DESCTIPOEU",
			"AB6311S00ORDENACION", "AB6311S00TIPIFICACION", "AB6311S00FECHAREGISTRO", "AB6311S00USUARIOREGISTRO",
			"AB6311S00FECHAULTMODIFICACION", "AB6311S00USUARIOULTMODIFI" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Grupo> rwMap = new RowMapper<Grupo>() {
		public Grupo mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Grupo(resultSet.getString("IDGRUPO"), resultSet.getString("DESCGRUPOES"),
					resultSet.getDate("FECHAMODIFICACION"), resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"),
					resultSet.getString("DESCGRUPOEU"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TipoEstablecimiento(resultSet.getString("Ab6311s00IDTIPOESTABLECIMIENTO"),
							resultSet.getString("Ab6311s00DESCTIPOES"), resultSet.getDate("Ab6311s00FECHAMODIFICACION"),
							resultSet.getString("Ab6311s00NOMUSUARIO"), resultSet.getInt("Ab6311s00BAJA"),
							resultSet.getString("Ab6311s00DESCTIPOEU"), resultSet.getString("Ab6311s00ORDENACION"),
							resultSet.getString("Ab6311s00TIPIFICACION"), resultSet.getDate("Ab6311s00FECHAREGISTRO"),
							resultSet.getString("Ab6311s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6311s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6311s00USUARIOULTMODIFI"), null, null, null, null));
		}
	};

	private RowMapper<Grupo> rwMapPK = new RowMapper<Grupo>() {
		public Grupo mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Grupo(resultSet.getString("IDGRUPO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Grupo>> rwMapJerarquia = new RowMapper<JerarquiaDto<Grupo>>() {
		public JerarquiaDto<Grupo> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Grupo ab6312s00 = new Grupo(resultSet.getString("IDGRUPO"), resultSet.getString("DESCGRUPOES"),
					resultSet.getDate("FECHAMODIFICACION"), resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"),
					resultSet.getString("DESCGRUPOEU"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TipoEstablecimiento(resultSet.getString("Ab6311s00IDTIPOESTABLECIMIENTO"),
							resultSet.getString("Ab6311s00DESCTIPOES"), resultSet.getDate("Ab6311s00FECHAMODIFICACION"),
							resultSet.getString("Ab6311s00NOMUSUARIO"), resultSet.getInt("Ab6311s00BAJA"),
							resultSet.getString("Ab6311s00DESCTIPOEU"), resultSet.getString("Ab6311s00ORDENACION"),
							resultSet.getString("Ab6311s00TIPIFICACION"), resultSet.getDate("Ab6311s00FECHAREGISTRO"),
							resultSet.getString("Ab6311s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6311s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6311s00USUARIOULTMODIFI"), null, null, null, null));

			JerarquiaDto<Grupo> jerarquia = new JerarquiaDto<Grupo>();
			jerarquia.setModel(ab6312s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @return Ab6312s00
	 */
	public Grupo add(Grupo ab6312s00) {
		String query = "INSERT INTO AB6312S00 (ID_GRUPO, ID_TIPO_ESTABLECIMIENTO, DESC_GRUPO_ES, BAJA, DESC_GRUPO_EU, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,SYSDATE,?)";
		Object getAb6311s00IdTipoEstablecimientoAux = null;
		if (ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento() != null) {
			getAb6311s00IdTipoEstablecimientoAux = ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento();
		}
		this.jdbcTemplate.update(query, ab6312s00.getIdGrupo(), getAb6311s00IdTipoEstablecimientoAux,
				ab6312s00.getDescGrupoEs(), ab6312s00.getBaja(), ab6312s00.getDescGrupoEu(),
				PermisosXLNETS.getUserConnected());
		return ab6312s00;
	}

	/**
	 * Updates a single row in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @return Ab6312s00
	 */
	public Grupo update(Grupo ab6312s00) {
		String query = "UPDATE AB6312S00 SET ID_TIPO_ESTABLECIMIENTO=?, DESC_GRUPO_ES=?, BAJA=?, DESC_GRUPO_EU=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_GRUPO=?";
		Object getAb6311s00IdTipoEstablecimientoAux = null;
		if (ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento() != null) {
			getAb6311s00IdTipoEstablecimientoAux = ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento();
		}
		this.jdbcTemplate.update(query, getAb6311s00IdTipoEstablecimientoAux, ab6312s00.getDescGrupoEs(),
				ab6312s00.getBaja(), ab6312s00.getDescGrupoEu(), PermisosXLNETS.getUserConnected(),
				ab6312s00.getIdGrupo());
		return ab6312s00;
	}

	/**
	 * Finds a single row in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @return Ab6312s00
	 */
	@Transactional(readOnly = true)
	public Grupo find(Grupo ab6312s00) {
		String query = "SELECT t1.ID_GRUPO IDGRUPO, t1.DESC_GRUPO_ES DESCGRUPOES, t1.FECHA_MODIFICACION FECHAMODIFICACION, t1.NOM_USUARIO NOMUSUARIO, t1.BAJA BAJA, t1.DESC_GRUPO_EU DESCGRUPOEU, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO, t2.DESC_TIPO_ES AB6311S00DESCTIPOES, t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION, t2.NOM_USUARIO AB6311S00NOMUSUARIO, t2.BAJA AB6311S00BAJA, t2.DESC_TIPO_EU AB6311S00DESCTIPOEU, t2.ORDENACION AB6311S00ORDENACION, t2.TIPIFICACION AB6311S00TIPIFICACION, t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI FROM AB6312S00 t1 , AB6311S00 t2  WHERE t1.ID_GRUPO = ?   AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+)";

		List<Grupo> ab6312s00List = this.jdbcTemplate.query(query, this.rwMap, ab6312s00.getIdGrupo());
		return (Grupo) DataAccessUtils.uniqueResult(ab6312s00List);
	}

	/**
	 * Removes a single row in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @return
	 */
	public void remove(Grupo ab6312s00) {
		String query = "DELETE FROM AB6312S00 WHERE ID_GRUPO=?";
		this.jdbcTemplate.update(query, ab6312s00.getIdGrupo());
	}

	/**
	 * Finds a list of rows in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6312s00>
	 */
	@Transactional(readOnly = true)
	public List<Grupo> findAll(Grupo ab6312s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		query.append("FROM AB6312S00 t1 ,AB6311S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6312s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, GrupoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Grupo>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6312s00 table using like.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6312s00>
	 */
	@Transactional(readOnly = true)
	public List<Grupo> findAllLike(Grupo ab6312s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		query.append("FROM AB6312S00 t1 ,AB6311S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6312s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, GrupoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Grupo>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6312s00 table.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Grupo ab6312s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6312S00 t1 , AB6311S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6312s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6312s00 table using like.
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Grupo ab6312s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6312S00 t1 ,AB6311S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6312s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6312s00 selected for rup_table
	 *
	 * @param ab6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6312s00>>
	 */
	@Override
	public List<TableRowDto<Grupo>> reorderSelection(Grupo ab6312s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		// FROM
		query.append("FROM AB6312S00 t1 ,AB6311S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6312s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Grupo.class,
				filterParamList, "IDGRUPO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Grupo>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6312s00
	 * @param searchParams
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6312s00>>
	 */
	@Override
	public List<TableRowDto<Grupo>> search(Grupo filterParams, Grupo searchParams, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		// FROM
		query.append("FROM AB6312S00 t1 ,AB6311S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_ESTABLECIMIENTO= t2.ID_TIPO_ESTABLECIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Grupo.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_GRUPO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Grupo>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Grupo filterab6312s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		// FROM
		query.append("FROM AB6312S00 t1 ,AB6311S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6312s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Grupo.class, query,
				params, "ID_GRUPO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6312s00 table.
	 *
	 * @param filterAb6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6312s00>>
	 */
	@Override
	public List<JerarquiaDto<Grupo>> findAllLikeJerarquia(Grupo filterAb6312s00, JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_GRUPO IDGRUPO,t1.DESC_GRUPO_ES DESCGRUPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_GRUPO_EU DESCGRUPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_TIPO_ESTABLECIMIENTO AB6311S00IDTIPOESTABLECIMIENTO,t2.DESC_TIPO_ES AB6311S00DESCTIPOES,t2.FECHA_MODIFICACION AB6311S00FECHAMODIFICACION,t2.NOM_USUARIO AB6311S00NOMUSUARIO,t2.BAJA AB6311S00BAJA,t2.DESC_TIPO_EU AB6311S00DESCTIPOEU,t2.ORDENACION AB6311S00ORDENACION,t2.TIPIFICACION AB6311S00TIPIFICACION,t2.FECHA_REGISTRO AB6311S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6311S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6311S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6311S00USUARIOULTMODIFI ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6312S00 t1 ,AB6311S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6312S00");
		from.add("AB6311S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6312s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_GRUPO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					GrupoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Grupo filterAb6312s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6312S00 t1 ,AB6311S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6312S00");
		from.add("AB6311S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6312s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_GRUPO", "ID_PADRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6312s00
	 *            Ab6312s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6312s00>>
	 */
	@Override
	public List<TableRowDto<Grupo>> findAllChild(Grupo filterAb6312s00, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6312S00 t1 ,AB6311S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6312S00");
		from.add("AB6311S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6312s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_GRUPO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(), new RowNumResultSetExtractor<Grupo>(this.rwMapPK, "ID_GRUPO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6312s00 entity
	 *
	 * @param ab6312s00
	 *            Ab6312s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Grupo ab6312s00) {

		StringBuilder where = new StringBuilder(GrupoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6312s00 != null && ab6312s00.getIdGrupo() != null) {
			where.append(" AND t1.ID_GRUPO = ?");
			params.add(ab6312s00.getIdGrupo());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento() != null) {
			where.append(" AND t2.ID_TIPO_ESTABLECIMIENTO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getDescTipoEs() != null) {
			where.append(" AND t2.DESC_TIPO_ES = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getDescTipoEs());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaModificacion() != null) {
			where.append(" AND t2.FECHA_MODIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaModificacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getNomUsuario() != null) {
			where.append(" AND t2.NOM_USUARIO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getNomUsuario());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getBaja() != null) {
			where.append(" AND t2.BAJA = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getBaja());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getDescTipoEu() != null) {
			where.append(" AND t2.DESC_TIPO_EU = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getDescTipoEu());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getOrdenacion() != null) {
			where.append(" AND t2.ORDENACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getOrdenacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getTipificacion() != null) {
			where.append(" AND t2.TIPIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getTipificacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getUsuarioRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaUltmodificacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getUsuarioUltmodificacion());
		}
		if (ab6312s00 != null && ab6312s00.getDescGrupoEs() != null) {
			where.append(" AND t1.DESC_GRUPO_ES = ?");
			params.add(ab6312s00.getDescGrupoEs());
		}
		if (ab6312s00 != null && ab6312s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6312s00.getFechaModificacion());
		}
		if (ab6312s00 != null && ab6312s00.getNomUsuario() != null) {
			where.append(" AND t1.NOM_USUARIO = ?");
			params.add(ab6312s00.getNomUsuario());
		}
		if (ab6312s00 != null && ab6312s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6312s00.getBaja());
		}
		if (ab6312s00 != null && ab6312s00.getDescGrupoEu() != null) {
			where.append(" AND t1.DESC_GRUPO_EU = ?");
			params.add(ab6312s00.getDescGrupoEu());
		}
		if (ab6312s00 != null && ab6312s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6312s00.getFechaRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6312s00.getUsuarioRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6312s00.getFechaUltmodificacion());
		}
		if (ab6312s00 != null && ab6312s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6312s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6312s00 entity
	 *
	 * @param ab6312s00
	 *            Ab6312s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Grupo ab6312s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(GrupoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6312s00 != null && ab6312s00.getIdGrupo() != null) {
			where.append(" AND UPPER(t1.ID_GRUPO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getIdGrupo().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getIdGrupo().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_GRUPO IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento() != null) {
			where.append(" AND t2.ID_TIPO_ESTABLECIMIENTO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getIdTipoEstablecimiento());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getDescTipoEs() != null) {
			where.append(" AND UPPER(t2.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaModificacion() != null) {
			where.append(" AND t2.FECHA_MODIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaModificacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getNomUsuario() != null) {
			where.append(" AND UPPER(t2.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t2.NOM_USUARIO IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getBaja() != null) {
			where.append(" AND t2.BAJA = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getBaja());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getDescTipoEu() != null) {
			where.append(" AND UPPER(t2.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getOrdenacion() != null) {
			where.append(" AND UPPER(t2.ORDENACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getOrdenacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getOrdenacion().toUpperCase() + "%");
			}
			where.append(" AND t2.ORDENACION IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getTipificacion() != null) {
			where.append(" AND UPPER(t2.TIPIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getTipificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getTipificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.TIPIFICACION IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6312s00.getTipoEstablecimiento().getFechaUltmodificacion());
		}
		if (ab6312s00 != null && ab6312s00.getTipoEstablecimiento() != null
				&& ab6312s00.getTipoEstablecimiento().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getTipoEstablecimiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getTipoEstablecimiento().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getDescGrupoEs() != null) {
			where.append(" AND UPPER(t1.DESC_GRUPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getDescGrupoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getDescGrupoEs().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_GRUPO_ES IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6312s00.getFechaModificacion());
		}
		if (ab6312s00 != null && ab6312s00.getNomUsuario() != null) {
			where.append(" AND UPPER(t1.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t1.NOM_USUARIO IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6312s00.getBaja());
		}
		if (ab6312s00 != null && ab6312s00.getDescGrupoEu() != null) {
			where.append(" AND UPPER(t1.DESC_GRUPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getDescGrupoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getDescGrupoEu().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_GRUPO_EU IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6312s00.getFechaRegistro());
		}
		if (ab6312s00 != null && ab6312s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6312s00 != null && ab6312s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6312s00.getFechaUltmodificacion());
		}
		if (ab6312s00 != null && ab6312s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6312s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6312s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
