package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.model.Habitacion;
import com.ejie.ab63.model.TipoAseo;
import com.ejie.ab63.model.TipoHabitacion;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6322s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class HabitacionDaoImpl implements HabitacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDHABITACION", "NUMUNIDADES", "NUMPLAZAS",
			"FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION",
			"AB6317S00IDTIPOHABITACION", "AB6317S00INDIVDOBL", "AB6317S00DESCTIPOES", "AB6317S00CONSALON",
			"AB6317S00NUMPLAZAS", "AB6317S00FECHAMODIFICACION", "AB6317S00NOMUSUARIO", "AB6317S00BAJA",
			"AB6317S00DESCTIPOEU", "AB6317S00FECHAREGISTRO", "AB6317S00USUARIOREGISTRO",
			"AB6317S00FECHAULTMODIFICACION", "AB6317S00USULTMODIFICACION", "AB6321S00IDESTABLECIMIENTO",
			"AB6321S00FECHAANOCONSTRUCCION", "AB6321S00FECHAANORENOVACION", "AB6321S00DERECHOCOCINA",
			"AB6321S00SERVICIOCOMEDOR", "AB6321S00NUMSALONES", "AB6321S00NUMSALONESCOMEDOR", "AB6321S00NUMCOMEDORES",
			"AB6321S00NUMBAOSGENERALES", "AB6321S00NUMCONJUNTOS", "AB6321S00NUMESTUDIOS", "AB6321S00NUMHABDOBLE",
			"AB6321S00NUMHABINDIVIDUALES", "AB6321S00NUMMAXIMOSUPLETORIAS", "AB6321S00NUMPLAZAS",
			"AB6321S00EDIFICIOCATALOGADO", "AB6321S00NUMHABMAS4", "AB6321S00NUMHABMENOS4", "AB6321S00COMPARTEVIVIENDAS",
			"AB6321S00NUMHABDOBLECS", "AB6321S00NUMAPARTAMENTOS", "AB6321S00NUMSUITES", "AB6321S00COMPARTEINSTAL",
			"AB6321S00NUMINSTALCOMPARTE", "AB6321S00NUMSUPACAMPADA", "AB6321S00BAR", "AB6321S00RESTAURANTE",
			"AB6321S00PISCINA", "AB6321S00NUMTOTPARCELAS", "AB6321S00NUMPARCELASANF", "AB6321S00NUMPARCELASAF",
			"AB6321S00NUMPARCELASSA", "AB6321S00INDICADORIA", "AB6321S00FECHACONTROLIA", "AB6321S00REQUISITOS",
			"AB6321S00NUMCONTROL", "AB6321S00FECHAANTCONTROL", "AB6321S00NUMHABITACIONES", "AB6321S00NUMRESIDENTESPERM",
			"AB6321S00SUPTOTHABITAC", "AB6321S00SUPRESTODEPEN", "AB6321S00FECHAREGISTRO", "AB6321S00USUARIOREGISTRO",
			"AB6321S00FECHAULTMODIFICACION", "AB6321S00USULTMODIFICACION", "AB6316S00IDTIPOASEO", "AB6316S00DESCTIPOES",
			"AB6316S00FECHAMODIFICACION", "AB6316S00NOMUSUARIO", "AB6316S00BAJA", "AB6316S00DESCTIPOEU",
			"AB6316S00FECHAREGISTRO", "AB6316S00USUARIOREGISTRO", "AB6316S00FECHAULTMODIFICACION",
			"AB6316S00USULTMODIFICACION", "NUMSUPBANOCOMPLETO", "NUMSUPDUCHALAVABOINO", "NUMSUPBANOLAVABO", "LAVABO",
			"TIPOREGISTRO", "NUMHABITACION", "NUMSUPTOTAL", "SALONPRIVADO", "NUMSUPSALON", "TERRAZA", "NUMSUPTERRAZA",
			"CAMASUPLETORIA", "ACCESIBILIDAD", "OTRASCARACTERISTICAS", "NUMSUPCOCINA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Habitacion> rwMap = new RowMapper<Habitacion>() {
		public Habitacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Habitacion(resultSet.getInt("IDHABITACION"), resultSet.getLong("NUMUNIDADES"),
					resultSet.getLong("NUMPLAZAS"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TipoHabitacion(resultSet.getString("Ab6317s00IDTIPOHABITACION"),
							resultSet.getString("Ab6317s00INDIVDOBL"), resultSet.getString("Ab6317s00DESCTIPOES"),
							resultSet.getInt("Ab6317s00CONSALON"), resultSet.getLong("Ab6317s00NUMPLAZAS"),
							resultSet.getDate("Ab6317s00FECHAMODIFICACION"), resultSet.getString("Ab6317s00NOMUSUARIO"),
							resultSet.getInt("Ab6317s00BAJA"), resultSet.getString("Ab6317s00DESCTIPOEU"),
							resultSet.getDate("Ab6317s00FECHAREGISTRO"),
							resultSet.getString("Ab6317s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6317s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6317s00USULTMODIFICACION")),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO"),
							resultSet.getLong("Ab6321s00FECHAANOCONSTRUCCION"),
							resultSet.getLong("Ab6321s00FECHAANORENOVACION"),
							resultSet.getInt("Ab6321s00DERECHOCOCINA"), resultSet.getInt("Ab6321s00SERVICIOCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMSALONES"), resultSet.getLong("Ab6321s00NUMSALONESCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMCOMEDORES"), resultSet.getLong("Ab6321s00NUMBAOSGENERALES"),
							resultSet.getLong("Ab6321s00NUMCONJUNTOS"), resultSet.getLong("Ab6321s00NUMESTUDIOS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLE"), resultSet.getLong("Ab6321s00NUMHABINDIVIDUALES"),
							resultSet.getLong("Ab6321s00NUMMAXIMOSUPLETORIAS"), resultSet.getLong("Ab6321s00NUMPLAZAS"),
							resultSet.getInt("Ab6321s00EDIFICIOCATALOGADO"), resultSet.getLong("Ab6321s00NUMHABMAS4"),
							resultSet.getLong("Ab6321s00NUMHABMENOS4"), resultSet.getInt("Ab6321s00COMPARTEVIVIENDAS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLECS"), resultSet.getLong("Ab6321s00NUMAPARTAMENTOS"),
							resultSet.getLong("Ab6321s00NUMSUITES"), resultSet.getInt("Ab6321s00COMPARTEINSTAL"),
							resultSet.getString("Ab6321s00NUMINSTALCOMPARTE"),
							resultSet.getBigDecimal("Ab6321s00NUMSUPACAMPADA"), resultSet.getInt("Ab6321s00BAR"),
							resultSet.getInt("Ab6321s00RESTAURANTE"), resultSet.getInt("Ab6321s00PISCINA"),
							resultSet.getLong("Ab6321s00NUMTOTPARCELAS"), resultSet.getLong("Ab6321s00NUMPARCELASANF"),
							resultSet.getLong("Ab6321s00NUMPARCELASAF"), resultSet.getLong("Ab6321s00NUMPARCELASSA"),
							resultSet.getInt("Ab6321s00INDICADORIA"), resultSet.getDate("Ab6321s00FECHACONTROLIA"),
							resultSet.getString("Ab6321s00REQUISITOS"), resultSet.getLong("Ab6321s00NUMCONTROL"),
							resultSet.getDate("Ab6321s00FECHAANTCONTROL"),
							resultSet.getString("Ab6321s00NUMHABITACIONES"),
							resultSet.getString("Ab6321s00NUMRESIDENTESPERM"),
							resultSet.getString("Ab6321s00SUPTOTHABITAC"),
							resultSet.getBigDecimal("Ab6321s00SUPRESTODEPEN"),
							resultSet.getDate("Ab6321s00FECHAREGISTRO"),
							resultSet.getString("Ab6321s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6321s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6321s00USULTMODIFICACION"), null, null, null, null, null, null,
							resultSet.getBigDecimal("NUMSUPCOCINA")),
					new TipoAseo(resultSet.getString("Ab6316s00IDTIPOASEO"), resultSet.getString("Ab6316s00DESCTIPOES"),
							resultSet.getDate("Ab6316s00FECHAMODIFICACION"), resultSet.getString("Ab6316s00NOMUSUARIO"),
							resultSet.getInt("Ab6316s00BAJA"), resultSet.getString("Ab6316s00DESCTIPOEU"),
							resultSet.getDate("Ab6316s00FECHAREGISTRO"),
							resultSet.getString("Ab6316s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6316s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6316s00USULTMODIFICACION")),
					resultSet.getInt("TIPOREGISTRO"), resultSet.getBigDecimal("NUMSUPBANOCOMPLETO"),
					resultSet.getBigDecimal("NUMSUPDUCHALAVABOINO"), resultSet.getBigDecimal("NUMSUPBANOLAVABO"),
					resultSet.getInt("LAVABO"), resultSet.getInt("NUMHABITACION"),
					resultSet.getBigDecimal("NUMSUPTOTAL"), resultSet.getInt("SALONPRIVADO"),
					resultSet.getBigDecimal("NUMSUPSALON"), resultSet.getInt("TERRAZA"),
					resultSet.getBigDecimal("NUMSUPTERRAZA"), resultSet.getInt("CAMASUPLETORIA"),
					resultSet.getInt("ACCESIBILIDAD"), resultSet.getString("OTRASCARACTERISTICAS"));
		}
	};

	private RowMapper<Habitacion> rwMapPK = new RowMapper<Habitacion>() {
		public Habitacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Habitacion(resultSet.getInt("IDHABITACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Habitacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<Habitacion>>() {
		public JerarquiaDto<Habitacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Habitacion ab6322s00 = new Habitacion(resultSet.getInt("IDHABITACION"), resultSet.getLong("NUMUNIDADES"),
					resultSet.getLong("NUMPLAZAS"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new TipoHabitacion(resultSet.getString("Ab6317s00IDTIPOHABITACION"),
							resultSet.getString("Ab6317s00INDIVDOBL"), resultSet.getString("Ab6317s00DESCTIPOES"),
							resultSet.getInt("Ab6317s00CONSALON"), resultSet.getLong("Ab6317s00NUMPLAZAS"),
							resultSet.getDate("Ab6317s00FECHAMODIFICACION"), resultSet.getString("Ab6317s00NOMUSUARIO"),
							resultSet.getInt("Ab6317s00BAJA"), resultSet.getString("Ab6317s00DESCTIPOEU"),
							resultSet.getDate("Ab6317s00FECHAREGISTRO"),
							resultSet.getString("Ab6317s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6317s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6317s00USULTMODIFICACION")),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO"),
							resultSet.getLong("Ab6321s00FECHAANOCONSTRUCCION"),
							resultSet.getLong("Ab6321s00FECHAANORENOVACION"),
							resultSet.getInt("Ab6321s00DERECHOCOCINA"), resultSet.getInt("Ab6321s00SERVICIOCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMSALONES"), resultSet.getLong("Ab6321s00NUMSALONESCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMCOMEDORES"), resultSet.getLong("Ab6321s00NUMBAOSGENERALES"),
							resultSet.getLong("Ab6321s00NUMCONJUNTOS"), resultSet.getLong("Ab6321s00NUMESTUDIOS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLE"), resultSet.getLong("Ab6321s00NUMHABINDIVIDUALES"),
							resultSet.getLong("Ab6321s00NUMMAXIMOSUPLETORIAS"), resultSet.getLong("Ab6321s00NUMPLAZAS"),
							resultSet.getInt("Ab6321s00EDIFICIOCATALOGADO"), resultSet.getLong("Ab6321s00NUMHABMAS4"),
							resultSet.getLong("Ab6321s00NUMHABMENOS4"), resultSet.getInt("Ab6321s00COMPARTEVIVIENDAS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLECS"), resultSet.getLong("Ab6321s00NUMAPARTAMENTOS"),
							resultSet.getLong("Ab6321s00NUMSUITES"), resultSet.getInt("Ab6321s00COMPARTEINSTAL"),
							resultSet.getString("Ab6321s00NUMINSTALCOMPARTE"),
							resultSet.getBigDecimal("Ab6321s00NUMSUPACAMPADA"), resultSet.getInt("Ab6321s00BAR"),
							resultSet.getInt("Ab6321s00RESTAURANTE"), resultSet.getInt("Ab6321s00PISCINA"),
							resultSet.getLong("Ab6321s00NUMTOTPARCELAS"), resultSet.getLong("Ab6321s00NUMPARCELASANF"),
							resultSet.getLong("Ab6321s00NUMPARCELASAF"), resultSet.getLong("Ab6321s00NUMPARCELASSA"),
							resultSet.getInt("Ab6321s00INDICADORIA"), resultSet.getDate("Ab6321s00FECHACONTROLIA"),
							resultSet.getString("Ab6321s00REQUISITOS"), resultSet.getLong("Ab6321s00NUMCONTROL"),
							resultSet.getDate("Ab6321s00FECHAANTCONTROL"),
							resultSet.getString("Ab6321s00NUMHABITACIONES"),
							resultSet.getString("Ab6321s00NUMRESIDENTESPERM"),
							resultSet.getString("Ab6321s00SUPTOTHABITAC"),
							resultSet.getBigDecimal("Ab6321s00SUPRESTODEPEN"),
							resultSet.getDate("Ab6321s00FECHAREGISTRO"),
							resultSet.getString("Ab6321s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6321s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6321s00USULTMODIFICACION"), null, null, null, null, null, null,
							resultSet.getBigDecimal("NUMSUPCOCINA")),
					new TipoAseo(resultSet.getString("Ab6316s00IDTIPOASEO"), resultSet.getString("Ab6316s00DESCTIPOES"),
							resultSet.getDate("Ab6316s00FECHAMODIFICACION"), resultSet.getString("Ab6316s00NOMUSUARIO"),
							resultSet.getInt("Ab6316s00BAJA"), resultSet.getString("Ab6316s00DESCTIPOEU"),
							resultSet.getDate("Ab6316s00FECHAREGISTRO"),
							resultSet.getString("Ab6316s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6316s00FECHAULTMODIFICACION"),
							resultSet.getString("Ab6316s00USULTMODIFICACION")),
					null, null, null, null, null, resultSet.getInt("NUMHABITACION"),
					resultSet.getBigDecimal("NUMSUPTOTAL"), resultSet.getInt("SALONPRIVADO"),
					resultSet.getBigDecimal("NUMSUPSALON"), resultSet.getInt("TERRAZA"),
					resultSet.getBigDecimal("NUMSUPTERRAZA"), resultSet.getInt("CAMASUPLETORIA"),
					resultSet.getInt("ACCESIBILIDAD"), resultSet.getString("OTRASCARACTERISTICAS"));

			JerarquiaDto<Habitacion> jerarquia = new JerarquiaDto<Habitacion>();
			jerarquia.setModel(ab6322s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @return Ab6322s00
	 */
	public Habitacion add(Habitacion ab6322s00) {
		String query = "INSERT INTO AB6322S00 (ID_HABITACION, ID_TIPO_HABITACION, ID_ESTABLECIMIENTO, ID_TIPO_ASEO, NUM_UNIDADES, NUM_PLAZAS, TIPO_REGISTRO, FECHA_REGISTRO, USUARIO_REGISTRO, NUM_HABITACION, NUM_SUP_TOTAL, SALON_PRIVADO, NUM_SUP_SALON, TERRAZA, NUM_SUP_TERRAZA, CAMA_SUPLETORIA, ACCESIBILIDAD, OTRAS_CARACTERISTICAS,NUM_SUP_BANO_COMPLETO,NUM_SUP_DUCHA_LAVABO_INO,NUM_SUP_BANO_LAVABO,LAVABO) VALUES (AB6322Q00.NEXTVAL,?,?,?,?,?,?,SYSDATE,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
		Object getAb6317s00IdTipoHabitacionAux = null;
		if (ab6322s00.getTipoHabitacion() != null && ab6322s00.getTipoHabitacion().getIdTipoHabitacion() != null) {
			getAb6317s00IdTipoHabitacionAux = ab6322s00.getTipoHabitacion().getIdTipoHabitacion();
		}
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6322s00.getEstablecimientoData().getIdEstablecimiento();
		}
		Object getAb6316s00IdTipoAseoAux = null;
		if (ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getIdTipoAseo() != null) {
			getAb6316s00IdTipoAseoAux = ab6322s00.getTipoAseo().getIdTipoAseo();
		}
		this.jdbcTemplate.update(query, getAb6317s00IdTipoHabitacionAux, getAb6321s00IdEstablecimientoAux,
				getAb6316s00IdTipoAseoAux, ab6322s00.getNumUnidades(), ab6322s00.getNumPlazas(),
				ab6322s00.getTipoRegistro(), PermisosXLNETS.getUserConnected(), ab6322s00.getNumHabitacion(),
				ab6322s00.getNumSupTotal(), ab6322s00.getSalonPrivado(), ab6322s00.getNumSupSalon(),
				ab6322s00.getTerraza(), ab6322s00.getNumSupTerraza(), ab6322s00.getCamaSupletoria(),
				ab6322s00.getAccesibilidad(), ab6322s00.getOtrasCaracteristicas(), ab6322s00.getNumSupBanyoCompleto(),
				ab6322s00.getNumSupDuchaLavaboIno(), ab6322s00.getNumSupBanyoLavabo(), ab6322s00.getLavabo());
		return ab6322s00;
	}

	/**
	 * Updates a single row in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @return Ab6322s00
	 */
	public Habitacion update(Habitacion ab6322s00) {
		String query = "UPDATE AB6322S00 SET ID_TIPO_HABITACION=?, ID_ESTABLECIMIENTO=?, ID_TIPO_ASEO=?, NUM_UNIDADES=?, NUM_PLAZAS=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=?, NUM_HABITACION=?, NUM_SUP_TOTAL=?, SALON_PRIVADO=?, NUM_SUP_SALON=?, TERRAZA=?, NUM_SUP_TERRAZA=?, CAMA_SUPLETORIA=?, ACCESIBILIDAD=?, OTRAS_CARACTERISTICAS=?, NUM_SUP_BANO_COMPLETO=?, NUM_SUP_DUCHA_LAVABO_INO=?, NUM_SUP_BANO_LAVABO=?, LAVABO=? WHERE ID_HABITACION=?";
		Object getAb6317s00IdTipoHabitacionAux = null;
		if (ab6322s00.getTipoHabitacion() != null && ab6322s00.getTipoHabitacion().getIdTipoHabitacion() != null) {
			getAb6317s00IdTipoHabitacionAux = ab6322s00.getTipoHabitacion().getIdTipoHabitacion();
		}
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6322s00.getEstablecimientoData().getIdEstablecimiento();
		}
		Object getAb6316s00IdTipoAseoAux = null;
		if (ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getIdTipoAseo() != null) {
			getAb6316s00IdTipoAseoAux = ab6322s00.getTipoAseo().getIdTipoAseo();
		}
		this.jdbcTemplate.update(query, getAb6317s00IdTipoHabitacionAux, getAb6321s00IdEstablecimientoAux,
				getAb6316s00IdTipoAseoAux, ab6322s00.getNumUnidades(), ab6322s00.getNumPlazas(),
				PermisosXLNETS.getUserConnected(), ab6322s00.getNumHabitacion(), ab6322s00.getNumSupTotal(),
				ab6322s00.getSalonPrivado(), ab6322s00.getNumSupSalon(), ab6322s00.getTerraza(),
				ab6322s00.getNumSupTerraza(), ab6322s00.getCamaSupletoria(), ab6322s00.getAccesibilidad(),
				ab6322s00.getOtrasCaracteristicas(), ab6322s00.getNumSupBanyoCompleto(),
				ab6322s00.getNumSupDuchaLavaboIno(), ab6322s00.getNumSupBanyoLavabo(), ab6322s00.getLavabo(),
				ab6322s00.getIdHabitacion());
		return ab6322s00;
	}

	/**
	 * Finds a single row in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @return Ab6322s00
	 */
	@Transactional(readOnly = true)
	public Habitacion find(Habitacion ab6322s00) {
		String query = "SELECT t1.ID_HABITACION IDHABITACION, t1.NUM_UNIDADES NUMUNIDADES, t1.NUM_PLAZAS NUMPLAZAS, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_SUP_BANO_COMPLETO NUMSUPBANOCOMPLETO, t1.NUM_SUP_DUCHA_LAVABO_INO NUMSUPDUCHALAVABOINO, t1.NUM_SUP_BANO_LAVABO NUMSUPBANOLAVABO, t1.LAVABO LAVABO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS, t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION, t2.INDIVDOBL AB6317S00INDIVDOBL, t2.DESC_TIPO_ES AB6317S00DESCTIPOES, t2.CONSALON AB6317S00CONSALON, t2.NUM_PLAZAS AB6317S00NUMPLAZAS, t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION, t2.NOM_USUARIO AB6317S00NOMUSUARIO, t2.BAJA AB6317S00BAJA, t2.DESC_TIPO_EU AB6317S00DESCTIPOEU, t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION, t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION, t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION, t3.DERECHO_COCINA AB6321S00DERECHOCOCINA, t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR, t3.NUM_SALONES AB6321S00NUMSALONES, t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR, t3.NUM_COMEDORES AB6321S00NUMCOMEDORES, t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES, t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS, t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS, t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE, t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES, t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS, t3.NUM_PLAZAS AB6321S00NUMPLAZAS, t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO, t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4, t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4, t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS, t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS, t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS, t3.NUM_SUITES AB6321S00NUMSUITES, t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL, t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE, t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA, t3.BAR AB6321S00BAR, t3.RESTAURANTE AB6321S00RESTAURANTE, t3.PISCINA AB6321S00PISCINA, t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS, t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF, t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF, t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA, t3.INDICADOR_IA AB6321S00INDICADORIA, t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA, t3.REQUISITOS AB6321S00REQUISITOS, t3.NUM_CONTROL AB6321S00NUMCONTROL, t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL, t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES, t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM, t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC, t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN, t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO, t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO, t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION, t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION, t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO, t4.DESC_TIPO_ES AB6316S00DESCTIPOES, t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION, t4.NOM_USUARIO AB6316S00NOMUSUARIO, t4.BAJA AB6316S00BAJA, t4.DESC_TIPO_EU AB6316S00DESCTIPOEU, t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO, t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO, t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION, t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION,t3.NUM_SUP_COCINA NUMSUPCOCINA FROM AB6322S00 t1 , AB6317S00 t2 , AB6321S00 t3 , AB6316S00 t4  WHERE t1.ID_HABITACION = ?   AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+)";

		List<Habitacion> ab6322s00List = this.jdbcTemplate.query(query, this.rwMap, ab6322s00.getIdHabitacion());
		return (Habitacion) DataAccessUtils.uniqueResult(ab6322s00List);
	}

	/**
	 * Removes a single row in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @return
	 */
	public void remove(Habitacion ab6322s00) {
		String query = "DELETE FROM AB6322S00 WHERE ID_HABITACION=?";
		this.jdbcTemplate.update(query, ab6322s00.getIdHabitacion());
	}

	/**
	 * Finds a list of rows in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<Ab6322s00>
	 */
	@Transactional(readOnly = true)
	public List<Habitacion> findAll(Habitacion ab6322s00, TableRequestDto tableRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_SUP_BANO_COMPLETO NUMSUPBANOCOMPLETO, t1.NUM_SUP_DUCHA_LAVABO_INO NUMSUPDUCHALAVABOINO, t1.NUM_SUP_BANO_LAVABO NUMSUPBANOLAVABO, t1.LAVABO LAVABO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t1.num_sup_bano_completo NUMSUPBANOCOMPLETO, t1.num_sup_ducha_lavabo_ino NUMSUPDUCHALAVABOINO, t1.num_sup_bano_lavabo NUMSUPBANOLAVABO, t1.LAVABO LAVABO, t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION,t3.NUM_SUP_COCINA NUMSUPCOCINA ");
		query.append("FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6322s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, HabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Habitacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6322s00 table using like.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6322s00>
	 */
	@Transactional(readOnly = true)
	public List<Habitacion> findAllLike(Habitacion ab6322s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_SUP_BANO_COMPLETO NUMSUPBANOCOMPLETO, t1.NUM_SUP_DUCHA_LAVABO_INO NUMSUPDUCHALAVABOINO, t1.NUM_SUP_BANO_LAVABO NUMSUPBANOLAVABO, t1.LAVABO LAVABO, t1.TIPO_REGISTRO TIPOREGISTRO, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION,t3.NUM_SUP_COCINA NUMSUPCOCINA ");
		query.append("FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6322s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, HabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Habitacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6322s00 table.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Habitacion ab6322s00) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM AB6322S00 t1 , AB6317S00 t2 , AB6321S00 t3 , AB6316S00 t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6322s00);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6322s00 table using like.
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Habitacion ab6322s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6322s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6322s00 selected for rup_table
	 *
	 * @param ab6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6322s00>>
	 */
	@Override
	public List<TableRowDto<Habitacion>> reorderSelection(Habitacion ab6322s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION ");
		// FROM
		query.append("FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6322s00, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, tableRequestDto, Habitacion.class,
				filterParamList, "ID_HABITACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Habitacion>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6322s00
	 * @param searchParams
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6322s00>>
	 */
	@Override
	public List<TableRowDto<Habitacion>> search(Habitacion filterParams, Habitacion searchParams,
			TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION ");
		// FROM
		query.append("FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TIPO_HABITACION= t2.ID_TIPO_HABITACION(+) AND t1.ID_ESTABLECIMIENTO= t3.ID_ESTABLECIMIENTO(+) AND t1.ID_TIPO_ASEO= t4.ID_TIPO_ASEO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, tableRequestDto, Habitacion.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_HABITACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Habitacion>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Habitacion filterab6322s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION ");
		// FROM
		query.append("FROM AB6322S00 t1 ,AB6317S00 t2 ,AB6321S00 t3 ,AB6316S00 t4 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6322s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(tableRequestDto, Habitacion.class,
				query, params, "ID_HABITACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6322s00 table.
	 *
	 * @param filterAb6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<JerarquiaDto<Ab6322s00>>
	 */
	@Override
	public List<JerarquiaDto<Habitacion>> findAllLikeJerarquia(Habitacion filterAb6322s00,
			TableRequestDto tableRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HABITACION IDHABITACION,t1.NUM_UNIDADES NUMUNIDADES,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.NUM_HABITACION NUMHABITACION, t1.NUM_SUP_TOTAL NUMSUPTOTAL, t1.SALON_PRIVADO SALONPRIVADO, t1.NUM_SUP_SALON NUMSUPSALON, t1.TERRAZA TERRAZA, t1.NUM_SUP_TERRAZA NUMSUPTERRAZA, t1.CAMA_SUPLETORIA CAMASUPLETORIA, t1.ACCESIBILIDAD ACCESIBILIDAD, t1.OTRAS_CARACTERISTICAS OTRASCARACTERISTICAS,t2.ID_TIPO_HABITACION AB6317S00IDTIPOHABITACION,t2.INDIVDOBL AB6317S00INDIVDOBL,t2.DESC_TIPO_ES AB6317S00DESCTIPOES,t2.CONSALON AB6317S00CONSALON,t2.NUM_PLAZAS AB6317S00NUMPLAZAS,t2.FECHA_MODIFICACION AB6317S00FECHAMODIFICACION,t2.NOM_USUARIO AB6317S00NOMUSUARIO,t2.BAJA AB6317S00BAJA,t2.DESC_TIPO_EU AB6317S00DESCTIPOEU,t2.FECHA_REGISTRO AB6317S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6317S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6317S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6317S00USULTMODIFICACION,t3.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t3.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t3.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t3.DERECHO_COCINA AB6321S00DERECHOCOCINA,t3.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t3.NUM_SALONES AB6321S00NUMSALONES,t3.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t3.NUM_COMEDORES AB6321S00NUMCOMEDORES,t3.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t3.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t3.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t3.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t3.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t3.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t3.NUM_PLAZAS AB6321S00NUMPLAZAS,t3.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t3.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t3.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t3.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t3.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t3.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t3.NUM_SUITES AB6321S00NUMSUITES,t3.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t3.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t3.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t3.BAR AB6321S00BAR,t3.RESTAURANTE AB6321S00RESTAURANTE,t3.PISCINA AB6321S00PISCINA,t3.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t3.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t3.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t3.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t3.INDICADOR_IA AB6321S00INDICADORIA,t3.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t3.REQUISITOS AB6321S00REQUISITOS,t3.NUM_CONTROL AB6321S00NUMCONTROL,t3.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t3.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t3.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t3.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t3.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t3.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t3.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t3.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t3.USUARIO_ULTMODIFICACION AB6321S00USULTMODIFICACION,t4.ID_TIPO_ASEO AB6316S00IDTIPOASEO,t4.DESC_TIPO_ES AB6316S00DESCTIPOES,t4.FECHA_MODIFICACION AB6316S00FECHAMODIFICACION,t4.NOM_USUARIO AB6316S00NOMUSUARIO,t4.BAJA AB6316S00BAJA,t4.DESC_TIPO_EU AB6316S00DESCTIPOEU,t4.FECHA_REGISTRO AB6316S00FECHAREGISTRO,t4.USUARIO_REGISTRO AB6316S00USUARIOREGISTRO,t4.FECHA_ULTMODIFICACION AB6316S00FECHAULTMODIFICACION,t4.USUARIO_ULTMODIFICACION AB6316S00USULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6322S00 t1 ,AB6317S00
		// t2 ,AB6321S00 t3 ,AB6316S00 t4 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6322S00");
		from.add("AB6317S00");
		from.add("AB6321S00");
		from.add("AB6316S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6322s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = TableManagerJerarquia.getQuery(tableRequestDto, query, mapaWhere, "ID_HABITACION", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = TableManagerJerarquia.getQuery(tableRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (tableRequestDto != null) {
			query = TableManagerJerarquia.getPaginationQuery(tableRequestDto, query,
					HabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Habitacion filterAb6322s00, TableRequestDto tableRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6322S00 t1 ,AB6317S00
		// t2 ,AB6321S00 t3 ,AB6316S00 t4 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6322S00");
		from.add("AB6317S00");
		from.add("AB6321S00");
		from.add("AB6316S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6322s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere, "ID_HABITACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6322s00
	 *            Ab6322s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<TableRowDto<Ab6322s00>>
	 */
	@Override
	public List<TableRowDto<Habitacion>> findAllChild(Habitacion filterAb6322s00, TableRequestDto tableRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6322S00 t1 ,AB6317S00
		// t2 ,AB6321S00 t3 ,AB6316S00 t4 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6322S00");
		from.add("AB6317S00");
		from.add("AB6321S00");
		from.add("AB6316S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");
		from_alias.add(" t4 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6322s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "ID_HABITACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Habitacion>(this.rwMapPK, "ID_HABITACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6322s00 entity
	 *
	 * @param ab6322s00
	 *            Ab6322s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Habitacion ab6322s00) {

		StringBuilder where = new StringBuilder(HabitacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6322s00 != null && ab6322s00.getIdHabitacion() != null) {
			where.append(" AND t1.ID_HABITACION = ?");
			params.add(ab6322s00.getIdHabitacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getIdTipoHabitacion() != null) {
			where.append(" AND t2.ID_TIPO_HABITACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getIdTipoHabitacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getIndivdobl() != null) {
			where.append(" AND t2.INDIVDOBL = ?");
			params.add(ab6322s00.getTipoHabitacion().getIndivdobl());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getDescTipoEs() != null) {
			where.append(" AND t2.DESC_TIPO_ES = ?");
			params.add(ab6322s00.getTipoHabitacion().getDescTipoEs());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getConsalon() != null) {
			where.append(" AND t2.CONSALON = ?");
			params.add(ab6322s00.getTipoHabitacion().getConsalon());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getNumPlazas() != null) {
			where.append(" AND t2.NUM_PLAZAS = ?");
			params.add(ab6322s00.getTipoHabitacion().getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaModificacion() != null) {
			where.append(" AND t2.FECHA_MODIFICACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaModificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getNomUsuario() != null) {
			where.append(" AND t2.NOM_USUARIO = ?");
			params.add(ab6322s00.getTipoHabitacion().getNomUsuario());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getBaja() != null) {
			where.append(" AND t2.BAJA = ?");
			params.add(ab6322s00.getTipoHabitacion().getBaja());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getDescTipoEu() != null) {
			where.append(" AND t2.DESC_TIPO_EU = ?");
			params.add(ab6322s00.getTipoHabitacion().getDescTipoEu());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6322s00.getTipoHabitacion().getUsuarioRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getUsuarioUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t3.ID_ESTABLECIMIENTO = ?");
			params.add(ab6322s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAnoConstruccion() != null) {
			where.append(" AND t3.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAnoConstruccion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAnoRenovacion() != null) {
			where.append(" AND t3.FECHA_ANO_RENOVACION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAnoRenovacion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getDerechoCocina() != null) {
			where.append(" AND t3.DERECHO_COCINA = ?");
			params.add(ab6322s00.getEstablecimientoData().getDerechoCocina());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getServicioComedor() != null) {
			where.append(" AND t3.SERVICIO_COMEDOR = ?");
			params.add(ab6322s00.getEstablecimientoData().getServicioComedor());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSalones() != null) {
			where.append(" AND t3.NUM_SALONES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSalones());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSalonesComedor() != null) {
			where.append(" AND t3.NUM_SALONES_COMEDOR = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSalonesComedor());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumComedores() != null) {
			where.append(" AND t3.NUM_COMEDORES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumComedores());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumBanosGenerales() != null) {
			where.append(" AND t3.NUM_BAOS_GENERALES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumBanosGenerales());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumConjuntos() != null) {
			where.append(" AND t3.NUM_CONJUNTOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumConjuntos());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumEstudios() != null) {
			where.append(" AND t3.NUM_ESTUDIOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumEstudios());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabDoble() != null) {
			where.append(" AND t3.NUM_HAB_DOBLE = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabDoble());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabIndividuales() != null) {
			where.append(" AND t3.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabIndividuales());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumMaximoSupletorias() != null) {
			where.append(" AND t3.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumMaximoSupletorias());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumPlazas() != null) {
			where.append(" AND t3.NUM_PLAZAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getEdificioCatalogado() != null) {
			where.append(" AND t3.EDIFICIO_CATALOGADO = ?");
			params.add(ab6322s00.getEstablecimientoData().getEdificioCatalogado());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabMas4() != null) {
			where.append(" AND t3.NUM_HAB_MAS_4 = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabMas4());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabMenos4() != null) {
			where.append(" AND t3.NUM_HAB_MENOS_4 = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabMenos4());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getComparteViviendas() != null) {
			where.append(" AND t3.COMPARTE_VIVIENDAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getComparteViviendas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabDobleCs() != null) {
			where.append(" AND t3.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabDobleCs());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumApartamentos() != null) {
			where.append(" AND t3.NUM_APARTAMENTOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumApartamentos());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSuites() != null) {
			where.append(" AND t3.NUM_SUITES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSuites());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getComparteInstal() != null) {
			where.append(" AND t3.COMPARTE_INSTAL = ?");
			params.add(ab6322s00.getEstablecimientoData().getComparteInstal());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumInstalComparte() != null) {
			where.append(" AND t3.NUM_INSTAL_COMPARTE = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumInstalComparte());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSupAcampada() != null) {
			where.append(" AND t3.NUM_SUP_ACAMPADA = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSupAcampada());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getBar() != null) {
			where.append(" AND t3.BAR = ?");
			params.add(ab6322s00.getEstablecimientoData().getBar());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getRestaurante() != null) {
			where.append(" AND t3.RESTAURANTE = ?");
			params.add(ab6322s00.getEstablecimientoData().getRestaurante());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getPiscina() != null) {
			where.append(" AND t3.PISCINA = ?");
			params.add(ab6322s00.getEstablecimientoData().getPiscina());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumTotParcelas() != null) {
			where.append(" AND t3.NUM_TOT_PARCELAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumTotParcelas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasAnf() != null) {
			where.append(" AND t3.NUM_PARCELAS_ANF = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasAnf());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasAf() != null) {
			where.append(" AND t3.NUM_PARCELAS_AF = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasAf());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasSa() != null) {
			where.append(" AND t3.NUM_PARCELAS_SA = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasSa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIndicadorIa() != null) {
			where.append(" AND t3.INDICADOR_IA = ?");
			params.add(ab6322s00.getEstablecimientoData().getIndicadorIa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaControlIa() != null) {
			where.append(" AND t3.FECHA_CONTROL_IA = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaControlIa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getRequisitos() != null) {
			where.append(" AND t3.REQUISITOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getRequisitos());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumControl() != null) {
			where.append(" AND t3.NUM_CONTROL = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumControl());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAntControl() != null) {
			where.append(" AND t3.FECHA_ANT_CONTROL = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAntControl());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabitaciones() != null) {
			where.append(" AND t3.NUM_HABITACIONES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabitaciones());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumResidentesPerm() != null) {
			where.append(" AND t3.NUM_RESIDENTES_PERM = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumResidentesPerm());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getSupTotHabitac() != null) {
			where.append(" AND t3.SUP_TOT_HABITAC = ?");
			params.add(ab6322s00.getEstablecimientoData().getSupTotHabitac());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getSupRestoDepen() != null) {
			where.append(" AND t3.SUP_RESTO_DEPEN = ?");
			params.add(ab6322s00.getEstablecimientoData().getSupRestoDepen());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(ab6322s00.getEstablecimientoData().getUsuarioRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getUsuarioUltmodificacion() != null) {
			where.append(" AND t3.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6322s00.getEstablecimientoData().getUsuarioUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getIdTipoAseo() != null) {
			where.append(" AND t4.ID_TIPO_ASEO = ?");
			params.add(ab6322s00.getTipoAseo().getIdTipoAseo());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getDescTipoEs() != null) {
			where.append(" AND t4.DESC_TIPO_ES = ?");
			params.add(ab6322s00.getTipoAseo().getDescTipoEs());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaModificacion() != null) {
			where.append(" AND t4.FECHA_MODIFICACION = ?");
			params.add(ab6322s00.getTipoAseo().getFechaModificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getNomUsuario() != null) {
			where.append(" AND t4.NOM_USUARIO = ?");
			params.add(ab6322s00.getTipoAseo().getNomUsuario());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getBaja() != null) {
			where.append(" AND t4.BAJA = ?");
			params.add(ab6322s00.getTipoAseo().getBaja());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getDescTipoEu() != null) {
			where.append(" AND t4.DESC_TIPO_EU = ?");
			params.add(ab6322s00.getTipoAseo().getDescTipoEu());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaRegistro() != null) {
			where.append(" AND t4.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getTipoAseo().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getUsuarioRegistro() != null) {
			where.append(" AND t4.USUARIO_REGISTRO = ?");
			params.add(ab6322s00.getTipoAseo().getUsuarioRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaUltmodificacion() != null) {
			where.append(" AND t4.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoAseo().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getUsuarioUltmodificacion() != null) {
			where.append(" AND t4.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoAseo().getUsuarioUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getNumUnidades() != null) {
			where.append(" AND t1.NUM_UNIDADES = ?");
			params.add(ab6322s00.getNumUnidades());
		}
		if (ab6322s00 != null && ab6322s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6322s00.getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6322s00.getUsuarioRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6322s00.getUsuarioUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getNumHabitacion() != null) {
			where.append(" AND t1.NUM_HABITACION = ?");
			params.add(ab6322s00.getNumHabitacion());
		}
		if (ab6322s00 != null && ab6322s00.getNumSupTotal() != null) {
			where.append(" AND t1.NUM_SUP_TOTAL = ?");
			params.add(ab6322s00.getNumSupTotal());
		}
		if (ab6322s00 != null && ab6322s00.getSalonPrivado() != null) {
			where.append(" AND t1.SALON_PRIVADO = ?");
			params.add(ab6322s00.getSalonPrivado());
		}
		if (ab6322s00 != null && ab6322s00.getNumSupSalon() != null) {
			where.append(" AND t1.NUM_SUP_SALON = ?");
			params.add(ab6322s00.getNumSupSalon());
		}
		if (ab6322s00 != null && ab6322s00.getTerraza() != null) {
			where.append(" AND t1.TERRAZA = ?");
			params.add(ab6322s00.getTerraza());
		}
		if (ab6322s00 != null && ab6322s00.getNumSupTerraza() != null) {
			where.append(" AND t1.NUM_SUP_TERRAZA = ?");
			params.add(ab6322s00.getNumSupTerraza());
		}
		if (ab6322s00 != null && ab6322s00.getCamaSupletoria() != null) {
			where.append(" AND t1.CAMA_SUPLETORIA = ?");
			params.add(ab6322s00.getCamaSupletoria());
		}
		if (ab6322s00 != null && ab6322s00.getAccesibilidad() != null) {
			where.append(" AND t1.ACCESIBILIDAD = ?");
			params.add(ab6322s00.getAccesibilidad());
		}
		if (ab6322s00 != null && ab6322s00.getOtrasCaracteristicas() != null) {
			where.append(" AND t1.OTRAS_CARACTERISTICAS = ?");
			params.add(ab6322s00.getOtrasCaracteristicas());
		}
		if (ab6322s00 != null && ab6322s00.getTipoRegistro() != null) {
			where.append(" AND t1.TIPO_REGISTRO = ?");
			params.add(ab6322s00.getTipoRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6322s00 entity
	 *
	 * @param ab6322s00
	 *            Ab6322s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Habitacion ab6322s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(HabitacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6322s00 != null && ab6322s00.getIdHabitacion() != null) {
			where.append(" AND t1.ID_HABITACION = ?");
			params.add(ab6322s00.getIdHabitacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getIdTipoHabitacion() != null) {
			where.append(" AND t2.ID_TIPO_HABITACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getIdTipoHabitacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getIndivdobl() != null) {
			where.append(" AND UPPER(t2.INDIVDOBL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getIndivdobl().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getIndivdobl().toUpperCase() + "%");
			}
			where.append(" AND t2.INDIVDOBL IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getDescTipoEs() != null) {
			where.append(" AND UPPER(t2.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getConsalon() != null) {
			where.append(" AND t2.CONSALON = ?");
			params.add(ab6322s00.getTipoHabitacion().getConsalon());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getNumPlazas() != null) {
			where.append(" AND t2.NUM_PLAZAS = ?");
			params.add(ab6322s00.getTipoHabitacion().getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaModificacion() != null) {
			where.append(" AND t2.FECHA_MODIFICACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaModificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getNomUsuario() != null) {
			where.append(" AND UPPER(t2.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t2.NOM_USUARIO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getBaja() != null) {
			where.append(" AND t2.BAJA = ?");
			params.add(ab6322s00.getTipoHabitacion().getBaja());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getDescTipoEu() != null) {
			where.append(" AND UPPER(t2.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t2.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoHabitacion().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoHabitacion() != null
				&& ab6322s00.getTipoHabitacion().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoHabitacion().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoHabitacion().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t3.ID_ESTABLECIMIENTO = ?");
			params.add(ab6322s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAnoConstruccion() != null) {
			where.append(" AND t3.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAnoConstruccion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAnoRenovacion() != null) {
			where.append(" AND t3.FECHA_ANO_RENOVACION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAnoRenovacion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getDerechoCocina() != null) {
			where.append(" AND t3.DERECHO_COCINA = ?");
			params.add(ab6322s00.getEstablecimientoData().getDerechoCocina());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getServicioComedor() != null) {
			where.append(" AND t3.SERVICIO_COMEDOR = ?");
			params.add(ab6322s00.getEstablecimientoData().getServicioComedor());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSalones() != null) {
			where.append(" AND t3.NUM_SALONES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSalones());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSalonesComedor() != null) {
			where.append(" AND t3.NUM_SALONES_COMEDOR = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSalonesComedor());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumComedores() != null) {
			where.append(" AND t3.NUM_COMEDORES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumComedores());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumBanosGenerales() != null) {
			where.append(" AND t3.NUM_BAOS_GENERALES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumBanosGenerales());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumConjuntos() != null) {
			where.append(" AND t3.NUM_CONJUNTOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumConjuntos());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumEstudios() != null) {
			where.append(" AND t3.NUM_ESTUDIOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumEstudios());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabDoble() != null) {
			where.append(" AND t3.NUM_HAB_DOBLE = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabDoble());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabIndividuales() != null) {
			where.append(" AND t3.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabIndividuales());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumMaximoSupletorias() != null) {
			where.append(" AND t3.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumMaximoSupletorias());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumPlazas() != null) {
			where.append(" AND t3.NUM_PLAZAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getEdificioCatalogado() != null) {
			where.append(" AND t3.EDIFICIO_CATALOGADO = ?");
			params.add(ab6322s00.getEstablecimientoData().getEdificioCatalogado());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabMas4() != null) {
			where.append(" AND t3.NUM_HAB_MAS_4 = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabMas4());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabMenos4() != null) {
			where.append(" AND t3.NUM_HAB_MENOS_4 = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabMenos4());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getComparteViviendas() != null) {
			where.append(" AND t3.COMPARTE_VIVIENDAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getComparteViviendas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabDobleCs() != null) {
			where.append(" AND t3.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumHabDobleCs());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumApartamentos() != null) {
			where.append(" AND t3.NUM_APARTAMENTOS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumApartamentos());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSuites() != null) {
			where.append(" AND t3.NUM_SUITES = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSuites());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getComparteInstal() != null) {
			where.append(" AND t3.COMPARTE_INSTAL = ?");
			params.add(ab6322s00.getEstablecimientoData().getComparteInstal());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumInstalComparte() != null) {
			where.append(" AND UPPER(t3.NUM_INSTAL_COMPARTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getNumInstalComparte().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getNumInstalComparte().toUpperCase() + "%");
			}
			where.append(" AND t3.NUM_INSTAL_COMPARTE IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumSupAcampada() != null) {
			where.append(" AND t3.NUM_SUP_ACAMPADA = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumSupAcampada());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getBar() != null) {
			where.append(" AND t3.BAR = ?");
			params.add(ab6322s00.getEstablecimientoData().getBar());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getRestaurante() != null) {
			where.append(" AND t3.RESTAURANTE = ?");
			params.add(ab6322s00.getEstablecimientoData().getRestaurante());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getPiscina() != null) {
			where.append(" AND t3.PISCINA = ?");
			params.add(ab6322s00.getEstablecimientoData().getPiscina());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumTotParcelas() != null) {
			where.append(" AND t3.NUM_TOT_PARCELAS = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumTotParcelas());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasAnf() != null) {
			where.append(" AND t3.NUM_PARCELAS_ANF = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasAnf());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasAf() != null) {
			where.append(" AND t3.NUM_PARCELAS_AF = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasAf());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumParcelasSa() != null) {
			where.append(" AND t3.NUM_PARCELAS_SA = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumParcelasSa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getIndicadorIa() != null) {
			where.append(" AND t3.INDICADOR_IA = ?");
			params.add(ab6322s00.getEstablecimientoData().getIndicadorIa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaControlIa() != null) {
			where.append(" AND t3.FECHA_CONTROL_IA = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaControlIa());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getRequisitos() != null) {
			where.append(" AND UPPER(t3.REQUISITOS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getRequisitos().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getRequisitos().toUpperCase() + "%");
			}
			where.append(" AND t3.REQUISITOS IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumControl() != null) {
			where.append(" AND t3.NUM_CONTROL = ?");
			params.add(ab6322s00.getEstablecimientoData().getNumControl());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaAntControl() != null) {
			where.append(" AND t3.FECHA_ANT_CONTROL = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaAntControl());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumHabitaciones() != null) {
			where.append(" AND UPPER(t3.NUM_HABITACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getNumHabitaciones().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getNumHabitaciones().toUpperCase() + "%");
			}
			where.append(" AND t3.NUM_HABITACIONES IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getNumResidentesPerm() != null) {
			where.append(" AND UPPER(t3.NUM_RESIDENTES_PERM) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getNumResidentesPerm().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getNumResidentesPerm().toUpperCase() + "%");
			}
			where.append(" AND t3.NUM_RESIDENTES_PERM IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getSupTotHabitac() != null) {
			where.append(" AND UPPER(t3.SUP_TOT_HABITAC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getSupTotHabitac().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getSupTotHabitac().toUpperCase() + "%");
			}
			where.append(" AND t3.SUP_TOT_HABITAC IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getSupRestoDepen() != null) {
			where.append(" AND t3.SUP_RESTO_DEPEN = ? ");
			params.add(ab6322s00.getEstablecimientoData().getSupRestoDepen());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getFechaUltmodificacion() != null) {
			where.append(" AND t3.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getEstablecimientoData().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getEstablecimientoData() != null
				&& ab6322s00.getEstablecimientoData().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t3.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getEstablecimientoData().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getEstablecimientoData().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getIdTipoAseo() != null) {
			where.append(" AND t4.ID_TIPO_ASEO = ?");
			params.add(ab6322s00.getTipoAseo().getIdTipoAseo());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getDescTipoEs() != null) {
			where.append(" AND UPPER(t4.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoAseo().getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoAseo().getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t4.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaModificacion() != null) {
			where.append(" AND t4.FECHA_MODIFICACION = ?");
			params.add(ab6322s00.getTipoAseo().getFechaModificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getNomUsuario() != null) {
			where.append(" AND UPPER(t4.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoAseo().getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoAseo().getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t4.NOM_USUARIO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getBaja() != null) {
			where.append(" AND t4.BAJA = ?");
			params.add(ab6322s00.getTipoAseo().getBaja());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null && ab6322s00.getTipoAseo().getDescTipoEu() != null) {
			where.append(" AND UPPER(t4.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoAseo().getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoAseo().getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t4.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaRegistro() != null) {
			where.append(" AND t4.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getTipoAseo().getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t4.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoAseo().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoAseo().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t4.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getFechaUltmodificacion() != null) {
			where.append(" AND t4.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getTipoAseo().getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getTipoAseo() != null
				&& ab6322s00.getTipoAseo().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t4.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getTipoAseo().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getTipoAseo().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t4.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getNumUnidades() != null) {
			where.append(" AND t1.NUM_UNIDADES = ?");
			params.add(ab6322s00.getNumUnidades());
		}
		if (ab6322s00 != null && ab6322s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6322s00.getNumPlazas());
		}
		if (ab6322s00 != null && ab6322s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6322s00.getFechaRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6322s00.getFechaUltmodificacion());
		}
		if (ab6322s00 != null && ab6322s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6322s00 != null && ab6322s00.getTipoRegistro() != null) {
			where.append(" AND t1.TIPO_REGISTRO = ?");
			params.add(ab6322s00.getTipoRegistro());
		}
		if (ab6322s00 != null && ab6322s00.getNumHabitacion() != null) {
			where.append(" AND t1.NUM_HABITACION = ?");
			params.add(ab6322s00.getNumHabitacion());
		}

		if (ab6322s00 != null && ab6322s00.getNumSupTotal() != null) {
			where.append(" AND t1.NUM_SUP_TOTAL = ?");
			params.add(ab6322s00.getNumSupTotal());
		}
		if (ab6322s00 != null && ab6322s00.getSalonPrivado() != null) {
			where.append(" AND t1.SALON_PRIVADO = ?");
			params.add(ab6322s00.getSalonPrivado());
		}
		if (ab6322s00 != null && ab6322s00.getNumSupSalon() != null) {
			where.append(" AND t1.NUM_SUP_SALON = ?");
			params.add(ab6322s00.getNumSupSalon());
		}
		if (ab6322s00 != null && ab6322s00.getTerraza() != null) {
			where.append(" AND t1.TERRAZA = ?");
			params.add(ab6322s00.getTerraza());
		}
		if (ab6322s00 != null && ab6322s00.getNumSupTerraza() != null) {
			where.append(" AND t1.NUM_SUP_TERRAZA = ?");
			params.add(ab6322s00.getNumSupTerraza());
		}
		if (ab6322s00 != null && ab6322s00.getCamaSupletoria() != null) {
			where.append(" AND t1.CAMA_SUPLETORIA = ?");
			params.add(ab6322s00.getCamaSupletoria());
		}
		if (ab6322s00 != null && ab6322s00.getAccesibilidad() != null) {
			where.append(" AND t1.ACCESIBILIDAD = ?");
			params.add(ab6322s00.getAccesibilidad());
		}
		if (ab6322s00 != null && ab6322s00.getOtrasCaracteristicas() != null) {
			where.append(" AND UPPER(t1.OTRAS_CARACTERISTICAS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6322s00.getOtrasCaracteristicas().toUpperCase() + "%");
			} else {
				params.add("%" + ab6322s00.getOtrasCaracteristicas().toUpperCase() + "%");
			}
			where.append(" AND t1.OTRAS_CARACTERISTICAS IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;

	@Override
	public Long getTotalHabitacionesByIdEstablecimiento(Habitacion habitacion) {
		StringBuilder query = new StringBuilder("SELECT SUM(NUM_UNIDADES) FROM AB6322S00 WHERE ID_ESTABLECIMIENTO=?");

		if (null != habitacion.getTipoHabitacion()
				&& !"".equals(habitacion.getTipoHabitacion().getIdTipoHabitacion())) {

			if ("HD".equals(habitacion.getTipoHabitacion().getIdTipoHabitacion())) {
				query.append(" AND ID_TIPO_HABITACION='HD'");
			} else if ("DS".equals(habitacion.getTipoHabitacion().getIdTipoHabitacion())) {
				query.append(" AND ID_TIPO_HABITACION='DS'");
			} else if ("HI".equals(habitacion.getTipoHabitacion().getIdTipoHabitacion())) {
				query.append(" AND ID_TIPO_HABITACION='HI'");
			} else {
				query.append(" AND ID_TIPO_HABITACION='MU'");
			}

		}
		List<Object> params = new ArrayList<Object>();

		params.add(habitacion.getEstablecimientoData().getIdEstablecimiento());

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalHabDblByIdEst(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NUM_UNIDADES) FROM AB6322S00 WHERE ID_ESTABLECIMIENTO=? AND ID_TIPO_HABITACION='HD'");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalHabDblCsByIdEst(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NUM_UNIDADES) FROM AB6322S00 WHERE ID_ESTABLECIMIENTO=? AND ID_TIPO_HABITACION='DS'");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalHabIndByIdEst(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NUM_UNIDADES) FROM AB6322S00 WHERE ID_ESTABLECIMIENTO=? AND ID_TIPO_HABITACION='HI'");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalHabMultiplesByIdEst(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NUM_UNIDADES) FROM AB6322S00 WHERE ID_ESTABLECIMIENTO=? AND ID_TIPO_HABITACION='MU'");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalUnidadesResumen(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NUM_UNIDADES) FROM AB6322T00 WHERE ID_ESTABLECIMIENTO = ? AND TIPO_REGISTRO = 1");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalUnidadesDetalle(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT COUNT(1) FROM AB6322T00 WHERE ID_ESTABLECIMIENTO = ? AND TIPO_REGISTRO = 0");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalPlazasResumen(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NVL(NUM_PLAZAS, 0) * NVL(NUM_UNIDADES,0)) t_plazas FROM AB6322T00 WHERE ID_ESTABLECIMIENTO = ? AND TIPO_REGISTRO = 1");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	@Override
	public Long getTotalPlazasDetalle(Integer idEstablecimiento) {
		StringBuilder query = new StringBuilder(
				"SELECT SUM(NVL(NUM_PLAZAS, 0)) t_plazas FROM AB6322T00 WHERE ID_ESTABLECIMIENTO = ? AND TIPO_REGISTRO = 0");

		List<Object> params = new ArrayList<Object>();

		params.add(idEstablecimiento);

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}
}
