package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.model.HabitacionVivienda;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6341s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class HabitacionViviendaDaoImpl implements HabitacionViviendaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDHABVIVIENDA", "SUPDORMITORIO", "PLAZASHAB",
			"IDENTHABITACION", "ACCESIBLE", "ILUMNATURAL", "VENTILACIONPATIO", "USOTURISTICO", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "AB6321S00IDESTABLECIMIENTO",
			"AB6321S00FECHAANOCONSTRUCCION", "AB6321S00FECHAANORENOVACION", "AB6321S00DERECHOCOCINA",
			"AB6321S00SERVICIOCOMEDOR", "AB6321S00NUMSALONES", "AB6321S00NUMSALONESCOMEDOR", "AB6321S00NUMCOMEDORES",
			"AB6321S00NUMBAOSGENERALES", "AB6321S00NUMCONJUNTOS", "AB6321S00NUMESTUDIOS", "AB6321S00NUMHABDOBLE",
			"AB6321S00NUMHABINDIVIDUALES", "AB6321S00NUMMAXIMOSUPLETORIAS", "AB6321S00NUMPLAZAS",
			"AB6321S00EDIFICIOCATALOGADO", "AB6321S00NUMHABMAS4", "AB6321S00NUMHABMENOS4", "AB6321S00COMPARTEVIVIENDAS",
			"AB6321S00NUMHABDOBLECS", "AB6321S00NUMAPARTAMENTOS", "AB6321S00NUMSUITES", "AB6321S00COMPARTEINSTAL",
			"AB6321S00NUMINSTALCOMPARTE", "AB6321S00NUMSUPACAMPADA", "AB6321S00BAR", "AB6321S00RESTAURANTE",
			"AB6321S00PISCINA", "AB6321S00NUMTOTPARCELAS", "AB6321S00NUMPARCELASANF", "AB6321S00NUMPARCELASAF",
			"AB6321S00NUMPARCELASSA", "AB6321S00INDICADORIA", "AB6321S00FECHACONTROLIA", "AB6321S00REQUISITOS",
			"AB6321S00NUMCONTROL", "AB6321S00FECHAANTCONTROL", "AB6321S00NUMHABITACIONES", "AB6321S00NUMRESIDENTESPERM",
			"AB6321S00SUPTOTHABITAC", "AB6321S00SUPRESTODEPEN", "AB6321S00FECHAREGISTRO", "AB6321S00USUARIOREGISTRO",
			"AB6321S00FECHAULTMODIFICACION", "AB6321S00USUARIOULTMODIF", "NUMSUPCOCINA" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<HabitacionVivienda> rwMap = new RowMapper<HabitacionVivienda>() {
		public HabitacionVivienda mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new HabitacionVivienda(resultSet.getString("IDHABVIVIENDA"),
					resultSet.getBigDecimal("SUPDORMITORIO"), resultSet.getString("PLAZASHAB"),
					resultSet.getString("IDENTHABITACION"), resultSet.getString("ACCESIBLE"),
					resultSet.getString("ILUMNATURAL"), resultSet.getString("VENTILACIONPATIO"),
					resultSet.getString("USOTURISTICO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO"),
							resultSet.getLong("Ab6321s00FECHAANOCONSTRUCCION"),
							resultSet.getLong("Ab6321s00FECHAANORENOVACION"),
							resultSet.getInt("Ab6321s00DERECHOCOCINA"), resultSet.getInt("Ab6321s00SERVICIOCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMSALONES"), resultSet.getLong("Ab6321s00NUMSALONESCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMCOMEDORES"), resultSet.getLong("Ab6321s00NUMBAOSGENERALES"),
							resultSet.getLong("Ab6321s00NUMCONJUNTOS"), resultSet.getLong("Ab6321s00NUMESTUDIOS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLE"), resultSet.getLong("Ab6321s00NUMHABINDIVIDUALES"),
							resultSet.getLong("Ab6321s00NUMMAXIMOSUPLETORIAS"), resultSet.getLong("Ab6321s00NUMPLAZAS"),
							resultSet.getInt("Ab6321s00EDIFICIOCATALOGADO"), resultSet.getLong("Ab6321s00NUMHABMAS4"),
							resultSet.getLong("Ab6321s00NUMHABMENOS4"), resultSet.getInt("Ab6321s00COMPARTEVIVIENDAS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLECS"), resultSet.getLong("Ab6321s00NUMAPARTAMENTOS"),
							resultSet.getLong("Ab6321s00NUMSUITES"), resultSet.getInt("Ab6321s00COMPARTEINSTAL"),
							resultSet.getString("Ab6321s00NUMINSTALCOMPARTE"),
							resultSet.getBigDecimal("Ab6321s00NUMSUPACAMPADA"), resultSet.getInt("Ab6321s00BAR"),
							resultSet.getInt("Ab6321s00RESTAURANTE"), resultSet.getInt("Ab6321s00PISCINA"),
							resultSet.getLong("Ab6321s00NUMTOTPARCELAS"), resultSet.getLong("Ab6321s00NUMPARCELASANF"),
							resultSet.getLong("Ab6321s00NUMPARCELASAF"), resultSet.getLong("Ab6321s00NUMPARCELASSA"),
							resultSet.getInt("Ab6321s00INDICADORIA"), resultSet.getDate("Ab6321s00FECHACONTROLIA"),
							resultSet.getString("Ab6321s00REQUISITOS"), resultSet.getLong("Ab6321s00NUMCONTROL"),
							resultSet.getDate("Ab6321s00FECHAANTCONTROL"),
							resultSet.getString("Ab6321s00NUMHABITACIONES"),
							resultSet.getString("Ab6321s00NUMRESIDENTESPERM"),
							resultSet.getString("Ab6321s00SUPTOTHABITAC"),
							resultSet.getBigDecimal("Ab6321s00SUPRESTODEPEN"),
							resultSet.getDate("Ab6321s00FECHAREGISTRO"),
							resultSet.getString("Ab6321s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6321s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6321S00USUARIOULTMODIF"), null, null, null, null, null, null,
							resultSet.getBigDecimal("NUMSUPCOCINA")));
		}
	};

	private RowMapper<HabitacionVivienda> rwMapPK = new RowMapper<HabitacionVivienda>() {
		public HabitacionVivienda mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new HabitacionVivienda(resultSet.getString("IDHABVIVIENDA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<HabitacionVivienda>> rwMapJerarquia = new RowMapper<JerarquiaDto<HabitacionVivienda>>() {
		public JerarquiaDto<HabitacionVivienda> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			HabitacionVivienda ab6341s00 = new HabitacionVivienda(resultSet.getString("IDHABVIVIENDA"),
					resultSet.getBigDecimal("SUPDORMITORIO"), resultSet.getString("PLAZASHAB"),
					resultSet.getString("IDENTHABITACION"), resultSet.getString("ACCESIBLE"),
					resultSet.getString("ILUMNATURAL"), resultSet.getString("VENTILACIONPATIO"),
					resultSet.getString("USOTURISTICO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO"),
							resultSet.getLong("Ab6321s00FECHAANOCONSTRUCCION"),
							resultSet.getLong("Ab6321s00FECHAANORENOVACION"),
							resultSet.getInt("Ab6321s00DERECHOCOCINA"), resultSet.getInt("Ab6321s00SERVICIOCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMSALONES"), resultSet.getLong("Ab6321s00NUMSALONESCOMEDOR"),
							resultSet.getLong("Ab6321s00NUMCOMEDORES"), resultSet.getLong("Ab6321s00NUMBAOSGENERALES"),
							resultSet.getLong("Ab6321s00NUMCONJUNTOS"), resultSet.getLong("Ab6321s00NUMESTUDIOS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLE"), resultSet.getLong("Ab6321s00NUMHABINDIVIDUALES"),
							resultSet.getLong("Ab6321s00NUMMAXIMOSUPLETORIAS"), resultSet.getLong("Ab6321s00NUMPLAZAS"),
							resultSet.getInt("Ab6321s00EDIFICIOCATALOGADO"), resultSet.getLong("Ab6321s00NUMHABMAS4"),
							resultSet.getLong("Ab6321s00NUMHABMENOS4"), resultSet.getInt("Ab6321s00COMPARTEVIVIENDAS"),
							resultSet.getLong("Ab6321s00NUMHABDOBLECS"), resultSet.getLong("Ab6321s00NUMAPARTAMENTOS"),
							resultSet.getLong("Ab6321s00NUMSUITES"), resultSet.getInt("Ab6321s00COMPARTEINSTAL"),
							resultSet.getString("Ab6321s00NUMINSTALCOMPARTE"),
							resultSet.getBigDecimal("Ab6321s00NUMSUPACAMPADA"), resultSet.getInt("Ab6321s00BAR"),
							resultSet.getInt("Ab6321s00RESTAURANTE"), resultSet.getInt("Ab6321s00PISCINA"),
							resultSet.getLong("Ab6321s00NUMTOTPARCELAS"), resultSet.getLong("Ab6321s00NUMPARCELASANF"),
							resultSet.getLong("Ab6321s00NUMPARCELASAF"), resultSet.getLong("Ab6321s00NUMPARCELASSA"),
							resultSet.getInt("Ab6321s00INDICADORIA"), resultSet.getDate("Ab6321s00FECHACONTROLIA"),
							resultSet.getString("Ab6321s00REQUISITOS"), resultSet.getLong("Ab6321s00NUMCONTROL"),
							resultSet.getDate("Ab6321s00FECHAANTCONTROL"),
							resultSet.getString("Ab6321s00NUMHABITACIONES"),
							resultSet.getString("Ab6321s00NUMRESIDENTESPERM"),
							resultSet.getString("Ab6321s00SUPTOTHABITAC"),
							resultSet.getBigDecimal("Ab6321s00SUPRESTODEPEN"),
							resultSet.getDate("Ab6321s00FECHAREGISTRO"),
							resultSet.getString("Ab6321s00USUARIOREGISTRO"),
							resultSet.getDate("Ab6321s00FECHAULTMODIFICACION"),
							resultSet.getString("AB6321S00USUARIOULTMODIF"), null, null, null, null, null, null,
							resultSet.getBigDecimal("NUMSUPCOCINA")));

			JerarquiaDto<HabitacionVivienda> jerarquia = new JerarquiaDto<HabitacionVivienda>();
			jerarquia.setModel(ab6341s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @return Ab6341s00
	 */
	public HabitacionVivienda add(HabitacionVivienda ab6341s00) {
		String query = "INSERT INTO AB6341S00 (ID_HAB_VIVIENDA, ID_ESTABLECIMIENTO, SUP_DORMITORIO, PLAZAS_HAB, IDENT_HABITACION, ACCESIBLE, ILUM_NATURAL, VENTILACION_PATIO, USO_TURISTICO, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB6341Q00.NEXTVAL,?,?,?,?,?,?,?,?,SYSDATE,?)";
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6341s00.getEstablecimientoData().getIdEstablecimiento();
		}
		this.jdbcTemplate.update(query, getAb6321s00IdEstablecimientoAux, ab6341s00.getSupDormitorio(),
				ab6341s00.getPlazasHab(), ab6341s00.getIdentHabitacion(), ab6341s00.getAccesible(),
				ab6341s00.getIlumNatural(), ab6341s00.getVentilacionPatio(), ab6341s00.getUsoTuristico(),
				PermisosXLNETS.getUserConnected());
		return ab6341s00;
	}

	/**
	 * Updates a single row in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @return Ab6341s00
	 */
	public HabitacionVivienda update(HabitacionVivienda ab6341s00) {
		String query = "UPDATE AB6341S00 SET ID_ESTABLECIMIENTO=?, SUP_DORMITORIO=?, PLAZAS_HAB=?, IDENT_HABITACION=?, ACCESIBLE=?, ILUM_NATURAL=?, VENTILACION_PATIO=?, USO_TURISTICO=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_HAB_VIVIENDA=?";
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6341s00.getEstablecimientoData().getIdEstablecimiento();
		}
		this.jdbcTemplate.update(query, getAb6321s00IdEstablecimientoAux, ab6341s00.getSupDormitorio(),
				ab6341s00.getPlazasHab(), ab6341s00.getIdentHabitacion(), ab6341s00.getAccesible(),
				ab6341s00.getIlumNatural(), ab6341s00.getVentilacionPatio(), ab6341s00.getUsoTuristico(),
				PermisosXLNETS.getUserConnected(), ab6341s00.getIdHabVivienda());
		return ab6341s00;
	}

	/**
	 * Finds a single row in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @return Ab6341s00
	 */
	@Transactional(readOnly = true)
	public HabitacionVivienda find(HabitacionVivienda ab6341s00) {
		String query = "SELECT t1.ID_HAB_VIVIENDA IDHABVIVIENDA, t1.SUP_DORMITORIO SUPDORMITORIO, t1.PLAZAS_HAB PLAZASHAB, t1.IDENT_HABITACION IDENTHABITACION, t1.ACCESIBLE ACCESIBLE, t1.ILUM_NATURAL ILUMNATURAL, t1.VENTILACION_PATIO VENTILACIONPATIO, t1.USO_TURISTICO USOTURISTICO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION, t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION, t2.DERECHO_COCINA AB6321S00DERECHOCOCINA, t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR, t2.NUM_SALONES AB6321S00NUMSALONES, t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR, t2.NUM_COMEDORES AB6321S00NUMCOMEDORES, t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES, t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS, t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS, t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE, t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES, t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS, t2.NUM_PLAZAS AB6321S00NUMPLAZAS, t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO, t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4, t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4, t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS, t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS, t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS, t2.NUM_SUITES AB6321S00NUMSUITES, t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL, t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE, t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA, t2.BAR AB6321S00BAR, t2.RESTAURANTE AB6321S00RESTAURANTE, t2.PISCINA AB6321S00PISCINA, t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS, t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF, t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF, t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA, t2.INDICADOR_IA AB6321S00INDICADORIA, t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA, t2.REQUISITOS AB6321S00REQUISITOS, t2.NUM_CONTROL AB6321S00NUMCONTROL, t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL, t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES, t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM, t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC, t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN, t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO, t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO, t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION, t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF ,t2.NUM_SUP_COCINA NUMSUPCOCINA FROM AB6341S00 t1 , AB6321S00 t2  WHERE t1.ID_HAB_VIVIENDA = ?   AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+)";

		List<HabitacionVivienda> ab6341s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6341s00.getIdHabVivienda());
		return (HabitacionVivienda) DataAccessUtils.uniqueResult(ab6341s00List);
	}

	/**
	 * Removes a single row in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @return
	 */
	public void remove(HabitacionVivienda ab6341s00) {
		String query = "DELETE FROM AB6341S00 WHERE ID_HAB_VIVIENDA=?";
		this.jdbcTemplate.update(query, ab6341s00.getIdHabVivienda());
	}

	/**
	 * Finds a list of rows in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6341s00>
	 */
	@Transactional(readOnly = true)
	public List<HabitacionVivienda> findAll(HabitacionVivienda ab6341s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF,t2.NUM_SUP_COCINA NUMSUPCOCINA ");
		query.append("FROM AB6341S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6341s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					HabitacionViviendaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<HabitacionVivienda>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6341s00 table using like.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6341s00>
	 */
	@Transactional(readOnly = true)
	public List<HabitacionVivienda> findAllLike(HabitacionVivienda ab6341s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF,t2.NUM_SUP_COCINA NUMSUPCOCINA ");
		query.append("FROM AB6341S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6341s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					HabitacionViviendaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<HabitacionVivienda>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6341s00 table.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(HabitacionVivienda ab6341s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6341S00 t1 , AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6341s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6341s00 table using like.
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(HabitacionVivienda ab6341s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6341S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6341s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6341s00 selected for rup_table
	 *
	 * @param ab6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6341s00>>
	 */
	@Override
	public List<TableRowDto<HabitacionVivienda>> reorderSelection(HabitacionVivienda ab6341s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF,t2.NUM_SUP_COCINA NUMSUPCOCINA ");
		// FROM
		query.append("FROM AB6341S00 t1 ,AB6321S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6341s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				HabitacionVivienda.class, filterParamList, "ID_HAB_VIVIENDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<HabitacionVivienda>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6341s00
	 * @param searchParams
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6341s00>>
	 */
	@Override
	public List<TableRowDto<HabitacionVivienda>> search(HabitacionVivienda filterParams,
			HabitacionVivienda searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF ");
		// FROM
		query.append("FROM AB6341S00 t1 ,AB6321S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				HabitacionVivienda.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_HAB_VIVIENDA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<HabitacionVivienda>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(HabitacionVivienda filterab6341s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF ");
		// FROM
		query.append("FROM AB6341S00 t1 ,AB6321S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6341s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				HabitacionVivienda.class, query, params, "ID_HAB_VIVIENDA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6341s00 table.
	 *
	 * @param filterAb6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6341s00>>
	 */
	@Override
	public List<JerarquiaDto<HabitacionVivienda>> findAllLikeJerarquia(HabitacionVivienda filterAb6341s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_HAB_VIVIENDA IDHABVIVIENDA,t1.SUP_DORMITORIO SUPDORMITORIO,t1.PLAZAS_HAB PLAZASHAB,t1.IDENT_HABITACION IDENTHABITACION,t1.ACCESIBLE ACCESIBLE,t1.ILUM_NATURAL ILUMNATURAL,t1.VENTILACION_PATIO VENTILACIONPATIO,t1.USO_TURISTICO USOTURISTICO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t2.FECHA_ANO_CONSTRUCCION AB6321S00FECHAANOCONSTRUCCION,t2.FECHA_ANO_RENOVACION AB6321S00FECHAANORENOVACION,t2.DERECHO_COCINA AB6321S00DERECHOCOCINA,t2.SERVICIO_COMEDOR AB6321S00SERVICIOCOMEDOR,t2.NUM_SALONES AB6321S00NUMSALONES,t2.NUM_SALONES_COMEDOR AB6321S00NUMSALONESCOMEDOR,t2.NUM_COMEDORES AB6321S00NUMCOMEDORES,t2.NUM_BAOS_GENERALES AB6321S00NUMBAOSGENERALES,t2.NUM_CONJUNTOS AB6321S00NUMCONJUNTOS,t2.NUM_ESTUDIOS AB6321S00NUMESTUDIOS,t2.NUM_HAB_DOBLE AB6321S00NUMHABDOBLE,t2.NUM_HAB_INDIVIDUALES AB6321S00NUMHABINDIVIDUALES,t2.NUM_MAXIMO_SUPLETORIAS AB6321S00NUMMAXIMOSUPLETORIAS,t2.NUM_PLAZAS AB6321S00NUMPLAZAS,t2.EDIFICIO_CATALOGADO AB6321S00EDIFICIOCATALOGADO,t2.NUM_HAB_MAS_4 AB6321S00NUMHABMAS4,t2.NUM_HAB_MENOS_4 AB6321S00NUMHABMENOS4,t2.COMPARTE_VIVIENDAS AB6321S00COMPARTEVIVIENDAS,t2.NUM_HAB_DOBLE_CS AB6321S00NUMHABDOBLECS,t2.NUM_APARTAMENTOS AB6321S00NUMAPARTAMENTOS,t2.NUM_SUITES AB6321S00NUMSUITES,t2.COMPARTE_INSTAL AB6321S00COMPARTEINSTAL,t2.NUM_INSTAL_COMPARTE AB6321S00NUMINSTALCOMPARTE,t2.NUM_SUP_ACAMPADA AB6321S00NUMSUPACAMPADA,t2.BAR AB6321S00BAR,t2.RESTAURANTE AB6321S00RESTAURANTE,t2.PISCINA AB6321S00PISCINA,t2.NUM_TOT_PARCELAS AB6321S00NUMTOTPARCELAS,t2.NUM_PARCELAS_ANF AB6321S00NUMPARCELASANF,t2.NUM_PARCELAS_AF AB6321S00NUMPARCELASAF,t2.NUM_PARCELAS_SA AB6321S00NUMPARCELASSA,t2.INDICADOR_IA AB6321S00INDICADORIA,t2.FECHA_CONTROL_IA AB6321S00FECHACONTROLIA,t2.REQUISITOS AB6321S00REQUISITOS,t2.NUM_CONTROL AB6321S00NUMCONTROL,t2.FECHA_ANT_CONTROL AB6321S00FECHAANTCONTROL,t2.NUM_HABITACIONES AB6321S00NUMHABITACIONES,t2.NUM_RESIDENTES_PERM AB6321S00NUMRESIDENTESPERM,t2.SUP_TOT_HABITAC AB6321S00SUPTOTHABITAC,t2.SUP_RESTO_DEPEN AB6321S00SUPRESTODEPEN,t2.FECHA_REGISTRO AB6321S00FECHAREGISTRO,t2.USUARIO_REGISTRO AB6321S00USUARIOREGISTRO,t2.FECHA_ULTMODIFICACION AB6321S00FECHAULTMODIFICACION,t2.USUARIO_ULTMODIFICACION AB6321S00USUARIOULTMODIF ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6341S00 t1 ,AB6321S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6341S00");
		from.add("AB6321S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6341s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_HAB_VIVIENDA", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					HabitacionViviendaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(HabitacionVivienda filterAb6341s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6341S00 t1 ,AB6321S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6341S00");
		from.add("AB6321S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6341s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_HAB_VIVIENDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6341s00
	 *            Ab6341s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6341s00>>
	 */
	@Override
	public List<TableRowDto<HabitacionVivienda>> findAllChild(HabitacionVivienda filterAb6341s00,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6341S00 t1 ,AB6321S00
		// t2 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6341S00");
		from.add("AB6321S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6341s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_HAB_VIVIENDA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<HabitacionVivienda>(this.rwMapPK, "ID_HAB_VIVIENDA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6341s00 entity
	 *
	 * @param ab6341s00
	 *            Ab6341s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(HabitacionVivienda ab6341s00) {

		StringBuilder where = new StringBuilder(HabitacionViviendaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6341s00 != null && ab6341s00.getIdHabVivienda() != null) {
			where.append(" AND t1.ID_HAB_VIVIENDA = ?");
			params.add(ab6341s00.getIdHabVivienda());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6341s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAnoConstruccion() != null) {
			where.append(" AND t2.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAnoConstruccion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAnoRenovacion() != null) {
			where.append(" AND t2.FECHA_ANO_RENOVACION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAnoRenovacion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getDerechoCocina() != null) {
			where.append(" AND t2.DERECHO_COCINA = ?");
			params.add(ab6341s00.getEstablecimientoData().getDerechoCocina());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getServicioComedor() != null) {
			where.append(" AND t2.SERVICIO_COMEDOR = ?");
			params.add(ab6341s00.getEstablecimientoData().getServicioComedor());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSalones() != null) {
			where.append(" AND t2.NUM_SALONES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSalones());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSalonesComedor() != null) {
			where.append(" AND t2.NUM_SALONES_COMEDOR = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSalonesComedor());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumComedores() != null) {
			where.append(" AND t2.NUM_COMEDORES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumComedores());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumBanosGenerales() != null) {
			where.append(" AND t2.NUM_BAOS_GENERALES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumBanosGenerales());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumConjuntos() != null) {
			where.append(" AND t2.NUM_CONJUNTOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumConjuntos());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumEstudios() != null) {
			where.append(" AND t2.NUM_ESTUDIOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumEstudios());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabDoble() != null) {
			where.append(" AND t2.NUM_HAB_DOBLE = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabDoble());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabIndividuales() != null) {
			where.append(" AND t2.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabIndividuales());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumMaximoSupletorias() != null) {
			where.append(" AND t2.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumMaximoSupletorias());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumPlazas() != null) {
			where.append(" AND t2.NUM_PLAZAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumPlazas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getEdificioCatalogado() != null) {
			where.append(" AND t2.EDIFICIO_CATALOGADO = ?");
			params.add(ab6341s00.getEstablecimientoData().getEdificioCatalogado());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabMas4() != null) {
			where.append(" AND t2.NUM_HAB_MAS_4 = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabMas4());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabMenos4() != null) {
			where.append(" AND t2.NUM_HAB_MENOS_4 = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabMenos4());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getComparteViviendas() != null) {
			where.append(" AND t2.COMPARTE_VIVIENDAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getComparteViviendas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabDobleCs() != null) {
			where.append(" AND t2.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabDobleCs());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumApartamentos() != null) {
			where.append(" AND t2.NUM_APARTAMENTOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumApartamentos());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSuites() != null) {
			where.append(" AND t2.NUM_SUITES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSuites());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getComparteInstal() != null) {
			where.append(" AND t2.COMPARTE_INSTAL = ?");
			params.add(ab6341s00.getEstablecimientoData().getComparteInstal());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumInstalComparte() != null) {
			where.append(" AND t2.NUM_INSTAL_COMPARTE = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumInstalComparte());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSupAcampada() != null) {
			where.append(" AND t2.NUM_SUP_ACAMPADA = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSupAcampada());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getBar() != null) {
			where.append(" AND t2.BAR = ?");
			params.add(ab6341s00.getEstablecimientoData().getBar());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getRestaurante() != null) {
			where.append(" AND t2.RESTAURANTE = ?");
			params.add(ab6341s00.getEstablecimientoData().getRestaurante());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getPiscina() != null) {
			where.append(" AND t2.PISCINA = ?");
			params.add(ab6341s00.getEstablecimientoData().getPiscina());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumTotParcelas() != null) {
			where.append(" AND t2.NUM_TOT_PARCELAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumTotParcelas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasAnf() != null) {
			where.append(" AND t2.NUM_PARCELAS_ANF = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasAnf());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasAf() != null) {
			where.append(" AND t2.NUM_PARCELAS_AF = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasAf());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasSa() != null) {
			where.append(" AND t2.NUM_PARCELAS_SA = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasSa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIndicadorIa() != null) {
			where.append(" AND t2.INDICADOR_IA = ?");
			params.add(ab6341s00.getEstablecimientoData().getIndicadorIa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaControlIa() != null) {
			where.append(" AND t2.FECHA_CONTROL_IA = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaControlIa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getRequisitos() != null) {
			where.append(" AND t2.REQUISITOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getRequisitos());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumControl() != null) {
			where.append(" AND t2.NUM_CONTROL = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumControl());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAntControl() != null) {
			where.append(" AND t2.FECHA_ANT_CONTROL = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAntControl());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabitaciones() != null) {
			where.append(" AND t2.NUM_HABITACIONES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabitaciones());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumResidentesPerm() != null) {
			where.append(" AND t2.NUM_RESIDENTES_PERM = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumResidentesPerm());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getSupTotHabitac() != null) {
			where.append(" AND t2.SUP_TOT_HABITAC = ?");
			params.add(ab6341s00.getEstablecimientoData().getSupTotHabitac());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getSupRestoDepen() != null) {
			where.append(" AND t2.SUP_RESTO_DEPEN = ?");
			params.add(ab6341s00.getEstablecimientoData().getSupRestoDepen());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(ab6341s00.getEstablecimientoData().getUsuarioRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaUltmodificacion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6341s00.getEstablecimientoData().getUsuarioUltmodificacion());
		}
		if (ab6341s00 != null && ab6341s00.getSupDormitorio() != null) {
			where.append(" AND t1.SUP_DORMITORIO = ?");
			params.add(ab6341s00.getSupDormitorio());
		}
		if (ab6341s00 != null && ab6341s00.getPlazasHab() != null) {
			where.append(" AND t1.PLAZAS_HAB = ?");
			params.add(ab6341s00.getPlazasHab());
		}
		if (ab6341s00 != null && ab6341s00.getIdentHabitacion() != null) {
			where.append(" AND t1.IDENT_HABITACION = ?");
			params.add(ab6341s00.getIdentHabitacion());
		}
		if (ab6341s00 != null && ab6341s00.getAccesible() != null) {
			where.append(" AND t1.ACCESIBLE = ?");
			params.add(ab6341s00.getAccesible());
		}
		if (ab6341s00 != null && ab6341s00.getIlumNatural() != null) {
			where.append(" AND t1.ILUM_NATURAL = ?");
			params.add(ab6341s00.getIlumNatural());
		}
		if (ab6341s00 != null && ab6341s00.getVentilacionPatio() != null) {
			where.append(" AND t1.VENTILACION_PATIO = ?");
			params.add(ab6341s00.getVentilacionPatio());
		}
		if (ab6341s00 != null && ab6341s00.getUsoTuristico() != null) {
			where.append(" AND t1.USO_TURISTICO = ?");
			params.add(ab6341s00.getUsoTuristico());
		}
		if (ab6341s00 != null && ab6341s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6341s00.getFechaRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6341s00.getUsuarioRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6341s00.getFechaUltmodificacion());
		}
		if (ab6341s00 != null && ab6341s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6341s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6341s00 entity
	 *
	 * @param ab6341s00
	 *            Ab6341s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(HabitacionVivienda ab6341s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(HabitacionViviendaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6341s00 != null && ab6341s00.getIdHabVivienda() != null) {
			where.append(" AND UPPER(t1.ID_HAB_VIVIENDA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getIdHabVivienda().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getIdHabVivienda().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_HAB_VIVIENDA IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6341s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAnoConstruccion() != null) {
			where.append(" AND t2.FECHA_ANO_CONSTRUCCION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAnoConstruccion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAnoRenovacion() != null) {
			where.append(" AND t2.FECHA_ANO_RENOVACION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAnoRenovacion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getDerechoCocina() != null) {
			where.append(" AND t2.DERECHO_COCINA = ?");
			params.add(ab6341s00.getEstablecimientoData().getDerechoCocina());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getServicioComedor() != null) {
			where.append(" AND t2.SERVICIO_COMEDOR = ?");
			params.add(ab6341s00.getEstablecimientoData().getServicioComedor());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSalones() != null) {
			where.append(" AND t2.NUM_SALONES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSalones());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSalonesComedor() != null) {
			where.append(" AND t2.NUM_SALONES_COMEDOR = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSalonesComedor());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumComedores() != null) {
			where.append(" AND t2.NUM_COMEDORES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumComedores());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumBanosGenerales() != null) {
			where.append(" AND t2.NUM_BAOS_GENERALES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumBanosGenerales());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumConjuntos() != null) {
			where.append(" AND t2.NUM_CONJUNTOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumConjuntos());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumEstudios() != null) {
			where.append(" AND t2.NUM_ESTUDIOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumEstudios());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabDoble() != null) {
			where.append(" AND t2.NUM_HAB_DOBLE = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabDoble());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabIndividuales() != null) {
			where.append(" AND t2.NUM_HAB_INDIVIDUALES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabIndividuales());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumMaximoSupletorias() != null) {
			where.append(" AND t2.NUM_MAXIMO_SUPLETORIAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumMaximoSupletorias());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumPlazas() != null) {
			where.append(" AND t2.NUM_PLAZAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumPlazas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getEdificioCatalogado() != null) {
			where.append(" AND t2.EDIFICIO_CATALOGADO = ?");
			params.add(ab6341s00.getEstablecimientoData().getEdificioCatalogado());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabMas4() != null) {
			where.append(" AND t2.NUM_HAB_MAS_4 = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabMas4());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabMenos4() != null) {
			where.append(" AND t2.NUM_HAB_MENOS_4 = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabMenos4());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getComparteViviendas() != null) {
			where.append(" AND t2.COMPARTE_VIVIENDAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getComparteViviendas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabDobleCs() != null) {
			where.append(" AND t2.NUM_HAB_DOBLE_CS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumHabDobleCs());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumApartamentos() != null) {
			where.append(" AND t2.NUM_APARTAMENTOS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumApartamentos());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSuites() != null) {
			where.append(" AND t2.NUM_SUITES = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSuites());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getComparteInstal() != null) {
			where.append(" AND t2.COMPARTE_INSTAL = ?");
			params.add(ab6341s00.getEstablecimientoData().getComparteInstal());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumInstalComparte() != null) {
			where.append(" AND UPPER(t2.NUM_INSTAL_COMPARTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getNumInstalComparte().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getNumInstalComparte().toUpperCase() + "%");
			}
			where.append(" AND t2.NUM_INSTAL_COMPARTE IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumSupAcampada() != null) {
			where.append(" AND t2.NUM_SUP_ACAMPADA = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumSupAcampada());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getBar() != null) {
			where.append(" AND t2.BAR = ?");
			params.add(ab6341s00.getEstablecimientoData().getBar());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getRestaurante() != null) {
			where.append(" AND t2.RESTAURANTE = ?");
			params.add(ab6341s00.getEstablecimientoData().getRestaurante());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getPiscina() != null) {
			where.append(" AND t2.PISCINA = ?");
			params.add(ab6341s00.getEstablecimientoData().getPiscina());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumTotParcelas() != null) {
			where.append(" AND t2.NUM_TOT_PARCELAS = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumTotParcelas());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasAnf() != null) {
			where.append(" AND t2.NUM_PARCELAS_ANF = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasAnf());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasAf() != null) {
			where.append(" AND t2.NUM_PARCELAS_AF = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasAf());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumParcelasSa() != null) {
			where.append(" AND t2.NUM_PARCELAS_SA = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumParcelasSa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getIndicadorIa() != null) {
			where.append(" AND t2.INDICADOR_IA = ?");
			params.add(ab6341s00.getEstablecimientoData().getIndicadorIa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaControlIa() != null) {
			where.append(" AND t2.FECHA_CONTROL_IA = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaControlIa());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getRequisitos() != null) {
			where.append(" AND UPPER(t2.REQUISITOS) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getRequisitos().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getRequisitos().toUpperCase() + "%");
			}
			where.append(" AND t2.REQUISITOS IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumControl() != null) {
			where.append(" AND t2.NUM_CONTROL = ?");
			params.add(ab6341s00.getEstablecimientoData().getNumControl());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaAntControl() != null) {
			where.append(" AND t2.FECHA_ANT_CONTROL = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaAntControl());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumHabitaciones() != null) {
			where.append(" AND UPPER(t2.NUM_HABITACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getNumHabitaciones().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getNumHabitaciones().toUpperCase() + "%");
			}
			where.append(" AND t2.NUM_HABITACIONES IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getNumResidentesPerm() != null) {
			where.append(" AND UPPER(t2.NUM_RESIDENTES_PERM) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getNumResidentesPerm().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getNumResidentesPerm().toUpperCase() + "%");
			}
			where.append(" AND t2.NUM_RESIDENTES_PERM IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getSupTotHabitac() != null) {
			where.append(" AND UPPER(t2.SUP_TOT_HABITAC) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getSupTotHabitac().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getSupTotHabitac().toUpperCase() + "%");
			}
			where.append(" AND t2.SUP_TOT_HABITAC IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getSupRestoDepen() != null) {
			where.append(" AND t2.SUP_RESTO_DEPEN = ? ");
			params.add(ab6341s00.getEstablecimientoData().getSupRestoDepen());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(ab6341s00.getEstablecimientoData().getFechaUltmodificacion());
		}
		if (ab6341s00 != null && ab6341s00.getEstablecimientoData() != null
				&& ab6341s00.getEstablecimientoData().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getEstablecimientoData().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getEstablecimientoData().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getSupDormitorio() != null) {
			where.append(" AND t1.SUP_DORMITORIO = ? ");
			params.add(ab6341s00.getSupDormitorio());
		}
		if (ab6341s00 != null && ab6341s00.getPlazasHab() != null) {
			where.append(" AND UPPER(t1.PLAZAS_HAB) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getPlazasHab().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getPlazasHab().toUpperCase() + "%");
			}
			where.append(" AND t1.PLAZAS_HAB IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getIdentHabitacion() != null) {
			where.append(" AND UPPER(t1.IDENT_HABITACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getIdentHabitacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getIdentHabitacion().toUpperCase() + "%");
			}
			where.append(" AND t1.IDENT_HABITACION IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getAccesible() != null) {
			where.append(" AND UPPER(t1.ACCESIBLE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getAccesible().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getAccesible().toUpperCase() + "%");
			}
			where.append(" AND t1.ACCESIBLE IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getIlumNatural() != null) {
			where.append(" AND UPPER(t1.ILUM_NATURAL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getIlumNatural().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getIlumNatural().toUpperCase() + "%");
			}
			where.append(" AND t1.ILUM_NATURAL IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getVentilacionPatio() != null) {
			where.append(" AND UPPER(t1.VENTILACION_PATIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getVentilacionPatio().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getVentilacionPatio().toUpperCase() + "%");
			}
			where.append(" AND t1.VENTILACION_PATIO IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getUsoTuristico() != null) {
			where.append(" AND UPPER(t1.USO_TURISTICO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getUsoTuristico().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getUsoTuristico().toUpperCase() + "%");
			}
			where.append(" AND t1.USO_TURISTICO IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6341s00.getFechaRegistro());
		}
		if (ab6341s00 != null && ab6341s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6341s00 != null && ab6341s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6341s00.getFechaUltmodificacion());
		}
		if (ab6341s00 != null && ab6341s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6341s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6341s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
