package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.Recurso;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6300s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RecursoDaoImpl implements RecursoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRECURSO", "TIPORECURSO", "DESCNOMBRE",
			"FECHABAJA", "NUMREGISTRO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Recurso> rwMap = new RowMapper<Recurso>() {
		public Recurso mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Recurso(resultSet.getString("IDRECURSO"), resultSet.getString("TIPORECURSO"),
					resultSet.getString("DESCNOMBRE"), resultSet.getDate("FECHABAJA"),
					resultSet.getString("NUMREGISTRO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<Recurso> rwMapPK = new RowMapper<Recurso>() {
		public Recurso mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Recurso(resultSet.getString("IDRECURSO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Recurso>> rwMapJerarquia = new RowMapper<JerarquiaDto<Recurso>>() {
		public JerarquiaDto<Recurso> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Recurso ab6300s00 = new Recurso(resultSet.getString("IDRECURSO"), resultSet.getString("TIPORECURSO"),
					resultSet.getString("DESCNOMBRE"), resultSet.getDate("FECHABAJA"),
					resultSet.getString("NUMREGISTRO"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<Recurso> jerarquia = new JerarquiaDto<Recurso>();
			jerarquia.setModel(ab6300s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @return Ab6300s00
	 */
	public Recurso add(Recurso ab6300s00) {
		String query = "INSERT INTO AB6300S00 (ID_RECURSO, TIPO_RECURSO, DESC_NOMBRE, FECHA_BAJA, NUM_REGISTRO, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, ab6300s00.getIdRecurso(), ab6300s00.getTipoRecurso(), ab6300s00.getDescNombre(),
				ab6300s00.getFechaBaja(), ab6300s00.getNumRegistro(), ab6300s00.getFechaRegistro(),
				ab6300s00.getUsuarioRegistro(), ab6300s00.getFechaUltmodificacion(),
				ab6300s00.getUsuarioUltmodificacion());
		return ab6300s00;
	}

	/**
	 * Updates a single row in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @return Ab6300s00
	 */
	public Recurso update(Recurso ab6300s00) {
		String query = "UPDATE AB6300S00 SET TIPO_RECURSO=?, DESC_NOMBRE=?, FECHA_BAJA=?, NUM_REGISTRO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_RECURSO=?";
		this.jdbcTemplate.update(query, ab6300s00.getTipoRecurso(), ab6300s00.getDescNombre(), ab6300s00.getFechaBaja(),
				ab6300s00.getNumRegistro(), ab6300s00.getFechaRegistro(), ab6300s00.getUsuarioRegistro(),
				ab6300s00.getFechaUltmodificacion(), ab6300s00.getUsuarioUltmodificacion(), ab6300s00.getIdRecurso());
		return ab6300s00;
	}

	/**
	 * Finds a single row in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @return Ab6300s00
	 */
	@Transactional(readOnly = true)
	public Recurso find(Recurso ab6300s00) {
		String query = "SELECT t1.ID_RECURSO IDRECURSO, t1.TIPO_RECURSO TIPORECURSO, t1.DESC_NOMBRE DESCNOMBRE, t1.FECHA_BAJA FECHABAJA, t1.NUM_REGISTRO NUMREGISTRO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6300S00 t1  WHERE t1.ID_RECURSO = ?  ";

		List<Recurso> ab6300s00List = this.jdbcTemplate.query(query, this.rwMap, ab6300s00.getIdRecurso());
		return (Recurso) DataAccessUtils.uniqueResult(ab6300s00List);
	}

	/**
	 * Removes a single row in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @return
	 */
	public void remove(Recurso ab6300s00) {
		String query = "DELETE FROM AB6300S00 WHERE ID_RECURSO=?";
		this.jdbcTemplate.update(query, ab6300s00.getIdRecurso());
	}

	/**
	 * Finds a list of rows in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6300s00>
	 */
	@Transactional(readOnly = true)
	public List<Recurso> findAll(Recurso ab6300s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6300S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6300s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RecursoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Recurso>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6300s00 table using like.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6300s00>
	 */
	@Transactional(readOnly = true)
	public List<Recurso> findAllLike(Recurso ab6300s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6300S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6300s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RecursoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Recurso>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6300s00 table.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Recurso ab6300s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6300S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6300s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6300s00 table using like.
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Recurso ab6300s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6300S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6300s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6300s00 selected for rup_table
	 *
	 * @param ab6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6300s00>>
	 */
	@Override
	public List<TableRowDto<Recurso>> reorderSelection(Recurso ab6300s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6300S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6300s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, Recurso.class,
				filterParamList, "ID_RECURSO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Recurso>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6300s00
	 * @param searchParams
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6300s00>>
	 */
	@Override
	public List<TableRowDto<Recurso>> search(Recurso filterParams, Recurso searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6300S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, Recurso.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_RECURSO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Recurso>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Recurso filterab6300s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6300S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6300s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Recurso.class, query,
				params, "ID_RECURSO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6300s00 table.
	 *
	 * @param filterAb6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6300s00>>
	 */
	@Override
	public List<JerarquiaDto<Recurso>> findAllLikeJerarquia(Recurso filterAb6300s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_RECURSO IDRECURSO,t1.TIPO_RECURSO TIPORECURSO,t1.DESC_NOMBRE DESCNOMBRE,t1.FECHA_BAJA FECHABAJA,t1.NUM_REGISTRO NUMREGISTRO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6300S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6300S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6300s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_RECURSO", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					RecursoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Recurso filterAb6300s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6300S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6300S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6300s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_RECURSO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6300s00
	 *            Ab6300s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6300s00>>
	 */
	@Override
	public List<TableRowDto<Recurso>> findAllChild(Recurso filterAb6300s00, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6300S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6300S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6300s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_RECURSO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Recurso>(this.rwMapPK, "ID_RECURSO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6300s00 entity
	 *
	 * @param ab6300s00
	 *            Ab6300s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Recurso ab6300s00) {

		StringBuilder where = new StringBuilder(RecursoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6300s00 != null && ab6300s00.getIdRecurso() != null) {
			where.append(" AND t1.ID_RECURSO = ?");
			params.add(ab6300s00.getIdRecurso());
		}
		if (ab6300s00 != null && ab6300s00.getTipoRecurso() != null) {
			where.append(" AND t1.TIPO_RECURSO = ?");
			params.add(ab6300s00.getTipoRecurso());
		}
		if (ab6300s00 != null && ab6300s00.getDescNombre() != null) {
			where.append(" AND t1.DESC_NOMBRE = ?");
			params.add(ab6300s00.getDescNombre());
		}
		if (ab6300s00 != null && ab6300s00.getFechaBaja() != null) {
			where.append(" AND t1.FECHA_BAJA = ?");
			params.add(ab6300s00.getFechaBaja());
		}
		if (ab6300s00 != null && ab6300s00.getNumRegistro() != null) {
			where.append(" AND t1.NUM_REGISTRO = ?");
			params.add(ab6300s00.getNumRegistro());
		}
		if (ab6300s00 != null && ab6300s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6300s00.getFechaRegistro());
		}
		if (ab6300s00 != null && ab6300s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6300s00.getUsuarioRegistro());
		}
		if (ab6300s00 != null && ab6300s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6300s00.getFechaUltmodificacion());
		}
		if (ab6300s00 != null && ab6300s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6300s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6300s00 entity
	 *
	 * @param ab6300s00
	 *            Ab6300s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Recurso ab6300s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RecursoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6300s00 != null && ab6300s00.getIdRecurso() != null) {
			where.append(" AND UPPER(t1.ID_RECURSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getIdRecurso().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getIdRecurso().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_RECURSO IS NOT NULL");
		}
		if (ab6300s00 != null && ab6300s00.getTipoRecurso() != null) {
			where.append(" AND UPPER(t1.TIPO_RECURSO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getTipoRecurso().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getTipoRecurso().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPO_RECURSO IS NOT NULL");
		}
		if (ab6300s00 != null && ab6300s00.getDescNombre() != null) {
			where.append(" AND UPPER(t1.DESC_NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getDescNombre().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getDescNombre().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_NOMBRE IS NOT NULL");
		}
		if (ab6300s00 != null && ab6300s00.getFechaBaja() != null) {
			where.append(" AND t1.FECHA_BAJA = ?");
			params.add(ab6300s00.getFechaBaja());
		}
		if (ab6300s00 != null && ab6300s00.getNumRegistro() != null) {
			where.append(" AND UPPER(t1.NUM_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getNumRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getNumRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.NUM_REGISTRO IS NOT NULL");
		}
		if (ab6300s00 != null && ab6300s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6300s00.getFechaRegistro());
		}
		if (ab6300s00 != null && ab6300s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6300s00 != null && ab6300s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6300s00.getFechaUltmodificacion());
		}
		if (ab6300s00 != null && ab6300s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6300s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6300s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
