package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6311s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TipoEstablecimientoDaoImpl implements TipoEstablecimientoDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOESTABLECIMIENTO", "DESCTIPOES",
			"FECHAMODIFICACION", "NOMUSUARIO", "BAJA", "DESCTIPOEU", "ORDENACION", "TIPIFICACION", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "PROCLEYES", "PROCLEYEU", "PROCDECES",
			"PROCDECEU" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TipoEstablecimiento> rwMap = new RowMapper<TipoEstablecimiento>() {
		public TipoEstablecimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoEstablecimiento(resultSet.getString("IDTIPOESTABLECIMIENTO"),
					resultSet.getString("DESCTIPOES"), resultSet.getDate("FECHAMODIFICACION"),
					resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"), resultSet.getString("DESCTIPOEU"),
					resultSet.getString("ORDENACION"), resultSet.getString("TIPIFICACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getString("PROCLEYES"), resultSet.getString("PROCLEYEU"),
					resultSet.getString("PROCDECES"), resultSet.getString("PROCDECEU"));
		}
	};

	private RowMapper<TipoEstablecimiento> rwMapPK = new RowMapper<TipoEstablecimiento>() {
		public TipoEstablecimiento mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoEstablecimiento(resultSet.getString("IDTIPOESTABLECIMIENTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TipoEstablecimiento>> rwMapJerarquia = new RowMapper<JerarquiaDto<TipoEstablecimiento>>() {
		public JerarquiaDto<TipoEstablecimiento> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TipoEstablecimiento ab6311s00 = new TipoEstablecimiento(resultSet.getString("IDTIPOESTABLECIMIENTO"),
					resultSet.getString("DESCTIPOES"), resultSet.getDate("FECHAMODIFICACION"),
					resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"), resultSet.getString("DESCTIPOEU"),
					resultSet.getString("ORDENACION"), resultSet.getString("TIPIFICACION"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"), null,
					null, null, null);

			JerarquiaDto<TipoEstablecimiento> jerarquia = new JerarquiaDto<TipoEstablecimiento>();
			jerarquia.setModel(ab6311s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	public TipoEstablecimiento add(TipoEstablecimiento ab6311s00) {
		String query = "INSERT INTO AB6311S00 (ID_TIPO_ESTABLECIMIENTO, DESC_TIPO_ES, BAJA, DESC_TIPO_EU, ORDENACION, TIPIFICACION, FECHA_REGISTRO, USUARIO_REGISTRO, PROCEDIMIENTO_LEY, PROCEDIMIENTO_LEY_EU, PROCEDIMIENTO_DECRETO, PROCEDIMIENTO_DECRETO_EU) VALUES (?,?,?,?,?,?,SYSDATE,?,?,?,?,?)";
		this.jdbcTemplate.update(query, ab6311s00.getIdTipoEstablecimiento(), ab6311s00.getDescTipoEs(),
				ab6311s00.getBaja(), ab6311s00.getDescTipoEu(), ab6311s00.getOrdenacion(), ab6311s00.getTipificacion(),
				PermisosXLNETS.getUserConnected(), ab6311s00.getProcedimientoLeyEs(), ab6311s00.getProcedimientoLeyEu(),
				ab6311s00.getProcedimientoDecretoEs(), ab6311s00.getProcedimientoDecretoEu());
		return ab6311s00;
	}

	/**
	 * Updates a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	public TipoEstablecimiento update(TipoEstablecimiento ab6311s00) {
		String query = "UPDATE AB6311S00 SET DESC_TIPO_ES=?, DESC_TIPO_EU=?, BAJA=?, ORDENACION=?, TIPIFICACION=?, PROCEDIMIENTO_LEY=?, PROCEDIMIENTO_LEY_EU=?, PROCEDIMIENTO_DECRETO=?, PROCEDIMIENTO_DECRETO_EU=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_TIPO_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6311s00.getDescTipoEs(), ab6311s00.getDescTipoEu(), ab6311s00.getBaja(),
				ab6311s00.getOrdenacion(), ab6311s00.getTipificacion(), ab6311s00.getProcedimientoLeyEs(),
				ab6311s00.getProcedimientoLeyEu(), ab6311s00.getProcedimientoDecretoEs(),
				ab6311s00.getProcedimientoDecretoEu(), PermisosXLNETS.getUserConnected(),
				ab6311s00.getIdTipoEstablecimiento());
		return ab6311s00;
	}

	/**
	 * Finds a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	@Transactional(readOnly = true)
	public TipoEstablecimiento find(TipoEstablecimiento ab6311s00) {
		String query = "SELECT t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO, t1.DESC_TIPO_ES DESCTIPOES, t1.FECHA_MODIFICACION FECHAMODIFICACION, t1.NOM_USUARIO NOMUSUARIO, t1.BAJA BAJA, t1.DESC_TIPO_EU DESCTIPOEU, t1.ORDENACION ORDENACION, t1.TIPIFICACION TIPIFICACION, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.PROCEDIMIENTO_LEY PROCLEYES, t1.PROCEDIMIENTO_LEY_EU PROCLEYEU, t1.PROCEDIMIENTO_DECRETO PROCDECES, t1.PROCEDIMIENTO_DECRETO_EU PROCDECEU FROM AB6311S00 t1  WHERE t1.ID_TIPO_ESTABLECIMIENTO = ?  ";

		List<TipoEstablecimiento> ab6311s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6311s00.getIdTipoEstablecimiento());
		return (TipoEstablecimiento) DataAccessUtils.uniqueResult(ab6311s00List);
	}

	/**
	 * Removes a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return
	 */
	public void remove(TipoEstablecimiento ab6311s00) {
		String query = "DELETE FROM AB6311S00 WHERE ID_TIPO_ESTABLECIMIENTO=?";
		this.jdbcTemplate.update(query, ab6311s00.getIdTipoEstablecimiento());
	}

	/**
	 * Finds a list of rows in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6311s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoEstablecimiento> findAll(TipoEstablecimiento ab6311s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.PROCEDIMIENTO_LEY PROCLEYES, t1.PROCEDIMIENTO_LEY_EU PROCLEYEU, t1.PROCEDIMIENTO_DECRETO PROCDECES, t1.PROCEDIMIENTO_DECRETO_EU PROCDECEU ");
		query.append("FROM AB6311S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6311s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TipoEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoEstablecimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6311s00 table using like.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6311s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoEstablecimiento> findAllLike(TipoEstablecimiento ab6311s00, TableRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.PROCEDIMIENTO_LEY PROCLEYES, t1.PROCEDIMIENTO_LEY_EU PROCLEYEU, t1.PROCEDIMIENTO_DECRETO PROCDECES, t1.PROCEDIMIENTO_DECRETO_EU PROCDECEU ");
		query.append("FROM AB6311S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6311s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = TableManager.getPaginationQuery(jqGridRequestDto, query,
					TipoEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoEstablecimiento>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TipoEstablecimiento ab6311s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6311S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6311s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6311s00 table using like.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TipoEstablecimiento ab6311s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6311S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6311s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6311s00 selected for rup_table
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6311s00>>
	 */
	@Override
	public List<TableRowDto<TipoEstablecimiento>> reorderSelection(TipoEstablecimiento ab6311s00,
			TableRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6311S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6311s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, jqGridRequestDto,
				TipoEstablecimiento.class, filterParamList, "IDTIPOESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoEstablecimiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6311s00
	 * @param searchParams
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6311s00>>
	 */
	@Override
	public List<TableRowDto<TipoEstablecimiento>> search(TipoEstablecimiento filterParams,
			TipoEstablecimiento searchParams, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6311S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TipoEstablecimiento.class, filterParamList, searchSQL, searchParamList, from_alias,
				"ID_TIPO_ESTABLECIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoEstablecimiento>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TipoEstablecimiento filterab6311s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6311S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6311s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				TipoEstablecimiento.class, query, params, "ID_TIPO_ESTABLECIMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6311s00>>
	 */
	@Override
	public List<JerarquiaDto<TipoEstablecimiento>> findAllLikeJerarquia(TipoEstablecimiento filterAb6311s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_ESTABLECIMIENTO IDTIPOESTABLECIMIENTO,t1.DESC_TIPO_ES DESCTIPOES,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.ORDENACION ORDENACION,t1.TIPIFICACION TIPIFICACION,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6311S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6311S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6311s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_ESTABLECIMIENTO",
				"ID_PADRE", "NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TipoEstablecimientoDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TipoEstablecimiento filterAb6311s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6311S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6311S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6311s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
				"ID_TIPO_ESTABLECIMIENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6311s00>>
	 */
	@Override
	public List<TableRowDto<TipoEstablecimiento>> findAllChild(TipoEstablecimiento filterAb6311s00,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6311S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6311S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6311s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
				"ID_TIPO_ESTABLECIMIENTO", "ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TipoEstablecimiento>(this.rwMapPK, "ID_TIPO_ESTABLECIMIENTO"),
				params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6311s00 entity
	 *
	 * @param ab6311s00
	 *            Ab6311s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TipoEstablecimiento ab6311s00) {

		StringBuilder where = new StringBuilder(TipoEstablecimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6311s00 != null && ab6311s00.getIdTipoEstablecimiento() != null) {
			where.append(" AND t1.ID_TIPO_ESTABLECIMIENTO = ?");
			params.add(ab6311s00.getIdTipoEstablecimiento());
		}
		if (ab6311s00 != null && ab6311s00.getDescTipoEs() != null) {
			where.append(" AND t1.DESC_TIPO_ES = ?");
			params.add(ab6311s00.getDescTipoEs());
		}
		if (ab6311s00 != null && ab6311s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6311s00.getFechaModificacion());
		}
		if (ab6311s00 != null && ab6311s00.getNomUsuario() != null) {
			where.append(" AND t1.NOM_USUARIO = ?");
			params.add(ab6311s00.getNomUsuario());
		}
		if (ab6311s00 != null && ab6311s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6311s00.getBaja());
		}
		if (ab6311s00 != null && ab6311s00.getDescTipoEu() != null) {
			where.append(" AND t1.DESC_TIPO_EU = ?");
			params.add(ab6311s00.getDescTipoEu());
		}
		if (ab6311s00 != null && ab6311s00.getOrdenacion() != null) {
			where.append(" AND t1.ORDENACION = ?");
			params.add(ab6311s00.getOrdenacion());
		}
		if (ab6311s00 != null && ab6311s00.getTipificacion() != null) {
			where.append(" AND t1.TIPIFICACION = ?");
			params.add(ab6311s00.getTipificacion());
		}
		if (ab6311s00 != null && ab6311s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6311s00.getFechaRegistro());
		}
		if (ab6311s00 != null && ab6311s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6311s00.getUsuarioRegistro());
		}
		if (ab6311s00 != null && ab6311s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6311s00.getFechaUltmodificacion());
		}
		if (ab6311s00 != null && ab6311s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6311s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6311s00 entity
	 *
	 * @param ab6311s00
	 *            Ab6311s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TipoEstablecimiento ab6311s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TipoEstablecimientoDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6311s00 != null && ab6311s00.getIdTipoEstablecimiento() != null) {
			where.append(" AND UPPER(t1.ID_TIPO_ESTABLECIMIENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getIdTipoEstablecimiento().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getIdTipoEstablecimiento().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_TIPO_ESTABLECIMIENTO IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getDescTipoEs() != null) {
			where.append(" AND UPPER(t1.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6311s00.getFechaModificacion());
		}
		if (ab6311s00 != null && ab6311s00.getNomUsuario() != null) {
			where.append(" AND UPPER(t1.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t1.NOM_USUARIO IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6311s00.getBaja());
		}
		if (ab6311s00 != null && ab6311s00.getDescTipoEu() != null) {
			where.append(" AND UPPER(t1.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getOrdenacion() != null) {
			where.append(" AND UPPER(t1.ORDENACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getOrdenacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getOrdenacion().toUpperCase() + "%");
			}
			where.append(" AND t1.ORDENACION IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getTipificacion() != null) {
			where.append(" AND UPPER(t1.TIPIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getTipificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getTipificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.TIPIFICACION IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6311s00.getFechaRegistro());
		}
		if (ab6311s00 != null && ab6311s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6311s00 != null && ab6311s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6311s00.getFechaUltmodificacion());
		}
		if (ab6311s00 != null && ab6311s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		if (ab6311s00 != null && ab6311s00.getProcedimientoLeyEs() != null) {
			where.append(" AND UPPER(t1.PROCEDIMIENTO_LEY) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getProcedimientoLeyEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getProcedimientoLeyEs().toUpperCase() + "%");
			}
			where.append(" AND t1.PROCEDIMIENTO_LEY IS NOT NULL");
		}

		if (ab6311s00 != null && ab6311s00.getProcedimientoLeyEu() != null) {
			where.append(" AND UPPER(t1.PROCEDIMIENTO_LEY_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getProcedimientoLeyEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getProcedimientoLeyEu().toUpperCase() + "%");
			}
			where.append(" AND t1.PROCEDIMIENTO_LEY_EU IS NOT NULL");
		}

		if (ab6311s00 != null && ab6311s00.getProcedimientoDecretoEs() != null) {
			where.append(" AND UPPER(t1.PROCEDIMIENTO_DECRETO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getProcedimientoDecretoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getProcedimientoDecretoEs().toUpperCase() + "%");
			}
			where.append(" AND t1.PROCEDIMIENTO_DECRETO IS NOT NULL");
		}

		if (ab6311s00 != null && ab6311s00.getProcedimientoDecretoEu() != null) {
			where.append(" AND UPPER(t1.PROCEDIMIENTO_DECRETO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6311s00.getProcedimientoDecretoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6311s00.getProcedimientoDecretoEu().toUpperCase() + "%");
			}
			where.append(" AND t1.PROCEDIMIENTO_DECRETO_EU IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
