package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.TipoFranquicia;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6336s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TipoFranquiciaDaoImpl implements TipoFranquiciaDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDFRANQUICIA", "DESCFRANQUICIAES",
			"DESCFRANQUICIAEU", "BAJA", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TipoFranquicia> rwMap = new RowMapper<TipoFranquicia>() {
		public TipoFranquicia mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoFranquicia(resultSet.getLong("IDFRANQUICIA"), resultSet.getString("DESCFRANQUICIAES"),
					resultSet.getString("DESCFRANQUICIAEU"), resultSet.getInt("BAJA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<TipoFranquicia> rwMapPK = new RowMapper<TipoFranquicia>() {
		public TipoFranquicia mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoFranquicia(resultSet.getLong("IDFRANQUICIA"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TipoFranquicia>> rwMapJerarquia = new RowMapper<JerarquiaDto<TipoFranquicia>>() {
		public JerarquiaDto<TipoFranquicia> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TipoFranquicia ab6336s00 = new TipoFranquicia(resultSet.getLong("IDFRANQUICIA"),
					resultSet.getString("DESCFRANQUICIAES"), resultSet.getString("DESCFRANQUICIAEU"),
					resultSet.getInt("BAJA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<TipoFranquicia> jerarquia = new JerarquiaDto<TipoFranquicia>();
			jerarquia.setModel(ab6336s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @return Ab6336s00
	 */
	public TipoFranquicia add(TipoFranquicia ab6336s00) {
		String query = "INSERT INTO AB6336S00 (ID_FRANQUICIA, DESC_FRANQUICIA_ES, DESC_FRANQUICIA_EU, BAJA, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_ULTMODIFICACION, USUARIO_ULTMODIFICACION) VALUES (?,?,?,?,?,?,?,?)";
		this.jdbcTemplate.update(query, ab6336s00.getIdFranquicia(), ab6336s00.getDescFranquiciaEs(),
				ab6336s00.getDescFranquiciaEu(), ab6336s00.getBaja(), ab6336s00.getFechaRegistro(),
				ab6336s00.getUsuarioRegistro(), ab6336s00.getFechaUltmodificacion(),
				ab6336s00.getUsuarioUltmodificacion());
		return ab6336s00;
	}

	/**
	 * Updates a single row in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @return Ab6336s00
	 */
	public TipoFranquicia update(TipoFranquicia ab6336s00) {
		String query = "UPDATE AB6336S00 SET DESC_FRANQUICIA_ES=?, DESC_FRANQUICIA_EU=?, BAJA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_FRANQUICIA=?";
		this.jdbcTemplate.update(query, ab6336s00.getDescFranquiciaEs(), ab6336s00.getDescFranquiciaEu(),
				ab6336s00.getBaja(), ab6336s00.getFechaRegistro(), ab6336s00.getUsuarioRegistro(),
				ab6336s00.getFechaUltmodificacion(), ab6336s00.getUsuarioUltmodificacion(),
				ab6336s00.getIdFranquicia());
		return ab6336s00;
	}

	/**
	 * Finds a single row in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @return Ab6336s00
	 */
	@Transactional(readOnly = true)
	public TipoFranquicia find(TipoFranquicia ab6336s00) {
		String query = "SELECT t1.ID_FRANQUICIA IDFRANQUICIA, t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES, t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU, t1.BAJA BAJA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6336S00 t1  WHERE t1.ID_FRANQUICIA = ?  ";

		List<TipoFranquicia> ab6336s00List = this.jdbcTemplate.query(query, this.rwMap, ab6336s00.getIdFranquicia());
		return (TipoFranquicia) DataAccessUtils.uniqueResult(ab6336s00List);
	}

	/**
	 * Removes a single row in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @return
	 */
	public void remove(TipoFranquicia ab6336s00) {
		String query = "DELETE FROM AB6336S00 WHERE ID_FRANQUICIA=?";
		this.jdbcTemplate.update(query, ab6336s00.getIdFranquicia());
	}

	/**
	 * Exporta Datos al clipBoard
	 *
	 */
	public List<TipoFranquicia> getMultiple(TipoFranquicia filterAb6336s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {

		// Where clause & Params
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterAb6336s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbMultipleSQL = TableManager.getSelectMultipleQuery(tableRequestDto, TipoFranquicia.class, params,
				"ID_FRANQUICIA");

		return this.jdbcTemplate.query(sbMultipleSQL.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds a list of rows in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<Ab6336s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoFranquicia> findAll(TipoFranquicia ab6336s00, TableRequestDto tableRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6336S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6336s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, TipoFranquiciaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoFranquicia>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6336s00 table using like.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6336s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoFranquicia> findAllLike(TipoFranquicia ab6336s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6336S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6336s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, TipoFranquiciaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoFranquicia>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6336s00 table.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TipoFranquicia ab6336s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6336S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6336s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6336s00 table using like.
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TipoFranquicia ab6336s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6336S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6336s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6336s00 selected for rup_table
	 *
	 * @param ab6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6336s00>>
	 */
	@Override
	public List<TableRowDto<TipoFranquicia>> reorderSelection(TipoFranquicia ab6336s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6336S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6336s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, tableRequestDto, TipoFranquicia.class,
				filterParamList, "IDFRANQUICIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoFranquicia>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6336s00
	 * @param searchParams
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6336s00>>
	 */
	@Override
	public List<TableRowDto<TipoFranquicia>> search(TipoFranquicia filterParams, TipoFranquicia searchParams,
			TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6336S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, tableRequestDto, TipoFranquicia.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_FRANQUICIA");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoFranquicia>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TipoFranquicia filterab6336s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6336S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6336s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(tableRequestDto, TipoFranquicia.class,
				query, params, "ID_FRANQUICIA");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6336s00 table.
	 *
	 * @param filterAb6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<JerarquiaDto<Ab6336s00>>
	 */
	@Override
	public List<JerarquiaDto<TipoFranquicia>> findAllLikeJerarquia(TipoFranquicia filterAb6336s00,
			TableRequestDto tableRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_FRANQUICIA IDFRANQUICIA,t1.DESC_FRANQUICIA_ES DESCFRANQUICIAES,t1.DESC_FRANQUICIA_EU DESCFRANQUICIAEU,t1.BAJA BAJA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6336S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6336S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6336s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = TableManagerJerarquia.getQuery(tableRequestDto, query, mapaWhere, "ID_FRANQUICIA", "ID_PADRE", "NOMBRE",
				from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = TableManagerJerarquia.getQuery(tableRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (tableRequestDto != null) {
			query = TableManagerJerarquia.getPaginationQuery(tableRequestDto, query,
					TipoFranquiciaDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TipoFranquicia filterAb6336s00, TableRequestDto tableRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6336S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6336S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6336s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere, "ID_FRANQUICIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// TableManagerJerarquia.getQueryCount(tableRequestDto, mapaWhere, "ID",
		// "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6336s00
	 *            Ab6336s00
	 * @param tableRequestDto
	 *            TableRequestDto
	 * @return List<TableRowDto<Ab6336s00>>
	 */
	@Override
	public List<TableRowDto<TipoFranquicia>> findAllChild(TipoFranquicia filterAb6336s00,
			TableRequestDto tableRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6336S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6336S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6336s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "ID_FRANQUICIA",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TipoFranquicia>(this.rwMapPK, "ID_FRANQUICIA"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6336s00 entity
	 *
	 * @param ab6336s00
	 *            Ab6336s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TipoFranquicia ab6336s00) {

		StringBuilder where = new StringBuilder(TipoFranquiciaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6336s00 != null && ab6336s00.getIdFranquicia() != null) {
			where.append(" AND t1.ID_FRANQUICIA = ?");
			params.add(ab6336s00.getIdFranquicia());
		}
		if (ab6336s00 != null && ab6336s00.getDescFranquiciaEs() != null) {
			where.append(" AND t1.DESC_FRANQUICIA_ES = ?");
			params.add(ab6336s00.getDescFranquiciaEs());
		}
		if (ab6336s00 != null && ab6336s00.getDescFranquiciaEu() != null) {
			where.append(" AND t1.DESC_FRANQUICIA_EU = ?");
			params.add(ab6336s00.getDescFranquiciaEu());
		}
		if (ab6336s00 != null && ab6336s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6336s00.getBaja());
		}
		if (ab6336s00 != null && ab6336s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6336s00.getFechaRegistro());
		}
		if (ab6336s00 != null && ab6336s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6336s00.getUsuarioRegistro());
		}
		if (ab6336s00 != null && ab6336s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6336s00.getFechaUltmodificacion());
		}
		if (ab6336s00 != null && ab6336s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6336s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6336s00 entity
	 *
	 * @param ab6336s00
	 *            Ab6336s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TipoFranquicia ab6336s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TipoFranquiciaDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6336s00 != null && ab6336s00.getIdFranquicia() != null) {
			where.append(" AND t1.ID_FRANQUICIA = ?");
			params.add(ab6336s00.getIdFranquicia());
		}
		if (ab6336s00 != null && ab6336s00.getDescFranquiciaEs() != null) {
			where.append(" AND UPPER(t1.DESC_FRANQUICIA_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6336s00.getDescFranquiciaEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6336s00.getDescFranquiciaEs().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_FRANQUICIA_ES IS NOT NULL");
		}
		if (ab6336s00 != null && ab6336s00.getDescFranquiciaEu() != null) {
			where.append(" AND UPPER(t1.DESC_FRANQUICIA_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6336s00.getDescFranquiciaEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6336s00.getDescFranquiciaEu().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_FRANQUICIA_EU IS NOT NULL");
		}
		if (ab6336s00 != null && ab6336s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6336s00.getBaja());
		}
		if (ab6336s00 != null && ab6336s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6336s00.getFechaRegistro());
		}
		if (ab6336s00 != null && ab6336s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6336s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6336s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6336s00 != null && ab6336s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6336s00.getFechaUltmodificacion());
		}
		if (ab6336s00 != null && ab6336s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6336s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6336s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
