package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.TipoHabitacion;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6317s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TipoHabitacionDaoImpl implements TipoHabitacionDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOHABITACION", "INDIVDOBL", "DESCTIPOES",
			"CONSALON", "NUMPLAZAS", "FECHAMODIFICACION", "NOMUSUARIO", "BAJA", "DESCTIPOEU", "FECHAREGISTRO",
			"USUARIOREGISTRO", "FECHAULTMODIFICACION", "USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TipoHabitacion> rwMap = new RowMapper<TipoHabitacion>() {
		public TipoHabitacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoHabitacion(resultSet.getString("IDTIPOHABITACION"), resultSet.getString("INDIVDOBL"),
					resultSet.getString("DESCTIPOES"), resultSet.getInt("CONSALON"), resultSet.getLong("NUMPLAZAS"),
					resultSet.getDate("FECHAMODIFICACION"), resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"),
					resultSet.getString("DESCTIPOEU"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<TipoHabitacion> rwMapPK = new RowMapper<TipoHabitacion>() {
		public TipoHabitacion mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TipoHabitacion(resultSet.getString("IDTIPOHABITACION"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TipoHabitacion>> rwMapJerarquia = new RowMapper<JerarquiaDto<TipoHabitacion>>() {
		public JerarquiaDto<TipoHabitacion> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TipoHabitacion ab6317s00 = new TipoHabitacion(resultSet.getString("IDTIPOHABITACION"),
					resultSet.getString("INDIVDOBL"), resultSet.getString("DESCTIPOES"), resultSet.getInt("CONSALON"),
					resultSet.getLong("NUMPLAZAS"), resultSet.getDate("FECHAMODIFICACION"),
					resultSet.getString("NOMUSUARIO"), resultSet.getInt("BAJA"), resultSet.getString("DESCTIPOEU"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<TipoHabitacion> jerarquia = new JerarquiaDto<TipoHabitacion>();
			jerarquia.setModel(ab6317s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @return Ab6317s00
	 */
	public TipoHabitacion add(TipoHabitacion ab6317s00) {
		String query = "INSERT INTO AB6317S00 (ID_TIPO_HABITACION, INDIVDOBL, DESC_TIPO_ES, CONSALON, NUM_PLAZAS, BAJA, DESC_TIPO_EU, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?,SYSDATE,?)";
		this.jdbcTemplate.update(query, ab6317s00.getIdTipoHabitacion(), ab6317s00.getIndivdobl(),
				ab6317s00.getDescTipoEs(), ab6317s00.getConsalon(), ab6317s00.getNumPlazas(), ab6317s00.getBaja(),
				ab6317s00.getDescTipoEu(), PermisosXLNETS.getUserConnected());
		return ab6317s00;
	}

	/**
	 * Updates a single row in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @return Ab6317s00
	 */
	public TipoHabitacion update(TipoHabitacion ab6317s00) {
		String query = "UPDATE AB6317S00 SET INDIVDOBL=?, DESC_TIPO_ES=?, CONSALON=?, NUM_PLAZAS=?, BAJA=?, DESC_TIPO_EU=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_TIPO_HABITACION=?";
		this.jdbcTemplate.update(query, ab6317s00.getIndivdobl(), ab6317s00.getDescTipoEs(), ab6317s00.getConsalon(),
				ab6317s00.getNumPlazas(), ab6317s00.getBaja(), ab6317s00.getDescTipoEu(),
				PermisosXLNETS.getUserConnected(), ab6317s00.getIdTipoHabitacion());
		return ab6317s00;
	}

	/**
	 * Finds a single row in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @return Ab6317s00
	 */
	@Transactional(readOnly = true)
	public TipoHabitacion find(TipoHabitacion ab6317s00) {
		String query = "SELECT t1.ID_TIPO_HABITACION IDTIPOHABITACION, t1.INDIVDOBL INDIVDOBL, t1.DESC_TIPO_ES DESCTIPOES, t1.CONSALON CONSALON, t1.NUM_PLAZAS NUMPLAZAS, t1.FECHA_MODIFICACION FECHAMODIFICACION, t1.NOM_USUARIO NOMUSUARIO, t1.BAJA BAJA, t1.DESC_TIPO_EU DESCTIPOEU, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6317S00 t1  WHERE t1.ID_TIPO_HABITACION = ?  ";

		List<TipoHabitacion> ab6317s00List = this.jdbcTemplate.query(query, this.rwMap,
				ab6317s00.getIdTipoHabitacion());
		return (TipoHabitacion) DataAccessUtils.uniqueResult(ab6317s00List);
	}

	/**
	 * Removes a single row in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @return
	 */
	public void remove(TipoHabitacion ab6317s00) {
		String query = "DELETE FROM AB6317S00 WHERE ID_TIPO_HABITACION=?";
		this.jdbcTemplate.update(query, ab6317s00.getIdTipoHabitacion());
	}

	/**
	 * Finds a list of rows in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6317s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoHabitacion> findAll(TipoHabitacion ab6317s00, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6317S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6317s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TipoHabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoHabitacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6317s00 table using like.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6317s00>
	 */
	@Transactional(readOnly = true)
	public List<TipoHabitacion> findAllLike(TipoHabitacion ab6317s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6317S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6317s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					TipoHabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TipoHabitacion>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6317s00 table.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TipoHabitacion ab6317s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6317S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6317s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6317s00 table using like.
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TipoHabitacion ab6317s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6317S00 t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6317s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6317s00 selected for rup_table
	 *
	 * @param ab6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6317s00>>
	 */
	@Override
	public List<TableRowDto<TipoHabitacion>> reorderSelection(TipoHabitacion ab6317s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6317S00 t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6317s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				TipoHabitacion.class, filterParamList, "IDTIPOHABITACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoHabitacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6317s00
	 * @param searchParams
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6317s00>>
	 */
	@Override
	public List<TableRowDto<TipoHabitacion>> search(TipoHabitacion filterParams, TipoHabitacion searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6317S00 t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				TipoHabitacion.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_HABITACION");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TipoHabitacion>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TipoHabitacion filterab6317s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6317S00 t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6317s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, TipoHabitacion.class,
				query, params, "ID_TIPO_HABITACION");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Ab6317s00 table.
	 *
	 * @param filterAb6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Ab6317s00>>
	 */
	@Override
	public List<JerarquiaDto<TipoHabitacion>> findAllLikeJerarquia(TipoHabitacion filterAb6317s00,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_HABITACION IDTIPOHABITACION,t1.INDIVDOBL INDIVDOBL,t1.DESC_TIPO_ES DESCTIPOES,t1.CONSALON CONSALON,t1.NUM_PLAZAS NUMPLAZAS,t1.FECHA_MODIFICACION FECHAMODIFICACION,t1.NOM_USUARIO NOMUSUARIO,t1.BAJA BAJA,t1.DESC_TIPO_EU DESCTIPOEU,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6317S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6317S00");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6317s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_HABITACION", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TipoHabitacionDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterAb6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TipoHabitacion filterAb6317s00, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6317S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6317S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6317s00, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_HABITACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6317s00
	 *            Ab6317s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6317s00>>
	 */
	@Override
	public List<TableRowDto<TipoHabitacion>> findAllChild(TipoHabitacion filterAb6317s00,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6317S00 t1 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6317S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6317s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_HABITACION",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TipoHabitacion>(this.rwMapPK, "ID_TIPO_HABITACION"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6317s00 entity
	 *
	 * @param ab6317s00
	 *            Ab6317s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TipoHabitacion ab6317s00) {

		StringBuilder where = new StringBuilder(TipoHabitacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6317s00 != null && ab6317s00.getIdTipoHabitacion() != null) {
			where.append(" AND t1.ID_TIPO_HABITACION = ?");
			params.add(ab6317s00.getIdTipoHabitacion());
		}
		if (ab6317s00 != null && ab6317s00.getIndivdobl() != null) {
			where.append(" AND t1.INDIVDOBL = ?");
			params.add(ab6317s00.getIndivdobl());
		}
		if (ab6317s00 != null && ab6317s00.getDescTipoEs() != null) {
			where.append(" AND t1.DESC_TIPO_ES = ?");
			params.add(ab6317s00.getDescTipoEs());
		}
		if (ab6317s00 != null && ab6317s00.getConsalon() != null) {
			where.append(" AND t1.CONSALON = ?");
			params.add(ab6317s00.getConsalon());
		}
		if (ab6317s00 != null && ab6317s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6317s00.getNumPlazas());
		}
		if (ab6317s00 != null && ab6317s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6317s00.getFechaModificacion());
		}
		if (ab6317s00 != null && ab6317s00.getNomUsuario() != null) {
			where.append(" AND t1.NOM_USUARIO = ?");
			params.add(ab6317s00.getNomUsuario());
		}
		if (ab6317s00 != null && ab6317s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6317s00.getBaja());
		}
		if (ab6317s00 != null && ab6317s00.getDescTipoEu() != null) {
			where.append(" AND t1.DESC_TIPO_EU = ?");
			params.add(ab6317s00.getDescTipoEu());
		}
		if (ab6317s00 != null && ab6317s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6317s00.getFechaRegistro());
		}
		if (ab6317s00 != null && ab6317s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6317s00.getUsuarioRegistro());
		}
		if (ab6317s00 != null && ab6317s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6317s00.getFechaUltmodificacion());
		}
		if (ab6317s00 != null && ab6317s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6317s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6317s00 entity
	 *
	 * @param ab6317s00
	 *            Ab6317s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TipoHabitacion ab6317s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TipoHabitacionDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6317s00 != null && ab6317s00.getIdTipoHabitacion() != null) {
			where.append(" AND UPPER(t1.ID_TIPO_HABITACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getIdTipoHabitacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getIdTipoHabitacion().toUpperCase() + "%");
			}
			where.append(" AND t1.ID_TIPO_HABITACION IS NOT NULL");
		}
		if (ab6317s00 != null && ab6317s00.getIndivdobl() != null) {
			// where.append(" AND UPPER(t1.INDIVDOBL) like ? ESCAPE '\\'");
			// if (startsWith) {
			// params.add(ab6317s00.getIndivdobl().toUpperCase() + "%");
			// } else {
			// params.add("%" + ab6317s00.getIndivdobl().toUpperCase() + "%");
			// }
			// where.append(" AND t1.INDIVDOBL IS NOT NULL");

			where.append(" AND t1.INDIVDOBL = ?");
			params.add(ab6317s00.getIndivdobl());
		}
		if (ab6317s00 != null && ab6317s00.getDescTipoEs() != null) {
			where.append(" AND UPPER(t1.DESC_TIPO_ES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getDescTipoEs().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getDescTipoEs().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6317s00 != null && ab6317s00.getConsalon() != null) {
			where.append(" AND t1.CONSALON = ?");
			params.add(ab6317s00.getConsalon());
		}
		if (ab6317s00 != null && ab6317s00.getNumPlazas() != null) {
			where.append(" AND t1.NUM_PLAZAS = ?");
			params.add(ab6317s00.getNumPlazas());
		}
		if (ab6317s00 != null && ab6317s00.getFechaModificacion() != null) {
			where.append(" AND t1.FECHA_MODIFICACION = ?");
			params.add(ab6317s00.getFechaModificacion());
		}
		if (ab6317s00 != null && ab6317s00.getNomUsuario() != null) {
			where.append(" AND UPPER(t1.NOM_USUARIO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getNomUsuario().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getNomUsuario().toUpperCase() + "%");
			}
			where.append(" AND t1.NOM_USUARIO IS NOT NULL");
		}
		if (ab6317s00 != null && ab6317s00.getBaja() != null) {
			where.append(" AND t1.BAJA = ?");
			params.add(ab6317s00.getBaja());
		}
		if (ab6317s00 != null && ab6317s00.getDescTipoEu() != null) {
			where.append(" AND UPPER(t1.DESC_TIPO_EU) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getDescTipoEu().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getDescTipoEu().toUpperCase() + "%");
			}
			where.append(" AND t1.DESC_TIPO_EU IS NOT NULL");
		}
		if (ab6317s00 != null && ab6317s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6317s00.getFechaRegistro());
		}
		if (ab6317s00 != null && ab6317s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6317s00 != null && ab6317s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6317s00.getFechaUltmodificacion());
		}
		if (ab6317s00 != null && ab6317s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6317s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6317s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
