package com.ejie.ab63.dao;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.model.ZonaOcio;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableManager;
import com.ejie.x38.dto.TableManagerJerarquia;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6333s00DaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class ZonaOcioDaoImpl implements ZonaOcioDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDZONAOCIO", "NUMSUPERFICIE", "DESCRIPCION",
			"DESCRIPCIONEU", "AB6321S00IDESTABLECIMIENTO", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ZonaOcio> rwMap = new RowMapper<ZonaOcio>() {
		public ZonaOcio mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ZonaOcio(resultSet.getInt("IDZONAOCIO"), resultSet.getBigDecimal("NUMSUPERFICIE"),
					resultSet.getString("DESCRIPCION"), resultSet.getString("DESCRIPCIONEU"),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO")),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));
		}
	};

	private RowMapper<ZonaOcio> rwMapPK = new RowMapper<ZonaOcio>() {
		public ZonaOcio mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ZonaOcio(resultSet.getInt("IDZONAOCIO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<ZonaOcio>> rwMapJerarquia = new RowMapper<JerarquiaDto<ZonaOcio>>() {
		public JerarquiaDto<ZonaOcio> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ZonaOcio ab6333s00 = new ZonaOcio(resultSet.getInt("IDZONAOCIO"), resultSet.getBigDecimal("NUMSUPERFICIE"),
					resultSet.getString("DESCRIPCION"), resultSet.getString("DESCRIPCIONEU"),
					new EstablecimientoData(resultSet.getInt("Ab6321s00IDESTABLECIMIENTO")),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"));

			JerarquiaDto<ZonaOcio> jerarquia = new JerarquiaDto<ZonaOcio>();
			jerarquia.setModel(ab6333s00);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @return Ab6333s00
	 */
	public ZonaOcio add(ZonaOcio ab6333s00) {
		String query = "INSERT INTO AB6333S00 (ID_ZONA_OCIO, ID_ESTABLECIMIENTO, NUM_SUPERFICIE, DESCRIPCION, DESCRIPCION_EU, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB6333Q00.NEXTVAL,?,?,?,?,SYSDATE,?)";
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6333s00.getEstablecimientoData() != null
				&& ab6333s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6333s00.getEstablecimientoData().getIdEstablecimiento();
		}

		this.jdbcTemplate.update(query, getAb6321s00IdEstablecimientoAux, ab6333s00.getNumSuperficie(),
				ab6333s00.getDescripcion(), ab6333s00.getDescripcionEu(), PermisosXLNETS.getUserConnected());
		return ab6333s00;
	}

	/**
	 * Updates a single row in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @return Ab6333s00
	 */
	public ZonaOcio update(ZonaOcio ab6333s00) {
		String query = "UPDATE AB6333S00 SET ID_ESTABLECIMIENTO=?, NUM_SUPERFICIE=?, DESCRIPCION=?, DESCRIPCION_EU=?, FECHA_ULTMODIFICACION=SYSDATE, USUARIO_ULTMODIFICACION=? WHERE ID_ZONA_OCIO=?";
		Object getAb6321s00IdEstablecimientoAux = null;
		if (ab6333s00.getEstablecimientoData() != null
				&& ab6333s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			getAb6321s00IdEstablecimientoAux = ab6333s00.getEstablecimientoData().getIdEstablecimiento();
		}

		this.jdbcTemplate.update(query, getAb6321s00IdEstablecimientoAux, ab6333s00.getNumSuperficie(),
				ab6333s00.getDescripcion(), ab6333s00.getDescripcionEu(), PermisosXLNETS.getUserConnected(),
				ab6333s00.getIdZonaOcio());
		return ab6333s00;
	}

	/**
	 * Finds a single row in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @return Ab6333s00
	 */
	@Transactional(readOnly = true)
	public ZonaOcio find(ZonaOcio ab6333s00) {
		String query = "SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION, t1.DESCRIPCION_EU DESCRIPCIONEU, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION FROM AB6333S00 t1 , AB6321S00 t2 WHERE t1.ID_ZONA_OCIO = ?   AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+)";

		List<ZonaOcio> ab6333s00List = this.jdbcTemplate.query(query, this.rwMap, ab6333s00.getIdZonaOcio());
		return (ZonaOcio) DataAccessUtils.uniqueResult(ab6333s00List);
	}

	/**
	 * Removes a single row in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @return
	 */
	public void remove(ZonaOcio ab6333s00) {
		String query = "DELETE FROM AB6333S00 WHERE ID_ZONA_OCIO=?";
		this.jdbcTemplate.update(query, ab6333s00.getIdZonaOcio());
	}

	/**
	 * Finds a list of rows in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6333s00>
	 */
	@Transactional(readOnly = true)
	public List<ZonaOcio> findAll(ZonaOcio ab6333s00, TableRequestDto tableRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION,t1.DESCRIPCION_EU DESCRIPCIONEU, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6333S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6333s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, ZonaOcioDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ZonaOcio>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Ab6333s00 table using like.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6333s00>
	 */
	@Transactional(readOnly = true)
	public List<ZonaOcio> findAllLike(ZonaOcio ab6333s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION,t1.DESCRIPCION_EU DESCRIPCIONEU, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		query.append("FROM AB6333S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6333s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (tableRequestDto != null) {
			query = TableManager.getPaginationQuery(tableRequestDto, query, ZonaOcioDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<ZonaOcio>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Ab6333s00 table.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(ZonaOcio ab6333s00) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6333S00 t1 , AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(ab6333s00);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Ab6333s00 table using like.
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(ZonaOcio ab6333s00, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB6333S00 t1 ,AB6321S00 t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6333s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of Ab6333s00 selected for rup_table
	 *
	 * @param ab6333s00
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6333s00>>
	 */
	@Override
	public List<TableRowDto<ZonaOcio>> reorderSelection(ZonaOcio ab6333s00, TableRequestDto tableRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6333S00 t1 ,AB6321S00 t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(ab6333s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = TableManager.getReorderQuery(query, tableRequestDto, ZonaOcio.class,
				filterParamList, "ID_ZONA_OCIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ZonaOcio>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Ab6333s00
	 * @param searchParams
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6333s00>>
	 */
	@Override
	public List<TableRowDto<ZonaOcio>> search(ZonaOcio filterParams, ZonaOcio searchParams,
			TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6333S00 t1 ,AB6321S00 t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_ESTABLECIMIENTO= t2.ID_ESTABLECIMIENTO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = TableManager.getSearchQuery(query, tableRequestDto, ZonaOcio.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_ZONA_OCIO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<ZonaOcio>(this.rwMapPK, tableRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterab6333s00
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(ZonaOcio filterab6333s00, TableRequestDto tableRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_ZONA_OCIO IDZONAOCIO, t1.NUM_SUPERFICIE NUMSUPERFICIE, t1.DESCRIPCION DESCRIPCION, t2.ID_ESTABLECIMIENTO AB6321S00IDESTABLECIMIENTO, t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION ");
		// FROM
		query.append("FROM AB6333S00 t1 ,AB6321S00 t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterab6333s00, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = TableManager.getRemoveMultipleQuery(tableRequestDto, ZonaOcio.class, query,
				params, "ID_ZONA_OCIO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterAb6333s00
	 *            Ab6333s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Ab6333s00>>
	 */
	@Override
	public List<TableRowDto<ZonaOcio>> findAllChild(ZonaOcio filterAb6333s00, TableRequestDto tableRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB6333S00 t1 ,AB6321S00
		// t2 ,AB6316S00 t3 ");
		List<String> from = new ArrayList<String>();
		from.add("AB6333S00");
		from.add("AB6321S00");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterAb6333s00, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = TableManagerJerarquia.getQueryChildren(tableRequestDto, mapaWhere, "ID_ZONA_OCIO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<ZonaOcio>(this.rwMapPK, "ID_ZONA_OCIO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6333s00 entity
	 *
	 * @param ab6333s00
	 *            Ab6333s00 Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(ZonaOcio ab6333s00) {

		StringBuilder where = new StringBuilder(ZonaOcioDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6333s00 != null && ab6333s00.getIdZonaOcio() != null) {
			where.append(" AND t1.ID_ZONA_OCIO = ?");
			params.add(ab6333s00.getIdZonaOcio());
		}
		if (ab6333s00 != null && ab6333s00.getEstablecimientoData() != null
				&& ab6333s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6333s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6333s00 != null && ab6333s00.getNumSuperficie() != null) {
			where.append(" AND t1.NUM_SUPERFICIE = ?");
			params.add(ab6333s00.getNumSuperficie());
		}
		if (ab6333s00 != null && ab6333s00.getDescripcion() != null) {
			where.append(" AND t3.DESCRIPCION = ?");
			params.add(ab6333s00.getDescripcion());
		}
		if (ab6333s00 != null && ab6333s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6333s00.getFechaRegistro());
		}
		if (ab6333s00 != null && ab6333s00.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(ab6333s00.getUsuarioRegistro());
		}
		if (ab6333s00 != null && ab6333s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6333s00.getFechaUltmodificacion());
		}
		if (ab6333s00 != null && ab6333s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(ab6333s00.getUsuarioUltmodificacion());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Ab6333s00 entity
	 *
	 * @param ab6333s00
	 *            Ab6333s00 Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(ZonaOcio ab6333s00, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ZonaOcioDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (ab6333s00 != null && ab6333s00.getIdZonaOcio() != null) {
			where.append(" AND t1.ID_ZONA_OCIO = ?");
			params.add(ab6333s00.getIdZonaOcio());
		}
		if (ab6333s00 != null && ab6333s00.getEstablecimientoData() != null
				&& ab6333s00.getEstablecimientoData().getIdEstablecimiento() != null) {
			where.append(" AND t2.ID_ESTABLECIMIENTO = ?");
			params.add(ab6333s00.getEstablecimientoData().getIdEstablecimiento());
		}
		if (ab6333s00 != null && ab6333s00.getNumSuperficie() != null) {
			where.append(" AND t1.NUM_SUPERFICIE = ?");
			params.add(ab6333s00.getNumSuperficie());
		}
		if (ab6333s00 != null && ab6333s00.getDescripcion() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6333s00.getDescripcion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6333s00.getDescripcion().toUpperCase() + "%");
			}
			where.append(" AND t3.DESC_TIPO_ES IS NOT NULL");
		}
		if (ab6333s00 != null && ab6333s00.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(ab6333s00.getFechaRegistro());
		}
		if (ab6333s00 != null && ab6333s00.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6333s00.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + ab6333s00.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (ab6333s00 != null && ab6333s00.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(ab6333s00.getFechaUltmodificacion());
		}
		if (ab6333s00 != null && ab6333s00.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(ab6333s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + ab6333s00.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
