package com.ejie.ab63.dao.pagos;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.pagos.PagosExpediente;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * PagosExpedienteDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class PagosExpedienteDaoImpl implements PagosExpedienteDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPAGOEXPEDIENTE", "IDEXPEDIENTE", "NUMEROPAGO",
			"PORCENTAJEPAGO", "IMPORTEPAGO", "ANYOPRESUPUESTARIO", "OBSERVACIONES", "FECHAREGISTRO", "USUARIOREGISTRO",
			"FECHAULTMODIFICACION", "USUARIOULTMODIFICACION", "FECHAPAGO", "FECHAENVSER", "FECHADOCPAG" };

	public static final String[] ORDER_BY_EXPORT_EXCEL = new String[] { "NUMEROPAGO", "PORCENTAJEPAGO", "IMPORTEPAGO",
			"ANYOPRESUPUESTARIO", "OBSERVACIONES", "FECHAREGISTRO", "USUARIOREGISTRO", "FECHAULTMODIFICACION",
			"USUARIOULTMODIFICACION", "FECHAPAGO", "FECHAENVSER", "FECHADOCPAG" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PagosExpediente> rwMap = new RowMapper<PagosExpediente>() {
		public PagosExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosExpediente(resultSet.getInt("IDPAGOEXPEDIENTE"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getLong("NUMEROPAGO"), resultSet.getBigDecimal("PORCENTAJEPAGO"),
					resultSet.getBigDecimal("IMPORTEPAGO"), resultSet.getLong("ANYOPRESUPUESTARIO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getDate("FECHAPAGO"),
					resultSet.getDate("FECHAENVSER"), resultSet.getDate("FECHADOCPAG"));
		}
	};

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<PagosExpediente> rwMapExportExcel = new RowMapper<PagosExpediente>() {
		public PagosExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosExpediente(resultSet.getLong("NUMEROPAGO"), resultSet.getBigDecimal("PORCENTAJEPAGO"),
					resultSet.getBigDecimal("IMPORTEPAGO"), resultSet.getLong("ANYOPRESUPUESTARIO"),
					resultSet.getString("OBSERVACIONES"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getDate("FECHAULTMODIFICACION"),
					resultSet.getString("USUARIOULTMODIFICACION"), resultSet.getDate("FECHAPAGO"),
					resultSet.getDate("FECHAENVSER"), resultSet.getDate("FECHADOCPAG"));
		}
	};

	private RowMapper<PagosExpediente> rwMapPK = new RowMapper<PagosExpediente>() {
		public PagosExpediente mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new PagosExpediente(resultSet.getInt("IDPAGOEXPEDIENTE"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<PagosExpediente>> rwMapJerarquia = new RowMapper<JerarquiaDto<PagosExpediente>>() {
		public JerarquiaDto<PagosExpediente> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			PagosExpediente pagosexpediente = new PagosExpediente(resultSet.getInt("IDPAGOEXPEDIENTE"),
					resultSet.getInt("IDEXPEDIENTE"), resultSet.getLong("NUMEROPAGO"),
					resultSet.getBigDecimal("PORCENTAJEPAGO"), resultSet.getBigDecimal("IMPORTEPAGO"),
					resultSet.getLong("ANYOPRESUPUESTARIO"), resultSet.getString("OBSERVACIONES"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getDate("FECHAULTMODIFICACION"), resultSet.getString("USUARIOULTMODIFICACION"),
					resultSet.getDate("FECHAPAGO"), resultSet.getDate("FECHAENVSER"), resultSet.getDate("FECHADOCPAG"));

			JerarquiaDto<PagosExpediente> jerarquia = new JerarquiaDto<PagosExpediente>();
			jerarquia.setModel(pagosexpediente);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return PagosExpediente
	 */
	public PagosExpediente add(PagosExpediente pagosexpediente) {
		String query = "INSERT INTO PAGOS_EXPEDIENTE (ID_PAGO_EXPEDIENTE, ID_EXPEDIENTE, NUMERO_PAGO, PORCENTAJE_PAGO, IMPORTE_PAGO, ANYO_PRESUPUESTARIO, OBSERVACIONES, FECHA_REGISTRO, USUARIO_REGISTRO, FECHA_PAGO, FECHA_ENV_SER, FECHA_DOC_PAG) VALUES (AB63.S_AB6310T00.NEXTVAL,?,?,?,?,?,?,?,?,TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'),TO_DATE (?,'DD/MM/YYYY'))";
		this.jdbcTemplate.update(query, pagosexpediente.getIdExpediente(), pagosexpediente.getNumeroPago(),
				pagosexpediente.getPorcentajePago(), pagosexpediente.getImportePago(),
				pagosexpediente.getAnyoPresupuestario(), pagosexpediente.getObservaciones(),
				pagosexpediente.getFechaRegistro(), pagosexpediente.getUsuarioRegistro(),
				pagosexpediente.getFechaPagoStr(), pagosexpediente.getFechaEnvSerStr(),
				pagosexpediente.getFechaDocPagStr());
		return pagosexpediente;
	}

	/**
	 * Updates a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return PagosExpediente
	 */
	public PagosExpediente update(PagosExpediente pagosexpediente) {
		String query = "UPDATE PAGOS_EXPEDIENTE SET ID_EXPEDIENTE=?, NUMERO_PAGO=?, PORCENTAJE_PAGO=?, IMPORTE_PAGO=?, ANYO_PRESUPUESTARIO=?, OBSERVACIONES=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=? WHERE ID_PAGO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, pagosexpediente.getIdExpediente(), pagosexpediente.getNumeroPago(),
				pagosexpediente.getPorcentajePago(), pagosexpediente.getImportePago(),
				pagosexpediente.getAnyoPresupuestario(), pagosexpediente.getObservaciones(),
				pagosexpediente.getFechaRegistro(), pagosexpediente.getUsuarioRegistro(),
				pagosexpediente.getFechaUltmodificacion(), pagosexpediente.getUsuarioUltmodificacion(),
				pagosexpediente.getIdPagoExpediente());
		return pagosexpediente;
	}

	/**
	 * Updates a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return PagosExpediente
	 */
	public PagosExpediente updatePagos(PagosExpediente pagosexpediente) {
		String query = "UPDATE PAGOS_EXPEDIENTE SET NUMERO_PAGO=?, PORCENTAJE_PAGO=?, IMPORTE_PAGO=?, FECHA_ULTMODIFICACION=?, USUARIO_ULTMODIFICACION=?, FECHA_PAGO=TO_DATE (?,'DD/MM/YYYY'), FECHA_ENV_SER=TO_DATE (?,'DD/MM/YYYY'), FECHA_DOC_PAG=TO_DATE (?,'DD/MM/YYYY') WHERE ID_PAGO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, pagosexpediente.getNumeroPago(), pagosexpediente.getPorcentajePago(),
				pagosexpediente.getImportePago(), pagosexpediente.getFechaUltmodificacion(),
				pagosexpediente.getUsuarioUltmodificacion(), pagosexpediente.getFechaPagoStr(),
				pagosexpediente.getFechaEnvSerStr(), pagosexpediente.getFechaDocPagStr(),
				pagosexpediente.getIdPagoExpediente());
		return pagosexpediente;
	}

	/**
	 * Finds a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return PagosExpediente
	 */
	@Transactional(readOnly = true)
	public PagosExpediente find(PagosExpediente pagosexpediente) {
		String query = "SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.NUMERO_PAGO NUMEROPAGO, t1.PORCENTAJE_PAGO PORCENTAJEPAGO, t1.IMPORTE_PAGO IMPORTEPAGO, t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG FROM PAGOS_EXPEDIENTE t1  WHERE t1.ID_PAGO_EXPEDIENTE = ?  ";

		List<PagosExpediente> pagosexpedienteList = this.jdbcTemplate.query(query, this.rwMap,
				pagosexpediente.getIdPagoExpediente());
		return (PagosExpediente) DataAccessUtils.uniqueResult(pagosexpedienteList);
	}

	/**
	 * Finds a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return PagosExpediente
	 */
	@Transactional(readOnly = true)
	public PagosExpediente findPagos(PagosExpediente pagosexpediente) {
		String query = "SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.NUMERO_PAGO NUMEROPAGO, t1.PORCENTAJE_PAGO PORCENTAJEPAGO, t1.IMPORTE_PAGO IMPORTEPAGO, t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO, t1.OBSERVACIONES OBSERVACIONES, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION, t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG FROM PAGOS_EXPEDIENTE t1  WHERE t1.ID_PAGO_EXPEDIENTE = ?  ";

		List<PagosExpediente> pagosexpedienteList = this.jdbcTemplate.query(query, this.rwMap,
				pagosexpediente.getIdPagoExpediente());
		return (PagosExpediente) DataAccessUtils.uniqueResult(pagosexpedienteList);
	}

	/**
	 * Removes a single row in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return
	 */
	public void remove(PagosExpediente pagosexpediente) {
		String query = "DELETE FROM PAGOS_EXPEDIENTE WHERE ID_PAGO_EXPEDIENTE=?";
		this.jdbcTemplate.update(query, pagosexpediente.getIdPagoExpediente());
	}

	/**
	 * Finds a list of rows in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<PagosExpediente>
	 */
	@Transactional(readOnly = true)
	public List<PagosExpediente> findAll(PagosExpediente pagosexpediente, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		query.append("FROM PAGOS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pagosexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PagosExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PagosExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the PagosExpediente table using like.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PagosExpediente>
	 */
	@Transactional(readOnly = true)
	public List<PagosExpediente> findAllLike(PagosExpediente pagosexpediente, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,"
						+ "t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, "
						+ "t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		query.append("FROM PAGOS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					PagosExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<PagosExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the PagosExpediente table using like.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<PagosExpediente>
	 */
	@Transactional(readOnly = true)
	public List<PagosExpediente> findAllLikeExportExcel(PagosExpediente pagosexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,"
						+ "t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, "
						+ "t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		query.append("FROM PAGOS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		/*
		 * if (jqGridRequestDto != null) { query =
		 * JQGridManager.getPaginationQuery(jqGridRequestDto, query,
		 * PagosExpedienteDaoImpl.ORDER_BY_WHITE_LIST); }
		 */

		return (List<PagosExpediente>) this.jdbcTemplate.query(query.toString(), this.rwMapExportExcel,
				params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the PagosExpediente table.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(PagosExpediente pagosexpediente) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PAGOS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(pagosexpediente);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the PagosExpediente table using like.
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(PagosExpediente pagosexpediente, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PAGOS_EXPEDIENTE t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of PagosExpediente selected for rup_table
	 *
	 * @param pagosexpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosExpediente>>
	 */
	@Override
	public List<TableRowDto<PagosExpediente>> reorderSelection(PagosExpediente pagosexpediente,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION,t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		// FROM
		query.append("FROM PAGOS_EXPEDIENTE t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(pagosexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				PagosExpediente.class, filterParamList, "ID_PAGO_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PagosExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            PagosExpediente
	 * @param searchParams
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<PagosExpediente>>
	 */
	@Override
	public List<TableRowDto<PagosExpediente>> search(PagosExpediente filterParams, PagosExpediente searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		// FROM
		query.append("FROM PAGOS_EXPEDIENTE t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				PagosExpediente.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_PAGO_EXPEDIENTE");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<PagosExpediente>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterpagosexpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(PagosExpediente filterpagosexpediente, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAG ");
		// FROM
		query.append("FROM PAGOS_EXPEDIENTE t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterpagosexpediente, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto,
				PagosExpediente.class, query, params, "ID_PAGO_EXPEDIENTE");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical PagosExpediente table.
	 *
	 * @param filterPagosExpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<PagosExpediente>>
	 */
	@Override
	public List<JerarquiaDto<PagosExpediente>> findAllLikeJerarquia(PagosExpediente filterPagosExpediente,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PAGO_EXPEDIENTE IDPAGOEXPEDIENTE,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.NUMERO_PAGO NUMEROPAGO,t1.PORCENTAJE_PAGO PORCENTAJEPAGO,t1.IMPORTE_PAGO IMPORTEPAGO,t1.ANYO_PRESUPUESTARIO ANYOPRESUPUESTARIO,t1.OBSERVACIONES OBSERVACIONES,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.FECHA_ULTMODIFICACION FECHAULTMODIFICACION,t1.USUARIO_ULTMODIFICACION USUARIOULTMODIFICACION, t1.FECHA_PAGO FECHAPAGO, t1.FECHA_ENV_SER FECHAENVSER, t1.FECHA_DOC_PAG FECHADOCPAGO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_EXPEDIENTE t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_EXPEDIENTE");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PAGO_EXPEDIENTE", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					PagosExpedienteDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterPagosExpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(PagosExpediente filterPagosExpediente, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_EXPEDIENTE t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosExpediente, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PAGO_EXPEDIENTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterPagosExpediente
	 *            PagosExpediente
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<PagosExpediente>>
	 */
	@Override
	public List<TableRowDto<PagosExpediente>> findAllChild(PagosExpediente filterPagosExpediente,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PAGOS_EXPEDIENTE t1 ");
		List<String> from = new ArrayList<String>();
		from.add("PAGOS_EXPEDIENTE");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterPagosExpediente, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_PAGO_EXPEDIENTE",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<PagosExpediente>(this.rwMapPK, "ID_PAGO_EXPEDIENTE"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PagosExpediente entity
	 *
	 * @param pagosexpediente
	 *            PagosExpediente Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(PagosExpediente pagosexpediente) {

		StringBuilder where = new StringBuilder(PagosExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pagosexpediente != null && pagosexpediente.getIdPagoExpediente() != null) {
			where.append(" AND t1.ID_PAGO_EXPEDIENTE = ?");
			params.add(pagosexpediente.getIdPagoExpediente());
		}
		if (pagosexpediente != null && pagosexpediente.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(pagosexpediente.getIdExpediente());
		}
		if (pagosexpediente != null && pagosexpediente.getNumeroPago() != null) {
			where.append(" AND t1.NUMERO_PAGO = ?");
			params.add(pagosexpediente.getNumeroPago());
		}
		if (pagosexpediente != null && pagosexpediente.getPorcentajePago() != null) {
			where.append(" AND t1.PORCENTAJE_PAGO = ?");
			params.add(pagosexpediente.getPorcentajePago());
		}
		if (pagosexpediente != null && pagosexpediente.getImportePago() != null) {
			where.append(" AND t1.IMPORTE_PAGO = ?");
			params.add(pagosexpediente.getImportePago());
		}
		if (pagosexpediente != null && pagosexpediente.getAnyoPresupuestario() != null) {
			where.append(" AND t1.ANYO_PRESUPUESTARIO = ?");
			params.add(pagosexpediente.getAnyoPresupuestario());
		}
		if (pagosexpediente != null && pagosexpediente.getObservaciones() != null) {
			where.append(" AND t1.OBSERVACIONES = ?");
			params.add(pagosexpediente.getObservaciones());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pagosexpediente.getFechaRegistro());
		}
		if (pagosexpediente != null && pagosexpediente.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(pagosexpediente.getUsuarioRegistro());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(pagosexpediente.getFechaUltmodificacion());
		}
		if (pagosexpediente != null && pagosexpediente.getUsuarioUltmodificacion() != null) {
			where.append(" AND t1.USUARIO_ULTMODIFICACION = ?");
			params.add(pagosexpediente.getUsuarioUltmodificacion());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaPago() != null) {
			where.append(" AND t1.FECHA_PAGO = ?");
			params.add(pagosexpediente.getFechaPago());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaEnvSer() != null) {
			where.append(" AND t1.FECHA_ENV_SER = ?");
			params.add(pagosexpediente.getFechaEnvSer());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaDocPag() != null) {
			where.append(" AND t1.FECHA_DOC_PAG = ?");
			params.add(pagosexpediente.getFechaDocPag());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the PagosExpediente entity
	 *
	 * @param pagosexpediente
	 *            PagosExpediente Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(PagosExpediente pagosexpediente, Boolean startsWith) {

		StringBuilder where = new StringBuilder(PagosExpedienteDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (pagosexpediente != null && pagosexpediente.getIdPagoExpediente() != null) {
			where.append(" AND t1.ID_PAGO_EXPEDIENTE = ?");
			params.add(pagosexpediente.getIdPagoExpediente());
		}
		if (pagosexpediente != null && pagosexpediente.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(pagosexpediente.getIdExpediente());
		}
		if (pagosexpediente != null && pagosexpediente.getNumeroPago() != null) {
			where.append(" AND t1.NUMERO_PAGO = ?");
			params.add(pagosexpediente.getNumeroPago());
		}
		if (pagosexpediente != null && pagosexpediente.getPorcentajePago() != null) {
			where.append(" AND t1.PORCENTAJE_PAGO = ?");
			params.add(pagosexpediente.getPorcentajePago());
		}
		if (pagosexpediente != null && pagosexpediente.getImportePago() != null) {
			where.append(" AND t1.IMPORTE_PAGO = ?");
			params.add(pagosexpediente.getImportePago());
		}
		if (pagosexpediente != null && pagosexpediente.getAnyoPresupuestario() != null) {
			where.append(" AND t1.ANYO_PRESUPUESTARIO = ?");
			params.add(pagosexpediente.getAnyoPresupuestario());
		}
		if (pagosexpediente != null && pagosexpediente.getObservaciones() != null) {
			where.append(" AND UPPER(t1.OBSERVACIONES) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosexpediente.getObservaciones().toUpperCase() + "%");
			} else {
				params.add("%" + pagosexpediente.getObservaciones().toUpperCase() + "%");
			}
			where.append(" AND t1.OBSERVACIONES IS NOT NULL");
		}
		if (pagosexpediente != null && pagosexpediente.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(pagosexpediente.getFechaRegistro());
		}
		if (pagosexpediente != null && pagosexpediente.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosexpediente.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + pagosexpediente.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}
		if (pagosexpediente != null && pagosexpediente.getFechaUltmodificacion() != null) {
			where.append(" AND t1.FECHA_ULTMODIFICACION = ?");
			params.add(pagosexpediente.getFechaUltmodificacion());
		}
		if (pagosexpediente != null && pagosexpediente.getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t1.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(pagosexpediente.getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + pagosexpediente.getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (pagosexpediente != null && pagosexpediente.getFechaPago() != null) {
			where.append(" AND t1.FECHA_PAGO = ?");
			params.add(pagosexpediente.getFechaPago());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaEnvSer() != null) {
			where.append(" AND t1.FECHA_ENV_SER = ?");
			params.add(pagosexpediente.getFechaEnvSer());
		}
		if (pagosexpediente != null && pagosexpediente.getFechaDocPag() != null) {
			where.append(" AND t1.FECHA_DOC_PAG = ?");
			params.add(pagosexpediente.getFechaDocPag());
		}
		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
