package com.ejie.ab63.dao.plantillas;

import java.util.List;

import com.ejie.ab63.model.plantillas.RelPlaCam;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelPlaCamDao  
 * 
 *  
 */

public interface RelPlaCamDao {

	/**
	 * Inserts a single row in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @return RelPlaCam
	 */
	RelPlaCam add(RelPlaCam relplacam);

	/**
	 * Updates a single row in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @return RelPlaCam
	 */
	RelPlaCam update(RelPlaCam relplacam);

	/**
	 * Finds a single row in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @return RelPlaCam
	 */
	RelPlaCam find(RelPlaCam relplacam);

	/**
	 * Removes a single row in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 */
	void remove(RelPlaCam relplacam);

	/**
	 * Finds a List of rows in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<RelPlaCam> findAll(RelPlaCam relplacam, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the RelPlaCam table using like.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<RelPlaCam> findAllLike(RelPlaCam relplacam, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the RelPlaCam table.
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(RelPlaCam filterRelPlaCam, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the RelPlaCam table using like.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(RelPlaCam relplacam, Boolean startsWith);

	/**
	 * Counts rows in the RelPlaCam table.
	 *
	 * @param relplacam
	 *            RelPlaCam
	 * @return Long
	 */
	Long findAllCount(RelPlaCam relplacam);

	/**
	 * Reorder selection.
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelPlaCam>>
	 */
	List<TableRowDto<RelPlaCam>> reorderSelection(RelPlaCam filterRelPlaCam, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param searchRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelPlaCam>>
	 */
	List<TableRowDto<RelPlaCam>> search(RelPlaCam filterRelPlaCam, RelPlaCam searchRelPlaCam,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical RelPlaCam table.
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<RelPlaCam>>
	 */
	List<JerarquiaDto<RelPlaCam>> findAllLikeJerarquia(RelPlaCam filterRelPlaCam, JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(RelPlaCam filterRelPlaCam, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelPlaCam
	 *            RelPlaCam
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelPlaCam>>
	 */
	List<TableRowDto<RelPlaCam>> findAllChild(RelPlaCam filterRelPlaCam, JQGridRequestDto jqGridRequestDto);

}
