package com.ejie.ab63.dao.procedimientos;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.procedimientos.ProcedimientoConfigCensos;

@Repository
@Transactional
public class ProcedimientosConfigCensosDaoImpl implements ProcedimientosConfigCensosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] {};

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ProcedimientoConfigCensos> rwMap = new RowMapper<ProcedimientoConfigCensos>() {
		public ProcedimientoConfigCensos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new ProcedimientoConfigCensos(resultSet.getInt("idConfiguracion"), resultSet.getInt("idProcedure"),
					resultSet.getString("plSql"), resultSet.getString("tipo"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Finds a single row in the ProcedimientoConfigCensos table.
	 *
	 * @param procedimientos
	 *            ProcedimientoConfigCensos
	 * @return ProcedimientoConfigCensos
	 */
	@Transactional(readOnly = true)
	public ProcedimientoConfigCensos find(ProcedimientoConfigCensos procedimientos) {
		String query = "SELECT ID_CONFIGURACION idConfiguracion, ID_PROCEDURE idProcedure, PLSQL plSql, TIPO tipo FROM AB6302S00 WHERE ID_CONFIGURACION = ? AND TIPO = ? ";

		List<ProcedimientoConfigCensos> procedimientosList = this.jdbcTemplate.query(query, this.rwMap,
				procedimientos.getIdConfiguracion(), procedimientos.getTipo());
		return (ProcedimientoConfigCensos) DataAccessUtils.uniqueResult(procedimientosList);
	}

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
