package com.ejie.ab63.dao.procedimientos;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.model.procedimientos.Areas;
import com.ejie.ab63.model.procedimientos.Departamentos;
import com.ejie.ab63.model.procedimientos.Direcciones;
import com.ejie.ab63.model.procedimientos.Procedimientos;
import com.ejie.ab63.model.procedimientos.ProcedimientosRelacionados;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

@Repository
@Transactional
public class ProcedimientosDaoImpl implements ProcedimientosDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDPROCEDIMIENTO", "CODPROCEDUREID", "FOLDERID",
			"FOLDERNUMBER", "CAMPOSTITULOEXPEDIENTE", "FECHAREGISTRO", "USUARIOREGISTRO", "DIRECCIONESIDDIRECCION",
			"DIRECCIONESCASTELLANO", "DIRECCIONESEUSKERA", "DIRECCIONESFECHAREGISTRO", "DIRECCIONESUSUARIOREGISTRO",
			"AREASIDAREA", "AREASDESCRIPCIONCASTELLANO", "AREASDESCRIPCIONEUSKERA", "AREASFECHAREGISTRO",
			"AREASUSUARIOREGISTRO", "DIRECCIONESIDDEPARTAMENTO", "AREASIDDIRECCION" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<Procedimientos> rwMap = new RowMapper<Procedimientos>() {
		public Procedimientos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Procedimientos(resultSet.getInt("IDPROCEDIMIENTO"), resultSet.getString("CODPROCEDUREID"),
					resultSet.getString("CAMPOSTITULOEXPEDIENTE"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new Direcciones(resultSet.getInt("DireccionesIDDIRECCION"),
							resultSet.getString("DIRECCIONESCASTELLANO"), resultSet.getString("DIRECCIONESEUSKERA"),
							resultSet.getDate("DireccionesFECHAREGISTRO"),
							resultSet.getString("DireccionesUSUARIOREGISTRO"),
							new Departamentos(resultSet.getInt("DireccionesIDDEPARTAMENTO"), null, null, null, null,
									null)),
					new Areas(resultSet.getInt("AreasIDAREA"), resultSet.getString("AreasDESCRIPCIONCASTELLANO"),
							resultSet.getString("AreasDESCRIPCIONEUSKERA"), resultSet.getDate("AreasFECHAREGISTRO"),
							resultSet.getString("AreasUSUARIOREGISTRO"),
							new Direcciones(resultSet.getInt("AreasIDDIRECCION"), null, null, null, null, null, null,
									null)),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getString("INSPECCIONABLE"));
		}
	};

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<ProcedimientosRelacionados> rwMapRel = new RowMapper<ProcedimientosRelacionados>() {
		public ProcedimientosRelacionados mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			ProcedimientosRelacionados procedimientosRelacionados = new ProcedimientosRelacionados();
			procedimientosRelacionados.setIdRelProcedimiento(resultSet.getInt("IDRELPROCEDIMIENTOS"));
			Procedimientos origen = new Procedimientos(resultSet.getInt("IDPROCEDIMIENTO"),
					resultSet.getString("CODPROCEDUREID"), resultSet.getString("CAMPOSTITULOEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"), null, null,
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getString("INSPECCIONABLE"));
			Procedimientos oficio = new Procedimientos(resultSet.getInt("OFICIOIDPROCEDIMIENTO"),
					resultSet.getString("OFICIOCODPROCEDUREID"), resultSet.getString("OFICIOCAMPOSTITULOEXPEDIENTE"),
					resultSet.getDate("OFICIOFECHAREGISTRO"), resultSet.getString("OFICIOUSUARIOREGISTRO"), null, null,
					resultSet.getString("OFICIODESCCASTELLANO"), resultSet.getString("OFICIODESCEUSKERA"),
					resultSet.getString("OFICIOINSPECCIONABLE"));
			procedimientosRelacionados.setProcedimientoOrigen(origen);
			procedimientosRelacionados.setProcedInicioOficio(oficio);

			return procedimientosRelacionados;
		}
	};

	private RowMapper<Procedimientos> rwMapPK = new RowMapper<Procedimientos>() {
		public Procedimientos mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new Procedimientos(resultSet.getInt("IDPROCEDIMIENTO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<Procedimientos>> rwMapJerarquia = new RowMapper<JerarquiaDto<Procedimientos>>() {
		public JerarquiaDto<Procedimientos> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			Procedimientos procedimientos = new Procedimientos(resultSet.getInt("IDPROCEDIMIENTO"),
					resultSet.getString("CODPROCEDUREID"), resultSet.getString("CAMPOSTITULOEXPEDIENTE"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					new Direcciones(resultSet.getInt("DireccionesIDDIRECCION"),
							resultSet.getString("DIRECCIONESCASTELLANO"), resultSet.getString("DIRECCIONESEUSKERA"),
							resultSet.getDate("DireccionesFECHAREGISTRO"),
							resultSet.getString("DireccionesUSUARIOREGISTRO"),
							new Departamentos(resultSet.getInt("DireccionesIDDEPARTAMENTO"), null, null, null, null,
									null)),
					new Areas(resultSet.getInt("AreasIDAREA"), resultSet.getString("AreasDESCRIPCIONCASTELLANO"),
							resultSet.getString("AreasDESCRIPCIONEUSKERA"), resultSet.getDate("AreasFECHAREGISTRO"),
							resultSet.getString("AreasUSUARIOREGISTRO"),
							new Direcciones(resultSet.getInt("AreasIDDIRECCION"), null, null, null, null, null, null,
									null)),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"), null);

			JerarquiaDto<Procedimientos> jerarquia = new JerarquiaDto<Procedimientos>();
			jerarquia.setModel(procedimientos);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	public Procedimientos add(Procedimientos procedimientos) {
		String query = "INSERT INTO PROCEDIMIENTOS (ID_PROCEDIMIENTO, ID_DIRECCION, ID_AREA, COD_PROCEDURE_ID, CAMPOS_TITULO_EXPEDIENTE, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?,?,?)";
		Object getDireccionesIdDireccionAux = null;
		if (procedimientos.getDirecciones() != null && procedimientos.getDirecciones().getIdDireccion() != null) {
			getDireccionesIdDireccionAux = procedimientos.getDirecciones().getIdDireccion();
		}
		Object getAreasIdAreaAux = null;
		if (procedimientos.getAreas() != null && procedimientos.getAreas().getIdArea() != null) {
			getAreasIdAreaAux = procedimientos.getAreas().getIdArea();
		}
		this.jdbcTemplate.update(query, procedimientos.getIdProcedimiento(), getDireccionesIdDireccionAux,
				getAreasIdAreaAux, procedimientos.getCodProcedureId(), procedimientos.getCamposTituloExpediente(),
				procedimientos.getFechaRegistro(), procedimientos.getUsuarioRegistro());
		return procedimientos;
	}

	/**
	 * Updates a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	public Procedimientos update(Procedimientos procedimientos) {
		String query = "UPDATE PROCEDIMIENTOS SET ID_DIRECCION=?, ID_AREA=?, COD_PROCEDURE_ID=?, CAMPOS_TITULO_EXPEDIENTE=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_PROCEDIMIENTO=?";
		Object getDireccionesIdDireccionAux = null;
		if (procedimientos.getDirecciones() != null && procedimientos.getDirecciones().getIdDireccion() != null) {
			getDireccionesIdDireccionAux = procedimientos.getDirecciones().getIdDireccion();
		}
		Object getAreasIdAreaAux = null;
		if (procedimientos.getAreas() != null && procedimientos.getAreas().getIdArea() != null) {
			getAreasIdAreaAux = procedimientos.getAreas().getIdArea();
		}
		this.jdbcTemplate.update(query, getDireccionesIdDireccionAux, getAreasIdAreaAux,
				procedimientos.getCodProcedureId(), procedimientos.getCamposTituloExpediente(),
				procedimientos.getFechaRegistro(), procedimientos.getUsuarioRegistro(),
				procedimientos.getIdProcedimiento());
		return procedimientos;
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	@Transactional(readOnly = true)
	public Procedimientos find(Procedimientos procedimientos) {
		String query = "SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.COD_PROCEDURE_ID CODPROCEDUREID, t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.INSPECCIONABLE INSPECCIONABLE, t2.ID_DIRECCION DIRECCIONESIDDIRECCION, t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO, t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA, t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO, t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO, t3.ID_AREA AREASIDAREA, t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA, t3.FECHA_REGISTRO AREASFECHAREGISTRO, t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO, t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO, t3.ID_DIRECCION AREASIDDIRECCION FROM PROCEDIMIENTOS t1 , DIRECCIONES t2 , AREAS t3  WHERE t1.ID_PROCEDIMIENTO = ?   AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+)";

		List<Procedimientos> procedimientosList = this.jdbcTemplate.query(query, this.rwMap,
				procedimientos.getIdProcedimiento());
		return (Procedimientos) DataAccessUtils.uniqueResult(procedimientosList);
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	@Transactional(readOnly = true)
	public Procedimientos findProc(Procedimientos procedimientos) {
		String query = "SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.COD_PROCEDURE_ID CODPROCEDUREID, t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.INSPECCIONABLE INSPECCIONABLE, t2.ID_DIRECCION DIRECCIONESIDDIRECCION, t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO, t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA, t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO, t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO, t3.ID_AREA AREASIDAREA, t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO, t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA, t3.FECHA_REGISTRO AREASFECHAREGISTRO, t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO, t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO, t3.ID_DIRECCION AREASIDDIRECCION FROM PROCEDIMIENTOS t1 , DIRECCIONES t2 , AREAS t3  WHERE t1.COD_PROCEDURE_ID = ? AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+)";

		List<Procedimientos> procedimientosList = this.jdbcTemplate.query(query, this.rwMap,
				procedimientos.getCodProcedureId());
		return (Procedimientos) DataAccessUtils.uniqueResult(procedimientosList);
	}

	/**
	 * Removes a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return
	 */
	public void remove(Procedimientos procedimientos) {
		String query = "DELETE FROM PROCEDIMIENTOS WHERE ID_PROCEDIMIENTO=?";
		this.jdbcTemplate.update(query, procedimientos.getIdProcedimiento());
	}

	/**
	 * Finds a list of rows in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Procedimientos>
	 */
	@Transactional(readOnly = true)
	public List<Procedimientos> findAll(Procedimientos procedimientos, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.INSPECCIONABLE INSPECCIONABLE,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		query.append("FROM PROCEDIMIENTOS t1, DIRECCIONES t2, AREAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(procedimientos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ProcedimientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Procedimientos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds a list of rows in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Procedimientos>
	 */
	@Transactional(readOnly = true)
	public List<Procedimientos> findAllCenso(Procedimientos procedimientos) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.INSPECCIONABLE INSPECCIONABLE,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		query.append("FROM PROCEDIMIENTOS t1, DIRECCIONES t2, AREAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(procedimientos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) AND t1.COD_PROCEDURE_ID IN ( ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_INICIO_ACTIVIDAD).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_MODIFICACIONES_ACTIVIDAD).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_CESE_ACTIVIDAD).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_DISPENSAS_ACTIVIDAD).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_COMPROBACION_DE_OFICIO).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_ADAPTACION_DECRETO_ACTIVIDAD).append("', ");
		where.append(" '").append(Constantes.PROCEDIMIENTO_COMPROBACION_DE_OFICIO).append("') ");

		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return (List<Procedimientos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the Procedimientos table using like.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Procedimientos>
	 */
	@Transactional(readOnly = true)
	public List<Procedimientos> findAllLike(Procedimientos procedimientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID, t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t1.INSPECCIONABLE INSPECCIONABLE,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		query.append("FROM PROCEDIMIENTOS t1 ,DIRECCIONES t2 ,AREAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(procedimientos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query,
					ProcedimientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<Procedimientos>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(Procedimientos procedimientos) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PROCEDIMIENTOS t1 , DIRECCIONES t2 , AREAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(procedimientos);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the Procedimientos table using like.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(Procedimientos procedimientos, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM PROCEDIMIENTOS t1 ,DIRECCIONES t2 ,AREAS t3 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(procedimientos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	@Transactional(readOnly = true)
	public List<ProcedimientosRelacionados> findRelInicioOficio(Procedimientos procedimientos) {
		String query = "SELECT RELINIOFI.ID_REL_INI_OFI_ORI IDRELPROCEDIMIENTOS, RELINIOFI.ID_PROC_ORIGEN IDPROCEDIMIENTO, T1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, T1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, T1.COD_PROCEDURE_ID CODPROCEDUREID, T1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE, T1.FECHA_REGISTRO FECHAREGISTRO, T1.USUARIO_REGISTRO USUARIOREGISTRO, T1.INSPECCIONABLE INSPECCIONABLE, RELINIOFI.ID_PROC_INICIO_OFICIO OFICIOIDPROCEDIMIENTO, T2.DESCRIPCION_CASTELLANO OFICIODESCCASTELLANO, T2.DESCRIPCION_EUSKERA OFICIODESCEUSKERA, T2.COD_PROCEDURE_ID OFICIOCODPROCEDUREID, T2.CAMPOS_TITULO_EXPEDIENTE OFICIOCAMPOSTITULOEXPEDIENTE, T2.FECHA_REGISTRO OFICIOFECHAREGISTRO, T2.USUARIO_REGISTRO OFICIOUSUARIOREGISTRO, T2.INSPECCIONABLE OFICIOINSPECCIONABLE  FROM PROCEDIMIENTOS T1, PROCEDIMIENTOS T2, AB61.AB6103T00 RELINIOFI WHERE T1.ID_PROCEDIMIENTO = ? AND RELINIOFI.ID_PROC_ORIGEN = T1.ID_PROCEDIMIENTO AND RELINIOFI.ID_PROC_INICIO_OFICIO = T2.ID_PROCEDIMIENTO";

		List<ProcedimientosRelacionados> procedimientosList = this.jdbcTemplate.query(query, this.rwMapRel,
				procedimientos.getIdProcedimiento());
		return procedimientosList;
	}

	/**
	 * Reorder the data list of Procedimientos selected for rup_table
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Procedimientos>>
	 */
	@Override
	public List<TableRowDto<Procedimientos>> reorderSelection(Procedimientos procedimientos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		// FROM
		query.append("FROM PROCEDIMIENTOS t1 ,DIRECCIONES t2 ,AREAS t3 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(procedimientos, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto,
				Procedimientos.class, filterParamList, "ID_PROCEDIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Procedimientos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            Procedimientos
	 * @param searchParams
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Procedimientos>>
	 */
	@Override
	public List<TableRowDto<Procedimientos>> search(Procedimientos filterParams, Procedimientos searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		// FROM
		query.append("FROM PROCEDIMIENTOS t1 ,DIRECCIONES t2 ,AREAS t3 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_DIRECCION= t2.ID_DIRECCION(+) AND t1.ID_AREA= t3.ID_AREA(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto,
				Procedimientos.class, filterParamList, searchSQL, searchParamList, from_alias, "ID_PROCEDIMIENTO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<Procedimientos>(this.rwMapPK, jqGridRequestDto),
				filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterprocedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(Procedimientos filterprocedimientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		// FROM
		query.append("FROM PROCEDIMIENTOS t1 ,DIRECCIONES t2 ,AREAS t3 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterprocedimientos, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, Procedimientos.class,
				query, params, "ID_PROCEDIMIENTO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<Procedimientos>>
	 */
	@Override
	public List<JerarquiaDto<Procedimientos>> findAllLikeJerarquia(Procedimientos filterProcedimientos,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_PROCEDIMIENTO IDPROCEDIMIENTO,t1.COD_PROCEDURE_ID CODPROCEDUREID,t1.CAMPOS_TITULO_EXPEDIENTE CAMPOSTITULOEXPEDIENTE,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_DIRECCION DIRECCIONESIDDIRECCION,t2.DESCRIPCION_CASTELLANO DIRECCIONESCASTELLANO,t2.DESCRIPCION_EUSKERA DIRECCIONESEUSKERA,t2.FECHA_REGISTRO DIRECCIONESFECHAREGISTRO,t2.USUARIO_REGISTRO DIRECCIONESUSUARIOREGISTRO,t3.ID_AREA AREASIDAREA,t3.DESCRIPCION_CASTELLANO AREASDESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA AREASDESCRIPCIONEUSKERA,t3.FECHA_REGISTRO AREASFECHAREGISTRO,t3.USUARIO_REGISTRO AREASUSUARIOREGISTRO,t2.ID_DEPARTAMENTO DIRECCIONESIDDEPARTAMENTO,t3.ID_DIRECCION AREASIDDIRECCION ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM PROCEDIMIENTOS t1
		// ,DIRECCIONES t2 ,AREAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROCEDIMIENTOS");
		from.add("DIRECCIONES");
		from.add("AREAS");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProcedimientos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_PROCEDIMIENTO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					ProcedimientosDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(Procedimientos filterProcedimientos, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM PROCEDIMIENTOS t1
		// ,DIRECCIONES t2 ,AREAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROCEDIMIENTOS");
		from.add("DIRECCIONES");
		from.add("AREAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProcedimientos, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_PROCEDIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<Procedimientos>>
	 */
	@Override
	public List<TableRowDto<Procedimientos>> findAllChild(Procedimientos filterProcedimientos,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM PROCEDIMIENTOS t1
		// ,DIRECCIONES t2 ,AREAS t3 ");
		List<String> from = new ArrayList<String>();
		from.add("PROCEDIMIENTOS");
		from.add("DIRECCIONES");
		from.add("AREAS");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");
		from_alias.add(" t3 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterProcedimientos, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_PROCEDIMIENTO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<Procedimientos>(this.rwMapPK, "ID_PROCEDIMIENTO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Procedimientos entity
	 *
	 * @param procedimientos
	 *            Procedimientos Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(Procedimientos procedimientos) {

		StringBuilder where = new StringBuilder(ProcedimientosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (procedimientos != null && procedimientos.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(procedimientos.getIdProcedimiento());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getIdDireccion() != null) {
			where.append(" AND t2.ID_DIRECCION = ?");
			params.add(procedimientos.getDirecciones().getIdDireccion());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDepartamentos() != null
				&& procedimientos.getDirecciones().getDepartamentos().getIdDepartamento() != null) {
			where.append(" AND t2.ID_DEPARTAMENTO = ?");
			params.add(procedimientos.getDirecciones().getDepartamentos().getIdDepartamento());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDescripcionCastellano() != null) {
			where.append(" AND t2.DESCRIPCION_CASTELLANO = ?");
			params.add(procedimientos.getDirecciones().getDescripcionCastellano());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDescripcionEuskera() != null) {
			where.append(" AND t2.DESCRIPCION_EUSKERA = ?");
			params.add(procedimientos.getDirecciones().getDescripcionEuskera());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(procedimientos.getDirecciones().getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(procedimientos.getDirecciones().getUsuarioRegistro());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getIdArea() != null) {
			where.append(" AND t3.ID_AREA = ?");
			params.add(procedimientos.getAreas().getIdArea());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDirecciones() != null
				&& procedimientos.getAreas().getDirecciones().getIdDireccion() != null) {
			where.append(" AND t3.ID_DIRECCION = ?");
			params.add(procedimientos.getAreas().getDirecciones().getIdDireccion());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDescripcionCastellano() != null) {
			where.append(" AND t3.DESCRIPCION_CASTELLANO = ?");
			params.add(procedimientos.getAreas().getDescripcionCastellano());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDescripcionEuskera() != null) {
			where.append(" AND t3.DESCRIPCION_EUSKERA = ?");
			params.add(procedimientos.getAreas().getDescripcionEuskera());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(procedimientos.getAreas().getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getUsuarioRegistro() != null) {
			where.append(" AND t3.USUARIO_REGISTRO = ?");
			params.add(procedimientos.getAreas().getUsuarioRegistro());
		}
		if (procedimientos != null && procedimientos.getCodProcedureId() != null) {
			where.append(" AND t1.COD_PROCEDURE_ID = ?");
			params.add(procedimientos.getCodProcedureId());
		}
		if (procedimientos != null && procedimientos.getCamposTituloExpediente() != null) {
			where.append(" AND t1.CAMPOS_TITULO_EXPEDIENTE = ?");
			params.add(procedimientos.getCamposTituloExpediente());
		}
		if (procedimientos != null && procedimientos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(procedimientos.getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(procedimientos.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the Procedimientos entity
	 *
	 * @param procedimientos
	 *            Procedimientos Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(Procedimientos procedimientos, Boolean startsWith) {

		StringBuilder where = new StringBuilder(ProcedimientosDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (procedimientos != null && procedimientos.getIdProcedimiento() != null) {
			where.append(" AND t1.ID_PROCEDIMIENTO = ?");
			params.add(procedimientos.getIdProcedimiento());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getIdDireccion() != null) {
			where.append(" AND t2.ID_DIRECCION = ?");
			params.add(procedimientos.getDirecciones().getIdDireccion());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDepartamentos() != null
				&& procedimientos.getDirecciones().getDepartamentos().getIdDepartamento() != null) {
			where.append(" AND t2.ID_DEPARTAMENTO = ?");
			params.add(procedimientos.getDirecciones().getDepartamentos().getIdDepartamento());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getDirecciones().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getDirecciones().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t2.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getDirecciones().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getDirecciones().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t2.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(procedimientos.getDirecciones().getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getDirecciones() != null
				&& procedimientos.getDirecciones().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getDirecciones().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getDirecciones().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getIdArea() != null) {
			where.append(" AND t3.ID_AREA = ?");
			params.add(procedimientos.getAreas().getIdArea());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDirecciones() != null
				&& procedimientos.getAreas().getDirecciones().getIdDireccion() != null) {
			where.append(" AND t3.ID_DIRECCION = ?");
			params.add(procedimientos.getAreas().getDirecciones().getIdDireccion());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getAreas().getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getAreas().getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t3.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getAreas().getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getAreas().getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t3.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getFechaRegistro() != null) {
			where.append(" AND t3.FECHA_REGISTRO = ?");
			params.add(procedimientos.getAreas().getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getAreas() != null
				&& procedimientos.getAreas().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t3.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getAreas().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getAreas().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t3.USUARIO_REGISTRO IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getCodProcedureId() != null) {
			where.append(" AND UPPER(t1.COD_PROCEDURE_ID) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getCodProcedureId().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getCodProcedureId().toUpperCase() + "%");
			}
			where.append(" AND t1.COD_PROCEDURE_ID IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getCamposTituloExpediente() != null) {
			where.append(" AND UPPER(t1.CAMPOS_TITULO_EXPEDIENTE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getCamposTituloExpediente().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getCamposTituloExpediente().toUpperCase() + "%");
			}
			where.append(" AND t1.CAMPOS_TITULO_EXPEDIENTE IS NOT NULL");
		}
		if (procedimientos != null && procedimientos.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(procedimientos.getFechaRegistro());
		}
		if (procedimientos != null && procedimientos.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(procedimientos.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + procedimientos.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
