package com.ejie.ab63.dao.terceros;

import java.util.List;

import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.expedientes.Expedientes;
import com.ejie.ab63.model.terceros.DatosTerceros;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DatosTercerosDao  
 * 
 *  
 */

public interface DatosTercerosDao {

	/**
	 * Inserts a single row in the DatosTerceros table.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros add(DatosTerceros datosterceros);

	/**
	 * Finds el siguiente al ultimo id de la tabla in the DatosTerceros table.
	 *
	 * @return datosTercerosiD
	 */
	DatosTerceros findUltimoId();

	/**
	 * Updates a single row in the DatosTerceros table.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros update(DatosTerceros datosterceros);

	/**
	 * Upadte los terceros que viene de searchFolder
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros updateTerceroSearchfolder(DatosTerceros datosterceros);

	/**
	 * Removes a single row in the DatosTerceros table.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 */
	void remove(Integer idTercero);

	/**
	 * Remove todo del tipo participante 2
	 *
	 * 
	 *
	 */
	public void remove();

	/**
	 * Finds a List of rows in the DatosTerceros table.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List
	 */
	List<DatosTerceros> findAll(DatosTerceros datosterceros, JQGridRequestDto jqGridRequestDto);

	/**
	 * Insert los terceros que viene de searchFolder
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @return DatosTerceros
	 */
	DatosTerceros addTerceroSearchFolder(DatosTerceros datosterceros);

	/**
	 * Finds rows in the DatosTerceros table using like.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List
	 */
	List<DatosTerceros> findAllLike(DatosTerceros datosterceros, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Filter in the DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Counts rows in the DatosTerceros table using like.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	Long findAllLikeCount(DatosTerceros datosterceros, Boolean startsWith);

	/**
	 * Counts rows in the DatosTerceros table.
	 *
	 * @param datosterceros
	 *            DatosTerceros
	 * @return Long
	 */
	Long findAllCount(DatosTerceros datosterceros);

	/**
	 * Reorder selection.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerceros>>
	 */
	List<TableRowDto<DatosTerceros>> reorderSelection(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Searches in the Usuario table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param searchDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<DatosTerceros>>
	 */
	List<TableRowDto<DatosTerceros>> search(DatosTerceros filterDatosTerceros, DatosTerceros searchDatosTerceros,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Filter in the hierarchical DatosTerceros table.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<DatosTerceros>>
	 */
	List<JerarquiaDto<DatosTerceros>> findAllLikeJerarquia(DatosTerceros filterDatosTerceros,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	Long findAllLikeCountJerarquia(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto);

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<DatosTerceros>>
	 */
	List<TableRowDto<DatosTerceros>> findAllChild(DatosTerceros filterDatosTerceros, JQGridRequestDto jqGridRequestDto);

	List<DatosTerceros> findAllByExpdiente(Expedientes expedientes);

	List<DatosTerceros> findAllByEstablecimiento(Establecimiento establecimiento);

	DatosTerceros findByEstablecimiento(Establecimiento establecimientoCambios, Integer idTercero);

	DatosTerceros findById(Integer idTercero);

}
