package com.ejie.ab63.dao.terceros;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.terceros.DatosTerceros;
import com.ejie.ab63.model.terceros.RelExpTer;
import com.ejie.ab63.model.terceros.Sexo;
import com.ejie.ab63.model.terceros.TiposDocumento;
import com.ejie.ab63.model.terceros.TiposTercero;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * RelExpTerDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class RelExpTerDaoImpl implements RelExpTerDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDRELEXPTER", "IDEXPEDIENTE", "IDTIPOTERCERO",
			"DESCRIPCIONCASTELLANO", "DESCRIPCIONEUSKERA", "PARTICIPANTID", "ORDEN", "FECHAREGISTRO", "USUARIOREGISTRO",
			"DATOSTERCEROSIDTERCERO", "DATOSTERCEROSDOCUMENTO", "DATOSTERCEROSIDTIPODOCUMENTO", "DATOSTERCEROSNOMBRE",
			"DATOSTERCEROSAPELLIDO1", "DATOSTERCEROSAPELLIDO2", "DATOSTERCEROSIDSEXO", "DATOSTERCEROSTELEFONO",
			"DATOSTERCEROSEMAIL", "DATOSTERCEROSIDIOMA", "DATOSTERCEROSTIPOPARTICIPANTE", "DATOSTERCEROSFECHAREGISTRO",
			"DATOSTERCEROSUSUARIOREGISTRO", "DATOSTERCEROSFECHAULTMOD", "DATOSTERCEROSUSUARIOULTMOD",
			"DATOSTERCEROSIDREPRESENTANTE" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<RelExpTer> rwMap = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpTer expTer = new RelExpTer(resultSet.getInt("IDRELEXPTER"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getString("PARTICIPANTID"), 0, resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"),
					new DatosTerceros(resultSet.getInt("DatosTercerosIDTERCERO"),
							resultSet.getString("DatosTercerosDOCUMENTO"),
							new TiposDocumento(resultSet.getLong("DATOSTERCEROSIDTIPODOCUMENTO"),
									resultSet.getString("DESCRIPCION_CASTELLANO"),
									resultSet.getString("DESCRIPCION_EUSKERA"), resultSet.getDate("FECHA_REGISTRO"),
									resultSet.getString("USUARIO_REGISTRO")),
							resultSet.getString("DatosTercerosNOMBRE"), resultSet.getString("DatosTercerosAPELLIDO1"),
							resultSet.getString("DatosTercerosAPELLIDO2"),
							new Sexo(resultSet.getLong("ID_SEXO"), resultSet.getString("DESCRIPCION_CASTELLANO"),
									resultSet.getString("DESCRIPCION_EUSKERA"), resultSet.getDate("FECHA_REGISTRO"),
									resultSet.getString("USUARIO_REGISTRO")),
							resultSet.getLong("DatosTercerosTELEFONO"), resultSet.getString("DatosTercerosEMAIL"),
							resultSet.getInt("DatosTercerosIDIOMA"), resultSet.getInt("DatosTercerosTIPOPARTICIPANTE"),
							resultSet.getDate("DatosTercerosFECHAREGISTRO"),
							resultSet.getString("DatosTercerosUSUARIOREGISTRO"),
							resultSet.getDate("DatosTercerosFECHAULTMOD"),
							resultSet.getString("DatosTercerosUSUARIOULTMOD")),
					new TiposTercero(resultSet.getLong("IDTIPOTERCERO"), resultSet.getString("DESCRIPCIONCASTELLANO"),
							resultSet.getString("DESCRIPCIONEUSKERA"), null, null, null));
			return expTer;
		}
	};

	private RowMapper<RelExpTer> rwMapAgrupado = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpTer expTer = new RelExpTer(resultSet.getInt("IDRELEXPTER"), resultSet.getInt("IDEXPEDIENTE"),
					resultSet.getString("PARTICIPANTID"), null, resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), new DatosTerceros(resultSet.getInt("IDTERCERO")),
					new TiposTercero(resultSet.getLong("IDTIPOTERCERO")));
			return expTer;
		}
	};

	private RowMapper<RelExpTer> rwMapIdTercero = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpTer ter = new RelExpTer();
			DatosTerceros datosTercero = new DatosTerceros();
			TiposTercero tiposTercero = new TiposTercero();
			tiposTercero.setIdTipoTercero(resultSet.getLong("IDTIPOTERCERO"));
			tiposTercero.setRole(resultSet.getString("ROLE"));
			datosTercero.setIdTercero(resultSet.getInt("DATOSTERCEROSIDTERCERO"));
			datosTercero.setTipoParticipante(resultSet.getInt("DATOSTERCEROSTIPOPARTICIPANTE"));
			datosTercero.setDocumento(resultSet.getString("DOCUMENTO"));
			ter.setDatosTerceros(datosTercero);
			ter.setTiposTercero(tiposTercero);
			ter.setParticipantId(resultSet.getString("PARTICIPANTID"));
			return ter;
		}
	};

	private RowMapper<DatosTerceros> rwMapTercero = new RowMapper<DatosTerceros>() {
		public DatosTerceros mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			DatosTerceros datosTercero = new DatosTerceros();
			TiposTercero tiposTercero = new TiposTercero();
			tiposTercero.setIdTipoTercero(resultSet.getLong("IDTIPOTERCERO"));
			tiposTercero.setRole(resultSet.getString("ROLE"));
			datosTercero.setIdTercero(resultSet.getInt("DATOSTERCEROSIDTERCERO"));
			datosTercero.setTipoParticipante(resultSet.getInt("DATOSTERCEROSTIPOPARTICIPANTE"));
			datosTercero.setDocumento(resultSet.getString("DOCUMENTO"));
			return datosTercero;
		}
	};

	private RowMapper<RelExpTer> rwMapValorParticipacion = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpTer ter = new RelExpTer(resultSet.getInt("IDRELEXPTER"));
			DatosTerceros datosTerceros = new DatosTerceros(resultSet.getInt("IDTERCERO"));
			datosTerceros.setDocumento(resultSet.getString("DOCUMENTO"));
			ter.setParticipantId(resultSet.getString("PARTICIPANTID"));
			ter.setDatosTerceros(datosTerceros);
			return ter;
		}
	};

	private RowMapper<RelExpTer> rwMapParticipantId = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			RelExpTer ter = new RelExpTer();
			DatosTerceros datosTercero = new DatosTerceros();
			datosTercero.setIdTercero(resultSet.getInt("DATOSTERCEROSIDTERCERO"));
			datosTercero.setDocumento(resultSet.getString("DOCUMENTO"));
			datosTercero.setTipoParticipante(resultSet.getInt("TIPOPARTICIPANTE"));
			ter.setDatosTerceros(datosTercero);
			ter.setParticipantId(resultSet.getString("PARTICIPANTID"));
			return ter;
		}
	};

	private RowMapper<RelExpTer> rwMapParticipantes = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			RelExpTer ter = new RelExpTer();
			DatosTerceros datosTercero = new DatosTerceros();
			TiposTercero tiposTercero = new TiposTercero();
			tiposTercero.setIdTipoTercero(resultSet.getLong("IDTIPOTERCERO"));
			tiposTercero.setDescripcionCastellano(resultSet.getString("DESCRIPCIONCASTELLANO"));
			tiposTercero.setDescripcionEuskera(resultSet.getString("DESCRIPCIONEUSKERA"));

			datosTercero.setIdTercero(resultSet.getInt("DATOSTERCEROSIDTERCERO"));
			datosTercero.setNombre(resultSet.getString("NOMBRE"));
			datosTercero.setApellido1(resultSet.getString("APELLIDO1"));
			datosTercero.setApellido2(resultSet.getString("APELLIDO2"));
			datosTercero.setDocumento(resultSet.getString("DOCUMENTO"));
			datosTercero.setTipoParticipante(resultSet.getInt("DATOSTERCEROSTIPOPARTICIPANTE"));
			ter.setDatosTerceros(datosTercero);
			ter.setTiposTercero(tiposTercero);
			ter.setParticipantId(resultSet.getString("PARTICIPANTID"));
			ter.setOrden(resultSet.getInt("ORDEN"));

			return ter;
		}
	};
	private RowMapper<RelExpTer> rwMapPK = new RowMapper<RelExpTer>() {
		public RelExpTer mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new RelExpTer(resultSet.getInt("IDRELEXPTER"));
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	public RelExpTer add(RelExpTer relexpter) {
		String query = "INSERT INTO REL_EXP_TER (ID_REL_EXP_TER, ID_TERCERO, ID_EXPEDIENTE, ID_TIPO_TERCERO, PARTICIPANT_ID, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (AB61.S_AB6134T00.NEXTVAL,?,?,?,?,?,?)";
		Object getDatosTercerosIdTerceroAux = null;
		if (relexpter.getDatosTerceros() != null && relexpter.getDatosTerceros().getIdTercero() != null) {
			getDatosTercerosIdTerceroAux = relexpter.getDatosTerceros().getIdTercero();
		}
		Object getTiposTerceroIdTipoTerceroAux = null;
		if (relexpter.getTiposTercero() != null && relexpter.getTiposTercero().getIdTipoTercero() != null) {
			getTiposTerceroIdTipoTerceroAux = relexpter.getTiposTercero().getIdTipoTercero();
		}
		this.jdbcTemplate.update(query, getDatosTercerosIdTerceroAux, relexpter.getIdExpediente(),
				getTiposTerceroIdTipoTerceroAux, relexpter.getParticipantId(), relexpter.getFechaRegistro(),
				relexpter.getUsuarioRegistro());
		return relexpter;
	}

	/**
	 * Updates a single row in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	public RelExpTer update(RelExpTer relexpter) {
		String query = "UPDATE REL_EXP_TER SET ID_TERCERO=?, ID_EXPEDIENTE=?, ID_TIPO_TERCERO=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_REL_EXP_TER=?";
		Object getDatosTercerosIdTerceroAux = null;
		if (relexpter.getDatosTerceros() != null && relexpter.getDatosTerceros().getIdTercero() != null) {
			getDatosTercerosIdTerceroAux = relexpter.getDatosTerceros().getIdTercero();
		}
		Object getTiposTerceroIdTipoTerceroAux = null;
		if (relexpter.getTiposTercero() != null && relexpter.getTiposTercero().getIdTipoTercero() != null) {
			getTiposTerceroIdTipoTerceroAux = relexpter.getTiposTercero().getIdTipoTercero();
		}
		this.jdbcTemplate.update(query, getDatosTercerosIdTerceroAux, relexpter.getIdExpediente(),
				getTiposTerceroIdTipoTerceroAux, relexpter.getFechaRegistro(), relexpter.getUsuarioRegistro(),
				relexpter.getIdRelExpTer());
		return relexpter;
	}

	/**
	 * Update tipo de una relacion
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	public RelExpTer updateByParticipantId(RelExpTer relexpter) {
		String query = "UPDATE REL_EXP_TER SET ID_TIPO_TERCERO=?, FECHA_ULTMODIFICACION =?, USUARIO_ULTMODIFICACION =? WHERE PARTICIPANT_ID =?";

		Object getTiposTerceroIdTipoTerceroAux = null;
		if (relexpter.getTiposTercero() != null && relexpter.getTiposTercero().getIdTipoTercero() != null) {
			getTiposTerceroIdTipoTerceroAux = relexpter.getTiposTercero().getIdTipoTercero();
		}
		this.jdbcTemplate.update(query, getTiposTerceroIdTipoTerceroAux, relexpter.getFechaUltmodificacion(),
				relexpter.getUsuarioUltmodificacion(), relexpter.getParticipantId());
		return relexpter;
	}

	/**
	 * Update valor de participacionid
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	public RelExpTer updateByParticipantValue(RelExpTer relexpter) {
		String query = "UPDATE REL_EXP_TER SET PARTICIPANT_ID =?, FECHA_ULTMODIFICACION =?, USUARIO_ULTMODIFICACION =? WHERE ID_TERCERO =?";

		this.jdbcTemplate.update(query, relexpter.getParticipantId(), relexpter.getFechaUltmodificacion(),
				relexpter.getUsuarioUltmodificacion(), relexpter.getDatosTerceros().getIdTercero());
		return relexpter;
	}

	/**
	 * Finds a single row in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	@Transactional(readOnly = true)
	public RelExpTer find(RelExpTer relexpter) {
		String query = "SELECT t1.ID_REL_EXP_TER IDRELEXPTER, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.PARTICIPANT_ID PARTICIPANTID, t1.ID_TIPO_TERCERO IDTIPOTERCERO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO, t2.ID_TERCERO DATOSTERCEROSIDTERCERO, t2.DOCUMENTO DATOSTERCEROSDOCUMENTO, t3.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t3.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t3.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t3.FECHA_REGISTRO,t3.USUARIO_REGISTRO, t2.NOMBRE DATOSTERCEROSNOMBRE, t2.APELLIDO1 DATOSTERCEROSAPELLIDO1, t2.APELLIDO2 DATOSTERCEROSAPELLIDO2, t4.ID_SEXO,t4.DESCRIPCION_CASTELLANO,t4.DESCRIPCION_EUSKERA,t4.FECHA_REGISTRO,t4.USUARIO_REGISTRO, t2.TELEFONO DATOSTERCEROSTELEFONO, t2.EMAIL DATOSTERCEROSEMAIL, t2.IDIOMA DATOSTERCEROSIDIOMA, t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE, t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO, t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD, t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD, t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE FROM REL_EXP_TER t1 , DATOS_TERCERO t2, TIPOS_DOCUMENTO t3, SEXO t4 WHERE t1.ID_REL_EXP_TER = ?   AND t1.ID_TERCERO= t2.ID_TERCERO(+) AND t2.ID_TIPO_DOCUMENTO  = t3.ID_TIPO_DOCUMENTO (+) AND t2.ID_SEXO = t4.ID_SEXO(+) ";

		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMap, relexpter.getIdRelExpTer());
		return (RelExpTer) DataAccessUtils.uniqueResult(relexpterList);
	}

	/**
	 * Finds lista de parcicipaciones de la tabla RelExpTer
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findParticipantId(Integer idExpediente) {
		String query = "SELECT t1.PARTICIPANT_ID AS PARTICIPANTID, t1.ID_TERCERO AS DATOSTERCEROSIDTERCERO, t2.DOCUMENTO AS DOCUMENTO, t2.TIPO_PARTICIPANTE AS TIPOPARTICIPANTE FROM AB61.REL_EXP_TER t1, AB61.DATOS_TERCEROS t2 WHERE t1.ID_TERCERO = t2.ID_TERCERO AND t1.ID_EXPEDIENTE = ? AND t1.PARTICIPANT_ID IS NOT NULL";
		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMapParticipantId, idExpediente);

		return relexpterList;
	}

	/**
	 * buscar valor de participaciones
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findValorParticipant(Integer idExpediente) {
		String query = "SELECT T1.ID_REL_EXP_TER IDRELEXPTER, T1.PARTICIPANT_ID PARTICIPANTID, t1.id_tercero IDTERCERO,t2.DOCUMENTO DOCUMENTO FROM REL_EXP_TER T1, DATOS_TERCERO t2 WHERE t1.id_tercero = T2.ID_TERCERO AND T1.ID_EXPEDIENTE = ?  AND (T1.ID_TIPO_TERCERO = 1 OR T1.ID_TIPO_TERCERO = 3) order by T1.PARTICIPANT_ID ";
		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMapValorParticipacion, idExpediente);

		return relexpterList;
	}

	/**
	 * Finds lista de participantes de la tabla RelExpTer
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return RelExpTer
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findParticipantes(Integer idExpediente) {
		String query = "SELECT  T1.ID_TIPO_TERCERO AS IDTIPOTERCERO,T3.DESCRIPCION_CASTELLANO AS DESCRIPCIONCASTELLANO, T3.DESCRIPCION_EUSKERA AS DESCRIPCIONEUSKERA, T1.PARTICIPANT_ID AS PARTICIPANTID, T1.ID_TERCERO AS DATOSTERCEROSIDTERCERO , T2.NOMBRE AS NOMBRE, T2.APELLIDO1 AS APELLIDO1, T2.APELLIDO2 AS APELLIDO2, T2.TIPO_PARTICIPANTE AS DATOSTERCEROSTIPOPARTICIPANTE , T2.DOCUMENTO AS DOCUMENTO ,DECODE(  T1.ID_TIPO_TERCERO, 1,1 ,2,9,3,2,4,3,5,4,6,8,7,6,8,7,5)AS ORDEN FROM   REL_EXP_TER T1, DATOS_TERCERO T2 , AB61.TIPOS_TERCERO T3  WHERE  T1.ID_EXPEDIENTE = ? AND T1.ID_TERCERO = T2.ID_TERCERO AND T1.ID_TIPO_TERCERO =  T3.ID_TIPO_TERCERO  ORDER BY ORDEN , PARTICIPANTID , DATOSTERCEROSTIPOPARTICIPANTE  ASC";
		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMapParticipantes, idExpediente);

		return relexpterList;
	}

	/**
	 * Removes a single row in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return
	 */
	public void remove(RelExpTer relexpter) {
		String query = "DELETE FROM REL_EXP_TER WHERE ID_REL_EXP_TER=?";
		this.jdbcTemplate.update(query, relexpter.getIdRelExpTer());
	}

	/**
	 * Remove a single row in the RelExpTer dado un idTercero
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return
	 */
	public void removeidTercero(Integer idTercero) {
		String query = "DELETE FROM REL_EXP_TER WHERE ID_TERCERO = ?";
		this.jdbcTemplate.update(query, idTercero);
	}

	/**
	 * Finds a list of rows in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<RelExpTer>
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findAll(RelExpTer relexpter, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_TER IDRELEXPTER,t1.PARTICIPANT_ID PARTICIPANTID,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TIPO_TERCERO IDTIPOTERCERO,T3.DESCRIPCION_CASTELLANO AS DESCRIPCIONCASTELLANO, T3.DESCRIPCION_EUSKERA AS DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TERCERO DATOSTERCEROSIDTERCERO,t2.DOCUMENTO DATOSTERCEROSDOCUMENTO,t2.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t2.NOMBRE DATOSTERCEROSNOMBRE,t2.APELLIDO1 DATOSTERCEROSAPELLIDO1,t2.APELLIDO2 DATOSTERCEROSAPELLIDO2,t2.ID_SEXO DATOSTERCEROSIDSEXO,t2.TELEFONO DATOSTERCEROSTELEFONO,t2.EMAIL DATOSTERCEROSEMAIL,t2.IDIOMA DATOSTERCEROSIDIOMA,t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE,t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO,t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD,t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD,t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE, DECODE(  T1.ID_TIPO_TERCERO, 1,1 ,2,9,3,2,4,3,5,4,6,8,7,6,8,7,5)AS ORDEN,t3.DESCRIPCION_CASTELLANO,t3.DESCRIPCION_EUSKERA,t3.FECHA_REGISTRO,t3.USUARIO_REGISTRO, t2.NOMBRE DATOSTERCEROSNOMBRE, t2.APELLIDO1 DATOSTERCEROSAPELLIDO1, t2.APELLIDO2 DATOSTERCEROSAPELLIDO2, t4.ID_SEXO,t4.DESCRIPCION_CASTELLANO,t4.DESCRIPCION_EUSKERA,t4.FECHA_REGISTRO,t4.USUARIO_REGISTRO, t2.TELEFONO DATOSTERCEROSTELEFONO, t2.EMAIL DATOSTERCEROSEMAIL, t2.IDIOMA DATOSTERCEROSIDIOMA, t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE, t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO, t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD, t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD, t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE   ");
		query.append("FROM REL_EXP_TER t1, DATOS_TERCERO t2, AB61.TIPOS_TERCERO t3, SEXO t4  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpter);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) AND t1.ID_TIPO_TERCERO = t3.ID_TIPO_TERCERO(+)  AND t2.ID_SEXO = t4.ID_SEXO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpTerDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpTer>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	@Transactional(readOnly = true)
	public List<RelExpTer> findParticipacionesAgrupadas(RelExpTer relexpter) {
		StringBuilder query = new StringBuilder(
				"SELECT DISTINCT t1.ID_REL_EXP_TER IDRELEXPTER, t1.PARTICIPANT_ID PARTICIPANTID, t1.ID_TERCERO IDTERCERO, t1.ID_EXPEDIENTE IDEXPEDIENTE, t1.ID_TIPO_TERCERO IDTIPOTERCERO, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append(" FROM REL_EXP_TER t1 WHERE t1.ID_EXPEDIENTE = ? ");
		return (List<RelExpTer>) this.jdbcTemplate.query(query.toString(), this.rwMapAgrupado,
				relexpter.getIdExpediente());
	}

	/**
	 * Finds rows in the RelExpTer table using like.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<RelExpTer>
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findAllLike(RelExpTer relexpter, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_REL_EXP_TER IDRELEXPTER,T1.PARTICIPANT_ID PARTICIPANTID,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TIPO_TERCERO IDTIPOTERCERO,T3.DESCRIPCION_CASTELLANO AS DESCRIPCIONCASTELLANO, T3.DESCRIPCION_EUSKERA AS DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TERCERO DATOSTERCEROSIDTERCERO,t2.DOCUMENTO DATOSTERCEROSDOCUMENTO,t2.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t2.NOMBRE DATOSTERCEROSNOMBRE,t2.APELLIDO1 DATOSTERCEROSAPELLIDO1,t2.APELLIDO2 DATOSTERCEROSAPELLIDO2,t2.ID_SEXO DATOSTERCEROSIDSEXO,t2.TELEFONO DATOSTERCEROSTELEFONO,t2.EMAIL DATOSTERCEROSEMAIL,t2.IDIOMA DATOSTERCEROSIDIOMA,t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE,t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO,t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD,t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD,t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE, DECODE(  T1.ID_TIPO_TERCERO, 1,1 ,2,9,3,2,4,3,5,4,6,8,7,6,8,7,5)AS ORDEN,t3.DESCRIPCION_CASTELLANO,t3.DESCRIPCION_EUSKERA,t3.FECHA_REGISTRO,t3.USUARIO_REGISTRO, t2.NOMBRE DATOSTERCEROSNOMBRE, t2.APELLIDO1 DATOSTERCEROSAPELLIDO1, t2.APELLIDO2 DATOSTERCEROSAPELLIDO2, t4.ID_SEXO,t4.DESCRIPCION_CASTELLANO,t4.DESCRIPCION_EUSKERA,t4.FECHA_REGISTRO,t4.USUARIO_REGISTRO, t2.TELEFONO DATOSTERCEROSTELEFONO, t2.EMAIL DATOSTERCEROSEMAIL, t2.IDIOMA DATOSTERCEROSIDIOMA, t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE, t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO, t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO, t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD, t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD, t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE   ");
		query.append(
				"FROM REL_EXP_TER t1, DATOS_TERCERO t2 , AB61.TIPOS_TERCERO t3, SEXO t4  AND t2.ID_SEXO = t4.ID_SEXO(+)  ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpter, startsWith);
		StringBuilder where = new StringBuilder(
				" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) AND t1.ID_TIPO_TERCERO = t3.ID_TIPO_TERCERO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, RelExpTerDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<RelExpTer>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Busca los id terceros en la tabla de Rel_Exp_Ter
	 *
	 * @param idExpediente
	 *            Integer
	 * @param partipant_id
	 *            String
	 * @param role
	 *            String
	 * 
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findIdTerceros(Integer idExpediente) {

		String query = "SELECT  T1.ID_TERCERO   AS DATOSTERCEROSIDTERCERO, T1.PARTICIPANT_ID PARTICIPANTID, T2.TIPO_PARTICIPANTE AS DATOSTERCEROSTIPOPARTICIPANTE,  T2.DOCUMENTO AS DOCUMENTO,  T3.ROLE  AS ROLE , T1.ID_TIPO_TERCERO   AS IDTIPOTERCERO FROM REL_EXP_TER T1, DATOS_TERCERO T2, AB61.TIPOS_TERCERO T3 WHERE T1.ID_EXPEDIENTE = ? AND T2.ID_TERCERO      = T1.ID_TERCERO AND T1.ID_TIPO_TERCERO = T3.ID_TIPO_TERCERO AND PARTICIPANT_ID IS NOT NULL ";
		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMapIdTercero, idExpediente);
		return relexpterList;

	}

	/**
	 * Busca los id terceros en la tabla de Rel_Exp_Ter
	 *
	 * @param idExpediente
	 *            Integer
	 * @param partipant_id
	 *            String
	 * @param role
	 *            String
	 * 
	 * @return List
	 */
	@Transactional(readOnly = true)
	public Integer findFirstTerceroWhitoutEstablecimiento(Integer idExpediente) {
		String query = "SELECT MIN(T1.ID_TERCERO) AS VALOR FROM REL_EXP_TER T1, DATOS_DIRECCIONES T2 WHERE T1.ID_TERCERO = T2.ID_TERCERO(+) AND T1.ID_EXPEDIENTE = ? ";
		return this.jdbcTemplate.queryForObject(query, Integer.class, idExpediente);

	}

	/**
	 * Busca los id terceros en la tabla de Rel_Exp_Ter
	 *
	 * @param idExpediente
	 *            Integer
	 * @param partipant_id
	 *            String
	 * @param role
	 *            String
	 * 
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<RelExpTer> findIdTerceros(Integer idExpediente, String participantId) {

		String query = "SELECT T1.ID_TERCERO AS DATOSTERCEROSIDTERCERO, T1.PARTICIPANT_ID PARTICIPANTID, T2.TIPO_PARTICIPANTE AS DATOSTERCEROSTIPOPARTICIPANTE,  T2.DOCUMENTO AS DOCUMENTO, T3.ROLE AS ROLE , T1.ID_TIPO_TERCERO AS IDTIPOTERCERO FROM REL_EXP_TER T1,DATOS_TERCERO T2, AB61.TIPOS_TERCERO T3 WHERE T1.ID_EXPEDIENTE = ? AND T1.PARTICIPANT_ID = ? AND T2.ID_TERCERO = T1.ID_TERCERO AND T1.ID_TIPO_TERCERO = T3.ID_TIPO_TERCERO";

		List<RelExpTer> relexpterList = this.jdbcTemplate.query(query, this.rwMapIdTercero, idExpediente,
				participantId);
		return relexpterList;

	}

	/**
	 * Busca los id terceros en la tabla de Rel_Exp_Ter
	 *
	 * @param idExpediente
	 *            Integer
	 * @param partipant_id
	 *            String
	 * @param role
	 *            String
	 * 
	 * @return List
	 */
	@Transactional(readOnly = true)
	public List<DatosTerceros> findTerceros(Integer idExpediente, String participantId) {

		String query = "SELECT T1.ID_TERCERO AS DATOSTERCEROSIDTERCERO, T1.PARTICIPANT_ID PARTICIPANTID, T2.TIPO_PARTICIPANTE AS DATOSTERCEROSTIPOPARTICIPANTE,  T2.DOCUMENTO AS DOCUMENTO, T3.ROLE AS ROLE , T1.ID_TIPO_TERCERO AS IDTIPOTERCERO FROM REL_EXP_TER T1,DATOS_TERCERO T2, AB61.TIPOS_TERCERO T3 WHERE  T2.ID_TERCERO = T1.ID_TERCERO AND T1.ID_TIPO_TERCERO = T3.ID_TIPO_TERCERO AND T1.ID_EXPEDIENTE = ? ";
		if (participantId == null) {
			query += "AND T1.PARTICIPANT_ID IS NULL ";
			return (List<DatosTerceros>) this.jdbcTemplate.query(query, this.rwMapTercero, idExpediente);
		} else {
			query += "AND T1.PARTICIPANT_ID = ? ";
			return (List<DatosTerceros>) this.jdbcTemplate.query(query, this.rwMapTercero, idExpediente, participantId);
		}
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the RelExpTer table.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(RelExpTer relexpter) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_TER t1 , DATOS_TERCERO t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(relexpter);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), Long.class, params.toArray());
	}

	/**
	 * Counts rows in the RelExpTer table using like.
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(RelExpTer relexpter, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM REL_EXP_TER t1 ,DATOS_TERCERO t2 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpter, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForObject(query.toString(), Long.class, params.toArray());
	}

	/**
	 * Reorder the data list of RelExpTer selected for rup_table
	 *
	 * @param relexpter
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpTer>>
	 */
	@Override
	public List<TableRowDto<RelExpTer>> reorderSelection(RelExpTer relexpter, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_TER IDRELEXPTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TERCERO DATOSTERCEROSIDTERCERO,t2.DOCUMENTO DATOSTERCEROSDOCUMENTO,t2.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t2.NOMBRE DATOSTERCEROSNOMBRE,t2.APELLIDO1 DATOSTERCEROSAPELLIDO1,t2.APELLIDO2 DATOSTERCEROSAPELLIDO2,t2.ID_SEXO DATOSTERCEROSIDSEXO,t2.TELEFONO DATOSTERCEROSTELEFONO,t2.EMAIL DATOSTERCEROSEMAIL,t2.IDIOMA DATOSTERCEROSIDIOMA,t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE,t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO,t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD,t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD,t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE ");
		// FROM
		query.append("FROM REL_EXP_TER t1 ,DATOS_TERCERO t2 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(relexpter, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, RelExpTer.class,
				filterParamList, "ID_REL_EXP_TER");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpTer>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            RelExpTer
	 * @param searchParams
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<RelExpTer>>
	 */
	@Override
	public List<TableRowDto<RelExpTer>> search(RelExpTer filterParams, RelExpTer searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_TER IDRELEXPTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TERCERO DATOSTERCEROSIDTERCERO,t2.DOCUMENTO DATOSTERCEROSDOCUMENTO,t2.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t2.NOMBRE DATOSTERCEROSNOMBRE,t2.APELLIDO1 DATOSTERCEROSAPELLIDO1,t2.APELLIDO2 DATOSTERCEROSAPELLIDO2,t2.ID_SEXO DATOSTERCEROSIDSEXO,t2.TELEFONO DATOSTERCEROSTELEFONO,t2.EMAIL DATOSTERCEROSEMAIL,t2.IDIOMA DATOSTERCEROSIDIOMA,t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE,t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO,t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD,t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD,t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE ");
		// FROM
		query.append("FROM REL_EXP_TER t1 ,DATOS_TERCERO t2 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ID_TERCERO= t2.ID_TERCERO(+) ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, RelExpTer.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_REL_EXP_TER");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<RelExpTer>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filterrelexpter
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(RelExpTer filterrelexpter, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_REL_EXP_TER IDRELEXPTER,t1.ID_EXPEDIENTE IDEXPEDIENTE,t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO,t2.ID_TERCERO DATOSTERCEROSIDTERCERO,t2.DOCUMENTO DATOSTERCEROSDOCUMENTO,t2.ID_TIPO_DOCUMENTO DATOSTERCEROSIDTIPODOCUMENTO,t2.NOMBRE DATOSTERCEROSNOMBRE,t2.APELLIDO1 DATOSTERCEROSAPELLIDO1,t2.APELLIDO2 DATOSTERCEROSAPELLIDO2,t2.ID_SEXO DATOSTERCEROSIDSEXO,t2.TELEFONO DATOSTERCEROSTELEFONO,t2.EMAIL DATOSTERCEROSEMAIL,t2.IDIOMA DATOSTERCEROSIDIOMA,t2.TIPO_PARTICIPANTE DATOSTERCEROSTIPOPARTICIPANTE,t2.FECHA_REGISTRO DATOSTERCEROSFECHAREGISTRO,t2.USUARIO_REGISTRO DATOSTERCEROSUSUARIOREGISTRO,t2.FECHA_ULTMODIFICACION DATOSTERCEROSFECHAULTMOD,t2.USUARIO_ULTMODIFICACION DATOSTERCEROSUSUARIOULTMOD,t2.ID_REPRESENTANTE DATOSTERCEROSIDREPRESENTANTE ");
		// FROM
		query.append("FROM REL_EXP_TER t1 ,DATOS_TERCERO t2 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filterrelexpter, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, RelExpTer.class,
				query, params, "ID_REL_EXP_TER");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterRelExpTer
	 *            RelExpTer
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<RelExpTer>>
	 */
	@Override
	public List<TableRowDto<RelExpTer>> findAllChild(RelExpTer filterRelExpTer, JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM REL_EXP_TER t1
		// ,DATOS_TERCERO t2 ");
		List<String> from = new ArrayList<String>();
		from.add("REL_EXP_TER");
		from.add("DATOS_TERCERO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");
		from_alias.add(" t2 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterRelExpTer, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_REL_EXP_TER",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<RelExpTer>(this.rwMapPK, "ID_REL_EXP_TER"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpTer entity
	 *
	 * @param relexpter
	 *            RelExpTer Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(RelExpTer relexpter) {

		StringBuilder where = new StringBuilder(RelExpTerDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpter != null && relexpter.getIdRelExpTer() != null) {
			where.append(" AND t1.ID_REL_EXP_TER = ?");
			params.add(relexpter.getIdRelExpTer());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getIdTercero() != null) {
			where.append(" AND t2.ID_TERCERO = ?");
			params.add(relexpter.getDatosTerceros().getIdTercero());
		}

		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getDocumento() != null) {
			where.append(" AND t2.DOCUMENTO = ?");
			params.add(relexpter.getDatosTerceros().getDocumento());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTiposDocumento().getIdTipoDocumento() != null) {
			where.append(" AND t2.ID_TIPO_DOCUMENTO = ?");
			params.add(relexpter.getDatosTerceros().getTiposDocumento().getIdTipoDocumento());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getNombre() != null) {
			where.append(" AND t2.NOMBRE = ?");
			params.add(relexpter.getDatosTerceros().getNombre());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getApellido1() != null) {
			where.append(" AND t2.APELLIDO1 = ?");
			params.add(relexpter.getDatosTerceros().getApellido1());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getApellido2() != null) {
			where.append(" AND t2.APELLIDO2 = ?");
			params.add(relexpter.getDatosTerceros().getApellido2());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getSexo().getIdSexo() != null) {
			where.append(" AND t2.ID_SEXO = ?");
			params.add(relexpter.getDatosTerceros().getSexo().getIdSexo());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTelefono() != null) {
			where.append(" AND t2.TELEFONO = ?");
			params.add(relexpter.getDatosTerceros().getTelefono());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getEmail() != null) {
			where.append(" AND t2.EMAIL = ?");
			params.add(relexpter.getDatosTerceros().getEmail());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getIdioma() != null) {
			where.append(" AND t2.IDIOMA = ?");
			params.add(relexpter.getDatosTerceros().getIdioma());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTipoParticipante() != null) {
			where.append(" AND t2.TIPO_PARTICIPANTE = ?");
			params.add(relexpter.getDatosTerceros().getTipoParticipante());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpter.getDatosTerceros().getFechaRegistro());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getUsuarioRegistro() != null) {
			where.append(" AND t2.USUARIO_REGISTRO = ?");
			params.add(relexpter.getDatosTerceros().getUsuarioRegistro());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpter.getDatosTerceros().getFechaUltmodificacion());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getUsuarioUltmodificacion() != null) {
			where.append(" AND t2.USUARIO_ULTMODIFICACION = ?");
			params.add(relexpter.getDatosTerceros().getUsuarioUltmodificacion());
		}
		if (relexpter != null && relexpter.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpter.getIdExpediente());
		}
		if (relexpter != null && relexpter.getTiposTercero() != null) {
			where.append(" AND t1.ID_TIPO_TERCERO = ?");
			params.add(relexpter.getTiposTercero().getIdTipoTercero());
		}
		if (relexpter != null && relexpter.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpter.getFechaRegistro());
		}
		if (relexpter != null && relexpter.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(relexpter.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the RelExpTer entity
	 *
	 * @param relexpter
	 *            RelExpTer Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(RelExpTer relexpter, Boolean startsWith) {

		StringBuilder where = new StringBuilder(RelExpTerDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (relexpter != null && relexpter.getIdRelExpTer() != null) {
			where.append(" AND t1.ID_REL_EXP_TER = ?");
			params.add(relexpter.getIdRelExpTer());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getIdTercero() != null) {
			where.append(" AND t2.ID_TERCERO = ?");
			params.add(relexpter.getDatosTerceros().getIdTercero());
		}

		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getDocumento() != null) {
			where.append(" AND UPPER(t2.DOCUMENTO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getDocumento().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getDocumento().toUpperCase() + "%");
			}
			where.append(" AND t2.DOCUMENTO IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTiposDocumento().getIdTipoDocumento() != null) {
			where.append(" AND t2.ID_TIPO_DOCUMENTO = ?");
			params.add(relexpter.getDatosTerceros().getTiposDocumento().getIdTipoDocumento());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getNombre() != null) {
			where.append(" AND UPPER(t2.NOMBRE) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getNombre().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getNombre().toUpperCase() + "%");
			}
			where.append(" AND t2.NOMBRE IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getApellido1() != null) {
			where.append(" AND UPPER(t2.APELLIDO1) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getApellido1().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getApellido1().toUpperCase() + "%");
			}
			where.append(" AND t2.APELLIDO1 IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getApellido2() != null) {
			where.append(" AND UPPER(t2.APELLIDO2) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getApellido2().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getApellido2().toUpperCase() + "%");
			}
			where.append(" AND t2.APELLIDO2 IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getSexo().getIdSexo() != null) {
			where.append(" AND t2.ID_SEXO = ?");
			params.add(relexpter.getDatosTerceros().getSexo().getIdSexo());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTelefono() != null) {
			where.append(" AND t2.TELEFONO = ?");
			params.add(relexpter.getDatosTerceros().getTelefono());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getEmail() != null) {
			where.append(" AND UPPER(t2.EMAIL) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getEmail().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getEmail().toUpperCase() + "%");
			}
			where.append(" AND t2.EMAIL IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getIdioma() != null) {
			where.append(" AND t2.IDIOMA = ?");
			params.add(relexpter.getDatosTerceros().getIdioma());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getTipoParticipante() != null) {
			where.append(" AND t2.TIPO_PARTICIPANTE = ?");
			params.add(relexpter.getDatosTerceros().getTipoParticipante());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getFechaRegistro() != null) {
			where.append(" AND t2.FECHA_REGISTRO = ?");
			params.add(relexpter.getDatosTerceros().getFechaRegistro());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t2.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_REGISTRO IS NOT NULL");
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getFechaUltmodificacion() != null) {
			where.append(" AND t2.FECHA_ULTMODIFICACION = ?");
			params.add(relexpter.getDatosTerceros().getFechaUltmodificacion());
		}
		if (relexpter != null && relexpter.getDatosTerceros() != null
				&& relexpter.getDatosTerceros().getUsuarioUltmodificacion() != null) {
			where.append(" AND UPPER(t2.USUARIO_ULTMODIFICACION) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getDatosTerceros().getUsuarioUltmodificacion().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getDatosTerceros().getUsuarioUltmodificacion().toUpperCase() + "%");
			}
			where.append(" AND t2.USUARIO_ULTMODIFICACION IS NOT NULL");
		}
		if (relexpter != null && relexpter.getIdExpediente() != null) {
			where.append(" AND t1.ID_EXPEDIENTE = ?");
			params.add(relexpter.getIdExpediente());
		}
		if (relexpter != null && relexpter.getTiposTercero() != null) {
			where.append(" AND t1.ID_TIPO_TERCERO = ?");
			params.add(relexpter.getTiposTercero().getIdTipoTercero());
		}
		if (relexpter != null && relexpter.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(relexpter.getFechaRegistro());
		}
		if (relexpter != null && relexpter.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(relexpter.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + relexpter.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
