package com.ejie.ab63.dao.terceros;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.sql.DataSource;

import org.springframework.dao.support.DataAccessUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.model.terceros.TiposTercero;
import com.ejie.x38.dao.RowNumResultSetExtractor;
import com.ejie.x38.dto.JQGridManager;
import com.ejie.x38.dto.JQGridManagerJerarquia;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposTerceroDaoImpl  
 * 
 *  
 */

@Repository
@Transactional
public class TiposTerceroDaoImpl implements TiposTerceroDao {

	public static final String[] ORDER_BY_WHITE_LIST = new String[] { "IDTIPOTERCERO", "DESCRIPCIONCASTELLANO",
			"DESCRIPCIONEUSKERA", "FECHAREGISTRO", "USUARIOREGISTRO", "ROLE" };

	private JdbcTemplate jdbcTemplate;

	/*
	 * ROW_MAPPERS
	 */
	private RowMapper<TiposTercero> rwMap = new RowMapper<TiposTercero>() {
		public TiposTercero mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposTercero(resultSet.getLong("IDTIPOTERCERO"), resultSet.getString("DESCRIPCIONCASTELLANO"),
					resultSet.getString("DESCRIPCIONEUSKERA"), resultSet.getDate("FECHAREGISTRO"),
					resultSet.getString("USUARIOREGISTRO"), resultSet.getString("ROLE"));
		}
	};

	private RowMapper<TiposTercero> rwMapPK = new RowMapper<TiposTercero>() {
		public TiposTercero mapRow(ResultSet resultSet, int rowNum) throws SQLException {
			return new TiposTercero(resultSet.getLong("IDTIPOTERCERO"));
		}
	};

	/**
	 * Rowmapper para Jerarquía
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	private RowMapper<JerarquiaDto<TiposTercero>> rwMapJerarquia = new RowMapper<JerarquiaDto<TiposTercero>>() {
		public JerarquiaDto<TiposTercero> mapRow(ResultSet resultSet, int rowNum) throws SQLException {

			TiposTercero tipostercero = new TiposTercero(resultSet.getLong("IDTIPOTERCERO"),
					resultSet.getString("DESCRIPCIONCASTELLANO"), resultSet.getString("DESCRIPCIONEUSKERA"),
					resultSet.getDate("FECHAREGISTRO"), resultSet.getString("USUARIOREGISTRO"),
					resultSet.getString("ROLE"));

			JerarquiaDto<TiposTercero> jerarquia = new JerarquiaDto<TiposTercero>();
			jerarquia.setModel(tipostercero);
			jerarquia.setLevel(resultSet.getBigDecimal("LEVEL").intValue());
			jerarquia.setParentNodes(resultSet.getString("PARENTNODES"));
			jerarquia.setIsLeaf(Boolean.parseBoolean(resultSet.getString("ISLEAF")));
			jerarquia.setFilter(Boolean.parseBoolean(resultSet.getString("FILTER")));
			return jerarquia;
		}
	};

	/**
	 * Method use to set the datasource.
	 *
	 * @param dataSource
	 *            DataSource
	 * @return
	 */
	@Resource
	public void setDataSource(DataSource dataSource) {
		this.jdbcTemplate = new JdbcTemplate(dataSource);
	}

	/*
	 * OPERACIONES CRUD
	 */

	/**
	 * Inserts a single row in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return TiposTercero
	 */
	public TiposTercero add(TiposTercero tipostercero) {
		String query = "INSERT INTO AB61.TIPOS_TERCERO (ID_TIPO_TERCERO, DESCRIPCION_CASTELLANO, DESCRIPCION_EUSKERA, FECHA_REGISTRO, USUARIO_REGISTRO) VALUES (?,?,?,?,?)";
		this.jdbcTemplate.update(query, tipostercero.getIdTipoTercero(), tipostercero.getDescripcionCastellano(),
				tipostercero.getDescripcionEuskera(), tipostercero.getFechaRegistro(),
				tipostercero.getUsuarioRegistro());
		return tipostercero;
	}

	/**
	 * Updates a single row in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return TiposTercero
	 */
	public TiposTercero update(TiposTercero tipostercero) {
		String query = "UPDATE AB61.TIPOS_TERCERO SET DESCRIPCION_CASTELLANO=?, DESCRIPCION_EUSKERA=?, FECHA_REGISTRO=?, USUARIO_REGISTRO=? WHERE ID_TIPO_TERCERO=?";
		this.jdbcTemplate.update(query, tipostercero.getDescripcionCastellano(), tipostercero.getDescripcionEuskera(),
				tipostercero.getFechaRegistro(), tipostercero.getUsuarioRegistro(), tipostercero.getIdTipoTercero());
		return tipostercero;
	}

	/**
	 * Finds a single row in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return TiposTercero
	 */
	@Transactional(readOnly = true)
	public TiposTercero find(TiposTercero tipostercero) {
		String query = "SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO, t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO, t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA, t1.FECHA_REGISTRO FECHAREGISTRO, t1.USUARIO_REGISTRO USUARIOREGISTRO FROM AB61.TIPOS_TERCERO t1  WHERE t1.ID_TIPO_TERCERO = ?  ";

		List<TiposTercero> tiposterceroList = this.jdbcTemplate.query(query, this.rwMap,
				tipostercero.getIdTipoTercero());
		return (TiposTercero) DataAccessUtils.uniqueResult(tiposterceroList);
	}

	/**
	 * Finds a idTipoTercero in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return TiposTercero
	 */
	@Transactional(readOnly = true)
	public TiposTercero findIdTipoTercero(String role) {
		String query = "SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO FROM AB61.TIPOS_TERCERO t1  WHERE t1.ROLE = ?  ";

		List<TiposTercero> tiposterceroList = this.jdbcTemplate.query(query, this.rwMapPK, role);
		return (TiposTercero) DataAccessUtils.uniqueResult(tiposterceroList);
	}

	/**
	 * Removes a single row in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return
	 */
	public void remove(TiposTercero tipostercero) {
		String query = "DELETE FROM  AB61.TIPOS_TERCERO WHERE ID_TIPO_TERCERO=?";
		this.jdbcTemplate.update(query, tipostercero.getIdTipoTercero());
	}

	/**
	 * Finds a list of rows in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposTercero>
	 */
	@Transactional(readOnly = true)
	public List<TiposTercero> findAll(TiposTercero tipostercero, JQGridRequestDto jqGridRequestDto) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO, t1.ROLE ROLE ");
		query.append("FROM AB61.TIPOS_TERCERO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tipostercero);
		StringBuilder where = new StringBuilder(" WHERE 1=1 AND t1.ROLE IS NULL ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposTerceroDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposTercero>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/**
	 * Finds rows in the TiposTercero table using like.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposTercero>
	 */
	@Transactional(readOnly = true)
	public List<TiposTercero> findAllLike(TiposTercero tipostercero, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		StringBuilder query = new StringBuilder(
				"SELECT  t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		query.append("FROM AB61.TIPOS_TERCERO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tipostercero, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		if (jqGridRequestDto != null) {
			query = JQGridManager.getPaginationQuery(jqGridRequestDto, query, TiposTerceroDaoImpl.ORDER_BY_WHITE_LIST);
		}

		return (List<TiposTercero>) this.jdbcTemplate.query(query.toString(), this.rwMap, params.toArray());
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Counts rows in the TiposTercero table.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllCount(TiposTercero tipostercero) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB61.TIPOS_TERCERO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereMap(tipostercero);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Counts rows in the TiposTercero table using like.
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @param startsWith
	 *            Boolean
	 * @return Long
	 */
	@Transactional(readOnly = true)
	public Long findAllLikeCount(TiposTercero tipostercero, Boolean startsWith) {
		StringBuilder query = new StringBuilder("SELECT COUNT(1) FROM AB61.TIPOS_TERCERO t1 ");

		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tipostercero, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Reorder the data list of TiposTercero selected for rup_table
	 *
	 * @param tipostercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposTercero>>
	 */
	@Override
	public List<TableRowDto<TiposTercero>> reorderSelection(TiposTercero tipostercero,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AB61.TIPOS_TERCERO t1 ");
		// FILTRADO
		// Where clause & Params
		Map<String, ?> mapaWhere = this.getWhereLikeMap(tipostercero, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		// Parámetros de filtrado
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhere.get("params");

		// SQL para la reordenación
		StringBuilder sbReorderSelectionSQL = JQGridManager.getReorderQuery(query, jqGridRequestDto, TiposTercero.class,
				filterParamList, "ID_TIPO_TERCERO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposTercero>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Search method for rup_table
	 *
	 * @param filterParams
	 *            TiposTercero
	 * @param searchParams
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposTercero>>
	 */
	@Override
	public List<TableRowDto<TiposTercero>> search(TiposTercero filterParams, TiposTercero searchParams,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AB61.TIPOS_TERCERO t1 ");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// FILTRADO
		Map<String, ?> mapaWhereFilter = this.getWhereLikeMap(filterParams, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhereFilter.get("query"));
		query.append(where);
		// Filter params
		@SuppressWarnings("unchecked")
		List<Object> filterParamList = (List<Object>) mapaWhereFilter.get("params");

		// BUSQUEDA
		Map<String, Object> mapaWhereSearch = this.getWhereLikeMap(searchParams, startsWith);
		String searchSQL = ((StringBuilder) mapaWhereSearch.get("query")).toString();
		// Search params
		@SuppressWarnings("unchecked")
		List<Object> searchParamList = (List<Object>) mapaWhereSearch.get("params");

		// SQL
		StringBuilder sbReorderSelectionSQL = JQGridManager.getSearchQuery(query, jqGridRequestDto, TiposTercero.class,
				filterParamList, searchSQL, searchParamList, from_alias, "ID_TIPO_TERCERO");

		return this.jdbcTemplate.query(sbReorderSelectionSQL.toString(),
				new RowNumResultSetExtractor<TiposTercero>(this.rwMapPK, jqGridRequestDto), filterParamList.toArray());
	}

	/**
	 * Remove multiple method for rup_table
	 *
	 * @param filtertipostercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	@Override
	public void removeMultiple(TiposTercero filtertipostercero, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		// SELECT
		/** TODO: select por clave */
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		query.append("FROM AB61.TIPOS_TERCERO t1 ");

		// WHERE
		Map<String, Object> mapaWhere = this.getWhereLikeMap(filtertipostercero, startsWith);
		StringBuilder where = new StringBuilder(" WHERE 1=1 ");
		where.append(mapaWhere.get("query"));
		query.append(where);

		@SuppressWarnings("unchecked")
		List<Object> params = (List<Object>) mapaWhere.get("params");

		StringBuilder sbRemoveMultipleSQL = JQGridManager.getRemoveMultipleQuery(jqGridRequestDto, TiposTercero.class,
				query, params, "ID_TIPO_TERCERO");
		this.jdbcTemplate.update(sbRemoveMultipleSQL.toString(), params.toArray());
	}

	/**
	 * Filter in the hierarchical TiposTercero table.
	 *
	 * @param filterTiposTercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<JerarquiaDto<TiposTercero>>
	 */
	@Override
	public List<JerarquiaDto<TiposTercero>> findAllLikeJerarquia(TiposTercero filterTiposTercero,
			JQGridRequestDto jqGridRequestDto) {
		// SELECT
		StringBuilder query = new StringBuilder(
				"SELECT t1.ID_TIPO_TERCERO IDTIPOTERCERO,t1.DESCRIPCION_CASTELLANO DESCRIPCIONCASTELLANO,t1.DESCRIPCION_EUSKERA DESCRIPCIONEUSKERA,t1.FECHA_REGISTRO FECHAREGISTRO,t1.USUARIO_REGISTRO USUARIOREGISTRO ");
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB61.TIPOS_TERCERO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AB61.TIPOS_TERCERO");
		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposTercero, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query, mapaWhere, "ID_TIPO_TERCERO", "ID_PADRE",
				"NOMBRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// query = JQGridManagerJerarquia.getQuery(jqGridRequestDto, query,
		// mapaWhere, "ID", "ID_PADRE", "NOMBRE", from, from_alias, joins,
		// businessFilters, businessParams);

		// PAGINACION
		if (jqGridRequestDto != null) {
			query = JQGridManagerJerarquia.getPaginationQuery(jqGridRequestDto, query,
					TiposTerceroDaoImpl.ORDER_BY_WHITE_LIST);
		}

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.query(query.toString(), this.rwMapJerarquia, params.toArray());
	}

	/**
	 * Count rows in hierarchy
	 *
	 * @param filterTiposTercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return Long
	 */
	@Override
	public Long findAllLikeCountJerarquia(TiposTercero filterTiposTercero, JQGridRequestDto jqGridRequestDto) {
		// FROM
		// StringBuilder from = new StringBuilder("FROM AB61.TIPOS_TERCERO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AB61.TIPOS_TERCERO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposTercero, false);

		// JERARQUIA
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere, "ID_TIPO_TERCERO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryCount(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");
		return this.jdbcTemplate.queryForLong(query.toString(), params.toArray());
	}

	/**
	 * Find dependent hierarchical rows
	 *
	 * @param filterTiposTercero
	 *            TiposTercero
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TableRowDto<TiposTercero>>
	 */
	@Override
	public List<TableRowDto<TiposTercero>> findAllChild(TiposTercero filterTiposTercero,
			JQGridRequestDto jqGridRequestDto) {

		// FROM
		// StringBuilder from = new StringBuilder("FROM AB61.TIPOS_TERCERO t1
		// ");
		List<String> from = new ArrayList<String>();
		from.add("AB61.TIPOS_TERCERO");

		// TABLAS_ALIAS
		List<String> from_alias = new ArrayList<String>();
		from_alias.add(" t1 ");

		// JOINS TABLAS
		/*
		 * Ejemplo de como indicar joins entre las tablas de la query
		 */
		/*
		 * StringBuilder joins = new StringBuilder("");
		 * joins.append("AND T1.ID=T2.ID_T1");
		 */

		// CONDICIONES (negocio)
		/*
		 * Ejemplo de como incluir condiciones de negocio en la consulta de la
		 * jerarquía
		 */
		/*
		 * StringBuilder businessFilters = new StringBuilder(); List<Object>
		 * businessParams = new ArrayList<Object>();
		 * businessFilters.append("   AND t1.EJIE = ?  ");
		 * businessParams.add("1");
		 */

		// FILTRO
		Map<String, ?> mapaWhere = this.getWhereLikeMap(filterTiposTercero, false);

		// MULTISELECCION
		// Especificar la columna padre correspondiente en lugar de la generada
		// por defecto (ID_PADRE)
		StringBuilder query = JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere, "ID_TIPO_TERCERO",
				"ID_PADRE", from, from_alias);

		/*
		 * Ejemplo de llamada en caso de indicar joins entre tablas y
		 * condiciones de negocio
		 */
		// StringBuilder query =
		// JQGridManagerJerarquia.getQueryChildren(jqGridRequestDto, mapaWhere,
		// "ID", "ID_PADRE", from, from_alias, joins, businessFilters,
		// businessParams);

		List<?> params = (List<?>) mapaWhere.get("params");

		return this.jdbcTemplate.query(query.toString(),
				new RowNumResultSetExtractor<TiposTercero>(this.rwMapPK, "ID_TIPO_TERCERO"), params.toArray());
	}

	/*
	 * MÉTODOS PRIVADOS
	 */

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposTercero entity
	 *
	 * @param tipostercero
	 *            TiposTercero Bean with the criteria values to filter by.
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, ?> getWhereMap(TiposTercero tipostercero) {

		StringBuilder where = new StringBuilder(TiposTerceroDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tipostercero != null && tipostercero.getIdTipoTercero() != null) {
			where.append(" AND t1.ID_TIPO_TERCERO = ?");
			params.add(tipostercero.getIdTipoTercero());
		}
		if (tipostercero != null && tipostercero.getDescripcionCastellano() != null) {
			where.append(" AND t1.DESCRIPCION_CASTELLANO = ?");
			params.add(tipostercero.getDescripcionCastellano());
		}
		if (tipostercero != null && tipostercero.getDescripcionEuskera() != null) {
			where.append(" AND t1.DESCRIPCION_EUSKERA = ?");
			params.add(tipostercero.getDescripcionEuskera());
		}
		if (tipostercero != null && tipostercero.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tipostercero.getFechaRegistro());
		}
		if (tipostercero != null && tipostercero.getUsuarioRegistro() != null) {
			where.append(" AND t1.USUARIO_REGISTRO = ?");
			params.add(tipostercero.getUsuarioRegistro());
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * Returns a map with the needed value to create the conditions to filter by
	 * the TiposTercero entity
	 *
	 * @param tipostercero
	 *            TiposTercero Bean with the criteria values to filter by.
	 * @param startsWith
	 *            Boolean
	 * @return Map created with two keys key query stores the sql query syntax
	 *         key params stores the parameter values to be used in the
	 *         condition sentence.
	 */
	// CHECKSTYLE:OFF CyclomaticComplexity - Generación de código de UDA
	private Map<String, Object> getWhereLikeMap(TiposTercero tipostercero, Boolean startsWith) {

		StringBuilder where = new StringBuilder(TiposTerceroDaoImpl.STRING_BUILDER_INIT);
		List<Object> params = new ArrayList<Object>();

		if (tipostercero != null && tipostercero.getIdTipoTercero() != null) {
			where.append(" AND t1.ID_TIPO_TERCERO = ?");
			params.add(tipostercero.getIdTipoTercero());
		}
		if (tipostercero != null && tipostercero.getDescripcionCastellano() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_CASTELLANO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tipostercero.getDescripcionCastellano().toUpperCase() + "%");
			} else {
				params.add("%" + tipostercero.getDescripcionCastellano().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_CASTELLANO IS NOT NULL");
		}
		if (tipostercero != null && tipostercero.getDescripcionEuskera() != null) {
			where.append(" AND UPPER(t1.DESCRIPCION_EUSKERA) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tipostercero.getDescripcionEuskera().toUpperCase() + "%");
			} else {
				params.add("%" + tipostercero.getDescripcionEuskera().toUpperCase() + "%");
			}
			where.append(" AND t1.DESCRIPCION_EUSKERA IS NOT NULL");
		}
		if (tipostercero != null && tipostercero.getFechaRegistro() != null) {
			where.append(" AND t1.FECHA_REGISTRO = ?");
			params.add(tipostercero.getFechaRegistro());
		}
		if (tipostercero != null && tipostercero.getUsuarioRegistro() != null) {
			where.append(" AND UPPER(t1.USUARIO_REGISTRO) like ? ESCAPE  '\\'");
			if (startsWith) {
				params.add(tipostercero.getUsuarioRegistro().toUpperCase() + "%");
			} else {
				params.add("%" + tipostercero.getUsuarioRegistro().toUpperCase() + "%");
			}
			where.append(" AND t1.USUARIO_REGISTRO IS NOT NULL");
		}

		Map<String, Object> mapWhere = new HashMap<String, Object>();
		mapWhere.put("query", where);
		mapWhere.put("params", params);

		return mapWhere;
	}
	// CHECKSTYLE:ON CyclomaticComplexity - Generación de código de UDA

	/**
	 * StringBuilder initilization value
	 */
	public static final int STRING_BUILDER_INIT = 4096;
}
