package com.ejie.ab63.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.dao.HabitacionAlojamientoDao;
import com.ejie.ab63.model.HabitacionAlojamiento;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6324s00ServiceImpl  
 * 
 *  
 */

@Service(value = "habitacionAlojamientoService")
public class HabitacionAlojamientoServiceImpl implements HabitacionAlojamientoService {

	@Autowired
	private HabitacionAlojamientoDao habitacionAlojamientoDao;

	/**
	 * Inserts a single row in the Ab6324s00 table.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 * @return Ab6324s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public HabitacionAlojamiento add(HabitacionAlojamiento ab6324s00) {
		return this.habitacionAlojamientoDao.add(ab6324s00);
	}

	/**
	 * Updates a single row in the Ab6324s00 table.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 * @return Ab6324s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public HabitacionAlojamiento update(HabitacionAlojamiento ab6324s00) {
		return this.habitacionAlojamientoDao.update(ab6324s00);
	}

	/**
	 * Finds a single row in the Ab6324s00 table.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 * @return Ab6324s00
	 */
	public HabitacionAlojamiento find(HabitacionAlojamiento ab6324s00) {
		return (HabitacionAlojamiento) this.habitacionAlojamientoDao.find(ab6324s00);
	}

	/**
	 * Deletes a single row in the Ab6324s00 table.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(HabitacionAlojamiento ab6324s00) {
		this.habitacionAlojamientoDao.remove(ab6324s00);
	}

	/**
	 * Finds a list of rows in the Ab6324s00 table.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6324s00>
	 */
	public List<HabitacionAlojamiento> findAll(HabitacionAlojamiento ab6324s00, JQGridRequestDto jqGridRequestDto) {
		return (List<HabitacionAlojamiento>) this.habitacionAlojamientoDao.findAll(ab6324s00, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Ab6324s00 table using like.
	 *
	 * @param ab6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6324s00>
	 */
	public List<HabitacionAlojamiento> findAllLike(HabitacionAlojamiento ab6324s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<HabitacionAlojamiento>) this.habitacionAlojamientoDao.findAllLike(ab6324s00, jqGridRequestDto,
				startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(HabitacionAlojamiento filterAb6324s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.habitacionAlojamientoDao.removeMultiple(filterAb6324s00, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Ab6324s00>
	 */
	public JQGridResponseDto<HabitacionAlojamiento> filter(HabitacionAlojamiento filterAb6324s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<HabitacionAlojamiento> listaAb6324s00 = this.habitacionAlojamientoDao.findAllLike(filterAb6324s00,
				jqGridRequestDto, false);
		for (HabitacionAlojamiento habitacionAlojamiento : listaAb6324s00) {

			if (null != habitacionAlojamiento.getTipoRegistro() && habitacionAlojamiento.getTipoRegistro() == 1) {
				habitacionAlojamiento
						.setTotalPlazas(habitacionAlojamiento.getNumUnidades() * habitacionAlojamiento.getNumPlazas());
			}

			if (null != habitacionAlojamiento.getTipoHabitacion()
					&& !"".equals(habitacionAlojamiento.getTipoHabitacion().getIdTipoHabitacion())) {
				if (LocaleContextHolder.getLocale().getLanguage().equalsIgnoreCase(Constantes.CASTELLANO)) {
					habitacionAlojamiento.setDescTipoHab(habitacionAlojamiento.getTipoHabitacion().getDescTipoEs());
				} else {
					habitacionAlojamiento.setDescTipoHab(habitacionAlojamiento.getTipoHabitacion().getDescTipoEu());
				}
			}
			if (null != habitacionAlojamiento.getTipoAseo()
					&& !"".equals(habitacionAlojamiento.getTipoAseo().getIdTipoAseo())) {
				if (LocaleContextHolder.getLocale().getLanguage().equalsIgnoreCase(Constantes.CASTELLANO)) {
					habitacionAlojamiento.setDescTipoAseo(habitacionAlojamiento.getTipoAseo().getDescTipoEs());
				} else {
					habitacionAlojamiento.setDescTipoAseo(habitacionAlojamiento.getTipoAseo().getDescTipoEu());
				}
			}
		}
		Long recordNum = this.habitacionAlojamientoDao
				.findAllLikeCount(filterAb6324s00 != null ? filterAb6324s00 : new HabitacionAlojamiento(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<HabitacionAlojamiento>> reorderSelection = this.habitacionAlojamientoDao
					.reorderSelection(filterAb6324s00, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<HabitacionAlojamiento>(jqGridRequestDto, recordNum, listaAb6324s00,
					reorderSelection);
		}
		return new JQGridResponseDto<HabitacionAlojamiento>(jqGridRequestDto, recordNum, listaAb6324s00);
	}

	/**
	 * Searches rows in the Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param searchAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6324s00>>
	 */
	public List<TableRowDto<HabitacionAlojamiento>> search(HabitacionAlojamiento filterAb6324s00,
			HabitacionAlojamiento searchAb6324s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.habitacionAlojamientoDao.search(filterAb6324s00, searchAb6324s00, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(HabitacionAlojamiento filterAb6324s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.habitacionAlojamientoDao.reorderSelection(filterAb6324s00, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Ab6324s00>>
	 */
	public JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>> jerarquia(HabitacionAlojamiento filterAb6324s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<HabitacionAlojamiento>> listaAb6324s00 = this.habitacionAlojamientoDao
				.findAllLikeJerarquia(filterAb6324s00, jqGridRequestDto);
		Long recordNum = this.habitacionAlojamientoDao.findAllLikeCountJerarquia(filterAb6324s00, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>>(jqGridRequestDto, recordNum, listaAb6324s00);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Ab6324s00 table.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Ab6324s00>>
	 */
	public JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>> jerarquiaChildren(
			HabitacionAlojamiento filterAb6324s00, JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.habitacionAlojamientoDao.findAllChild(filterAb6324s00, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public HabitacionAlojamiento save(HabitacionAlojamiento ab6324s00) {
		if (null != ab6324s00.getIdHabitacionAlo() && ab6324s00.getIdHabitacionAlo() > 0) {
			return this.update(ab6324s00);
		} else {
			return this.add(ab6324s00);
		}
	}

	@Override
	public void deleteByIdAlojamiento(Integer idAlojamiento) {
		this.habitacionAlojamientoDao.deleteByIdAlojamiento(idAlojamiento);

	}

	@Override
	public void addMasivo(List<HabitacionAlojamiento> listaHabitacionAlojamiento) {
		for (HabitacionAlojamiento habitacionAlojamiento : listaHabitacionAlojamiento) {
			this.habitacionAlojamientoDao.add(habitacionAlojamiento);
		}
	}

	@Override
	public Long getTotalUnidadesResumen(Integer idAlojamiento) {
		return this.habitacionAlojamientoDao.getTotalUnidadesResumen(idAlojamiento);
	}

	@Override
	public Long getTotalUnidadesDetalle(Integer idAlojamiento) {
		return this.habitacionAlojamientoDao.getTotalUnidadesDetalle(idAlojamiento);
	}

	@Override
	public Long getTotalPlazasResumen(Integer idAlojamiento) {
		return this.habitacionAlojamientoDao.getTotalPlazasResumen(idAlojamiento);
	}

	@Override
	public Long getTotalPlazasDetalle(Integer idAlojamiento) {
		return this.habitacionAlojamientoDao.getTotalPlazasDetalle(idAlojamiento);
	}
}
