package com.ejie.ab63.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.dao.TipoEstablecimientoDao;
import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6311s00ServiceImpl  
 * 
 *  
 */

@Service(value = "tipoEstablecimientoService")
public class TipoEstablecimientoServiceImpl implements TipoEstablecimientoService {

	@Autowired
	private ReloadableResourceBundleMessageSource appMessageSource;

	@Autowired
	private TipoEstablecimientoDao ab6311s00Dao;

	/**
	 * Inserts a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TipoEstablecimiento add(TipoEstablecimiento ab6311s00) {
		return this.ab6311s00Dao.add(ab6311s00);
	}

	/**
	 * Updates a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TipoEstablecimiento update(TipoEstablecimiento ab6311s00) {
		return this.ab6311s00Dao.update(ab6311s00);
	}

	/**
	 * Finds a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @return Ab6311s00
	 */
	public TipoEstablecimiento find(TipoEstablecimiento ab6311s00) {
		return (TipoEstablecimiento) this.ab6311s00Dao.find(ab6311s00);
	}

	/**
	 * Deletes a single row in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TipoEstablecimiento ab6311s00) {
		this.ab6311s00Dao.remove(ab6311s00);
	}

	/**
	 * Finds a list of rows in the Ab6311s00 table.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Ab6311s00>
	 */
	public List<TipoEstablecimiento> findAll(TipoEstablecimiento ab6311s00, JQGridRequestDto jqGridRequestDto) {
		return (List<TipoEstablecimiento>) this.ab6311s00Dao.findAll(ab6311s00, jqGridRequestDto);
	}

	/**
	 * Finds rows in the Ab6311s00 table using like.
	 *
	 * @param ab6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Ab6311s00>
	 */
	public List<TipoEstablecimiento> findAllLike(TipoEstablecimiento ab6311s00, TableRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<TipoEstablecimiento>) this.ab6311s00Dao.findAllLike(ab6311s00, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TipoEstablecimiento filterAb6311s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.ab6311s00Dao.removeMultiple(filterAb6311s00, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Ab6311s00>
	 */
	public TableResponseDto<TipoEstablecimiento> filter(TipoEstablecimiento filterAb6311s00,
			TableRequestDto jqGridRequestDto, Boolean startsWith) {
		List<TipoEstablecimiento> listaAb6311s00 = this.ab6311s00Dao.findAllLike(filterAb6311s00, jqGridRequestDto,
				false);
		Long recordNum = this.ab6311s00Dao
				.findAllLikeCount(filterAb6311s00 != null ? filterAb6311s00 : new TipoEstablecimiento(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TipoEstablecimiento>> reorderSelection = this.ab6311s00Dao
					.reorderSelection(filterAb6311s00, jqGridRequestDto, startsWith);
			return new TableResponseDto<TipoEstablecimiento>(jqGridRequestDto, recordNum, listaAb6311s00,
					reorderSelection);
		}

		for (TipoEstablecimiento tipoEstablecimiento : listaAb6311s00) {

			if (tipoEstablecimiento.getOrdenacion() != null) {

				if (Constantes.RECLAMACION.equals(tipoEstablecimiento.getOrdenacion().trim())) {

					tipoEstablecimiento.setDescOrdenacion(
							appMessageSource.getMessage("reclamaciones", null, LocaleContextHolder.getLocale()));

				} else if (Constantes.ORDENACION.equals(tipoEstablecimiento.getOrdenacion().trim())) {

					tipoEstablecimiento.setDescOrdenacion(
							appMessageSource.getMessage("ordenacion", null, LocaleContextHolder.getLocale()));

				}

			}

			if (tipoEstablecimiento.getTipificacion() != null) {

				if (Constantes.TIPIFICACION_ALOJAMIENTO.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(appMessageSource.getMessage("tipificacion.alojamiento",
							null, LocaleContextHolder.getLocale()));

				} else if (Constantes.TIPIFICACION_MEDIACION.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(appMessageSource.getMessage("tipificacion.mediacion", null,
							LocaleContextHolder.getLocale()));

				} else if (Constantes.TIPIFICACION_PROFESIONES_TURISTICAS
						.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(appMessageSource.getMessage("tipificacion.profesiones",
							null, LocaleContextHolder.getLocale()));

				} else if (Constantes.TIPIFICACION_OTRAS_ACAMPADAS
						.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(appMessageSource.getMessage("tipificacion.otrasAcampadas",
							null, LocaleContextHolder.getLocale()));

				} else if (Constantes.TIPIFICACION_INTERES_TURISTICO
						.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(
							appMessageSource.getMessage("tipificacion.interes", null, LocaleContextHolder.getLocale()));

				} else if (Constantes.TIPIFICACION_OTROS.equals(tipoEstablecimiento.getTipificacion().trim())) {

					tipoEstablecimiento.setDescTipificacion(
							appMessageSource.getMessage("tipificacion.otros", null, LocaleContextHolder.getLocale()));
				}
			}

		}

		return new TableResponseDto<TipoEstablecimiento>(jqGridRequestDto, recordNum, listaAb6311s00);
	}

	/**
	 * Searches rows in the Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param searchAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Ab6311s00>>
	 */
	public List<TableRowDto<TipoEstablecimiento>> search(TipoEstablecimiento filterAb6311s00,
			TipoEstablecimiento searchAb6311s00, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.ab6311s00Dao.search(filterAb6311s00, searchAb6311s00, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TipoEstablecimiento filterAb6311s00, TableRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.ab6311s00Dao.reorderSelection(filterAb6311s00, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Ab6311s00>>
	 */
	public JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>> jerarquia(TipoEstablecimiento filterAb6311s00,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TipoEstablecimiento>> listaAb6311s00 = this.ab6311s00Dao.findAllLikeJerarquia(filterAb6311s00,
				jqGridRequestDto);
		Long recordNum = this.ab6311s00Dao.findAllLikeCountJerarquia(filterAb6311s00, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>>(jqGridRequestDto, recordNum, listaAb6311s00);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Ab6311s00 table.
	 *
	 * @param filterAb6311s00
	 *            Ab6311s00
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Ab6311s00>>
	 */
	public JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>> jerarquiaChildren(TipoEstablecimiento filterAb6311s00,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.ab6311s00Dao.findAllChild(filterAb6311s00, jqGridRequestDto));
		return jqGridResponseDto;
	}

	@Override
	public Object reorderSelection(TipoEstablecimiento filterAb6311s00, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		// TODO Auto-generated method stub
		return null;
	}

}
