package com.ejie.ab63.service.expedientes;

import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.springframework.ui.Model;

import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab63.model.InfoExpedienteEstablecimiento;
import com.ejie.ab63.model.Inspeccion;
import com.ejie.ab63.model.expedientes.Expedientes;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.model.util.ResultAjaxOperation;
import com.ejie.ab63.service.procedimientos.ProcedureActions;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

public interface ExpedientesService {

	/**
	 * Inserts a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes add(Expedientes expedientes);

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes update(Expedientes expedientes);

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes updateFolder(Expedientes expedientes);

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes updateExpedienteFolder(Expedientes expedientes);

	/**
	 * Actualiza la informacion de la base de datos con los datos de platea
	 * 
	 * @param model
	 * @param form
	 * @param resultado
	 * @throws Exception
	 */
	void loadInfoFromPlatea(Model model, InitForm form, TFolderList resultado) throws Exception;

	/**
	 * Metodo que actualizar el titulo del expediente con el titulo que viene de
	 * Platea (Tramitagune)
	 * 
	 * @param resultado
	 * @param usuario
	 * @param initForm
	 */
	void actualizarExpediente(TFolderList resultado, String usuario, InitForm initForm) throws Exception;

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes find(Expedientes expedientes);

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes findProcedureIdPorExpediente(Expedientes expedientes);

	/**
	 * Finds a single row in the Expedientes table por FolderId.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes findByFolderId(Expedientes expedientes);

	/**
	 * Finds a single row in the Expedientes table por FolderId.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes findByFolderNumber(Expedientes expedientes);

	/**
	 * Deletes a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 */
	void remove(Expedientes expedientes);

	/**
	 * Finds a list of rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Expedientes>
	 */
	List<Expedientes> findAll(Expedientes expedientes, JQGridRequestDto jqGridRequestDto);

	/**
	 * Finds rows in the Expedientes table using like.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Expedientes>
	 */
	List<Expedientes> findAllLikeTer(Expedientes expedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	void removeMultiple(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Filter method in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Expedientes>
	 */
	JQGridResponseDto<Expedientes> filterTer(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	JQGridResponseDto<Expedientes> filter(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith);

	/**
	 * Searches rows in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param searchExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Expedientes>>
	 */
	List<TableRowDto<Expedientes>> search(Expedientes filterExpedientes, Expedientes searchExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Reorder the selection made in Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	Object reorderSelection(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquia(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith);

	/**
	 * Finder method for siblings rows in the hierarchical the Expedientes
	 * table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquiaChildren(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto);

	/**
	 * llama al WS searchFolders
	 * 
	 * @param folderId
	 * @return TFolderList
	 * @throws Exception
	 */
	TFolderList obtenerInfoPlatea(String folderId) throws Exception;

	/**
	 * Método para obtener el Expediente mediante el FOLDER_NUMBER.
	 *
	 * @param String
	 *            folderNumber
	 * 
	 * @return List<Expedientes>
	 */
	List<Expedientes> findExpediente(String folderNumber);

	/**
	 * 
	 * @param filterEstablecimiento
	 * @param jqGridRequestDto
	 * @return
	 */
	JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByDniTitular(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto);

	/**
	 * 
	 * @param filterEstablecimiento
	 * @param jqGridRequestDto
	 * @return
	 */
	JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByDniRepresentante(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto);

	/**
	 * 
	 * @param filterEstablecimiento
	 * @param jqGridRequestDto
	 * @return
	 */
	JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByUbicacion(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto);

	/**
	 * 
	 * @param filterEstablecimiento
	 * @param jqGridRequestDto
	 * @return
	 */
	JQGridResponseDto<InfoExpedienteEstablecimiento> findExpRelByIdentificadorEst(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto, String origen);

	List<InfoExpedienteEstablecimiento> findExpRelByIdentificadorEstExcel(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto, String origen);

	List<Expedientes> findExpedientesPendientesByExpediente(Integer idExpediente);

	ResultAjaxOperation saveExpediente(InitForm initForm, ProcedureActions procedureActions, HttpServletRequest request,
			Boolean executeProcess);

	ResultAjaxOperation procesarAsociar(HttpServletRequest request, InitForm initForm,
			ProcedureActions procedureActions, List<String> listExpedientes);

	void comprobarExpedienteOficio(TFolderList resultado, InitForm initForm);

	List<Expedientes> findAllExpedientesOrigen(String identificadorEstablecimiento);

	Boolean updateOrigen(Expedientes expedientes);

	Boolean hasInspectExpedient(Integer idExpediente);

	Inspeccion getInspectExpedient(Integer idExpediente);

	Inspeccion getInspect(String idInspeccion);

	Boolean updateExpedienteTitle(InitForm initForm, Map<String, String> data, ProcedureActions procedureActions);

	boolean checkIsClosed(Expedientes expediente);

	/**
	 * Actualiza el territorio histrico
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	Expedientes updateTerritorioHistorico(Expedientes expediente);

	Date getMaxDateExpediente(Integer idExpediente, String tipoFecha, boolean isEtiqueta);

	Map<String, String> createExpedienteInicioOficio(String folderID, Integer idProcedimientoOficio,
			HttpServletRequest request);

}
