package com.ejie.ab63.service.expedientes;

import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.logging.Logger;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.ejie.ab63.adaptadores.X43ExpedienteElectronicoAdaptadorService;
import com.ejie.ab63.adaptadores.ab61WebServiceAdaptadorService;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TBoolean;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolder;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderCompleteQuery;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderList;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderOriginType;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderQuery;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderSearchType;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TFolderSearchTypeList;
import com.ejie.ab63.clientesWS.X43ExpedienteElectronico.TStringList;
import com.ejie.ab63.clientesWS.ab61WebService.Ab61Exception;
import com.ejie.ab63.clientesWS.ab61WebService.DatosInicioOficio;
import com.ejie.ab63.clientesWS.ab61WebService.EmisorInicioOficio;
import com.ejie.ab63.clientesWS.ab61WebService.InicioOficioWS;
import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.dao.expedientes.ExpedientesDao;
import com.ejie.ab63.model.DispensaEstablecimiento;
import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.InfoExpedienteEstablecimiento;
import com.ejie.ab63.model.Inspeccion;
import com.ejie.ab63.model.expedientes.Expedientes;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.model.procedimientos.Procedimientos;
import com.ejie.ab63.model.terceros.DatosDirecciones;
import com.ejie.ab63.model.util.ErrorResultAjaxOperation;
import com.ejie.ab63.model.util.ResultAjaxOperation;
import com.ejie.ab63.model.util.SuccessResultAjaxOperation;
import com.ejie.ab63.service.DispensaEstablecimientoService;
import com.ejie.ab63.service.EstablecimientoService;
import com.ejie.ab63.service.procedimientos.ProcedimientosService;
import com.ejie.ab63.service.procedimientos.ProcedureActions;
import com.ejie.ab63.service.terceros.DatosDireccionesService;
import com.ejie.ab63.service.terceros.RelExpTerService;
import com.ejie.ab63.util.PermisosXLNETS;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

@SessionAttributes("usuario")
@Service(value = "expedientesService")
public class ExpedientesServiceImpl implements ExpedientesService {

	private final static Logger logger = Logger.getLogger(ExpedientesServiceImpl.class.getName());

	@Autowired
	private ExpedientesDao expedientesDao;

	@Autowired
	private ProcedimientosService procedimientosService;

	@Autowired
	private DatosDireccionesService direccionesService;

	@Autowired
	private EstablecimientoService establecimientoService;

	@Autowired
	private DispensaEstablecimientoService dispensasService;

	@Autowired
	private X43ExpedienteElectronicoAdaptadorService expedienteElectronicoWS;

	@Autowired
	private ab61WebServiceAdaptadorService ab61WebServiceService;

	@Autowired
	private ReloadableResourceBundleMessageSource appMessageSource;

	@Autowired
	private RelExpTerService relExpTerService;

	/**
	 * Inserts a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes add(Expedientes expedientes) {
		return this.expedientesDao.add(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes update(Expedientes expedientes) {
		return this.expedientesDao.update(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes updateFolder(Expedientes expedientes) {
		return this.expedientesDao.updateFolder(expedientes);
	}

	/**
	 * Updates a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Expedientes updateExpedienteFolder(Expedientes expedientes) {
		return this.expedientesDao.updateExpedienteFolder(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes find(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.find(expedientes);
	}

	@Transactional(rollbackFor = Throwable.class)
	public void loadInfoFromPlatea(Model model, InitForm form, TFolderList resultado) throws Exception {
		// Actualizamos el expediente.
		actualizarExpediente(resultado, PermisosXLNETS.getUserConnected(), form);

		// Comprobacion inicio de oficio
		comprobarExpedienteOficio(resultado, form);

		// Lista de personas de la Participacion
		this.relExpTerService.actualizarListParticipantesPorParticipacion(resultado, form.getIdExpediente(),
				PermisosXLNETS.getUserConnected(), form);
	}

	/**
	 * Finds a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findProcedureIdPorExpediente(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findProcedureIdPorExpediente(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table por Folder ID.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findByFolderId(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findByFolderId(expedientes);
	}

	/**
	 * Finds a single row in the Expedientes table por Folder ID.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @return Expedientes
	 */
	public Expedientes findByFolderNumber(Expedientes expedientes) {
		return (Expedientes) this.expedientesDao.findByFolderNumber(expedientes);
	}

	/**
	 * Deletes a single row in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Expedientes expedientes) {
		this.expedientesDao.remove(expedientes);
	}

	/**
	 * Finds a list of rows in the Expedientes table.
	 *
	 * @param expedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Expedientes>
	 */
	public List<Expedientes> findAll(Expedientes expedientes, JQGridRequestDto jqGridRequestDto) {
		return (List<Expedientes>) this.expedientesDao.findAll(expedientes, jqGridRequestDto);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		this.expedientesDao.removeMultiple(filterExpedientes, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDtor
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Expedientes>
	 */
	public JQGridResponseDto<Expedientes> filterTer(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		List<Expedientes> listaExpedientes = this.expedientesDao.findAllLikeTer(filterExpedientes, jqGridRequestDto,
				false);
		Long recordNum = this.expedientesDao
				.findAllLikeCountTer(filterExpedientes != null ? filterExpedientes : new Expedientes(), false);

		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Expedientes>> reorderSelection = this.expedientesDao.reorderSelection(filterExpedientes,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes, reorderSelection);
		}

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Filter method in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDtor
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Expedientes>
	 */
	public JQGridResponseDto<Expedientes> filter(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {

		List<Expedientes> listaExpedientes = this.expedientesDao.findAllLike(filterExpedientes, jqGridRequestDto,
				false);
		Long recordNum = this.expedientesDao
				.findAllLikeCount(filterExpedientes != null ? filterExpedientes : new Expedientes(), false);

		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Expedientes>> reorderSelection = this.expedientesDao.reorderSelection(filterExpedientes,
					jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes, reorderSelection);
		}

		return new JQGridResponseDto<Expedientes>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Finds rows in the ActSubvencionable table using like.
	 *
	 * @param Expedientes
	 *            expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<ActSubvencionable>
	 */
	public List<Expedientes> findAllLikeTer(Expedientes expedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<Expedientes>) this.expedientesDao.findAllLikeTer(expedientes, jqGridRequestDto, startsWith);
	}

	/**
	 * Método para obtener el Expediente mediante el FOLDER_NUMBER.
	 *
	 * @param String
	 *            folderNumber
	 * 
	 * @return List<Expedientes> Expedientes
	 */

	public List<Expedientes> findExpediente(String folderNumber) {

		return expedientesDao.findLupaExpediente(folderNumber);

	}

	/**
	 * Searches rows in the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param searchExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Expedientes>>
	 */
	public List<TableRowDto<Expedientes>> search(Expedientes filterExpedientes, Expedientes searchExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.expedientesDao.search(filterExpedientes, searchExpedientes, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Expedientes filterExpedientes, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.expedientesDao.reorderSelection(filterExpedientes, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Expedientes table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquia(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Expedientes>> listaExpedientes = this.expedientesDao.findAllLikeJerarquia(filterExpedientes,
				jqGridRequestDto);
		Long recordNum = this.expedientesDao.findAllLikeCountJerarquia(filterExpedientes, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Expedientes>>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Expedientes
	 * table.
	 *
	 * @param filterExpedientes
	 *            Expedientes
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Expedientes>>
	 */
	public JQGridResponseDto<JerarquiaDto<Expedientes>> jerarquiaChildren(Expedientes filterExpedientes,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Expedientes>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Expedientes>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.expedientesDao.findAllChild(filterExpedientes, jqGridRequestDto));
		return jqGridResponseDto;
	}

	/**
	 * llama al WS searchFolders
	 * 
	 * @param folderId
	 * @return TFolderList
	 * @throws Exception
	 */
	@Override
	public TFolderList obtenerInfoPlatea(String folderId) throws Exception {

		logger.info("obtenerInfoPlatea:inicio: folderId: " + folderId);
		String auditUser = Constantes.AUDIT_USER;

		TFolderList resultado = null;
		try {

			TFolderQuery query = new TFolderQuery();
			TFolderCompleteQuery tFolderComplete = new TFolderCompleteQuery();

			TStringList folderIdList = new TStringList();

			folderIdList.getItem().add(folderId);

			TFolderSearchType tFolderSearchType = TFolderSearchType.PARAM_ALL;
			TFolderSearchTypeList tFolderSearchTypeList = new TFolderSearchTypeList();
			tFolderSearchTypeList.getParam().add(tFolderSearchType);
			tFolderComplete.setParamList(tFolderSearchTypeList);

			tFolderComplete.setAuditUser(auditUser);
			tFolderComplete.setFolderIDList(folderIdList);
			tFolderComplete.setInterestedMode(TBoolean.TRUE);

			query.setComplete(tFolderComplete);

			resultado = expedienteElectronicoWS.SearchFolders(query, null);

		} catch (Exception e) {
			logger.info("No esta disponible el SearchFolders");
			resultado = null;
		}
		return resultado;
	}

	/**
	 * Método que actualizar el tiutlo del expediente con el titulo que viene
	 * de Platea (Tramitagune)
	 * 
	 * @param resultado
	 * @param usuario
	 */
	public void actualizarExpediente(TFolderList resultado, String usuario, InitForm initForm) throws Exception {
		logger.info("INICIO actualizarTituloExpediente");
		if (!resultado.getFolder().isEmpty()) {
			// actualizamos en BD
			Expedientes expediente = new Expedientes();
			TFolder expedientPlatea = resultado.getFolder().get(0);
			logger.info("FolderID = " + expedientPlatea.getFolderID());
			expediente.setFolderId(expedientPlatea.getFolderID());
			logger.info("FolderTitle = " + expedientPlatea.getFolderTitle());
			expediente.setTitulo(expedientPlatea.getFolderTitle());
			logger.info("FolderNumber = " + expedientPlatea.getFolderNumber());
			expediente.setFolderNumber(expedientPlatea.getFolderNumber());
			if (null != usuario && usuario.length() > 19) {
				logger.info("NombreUsuario = " + usuario.substring(0, 19));
				expediente.setUsuarioRegistro(usuario.substring(0, 19));
			} else {
				logger.info("NombreUsuario = " + usuario);
				expediente.setUsuarioRegistro(usuario);
			}
			this.updateExpedienteFolder(expediente);
			// actualizamos en el initForm
			initForm.setTituloExpediente(expedientPlatea.getFolderTitle());
			initForm.setFolderId(expediente.getFolderId());
			initForm.setFolderNumber(expediente.getFolderNumber());
		}
		logger.info("FIN actualizarTituloExpediente");
	}

	@Override
	public void comprobarExpedienteOficio(TFolderList resultado, InitForm initForm) {
		if (!resultado.getFolder().isEmpty()) {
			TFolder expedientPlatea = resultado.getFolder().get(0);
			if (!TFolderOriginType.INICIO_DE_PARTE.equals(expedientPlatea.getInitiationType())) {
				initForm.setExpedienteOficio(true);
			}
		}
	}

	public JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByDniTitular(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto) {
		List<InfoExpedienteEstablecimiento> listaExpedientes = this.expedientesDao.findExpedientesEstablecimientosByDni(
				filterEstablecimiento, Constantes.PARTICIPACION_SOLICITANTE, jqGridRequestDto);

		Long recordNum = this.expedientesDao.findExpedientesEstablecimientosByDniCount(filterEstablecimiento,
				Constantes.PARTICIPACION_SOLICITANTE);

		return new JQGridResponseDto<InfoExpedienteEstablecimiento>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	public JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByDniRepresentante(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto) {
		List<InfoExpedienteEstablecimiento> listaExpedientes = this.expedientesDao.findExpedientesEstablecimientosByDni(
				filterEstablecimiento, Constantes.PARTICIPANTE_REPRESENTANTE, jqGridRequestDto);

		Long recordNum = this.expedientesDao.findExpedientesEstablecimientosByDniCount(filterEstablecimiento,
				Constantes.PARTICIPANTE_REPRESENTANTE);

		return new JQGridResponseDto<InfoExpedienteEstablecimiento>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	public JQGridResponseDto<InfoExpedienteEstablecimiento> findExpedientesEstablecimientosByUbicacion(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto) {
		List<InfoExpedienteEstablecimiento> listaExpedientes = this.expedientesDao
				.findExpedientesEstablecimientosByUbicacion(filterEstablecimiento, jqGridRequestDto);

		Long recordNum = this.expedientesDao.findExpedientesEstablecimientosByUbicacionCount(filterEstablecimiento);

		return new JQGridResponseDto<InfoExpedienteEstablecimiento>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	/**
	 * Busca los expedientes que estan abiertos.
	 * 
	 * @param idExpediente
	 */
	public List<Expedientes> findExpedientesPendientesByExpediente(Integer idExpediente) {
		return this.expedientesDao.findExpedientesPendientesByExpediente(idExpediente);
	}

	@Override
	@Transactional(rollbackFor = Throwable.class)
	public ResultAjaxOperation saveExpediente(InitForm form, ProcedureActions procedureActions,
			HttpServletRequest request, Boolean executeProccess) {
		int idTercero = form.getIdTerceroTitular();

		Establecimiento establecimiento = procedureActions.findEstablecimiento(form);
		// Si esta disponible se actualiza las direcciones
		if (form.isEnableUpdateDirecciones()) {
			this.relExpTerService.registerDomicilioUbicacionSolicitante(request, idTercero, form);

		}

		if (form.getIdExpediente() != null && form.getIdProvinciaEstablecimiento() != null) {

			Expedientes expediente = new Expedientes(form.getIdExpediente());
			expediente.setIdTerritorioHistorico(Long.parseLong(form.getIdProvinciaEstablecimiento()));
			this.updateTerritorioHistorico(expediente);
		}

		DatosDirecciones datosDirecciones = procedureActions.findDireccioneEstablecimiento(form);
		if (establecimientoService.canChangeIdentifiadorExp(form.getIdExpediente(), form.getIdTerceroTitular())
				&& isChangeIdentificador(establecimiento, datosDirecciones)) {
			establecimientoService.reasingExpediente(form);
		}

		Map<String, String> data = new HashMap<String, String>();
		if (executeProccess && procedureActions.isEnableExecuteAction(form)) {
			data = procedureActions.executeAction(form);
			if (data.containsKey(Constantes.KEY_AJAX_ERROR)) {
				return new ErrorResultAjaxOperation(data.get(Constantes.KEY_AJAX_ERROR));
			}
		}

		SuccessResultAjaxOperation success = new SuccessResultAjaxOperation("datos_guardados_OK");
		if (data.containsKey(Constantes.KEY_AJAX_CALLBACK)) {
			success.setCallback(data.get(Constantes.KEY_AJAX_CALLBACK));
			data.remove(Constantes.KEY_AJAX_CALLBACK);
		}
		if (data.containsKey(Constantes.KEY_AJAX_MESSAGE)) {
			success.setMessage(data.get(Constantes.KEY_AJAX_MESSAGE));
			data.remove(Constantes.KEY_AJAX_MESSAGE);
		}
		data.put("idTercero", String.valueOf(idTercero));
		success.setData(data);
		return success;
	}

	private boolean isChangeIdentificador(Establecimiento establecimiento, DatosDirecciones datosDirecciones) {
		Boolean directionHasIdent = datosDirecciones.getIdentificadorEstablecimiento() != null;
		Boolean estHasIdent = establecimiento.getIdentificadorSolicitud() != null;

		return directionHasIdent && estHasIdent && !datosDirecciones.getIdentificadorEstablecimiento()
				.equals(establecimiento.getIdentificadorSolicitud());
	}

	@Transactional(rollbackFor = Throwable.class)
	public Boolean updateExpedienteTitle(InitForm initForm, Map<String, String> data,
			ProcedureActions procedureActions) {
		String titleOld = initForm.getTituloExpediente();
		try {
			String titleNew = createNewTitleExpediente(initForm, data, procedureActions);
			logger.info("[EXP] titulo nuevo: " + titleNew);
			Boolean isUpdateTitleTramitagune = this.expedienteElectronicoWS.updateTitle(initForm.getFolderId(),
					titleNew, PermisosXLNETS.getUserConnected(), null);
			if (isUpdateTitleTramitagune) {
				logger.info("[EXP] Actualizado en TRAMITAGUNE");
				Expedientes expediente = this.expedientesDao.find(new Expedientes(initForm.getIdExpediente()));
				expediente.setTitulo(titleNew);
				this.expedientesDao.updateExpedienteFolder(expediente);
				logger.info("[EXP] Actualizado en BBDD");
				data.put(Constantes.KEY_TITLE_UPDATED, titleNew);
				data.put(Constantes.KEY_TITLE_COMPLETE, initForm.getFolderNumber() + " - " + titleNew);
			}
			return isUpdateTitleTramitagune;
		} catch (Exception e) {
			logger.info("[EXP] ERROR al actualizar el titulo intentado restaurar el anterior...");
			try {
				this.expedienteElectronicoWS.updateTitle(initForm.getFolderId(), titleOld,
						PermisosXLNETS.getUserConnected(), null);
			} catch (Exception e1) {
				logger.info("[EXP] ERROR al restaurar el titulo anterior...");
			}
			return false;
		}
	}

	private String createNewTitleExpediente(InitForm initForm, Map<String, String> data,
			ProcedureActions procedureActions) {
		String lastTitle = initForm.getTituloExpediente();
		String ident = initForm.getIdentificadorEstablecimiento();

		Establecimiento establecimiento = procedureActions.findEstablecimiento(initForm);
		DatosDirecciones datosDirecciones = procedureActions.findDireccioneEstablecimiento(initForm);

		Procedimientos procedimientos = new Procedimientos();
		procedimientos.setCodProcedureId(initForm.getProcedureCod());
		procedimientos = this.procedimientosService.findProc(procedimientos);

		String template = procedimientos.getCamposTituloExpediente();
		String idProvincia = initForm.getIdProvinciaEstablecimiento();

		String tipoEstSign = establecimiento.getTipoEstablecimiento() != null
				&& establecimiento.getTipoEstablecimiento().getIdTipoEstablecimiento() != null
						? establecimiento.getTipoEstablecimiento().getIdTipoEstablecimiento() : "";

		String modalidad = "";
		if (Constantes.VIVIENDAS_TURISTICAS.equalsIgnoreCase(tipoEstSign)
				|| Constantes.HABITACIONES_CASAS_PARTICULARES.equalsIgnoreCase(tipoEstSign)) {
			modalidad = establecimiento.getModalidad() != null
					&& establecimiento.getModalidad().getIdModalidad() != null
					&& "2".equals(establecimiento.getModalidad().getIdModalidad()) ? "[R]" : "";
		}
		String signature = "";
		String correlativEstSign = "";
		if (ident != null) {
			signature = ident.substring(1, 3);
			correlativEstSign = ident.substring(3);
		} else {
			ident = tipoEstSign;
		}
		String checkModifEsencial = "S".equals(establecimiento.getModifEsencial()) ? "[F]" : "[EF]";

		String establecimientoNombre = establecimiento.getDescrNombre() != null
				&& establecimiento.getDescrNombre().equalsIgnoreCase(datosDirecciones.getEstablecimiento())
						? establecimiento.getDescrNombre() : datosDirecciones.getEstablecimiento();
		if (establecimientoNombre == null) {
			establecimientoNombre = "";
		}
		template = template.replace(
				"{{ubiEstablecimientoProvincia}}{{ubiEstablecimientoProvincia2}}{{holderchoicedatosDomicilioSocialProvince}}",
				"{{ubiEstablecimientoProvincia}}");
		String newTitle = template.replace("{{territEstSign}}", idProvincia);
		newTitle = newTitle.replace("{{ubiEstablecimientoProvincia}}", idProvincia);
		newTitle = newTitle.replace("{{territorio}}", idProvincia);

		newTitle = newTitle.replace("{{tipoActividad}}", "[{0}]".replace("{0}", ident));

		newTitle = newTitle.replace("{{tipoEstSign}}", tipoEstSign);
		newTitle = newTitle.replace("{{signature}}", signature);
		newTitle = newTitle.replace("{{correlativEstSign}}", correlativEstSign);

		if ("".equals(modalidad)) {
			newTitle = newTitle.replace("{{modalidad}}", " [{0}] ".replace("{0}", modalidad));
		} else {
			newTitle = newTitle.replace("{{modalidad}}", "");
		}
		newTitle = newTitle.replace("{{check_modifEsencial}}", checkModifEsencial);
		newTitle = newTitle.replace("{{establecimientoNombre}}", establecimientoNombre);
		newTitle = newTitle.replace("{{nombre_info}}", establecimientoNombre);
		newTitle = newTitle.replace("{{establecimientoNombre2}}", establecimientoNombre);

		return newTitle.contains("{{") ? lastTitle : newTitle;
	}

	/**
	 * 
	 * @param establecimiento
	 * @param expedientes
	 * @return
	 */
	@Override
	@Transactional(rollbackFor = Throwable.class)
	public ResultAjaxOperation procesarAsociar(HttpServletRequest request, InitForm initForm,
			ProcedureActions procedureActions, List<String> listExpedientes) {
		SuccessResultAjaxOperation operation = new SuccessResultAjaxOperation("asociados");
		Map<String, String> data = new HashMap<String, String>();
		Boolean isAltaCenso = false;
		// Comprobamos si se puede dar alta en el censo
		if (procedureActions.isEnableSaveExpediente(initForm)) {
			initForm.setEnableUpdateDirecciones(false);
			ResultAjaxOperation result = this.saveExpediente(initForm, procedureActions, request,
					procedureActions.isEnableExecuteAction(initForm));
			if (result.getResult() == Constantes.AJAX_ERROR) {
				return result;
			}
			isAltaCenso = true;
			operation = (SuccessResultAjaxOperation) result;
			operation.setCallback("showAltaConAsociados");
			data = operation.getData();
		}

		// Si el identificador no es el mismo se actualiza
		String identificadorEstablecimiento = initForm.getIdentificadorEstablecimiento();
		if (data.containsKey(Constantes.KEY_IDENTIFICADOR_DEFINITIVO)) {
			identificadorEstablecimiento = data.get(Constantes.KEY_IDENTIFICADOR_DEFINITIVO);
		}

		// Se extraen los indentificadores de las direcciones de los expedientes
		HashSet<String> listIdentificadores = new HashSet<String>();
		Establecimiento establecimiento = procedureActions.findEstablecimiento(initForm);
		for (Iterator<String> iterator = listExpedientes.iterator(); iterator.hasNext();) {
			String idExp = iterator.next();
			Integer idExpediente = Integer.parseInt(idExp);
			Expedientes expedienteAsociado = expedientesDao.find(new Expedientes(idExpediente));
			DatosDirecciones direccion = direccionesService.findEstablecimientoExpediente(idExpediente);

			if (expedienteAsociado != null && direccion.getIdDireccion() != null) {
				// Si el establecimiento provisional tiene una dispensa se
				// asocia al establecimiento del expediente.
				if (Constantes.PROCEDIMIENTO_DISPENSAS_ACTIVIDAD
						.equalsIgnoreCase(expedienteAsociado.getProcedimientos().getCodProcedureId())) {
					DispensaEstablecimiento dispensa = new DispensaEstablecimiento();
					dispensa.setFolderId(expedienteAsociado.getFolderId());
					dispensa = this.dispensasService.findByExpediente(dispensa);
					if (dispensa.getIdDispensasEstab() != null) {
						dispensa.setEstablecimiento(establecimiento);
						this.dispensasService.update(dispensa);
					}
				}
				listIdentificadores.add(direccion.getIdentificadorEstablecimiento());

				// Se actualizan los expediente seleccionados
				direccion.setIdentificadorEstablecimiento(identificadorEstablecimiento);
				this.direccionesService.update(direccion);
			}
		}

		// Se comprueba si hay ms expedientes con el identificador anterior del
		// expediente.
		DatosDirecciones filter = new DatosDirecciones();
		filter.setTipoEstablecimiento();
		for (Iterator<String> iterator = listIdentificadores.iterator(); iterator.hasNext();) {
			String identificadorEstAsociado = iterator.next();
			filter.setIdentificadorEstablecimiento(identificadorEstAsociado);
			List<DatosDirecciones> direccionesExpedientes = direccionesService.findAll(filter, null);

			// Si no quedan expedientes asociados se d de baja el
			// establecimento provisional
			if (direccionesExpedientes.isEmpty()) {
				Establecimiento estTemporal = new Establecimiento();
				estTemporal.setIdentificadorEstablecimiento(identificadorEstAsociado);
				estTemporal = establecimientoService.findByIdenticadorEstablecimiento(estTemporal);
				if (estTemporal != null && estTemporal.getIdEstablecimiento() != null) {
					estTemporal.setIdentificadorEstablecimiento(null);
					estTemporal.setTipoRegistro(Constantes.TIPO_REGISTRO_TEMPORAL);
					estTemporal.setFechaBaja(new Date());
					this.establecimientoService.update(estTemporal);
				}
			}
		}

		if (isAltaCenso) {
			operation.setMessage("asociadosAltaCenso");
		} else {
			operation.setMessage("asociados");
		}
		operation.setData(data);

		return operation;
	}

	@Override
	public JQGridResponseDto<InfoExpedienteEstablecimiento> findExpRelByIdentificadorEst(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto, String origen) {

		List<InfoExpedienteEstablecimiento> listaExpedientes = this.expedientesDao
				.findExpRelByIdentificadorEst(filterEstablecimiento, jqGridRequestDto, origen);

		for (InfoExpedienteEstablecimiento infoExpedienteEstablecimiento : listaExpedientes) {

			if (null != infoExpedienteEstablecimiento.getIdExpediente()
					&& infoExpedienteEstablecimiento.getIdExpediente() > 0) {

				// Expedientes AB63
				if (infoExpedienteEstablecimiento.getExpFechaCierre() != null) {

					infoExpedienteEstablecimiento.setEstado(
							appMessageSource.getMessage("estado.finalizado", null, LocaleContextHolder.getLocale()));

				} else {

					infoExpedienteEstablecimiento.setEstado(
							appMessageSource.getMessage("estado.tramitacion", null, LocaleContextHolder.getLocale()));
				}
			}

		}

		Long recordNum = this.expedientesDao.findExpRelByIdentificadorEstCount(filterEstablecimiento, origen);

		return new JQGridResponseDto<InfoExpedienteEstablecimiento>(jqGridRequestDto, recordNum, listaExpedientes);
	}

	public List<Expedientes> findAllExpedientesOrigen(String identificadorEstablecimiento) {
		return this.expedientesDao.findAllExpedientesOrigen(identificadorEstablecimiento);
	}

	@Transactional(rollbackFor = Throwable.class)
	public Boolean updateOrigen(Expedientes expedientes) {
		return this.expedientesDao.updateOrigen(expedientes);
	}

	public Boolean hasInspectExpedient(Integer idExpediente) {
		return this.expedientesDao.hasInspectExpedient(idExpediente);
	}

	public Inspeccion getInspect(String idInspeccion) {
		return this.expedientesDao.getInspect(idInspeccion);
	}

	public Inspeccion getInspectExpedient(Integer idExpediente) {
		return this.expedientesDao.getInspectExpedient(idExpediente);
	}

	@Override
	public List<InfoExpedienteEstablecimiento> findExpRelByIdentificadorEstExcel(
			InfoExpedienteEstablecimiento filterEstablecimiento, JQGridRequestDto jqGridRequestDto, String origen) {

		List<InfoExpedienteEstablecimiento> listaExpedientes = this.expedientesDao
				.findExpRelByIdentificadorEst(filterEstablecimiento, jqGridRequestDto, origen);

		for (InfoExpedienteEstablecimiento infoExpedienteEstablecimiento : listaExpedientes) {

			if (infoExpedienteEstablecimiento.getExpFechaCierre() != null) {

				infoExpedienteEstablecimiento.setEstado(
						appMessageSource.getMessage("estado.finalizado", null, LocaleContextHolder.getLocale()));

			} else {

				infoExpedienteEstablecimiento.setEstado(
						appMessageSource.getMessage("estado.tramitacion", null, LocaleContextHolder.getLocale()));
			}
		}

		return listaExpedientes;
	}

	@Override
	public boolean checkIsClosed(Expedientes expediente) {
		return this.expedientesDao.checkDateExpediente(expediente, Constantes.ETIQUETA_FECHA_EXP_CIERRE);
	}

	@Override
	public Expedientes updateTerritorioHistorico(Expedientes expediente) {
		return this.expedientesDao.updateTerritorioHistorico(expediente);
	}

	@Override
	public Date getMaxDateExpediente(Integer idExpediente, String tipoFecha, boolean isEtiqueta) {
		return this.expedientesDao.getMaxDateExpediente(idExpediente, tipoFecha, isEtiqueta);
	}

	@Override
	public Map<String, String> createExpedienteInicioOficio(String folderID, Integer idProcedimientoOficio,
			HttpServletRequest request) {
		InicioOficioWS inicioOficioWS = new InicioOficioWS();
		EmisorInicioOficio emisor = loadEmisorInicioOficio(request);
		Procedimientos procedimiento = new Procedimientos(idProcedimientoOficio);
		procedimiento = this.procedimientosService.find(procedimiento);

		inicioOficioWS.setFolderId(folderID);
		inicioOficioWS.setProcedureId(procedimiento.getCodProcedureId());
		inicioOficioWS.setEmisorInicioficio(emisor);
		Map<String, String> data = new HashMap<String, String>();
		try {
			DatosInicioOficio inicioOficio = this.ab61WebServiceService.generarInicioOficio(inicioOficioWS);
			data.put(Constantes.KEY_AJAX_MESSAGE, "expedienteOficioCreado");
			data.put(Constantes.KEY_FOLDER_ID, inicioOficio.getFolderID());
		} catch (Ab61Exception e) {
			data.put(Constantes.KEY_AJAX_ERROR, "errorGenerico");
		}

		return data;
	}

	private EmisorInicioOficio loadEmisorInicioOficio(HttpServletRequest request) {
		EmisorInicioOficio emisor = new EmisorInicioOficio();
		emisor.setIdEmsisor(PermisosXLNETS.fncIdUsuario(request));
		emisor.setNombreEmisor(PermisosXLNETS.fncNombre(request));
		emisor.setPrimerApellido(PermisosXLNETS.fncApellidos(request));
		return emisor;
	}
}
