package com.ejie.ab63.service.procedimientos;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.dao.procedimientos.ProcedimientosDao;
import com.ejie.ab63.model.procedimientos.Procedimientos;
import com.ejie.ab63.model.procedimientos.ProcedimientosRelacionados;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

@Service(value = "procedimientosService")
public class ProcedimientosServiceImpl implements ProcedimientosService {

	@Autowired
	private ProcedimientosDao procedimientosDao;

	/**
	 * Inserts a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Procedimientos add(Procedimientos procedimientos) {
		return this.procedimientosDao.add(procedimientos);
	}

	/**
	 * Updates a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public Procedimientos update(Procedimientos procedimientos) {
		return this.procedimientosDao.update(procedimientos);
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	public Procedimientos find(Procedimientos procedimientos) {
		return (Procedimientos) this.procedimientosDao.find(procedimientos);
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	public Procedimientos findProc(Procedimientos procedimientos) {
		return (Procedimientos) this.procedimientosDao.findProc(procedimientos);
	}

	/**
	 * Deletes a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(Procedimientos procedimientos) {
		this.procedimientosDao.remove(procedimientos);
	}

	/**
	 * Finds a list of rows in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Procedimientos>
	 */
	public List<Procedimientos> findAll(Procedimientos procedimientos, JQGridRequestDto jqGridRequestDto) {
		return (List<Procedimientos>) this.procedimientosDao.findAll(procedimientos, jqGridRequestDto);
	}

	/**
	 * Finds a list of rows in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<Procedimientos>
	 */
	public List<Procedimientos> findAllCenso(Procedimientos procedimientos) {
		return (List<Procedimientos>) this.procedimientosDao.findAllCenso(procedimientos);
	}

	/**
	 * Finds rows in the Procedimientos table using like.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<Procedimientos>
	 */
	public List<Procedimientos> findAllLike(Procedimientos procedimientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<Procedimientos>) this.procedimientosDao.findAllLike(procedimientos, jqGridRequestDto, startsWith);
	}

	/**
	 * Finds a single row in the Procedimientos table.
	 *
	 * @param procedimientos
	 *            Procedimientos
	 * @return Procedimientos
	 */
	public List<ProcedimientosRelacionados> findRelInicioOficio(Procedimientos procedimientos) {
		return (List<ProcedimientosRelacionados>) this.procedimientosDao.findRelInicioOficio(procedimientos);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(Procedimientos filterProcedimientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.procedimientosDao.removeMultiple(filterProcedimientos, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<Procedimientos>
	 */
	public JQGridResponseDto<Procedimientos> filter(Procedimientos filterProcedimientos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<Procedimientos> listaProcedimientos = this.procedimientosDao.findAllLike(filterProcedimientos,
				jqGridRequestDto, false);
		Long recordNum = this.procedimientosDao
				.findAllLikeCount(filterProcedimientos != null ? filterProcedimientos : new Procedimientos(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<Procedimientos>> reorderSelection = this.procedimientosDao
					.reorderSelection(filterProcedimientos, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<Procedimientos>(jqGridRequestDto, recordNum, listaProcedimientos,
					reorderSelection);
		}
		return new JQGridResponseDto<Procedimientos>(jqGridRequestDto, recordNum, listaProcedimientos);
	}

	/**
	 * Searches rows in the Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param searchProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<Procedimientos>>
	 */
	public List<TableRowDto<Procedimientos>> search(Procedimientos filterProcedimientos,
			Procedimientos searchProcedimientos, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.procedimientosDao.search(filterProcedimientos, searchProcedimientos, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(Procedimientos filterProcedimientos, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.procedimientosDao.reorderSelection(filterProcedimientos, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the Procedimientos table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<Procedimientos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Procedimientos>> jerarquia(Procedimientos filterProcedimientos,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<Procedimientos>> listaProcedimientos = this.procedimientosDao
				.findAllLikeJerarquia(filterProcedimientos, jqGridRequestDto);
		Long recordNum = this.procedimientosDao.findAllLikeCountJerarquia(filterProcedimientos, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<Procedimientos>>(jqGridRequestDto, recordNum, listaProcedimientos);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the Procedimientos
	 * table.
	 *
	 * @param filterProcedimientos
	 *            Procedimientos
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<Procedimientos>>
	 */
	public JQGridResponseDto<JerarquiaDto<Procedimientos>> jerarquiaChildren(Procedimientos filterProcedimientos,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<Procedimientos>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<Procedimientos>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.procedimientosDao.findAllChild(filterProcedimientos, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
