package com.ejie.ab63.service.terceros;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.ejie.ab63.dao.terceros.TiposDireccionDao;
import com.ejie.ab63.model.terceros.TiposDireccion;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * TiposDireccionServiceImpl  
 * 
 *  
 */

@Service(value = "tiposDireccionService")
public class TiposDireccionServiceImpl implements TiposDireccionService {

	@Autowired
	private TiposDireccionDao tiposDireccionDao;

	/**
	 * Inserts a single row in the TiposDireccion table.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 * @return TiposDireccion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposDireccion add(TiposDireccion tiposDireccion) {
		return this.tiposDireccionDao.add(tiposDireccion);
	}

	/**
	 * Updates a single row in the TiposDireccion table.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 * @return TiposDireccion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public TiposDireccion update(TiposDireccion tiposDireccion) {
		return this.tiposDireccionDao.update(tiposDireccion);
	}

	/**
	 * Finds a single row in the TiposDireccion table.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 * @return TiposDireccion
	 */
	public TiposDireccion find(TiposDireccion tiposDireccion) {
		return (TiposDireccion) this.tiposDireccionDao.find(tiposDireccion);
	}

	/**
	 * Deletes a single row in the TiposDireccion table.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 */
	@Transactional(rollbackFor = Throwable.class)
	public void remove(TiposDireccion tiposDireccion) {
		this.tiposDireccionDao.remove(tiposDireccion);
	}

	/**
	 * Finds a list of rows in the TiposDireccion table.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return List<TiposDireccion>
	 */
	public List<TiposDireccion> findAll(TiposDireccion tiposDireccion, JQGridRequestDto jqGridRequestDto) {
		return (List<TiposDireccion>) this.tiposDireccionDao.findAll(tiposDireccion, jqGridRequestDto);
	}

	/**
	 * Finds rows in the TiposDireccion table using like.
	 *
	 * @param tiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TiposDireccion>
	 */
	public List<TiposDireccion> findAllLike(TiposDireccion tiposDireccion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return (List<TiposDireccion>) this.tiposDireccionDao.findAllLike(tiposDireccion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE
	 */

	/**
	 * Removes rows from the TiposDireccion table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 */
	public void removeMultiple(TiposDireccion filterTiposDireccion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		this.tiposDireccionDao.removeMultiple(filterTiposDireccion, jqGridRequestDto, startsWith);
	}

	/**
	 * Filter method in the TiposDireccion table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<TiposDireccion>
	 */
	public JQGridResponseDto<TiposDireccion> filter(TiposDireccion filterTiposDireccion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<TiposDireccion> listaTiposDireccion = this.tiposDireccionDao.findAllLike(filterTiposDireccion,
				jqGridRequestDto, false);
		Long recordNum = this.tiposDireccionDao
				.findAllLikeCount(filterTiposDireccion != null ? filterTiposDireccion : new TiposDireccion(), false);
		if (jqGridRequestDto.getMultiselection().getSelectedIds() != null) {
			List<TableRowDto<TiposDireccion>> reorderSelection = this.tiposDireccionDao
					.reorderSelection(filterTiposDireccion, jqGridRequestDto, startsWith);
			return new JQGridResponseDto<TiposDireccion>(jqGridRequestDto, recordNum, listaTiposDireccion,
					reorderSelection);
		}
		return new JQGridResponseDto<TiposDireccion>(jqGridRequestDto, recordNum, listaTiposDireccion);
	}

	/**
	 * Searches rows in the TiposDireccion table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param searchTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return List<TableRowDto<TiposDireccion>>
	 */
	public List<TableRowDto<TiposDireccion>> search(TiposDireccion filterTiposDireccion,
			TiposDireccion searchTiposDireccion, JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		return this.tiposDireccionDao.search(filterTiposDireccion, searchTiposDireccion, jqGridRequestDto, startsWith);
	}

	/**
	 * Reorder the selection made in TiposDireccion table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return Object
	 */
	public Object reorderSelection(TiposDireccion filterTiposDireccion, JQGridRequestDto jqGridRequestDto,
			Boolean startsWith) {
		return this.tiposDireccionDao.reorderSelection(filterTiposDireccion, jqGridRequestDto, startsWith);
	}

	/*
	 * OPERACIONES RUP_TABLE JERARQUIA
	 */

	/**
	 * Finder method in the hierarchical the TiposDireccion table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @param startsWith
	 *            Boolean
	 * @return JQGridResponseDto<JerarquiaDto<TiposDireccion>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposDireccion>> jerarquia(TiposDireccion filterTiposDireccion,
			JQGridRequestDto jqGridRequestDto, Boolean startsWith) {
		List<JerarquiaDto<TiposDireccion>> listaTiposDireccion = this.tiposDireccionDao
				.findAllLikeJerarquia(filterTiposDireccion, jqGridRequestDto);
		Long recordNum = this.tiposDireccionDao.findAllLikeCountJerarquia(filterTiposDireccion, jqGridRequestDto);
		return new JQGridResponseDto<JerarquiaDto<TiposDireccion>>(jqGridRequestDto, recordNum, listaTiposDireccion);
	}

	/**
	 * Finder method for siblings rows in the hierarchical the TiposDireccion
	 * table.
	 *
	 * @param filterTiposDireccion
	 *            TiposDireccion
	 * @param jqGridRequestDto
	 *            JQGridRequestDto
	 * @return JQGridResponseDto<JerarquiaDto<TiposDireccion>>
	 */
	public JQGridResponseDto<JerarquiaDto<TiposDireccion>> jerarquiaChildren(TiposDireccion filterTiposDireccion,
			JQGridRequestDto jqGridRequestDto) {
		JQGridResponseDto<JerarquiaDto<TiposDireccion>> jqGridResponseDto = new JQGridResponseDto<JerarquiaDto<TiposDireccion>>();
		jqGridResponseDto.addAdditionalParam(JQGridResponseDto.CHILDREN,
				this.tiposDireccionDao.findAllChild(filterTiposDireccion, jqGridRequestDto));
		return jqGridResponseDto;
	}

}
