package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Ab6343s00;
import com.ejie.ab63.service.Ab6343s00Service;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6343s00Controller  
 *  
 */
 
@Controller
@RequestMapping (value = "/ab6343s00")

public class Ab6343s00Controller  {

	private static final Logger logger = LoggerFactory.getLogger(Ab6343s00Controller.class);

	@Autowired
	private Ab6343s00Service ab6343s00Service;
	
	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */
	
	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador indicado.
	 * 
	 * @param idRelEstExpnb29 Integer
	 * @return Ab6343s00 
	 *            Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRelEstExpnb29}", method = RequestMethod.GET)
	public @ResponseBody Ab6343s00 get(@PathVariable Integer idRelEstExpnb29) {
        Ab6343s00 ab6343s00 = new Ab6343s00();
		ab6343s00.setIdRelEstExpnb29(idRelEstExpnb29);
        ab6343s00 = this.ab6343s00Service.find(ab6343s00);
        Ab6343s00Controller.logger.info("[GET - findBy_PK] : Obtener Ab6343s00 por PK");
        return ab6343s00;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6343s00 Ab6343s00
	 *            Objeto que contiene los parametros de filtrado utilizados en
	 *            la busqueda.
	 * @return List<Ab6343s00> 
	 *            Lista de objetos correspondientes a la busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Ab6343s00> getAll(@ModelAttribute Ab6343s00 filterAb6343s00) {
		Ab6343s00Controller.logger.info("[GET - find_ALL] : Obtener Ab6343s00 por filtro");
	    return this.ab6343s00Service.findAll(filterAb6343s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param ab6343s00 Ab6343s00 
	 *            Bean que contiene la informacion a modificar.
	 * @return Ab6343s00 
	 *            Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
    public @ResponseBody Ab6343s00 edit(@RequestBody Ab6343s00 ab6343s00) {		
        Ab6343s00 ab6343s00Aux = this.ab6343s00Service.update(ab6343s00);
		Ab6343s00Controller.logger.info("[PUT] : Ab6343s00 actualizado correctamente");
        return ab6343s00Aux;
    }

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param ab6343s00 Ab6343s00 
	 *            Bean que contiene la informacion con la que se va a crear el
	 *            nuevo registro.
	 * @return Ab6343s00
	 *            Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Ab6343s00 add(@RequestBody Ab6343s00 ab6343s00) {		
        Ab6343s00 ab6343s00Aux = this.ab6343s00Service.add(ab6343s00);
        Ab6343s00Controller.logger.info("[POST] : Ab6343s00 insertado correctamente");
    	return ab6343s00Aux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRelEstExpnb29 Integer
	 *            Identificador del objeto que se desea eliminar.
	 * @return Ab6343s00
	 *            Bean eliminado.
	 */
	@RequestMapping(value = "/{idRelEstExpnb29}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
    public @ResponseBody Ab6343s00 remove(@PathVariable Integer idRelEstExpnb29) {
        Ab6343s00 ab6343s00 = new Ab6343s00();
        ab6343s00.setIdRelEstExpnb29(idRelEstExpnb29);
        this.ab6343s00Service.remove(ab6343s00);
       	Ab6343s00Controller.logger.info("[DELETE] : Ab6343s00 borrado correctamente");
       	return ab6343s00;
    }
    
	
	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	 /**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		Ab6343s00Controller.logger.info("[GET - View] : ab6343s00");
		return "ab6343s00";
	}
	 
	 /**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de filtrado a emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<Ab6343s00>
	 *            Dto que contiene el resultado del filtrado realizado por el 
	 *            componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<Ab6343s00> filter(
			@RequestJsonBody(param="filter") Ab6343s00 filterAb6343s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - filter] : Obtener Ab6343s00s");
		return this.ab6343s00Service.filter(filterAb6343s00, tableRequestDto, false);
	}
	 
	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de filtrado a emplear.
	 * @param searchAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de busqueda a emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6343s00> 
	 *            Dto que contiene el resultado de la busqueda realizada por el
	 *            componente RUP_TABLE. 
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Ab6343s00>> search(
			@RequestJsonBody(param="filter") Ab6343s00 filterAb6343s00,
			@RequestJsonBody(param="search") Ab6343s00 searchAb6343s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - search] : Buscar Ab6343s00s");
		return this.ab6343s00Service.search(filterAb6343s00, searchAb6343s00, tableRequestDto, false);
	}
	
	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de filtrado a emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String>
	 *            Lista de los identificadores de los registros eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param="filter") Ab6343s00 filterAb6343s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6343s00s");
		this.ab6343s00Service.removeMultiple(filterAb6343s00, tableRequestDto, false);
		Ab6343s00Controller.logger.info("All entities correctly deleted!");
		
		return tableRequestDto.getMultiselection().getSelectedIds();
	}
	
	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */
	
	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de filtrado a emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6343s00>>
	 *            Dto que contiene el resultado del filtrado realizado por el
	 *            componente RUP_TABLE. 
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Ab6343s00>> jerarquia(
			@RequestJsonBody(param="filter") Ab6343s00 filterAb6343s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - jerarquia] : Obtener Ab6343s00s jerarquia");
		return this.ab6343s00Service.jerarquia(filterAb6343s00, tableRequestDto, false);
	}
	
	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion jerarquica.
	 * 
	 * @param filterAb6343s00 Ab6343s00
	 *            Bean que contiene los parametros de filtrado a emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6343s00>>
	 *            Dto que contiene el resultado del filtrado realizado por el
	 *            componente RUP_TABLE. 
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Ab6343s00>> jerarquiaChildren(
			@RequestJsonBody(param="filter") Ab6343s00  filterAb6343s00 ,
			@RequestJsonBody TableRequestDto  tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - jerarquia] : Obtener Ab6343s00s jerarquia - Hijos");
		return this.ab6343s00Service.jerarquiaChildren(filterAb6343s00, tableRequestDto);
	}
	
	/**
 	 * EXPORTERS
 	 */
 	 
	@RequestMapping(value = "/clipboardReport", method = RequestMethod.POST)
	protected @ResponseBody List<Ab6343s00> getClipboardReport(
			@RequestJsonBody(param="filter") Ab6343s00  filterAb6343s00 ,
			@RequestJsonBody TableRequestDto  tableRequestDto) {
		Ab6343s00Controller.logger.info("[POST - clipboardReport] : : Copiar multiples usuarios");
		return this.ab6343s00Service.getMultiple(filterAb6343s00, tableRequestDto, false);
	}
	
}	
