package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.AgenciaData;
import com.ejie.ab63.service.AgenciaDataService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6335s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/agenciaData")

public class AgenciaDataController {

	private static final Logger logger = LoggerFactory.getLogger(AgenciaDataController.class);

	@Autowired
	private AgenciaDataService agenciaDataService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEstablecimiento
	 *            Integer
	 * @return Ab6335s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.GET)
	public @ResponseBody AgenciaData get(@PathVariable Integer idEstablecimiento) {
		AgenciaData filter = new AgenciaData();
		filter.setIdEstablecimiento(idEstablecimiento);
		filter = this.agenciaDataService.find(filter);
		AgenciaDataController.logger.info("[GET - findBy_PK] : Obtener Ab6335s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6335s00
	 *            Ab6335s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6335s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<AgenciaData> getAll(@ModelAttribute AgenciaData filterAb6335s00) {
		AgenciaDataController.logger.info("[GET - find_ALL] : Obtener Ab6335s00 por filtro");
		return this.agenciaDataService.findAll(filterAb6335s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6335s00 Bean que contiene la informacion a modificar.
	 * @return Ab6335s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody AgenciaData edit(@RequestBody AgenciaData filter) {
		AgenciaData filterAux = this.agenciaDataService.update(filter);
		AgenciaDataController.logger.info("[PUT] : Ab6335s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6335s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6335s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody AgenciaData add(@RequestBody AgenciaData filter) {
		AgenciaData filterAux = this.agenciaDataService.add(filter);
		AgenciaDataController.logger.info("[POST] : Ab6335s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idEstablecimiento
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6335s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AgenciaData remove(@PathVariable Integer idEstablecimiento) {
		AgenciaData filter = new AgenciaData();
		filter.setIdEstablecimiento(idEstablecimiento);
		this.agenciaDataService.remove(filter);
		AgenciaDataController.logger.info("[DELETE] : Ab6335s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AgenciaDataController.logger.info("[GET - View] : ab6335s00");
		return "ab6335s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6335s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AgenciaData> filter(
			@RequestJsonBody(param = "filter") AgenciaData filterAb6335s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AgenciaDataController.logger.info("[POST - filter] : Obtener Ab6335s00s");
		return this.agenciaDataService.filter(filterAb6335s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6335s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AgenciaData>> search(
			@RequestJsonBody(param = "filter") AgenciaData filterAb6335s00,
			@RequestJsonBody(param = "search") AgenciaData searchAb6335s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AgenciaDataController.logger.info("[POST - search] : Buscar Ab6335s00s");
		return this.agenciaDataService.search(filterAb6335s00, searchAb6335s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") AgenciaData filterAb6335s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AgenciaDataController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6335s00s");
		this.agenciaDataService.removeMultiple(filterAb6335s00, jqGridRequestDto, false);
		AgenciaDataController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6335s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AgenciaData>> jerarquia(
			@RequestJsonBody(param = "filter") AgenciaData filterAb6335s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AgenciaDataController.logger.info("[POST - jerarquia] : Obtener Ab6335s00s jerarquia");
		return this.agenciaDataService.jerarquia(filterAb6335s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6335s00
	 *            Ab6335s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6335s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AgenciaData>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") AgenciaData filterAb6335s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AgenciaDataController.logger.info("[POST - jerarquia] : Obtener Ab6335s00s jerarquia - Hijos");
		return this.agenciaDataService.jerarquiaChildren(filterAb6335s00, jqGridRequestDto);
	}

}
