package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Alojamiento;
import com.ejie.ab63.service.AlojamientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6323s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/alojamiento")

public class AlojamientoController {

	private static final Logger logger = LoggerFactory.getLogger(AlojamientoController.class);

	@Autowired
	private AlojamientoService alojamientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAlojamiento
	 *            Integer
	 * @return Ab6323s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idAlojamiento}", method = RequestMethod.GET)
	public @ResponseBody Alojamiento get(@PathVariable Integer idAlojamiento) {
		Alojamiento filter = new Alojamiento();
		filter.setIdAlojamiento(idAlojamiento);
		filter = this.alojamientoService.find(filter);
		AlojamientoController.logger.info("[GET - findBy_PK] : Obtener Ab6323s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6323s00
	 *            Ab6323s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6323s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Alojamiento> getAll(@ModelAttribute Alojamiento filterAb6323s00) {
		AlojamientoController.logger.info("[GET - find_ALL] : Obtener Ab6323s00 por filtro");
		return this.alojamientoService.findAll(filterAb6323s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6323s00 Bean que contiene la informacion a modificar.
	 * @return Ab6323s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Alojamiento edit(@RequestBody Alojamiento filter) {
		Alojamiento filterAux = this.alojamientoService.update(filter);
		AlojamientoController.logger.info("[PUT] : Ab6323s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6323s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6323s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Alojamiento add(@RequestBody Alojamiento filter) {
		// Alojamiento filterAux = this.alojamientoService.add(filter);
		// AlojamientoController.logger.info("[POST] : Ab6323s00 insertado
		// correctamente");
		Alojamiento filterAux = this.alojamientoService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAlojamiento
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6323s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Alojamiento remove(@PathVariable Integer idEstablecimiento,
			@RequestBody Alojamiento alojamiento) {
		this.alojamientoService.remove(alojamiento, idEstablecimiento);
		AlojamientoController.logger.info("[DELETE] : Ab6323s00 borrado correctamente");
		return alojamiento;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AlojamientoController.logger.info("[GET - View] : ab6323s00");
		return "ab6323s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6323s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<Alojamiento> filter(
			@RequestJsonBody(param = "filter") Alojamiento filterAb6323s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		AlojamientoController.logger.info("[POST - filter] : Obtener Ab6323s00s");
		return this.alojamientoService.filter(filterAb6323s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6323s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Alojamiento>> search(
			@RequestJsonBody(param = "filter") Alojamiento filterAb6323s00,
			@RequestJsonBody(param = "search") Alojamiento searchAb6323s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		AlojamientoController.logger.info("[POST - search] : Buscar Ab6323s00s");
		return this.alojamientoService.search(filterAb6323s00, searchAb6323s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Alojamiento filterAb6323s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		AlojamientoController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6323s00s");
		this.alojamientoService.removeMultiple(filterAb6323s00, jqGridRequestDto, false);
		AlojamientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6323s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Alojamiento>> jerarquia(
			@RequestJsonBody(param = "filter") Alojamiento filterAb6323s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		AlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6323s00s jerarquia");
		return this.alojamientoService.jerarquia(filterAb6323s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6323s00
	 *            Ab6323s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6323s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Alojamiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Alojamiento filterAb6323s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		AlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6323s00s jerarquia - Hijos");
		return this.alojamientoService.jerarquiaChildren(filterAb6323s00, jqGridRequestDto);
	}

}
