package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.AseoAlojamiento;
import com.ejie.ab63.service.AseoAlojamientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6326s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/aseoAlojamiento")

public class AseoAlojamientoController {

	private static final Logger logger = LoggerFactory.getLogger(AseoAlojamientoController.class);

	@Autowired
	private AseoAlojamientoService aseoAlojamientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAseoAlo
	 *            Integer
	 * @return Ab6326s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idAseoAlo}", method = RequestMethod.GET)
	public @ResponseBody AseoAlojamiento get(@PathVariable Integer idAseoAlo) {
		AseoAlojamiento filter = new AseoAlojamiento();
		filter.setIdAseoAlo(idAseoAlo);
		filter = this.aseoAlojamientoService.find(filter);
		AseoAlojamientoController.logger.info("[GET - findBy_PK] : Obtener Ab6326s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6326s00
	 *            Ab6326s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6326s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<AseoAlojamiento> getAll(@ModelAttribute AseoAlojamiento filterAb6326s00) {
		AseoAlojamientoController.logger.info("[GET - find_ALL] : Obtener Ab6326s00 por filtro");
		return this.aseoAlojamientoService.findAll(filterAb6326s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6326s00 Bean que contiene la informacion a modificar.
	 * @return Ab6326s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody AseoAlojamiento edit(@RequestBody AseoAlojamiento filter) {
		AseoAlojamiento filterAux = this.aseoAlojamientoService.update(filter);
		AseoAlojamientoController.logger.info("[PUT] : Ab6326s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6326s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6326s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody AseoAlojamiento add(@RequestBody AseoAlojamiento filter) {
		// AseoAlojamiento filterAux = this.aseoAlojamientoService.add(filter);
		// AseoAlojamientoController.logger.info("[POST] : Ab6326s00 insertado
		// correctamente");
		AseoAlojamiento filterAux = this.aseoAlojamientoService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAseoAlo
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6326s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idAseoAlo}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody AseoAlojamiento remove(@PathVariable Integer idAseoAlo) {
		AseoAlojamiento filter = new AseoAlojamiento();
		filter.setIdAseoAlo(idAseoAlo);
		this.aseoAlojamientoService.remove(filter);
		AseoAlojamientoController.logger.info("[DELETE] : Ab6326s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AseoAlojamientoController.logger.info("[GET - View] : ab6326s00");
		return "ab6326s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6326s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<AseoAlojamiento> filter(
			@RequestJsonBody(param = "filter") AseoAlojamiento filterAb6326s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoAlojamientoController.logger.info("[POST - filter] : Obtener Ab6326s00s");
		return this.aseoAlojamientoService.filter(filterAb6326s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6326s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<AseoAlojamiento>> search(
			@RequestJsonBody(param = "filter") AseoAlojamiento filterAb6326s00,
			@RequestJsonBody(param = "search") AseoAlojamiento searchAb6326s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoAlojamientoController.logger.info("[POST - search] : Buscar Ab6326s00s");
		return this.aseoAlojamientoService.search(filterAb6326s00, searchAb6326s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") AseoAlojamiento filterAb6326s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoAlojamientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6326s00s");
		this.aseoAlojamientoService.removeMultiple(filterAb6326s00, jqGridRequestDto, false);
		AseoAlojamientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6326s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AseoAlojamiento>> jerarquia(
			@RequestJsonBody(param = "filter") AseoAlojamiento filterAb6326s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoAlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6326s00s jerarquia");
		return this.aseoAlojamientoService.jerarquia(filterAb6326s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6326s00
	 *            Ab6326s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6326s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<AseoAlojamiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") AseoAlojamiento filterAb6326s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoAlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6326s00s jerarquia - Hijos");
		return this.aseoAlojamientoService.jerarquiaChildren(filterAb6326s00, jqGridRequestDto);
	}

}
