package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Aseo;
import com.ejie.ab63.service.AseoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6325s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/aseo")

public class AseoController {

	private static final Logger logger = LoggerFactory.getLogger(AseoController.class);

	@Autowired
	private AseoService aseoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idAseo
	 *            Integer
	 * @return Ab6325s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idAseo}", method = RequestMethod.GET)
	public @ResponseBody Aseo get(@PathVariable Integer idAseo) {
		Aseo filter = new Aseo();
		filter.setIdAseo(idAseo);
		filter = this.aseoService.find(filter);
		AseoController.logger.info("[GET - findBy_PK] : Obtener Ab6325s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6325s00
	 *            Ab6325s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6325s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Aseo> getAll(@ModelAttribute Aseo filterAb6325s00) {
		AseoController.logger.info("[GET - find_ALL] : Obtener Ab6325s00 por filtro");
		return this.aseoService.findAll(filterAb6325s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6325s00 Bean que contiene la informacion a modificar.
	 * @return Ab6325s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Aseo edit(@RequestBody Aseo filter) {
		Aseo filterAux = this.aseoService.update(filter);
		AseoController.logger.info("[PUT] : Ab6325s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6325s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6325s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Aseo add(@RequestBody Aseo filter) {
		// Aseo filterAux = this.aseoService.add(filter);
		// AseoController.logger.info("[POST] : Ab6325s00 insertado
		// correctamente");
		Aseo filterAux = this.aseoService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idAseo
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6325s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idAseo}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Aseo remove(@PathVariable Integer idAseo) {
		Aseo filter = new Aseo();
		filter.setIdAseo(idAseo);
		this.aseoService.remove(filter);
		AseoController.logger.info("[DELETE] : Ab6325s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		AseoController.logger.info("[GET - View] : ab6325s00");
		return "ab6325s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6325s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Aseo> filter(@RequestJsonBody(param = "filter") Aseo filterAb6325s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoController.logger.info("[POST - filter] : Obtener Ab6325s00s");
		return this.aseoService.filter(filterAb6325s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6325s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Aseo>> search(@RequestJsonBody(param = "filter") Aseo filterAb6325s00,
			@RequestJsonBody(param = "search") Aseo searchAb6325s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoController.logger.info("[POST - search] : Buscar Ab6325s00s");
		return this.aseoService.search(filterAb6325s00, searchAb6325s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Aseo filterAb6325s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6325s00s");
		this.aseoService.removeMultiple(filterAb6325s00, jqGridRequestDto, false);
		AseoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6325s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Aseo>> jerarquia(
			@RequestJsonBody(param = "filter") Aseo filterAb6325s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoController.logger.info("[POST - jerarquia] : Obtener Ab6325s00s jerarquia");
		return this.aseoService.jerarquia(filterAb6325s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6325s00
	 *            Ab6325s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6325s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Aseo>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Aseo filterAb6325s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AseoController.logger.info("[POST - jerarquia] : Obtener Ab6325s00s jerarquia - Hijos");
		return this.aseoService.jerarquiaChildren(filterAb6325s00, jqGridRequestDto);
	}

}
