package com.ejie.ab63.control;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.model.Categoria;
import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.CategoriaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6313s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/categoria")

public class CategoriaController {

	private static final Logger logger = LoggerFactory.getLogger(CategoriaController.class);

	@Autowired
	private CategoriaService categoriaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idCategorias
	 *            String
	 * @return Ab6313s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idCategorias}/{idTipoEstablecimiento}", method = RequestMethod.GET)
	public @ResponseBody Categoria get(@PathVariable String idCategorias, @PathVariable String idTipoEstablecimiento) {
		Categoria filter = new Categoria();
		filter.setIdCategorias(idCategorias);
		TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
		tipoEstablecimiento.setIdTipoEstablecimiento(idTipoEstablecimiento);
		filter.setTipoEstablecimiento(tipoEstablecimiento);
		filter = this.categoriaService.find(filter);
		CategoriaController.logger.info("[GET - findBy_PK] : Obtener Ab6313s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6313s00
	 *            Ab6313s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6313s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Categoria> getAll(@ModelAttribute Categoria filterAb6313s00,
			@RequestParam(value = "tipoEst", required = false) String tipoEst,
			@RequestParam(value = "grupo", required = false) String grupo) {
		CategoriaController.logger.info("[GET - find_ALL] : Obtener Ab6313s00 por filtro");
		if (StringUtils.isNotBlank(tipoEst)) {
			TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
			tipoEstablecimiento.setIdTipoEstablecimiento(tipoEst);
			filterAb6313s00.setTipoEstablecimiento(tipoEstablecimiento);
		}
		filterAb6313s00.setBaja(0);
		List<Categoria> lista = this.categoriaService.findAll(filterAb6313s00, null);
		if (Constantes.HOTEL.equals(tipoEst) && StringUtils.isNotBlank(grupo)
				&& Constantes.GrupoFijos.GRUPO_HOTEL_PENSION.equals(grupo)) {
			for (Categoria categoria : new ArrayList<Categoria>(lista)) {

				if (!"1 ESTRELLA".equals(categoria.getDescCategoriaEs())
						&& !"2 ESTRELLAS".equals(categoria.getDescCategoriaEs())) {
					lista.remove(categoria);
				}

			}
		}
		return lista;
		// return this.categoriaService.findAll(filterAb6313s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6313s00 Bean que contiene la informacion a modificar.
	 * @return Ab6313s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Categoria edit(@RequestBody Categoria filter) {
		Categoria filterAux = this.categoriaService.update(filter);
		CategoriaController.logger.info("[PUT] : Ab6313s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6313s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6313s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Categoria add(@RequestBody Categoria filter) {
		Categoria filterAux = this.categoriaService.add(filter);
		CategoriaController.logger.info("[POST] : Ab6313s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idCategorias
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6313s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idCategorias}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Categoria remove(@PathVariable String idCategorias) {
		Categoria filter = new Categoria();
		filter.setIdCategorias(idCategorias);
		this.categoriaService.remove(filter);
		CategoriaController.logger.info("[DELETE] : Ab6313s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		CategoriaController.logger.info("[GET - View] : categoria");
		Categoria categoria = new Categoria();
		model.addAttribute("busqCategoria", categoria);
		model.addAttribute("initForm", new InitForm());
		return "categorias";
	}

	/**
	 * METODO CREADO POST PARA EL CAMBIO DE IDIOMA Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		CategoriaController.logger.info("[GET - View] : categoria");
		Categoria categoria = new Categoria();
		model.addAttribute("busqCategoria", categoria);
		model.addAttribute("initForm", new InitForm());
		return "categorias";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6313s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<Categoria> filter(
			@RequestJsonBody(param = "filter") Categoria filterAb6313s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		CategoriaController.logger.info("[POST - filter] : Obtener Ab6313s00s");
		return this.categoriaService.filter(filterAb6313s00, tableRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6313s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Categoria>> search(
			@RequestJsonBody(param = "filter") Categoria filterAb6313s00,
			@RequestJsonBody(param = "search") Categoria searchAb6313s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CategoriaController.logger.info("[POST - search] : Buscar Ab6313s00s");
		return this.categoriaService.search(filterAb6313s00, searchAb6313s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Categoria filterAb6313s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CategoriaController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6313s00s");
		this.categoriaService.removeMultiple(filterAb6313s00, jqGridRequestDto, false);
		CategoriaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6313s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Categoria>> jerarquia(
			@RequestJsonBody(param = "filter") Categoria filterAb6313s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CategoriaController.logger.info("[POST - jerarquia] : Obtener Ab6313s00s jerarquia");
		return this.categoriaService.jerarquia(filterAb6313s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6313s00
	 *            Ab6313s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6313s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Categoria>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Categoria filterAb6313s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		CategoriaController.logger.info("[POST - jerarquia] : Obtener Ab6313s00s jerarquia - Hijos");
		return this.categoriaService.jerarquiaChildren(filterAb6313s00, jqGridRequestDto);
	}

}
