package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Direccion;
import com.ejie.ab63.service.DireccionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6328s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/direccion")

public class DireccionController {

	private static final Logger logger = LoggerFactory.getLogger(DireccionController.class);

	@Autowired
	private DireccionService direccionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idDireccion
	 *            Integer
	 * @return Ab6328s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idDireccion}", method = RequestMethod.GET)
	public @ResponseBody Direccion get(@PathVariable Integer idDireccion) {
		Direccion filter = new Direccion();
		filter.setIdDireccion(idDireccion);
		filter = this.direccionService.find(filter);
		DireccionController.logger.info("[GET - findBy_PK] : Obtener Ab6328s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6328s00
	 *            Ab6328s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6328s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Direccion> getAll(@ModelAttribute Direccion filterAb6328s00) {
		DireccionController.logger.info("[GET - find_ALL] : Obtener Ab6328s00 por filtro");
		return this.direccionService.findAll(filterAb6328s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6328s00 Bean que contiene la informacion a modificar.
	 * @return Ab6328s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Direccion edit(@RequestBody Direccion filter) {
		Direccion filterAux = this.direccionService.update(filter);
		DireccionController.logger.info("[PUT] : Ab6328s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6328s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6328s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Direccion add(@RequestBody Direccion filter) {
		Direccion filterAux = this.direccionService.add(filter);
		DireccionController.logger.info("[POST] : Ab6328s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idDireccion
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6328s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idDireccion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Direccion remove(@PathVariable Integer idDireccion) {
		Direccion filter = new Direccion();
		filter.setIdDireccion(idDireccion);
		this.direccionService.remove(filter);
		DireccionController.logger.info("[DELETE] : Ab6328s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		DireccionController.logger.info("[GET - View] : ab6328s00");
		return "ab6328s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6328s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Direccion> filter(
			@RequestJsonBody(param = "filter") Direccion filterAb6328s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionController.logger.info("[POST - filter] : Obtener Ab6328s00s");
		return this.direccionService.filter(filterAb6328s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6328s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Direccion>> search(
			@RequestJsonBody(param = "filter") Direccion filterAb6328s00,
			@RequestJsonBody(param = "search") Direccion searchAb6328s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionController.logger.info("[POST - search] : Buscar Ab6328s00s");
		return this.direccionService.search(filterAb6328s00, searchAb6328s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Direccion filterAb6328s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6328s00s");
		this.direccionService.removeMultiple(filterAb6328s00, jqGridRequestDto, false);
		DireccionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6328s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Direccion>> jerarquia(
			@RequestJsonBody(param = "filter") Direccion filterAb6328s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionController.logger.info("[POST - jerarquia] : Obtener Ab6328s00s jerarquia");
		return this.direccionService.jerarquia(filterAb6328s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6328s00
	 *            Ab6328s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6328s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Direccion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Direccion filterAb6328s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionController.logger.info("[POST - jerarquia] : Obtener Ab6328s00s jerarquia - Hijos");
		return this.direccionService.jerarquiaChildren(filterAb6328s00, jqGridRequestDto);
	}

}
