package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.DireccionEstablecimiento;
import com.ejie.ab63.service.DireccionEstablecimientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6340s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/direccionEstablecimiento")

public class DireccionEstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(DireccionEstablecimientoController.class);

	@Autowired
	private DireccionEstablecimientoService direccionEstablecimientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idDireccionEstab
	 *            Integer
	 * @return Ab6340s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idDireccionEstab}", method = RequestMethod.GET)
	public @ResponseBody DireccionEstablecimiento get(@PathVariable Integer idDireccionEstab) {
		DireccionEstablecimiento filter = new DireccionEstablecimiento();
		filter.setIdDireccionEstab(idDireccionEstab);
		filter = this.direccionEstablecimientoService.find(filter);
		DireccionEstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6340s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6340s00
	 *            Ab6340s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6340s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<DireccionEstablecimiento> getAll(
			@ModelAttribute DireccionEstablecimiento filterAb6340s00) {
		DireccionEstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6340s00 por filtro");
		return this.direccionEstablecimientoService.findAll(filterAb6340s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6340s00 Bean que contiene la informacion a modificar.
	 * @return Ab6340s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody DireccionEstablecimiento edit(@RequestBody DireccionEstablecimiento filter) {
		DireccionEstablecimiento filterAux = this.direccionEstablecimientoService.update(filter);
		DireccionEstablecimientoController.logger.info("[PUT] : Ab6340s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6340s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6340s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody DireccionEstablecimiento add(@RequestBody DireccionEstablecimiento filter) {
		DireccionEstablecimiento filterAux = this.direccionEstablecimientoService.add(filter);
		DireccionEstablecimientoController.logger.info("[POST] : Ab6340s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idDireccionEstab
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6340s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idDireccionEstab}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody DireccionEstablecimiento remove(@PathVariable Integer idDireccionEstab) {
		DireccionEstablecimiento filter = new DireccionEstablecimiento();
		filter.setIdDireccionEstab(idDireccionEstab);
		this.direccionEstablecimientoService.remove(filter);
		DireccionEstablecimientoController.logger.info("[DELETE] : Ab6340s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		DireccionEstablecimientoController.logger.info("[GET - View] : ab6340s00");
		return "ab6340s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6340s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DireccionEstablecimiento> filter(
			@RequestJsonBody(param = "filter") DireccionEstablecimiento filterAb6340s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionEstablecimientoController.logger.info("[POST - filter] : Obtener Ab6340s00s");
		return this.direccionEstablecimientoService.filter(filterAb6340s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6340s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<DireccionEstablecimiento>> search(
			@RequestJsonBody(param = "filter") DireccionEstablecimiento filterAb6340s00,
			@RequestJsonBody(param = "search") DireccionEstablecimiento searchAb6340s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionEstablecimientoController.logger.info("[POST - search] : Buscar Ab6340s00s");
		return this.direccionEstablecimientoService.search(filterAb6340s00, searchAb6340s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") DireccionEstablecimiento filterAb6340s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionEstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6340s00s");
		this.direccionEstablecimientoService.removeMultiple(filterAb6340s00, jqGridRequestDto, false);
		DireccionEstablecimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6340s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DireccionEstablecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") DireccionEstablecimiento filterAb6340s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6340s00s jerarquia");
		return this.direccionEstablecimientoService.jerarquia(filterAb6340s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6340s00
	 *            Ab6340s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6340s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DireccionEstablecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") DireccionEstablecimiento filterAb6340s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DireccionEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6340s00s jerarquia - Hijos");
		return this.direccionEstablecimientoService.jerarquiaChildren(filterAb6340s00, jqGridRequestDto);
	}

}
