package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.model.DispensaEstablecimiento;
import com.ejie.ab63.service.DispensaEstablecimientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6320s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/dispensaEstablecimiento")

public class DispensaEstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(DispensaEstablecimientoController.class);

	@Autowired
	private DispensaEstablecimientoService dispensaEstablecimientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idDispensasEstab
	 *            Integer
	 * @return Ab6320s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idDispensasEstab}", method = RequestMethod.GET)
	public @ResponseBody DispensaEstablecimiento get(@PathVariable Integer idDispensasEstab) {
		DispensaEstablecimiento filter = new DispensaEstablecimiento();
		filter.setIdDispensasEstab(idDispensasEstab);
		filter = this.dispensaEstablecimientoService.find(filter);
		DispensaEstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6320s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6320s00
	 *            Ab6320s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6320s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<DispensaEstablecimiento> getAll(@ModelAttribute DispensaEstablecimiento filterAb6320s00) {
		DispensaEstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6320s00 por filtro");
		return this.dispensaEstablecimientoService.findAll(filterAb6320s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6320s00 Bean que contiene la informacion a modificar.
	 * @return Ab6320s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody DispensaEstablecimiento edit(@RequestBody DispensaEstablecimiento filter) {
		DispensaEstablecimiento filterAux = this.dispensaEstablecimientoService.update(filter);
		DispensaEstablecimientoController.logger.info("[PUT] : Ab6320s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6320s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6320s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody DispensaEstablecimiento add(@RequestBody DispensaEstablecimiento filter) {
		DispensaEstablecimiento filterAux = this.dispensaEstablecimientoService.add(filter);
		DispensaEstablecimientoController.logger.info("[POST] : Ab6320s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idDispensasEstab
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6320s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idDispensasEstab}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody DispensaEstablecimiento remove(@PathVariable Integer idDispensasEstab) {
		DispensaEstablecimiento filter = new DispensaEstablecimiento();
		filter.setIdDispensasEstab(idDispensasEstab);
		filter = this.dispensaEstablecimientoService.find(filter);
		filter.setDispensado("0");
		this.dispensaEstablecimientoService.update(filter);
		// this.dispensaEstablecimientoService.remove(filter);
		DispensaEstablecimientoController.logger.info("[DELETE] : Ab6320s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		DispensaEstablecimientoController.logger.info("[GET - View] : ab6320s00");
		return "ab6320s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6320s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DispensaEstablecimiento> filter(
			@RequestJsonBody(param = "filter") DispensaEstablecimiento filterAb6320s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DispensaEstablecimientoController.logger.info("[POST - filter] : Obtener Ab6320s00s");
		return this.dispensaEstablecimientoService.filter(filterAb6320s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6320s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<DispensaEstablecimiento>> search(
			@RequestJsonBody(param = "filter") DispensaEstablecimiento filterAb6320s00,
			@RequestJsonBody(param = "search") DispensaEstablecimiento searchAb6320s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DispensaEstablecimientoController.logger.info("[POST - search] : Buscar Ab6320s00s");
		return this.dispensaEstablecimientoService.search(filterAb6320s00, searchAb6320s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") DispensaEstablecimiento filterAb6320s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DispensaEstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6320s00s");
		this.dispensaEstablecimientoService.removeMultiple(filterAb6320s00, jqGridRequestDto, false);
		DispensaEstablecimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6320s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DispensaEstablecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") DispensaEstablecimiento filterAb6320s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DispensaEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6320s00s jerarquia");
		return this.dispensaEstablecimientoService.jerarquia(filterAb6320s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6320s00
	 *            Ab6320s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6320s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DispensaEstablecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") DispensaEstablecimiento filterAb6320s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DispensaEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6320s00s jerarquia - Hijos");
		return this.dispensaEstablecimientoService.jerarquiaChildren(filterAb6320s00, jqGridRequestDto);
	}

}
