package com.ejie.ab63.control;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Especialidad;
import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.EspecialidadService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6315s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/especialidad")

public class EspecialidadController {

	private static final Logger logger = LoggerFactory.getLogger(EspecialidadController.class);

	@Autowired
	private EspecialidadService especialidadService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEspecialidad
	 *            String
	 * @return Ab6315s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idEspecialidad}", method = RequestMethod.GET)
	public @ResponseBody Especialidad get(@PathVariable String idEspecialidad) {
		Especialidad filter = new Especialidad();
		filter.setIdEspecialidad(idEspecialidad);
		filter = this.especialidadService.find(filter);
		EspecialidadController.logger.info("[GET - findBy_PK] : Obtener Ab6315s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6315s00
	 *            Ab6315s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6315s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Especialidad> getAll(@ModelAttribute Especialidad filterAb6315s00,
			@RequestParam(value = "tipoEst", required = false) String tipoEst) {
		EspecialidadController.logger.info("[GET - find_ALL] : Obtener Ab6315s00 por filtro");
		if (StringUtils.isNotBlank(tipoEst)) {
			TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
			tipoEstablecimiento.setIdTipoEstablecimiento(tipoEst);
			filterAb6315s00.setTipoEstablecimiento(tipoEstablecimiento);
		}
		filterAb6315s00.setBaja(0);
		return this.especialidadService.findAll(filterAb6315s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6315s00 Bean que contiene la informacion a modificar.
	 * @return Ab6315s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Especialidad edit(@RequestBody Especialidad filter) {
		Especialidad filterAux = this.especialidadService.update(filter);
		EspecialidadController.logger.info("[PUT] : Ab6315s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6315s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6315s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Especialidad add(@RequestBody Especialidad filter) {
		Especialidad filterAux = this.especialidadService.add(filter);
		EspecialidadController.logger.info("[POST] : Ab6315s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idEspecialidad
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6315s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEspecialidad}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Especialidad remove(@PathVariable String idEspecialidad) {
		Especialidad filter = new Especialidad();
		filter.setIdEspecialidad(idEspecialidad);
		this.especialidadService.remove(filter);
		EspecialidadController.logger.info("[DELETE] : Ab6315s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		EspecialidadController.logger.info("[GET - View] : ab6315s00");
		model.addAttribute("initForm", new InitForm());
		return "especialidades";
	}

	/**
	 * METODO CREADO POST PARA EL CAMBIO DE IDIOMA Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		EspecialidadController.logger.info("[GET - View] : ab6315s00");
		model.addAttribute("initForm", new InitForm());
		return "especialidades";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6315s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Especialidad> filter(
			@RequestJsonBody(param = "filter") Especialidad filterAb6315s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EspecialidadController.logger.info("[POST - filter] : Obtener Ab6315s00s");
		return this.especialidadService.filter(filterAb6315s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6315s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Especialidad>> search(
			@RequestJsonBody(param = "filter") Especialidad filterAb6315s00,
			@RequestJsonBody(param = "search") Especialidad searchAb6315s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EspecialidadController.logger.info("[POST - search] : Buscar Ab6315s00s");
		return this.especialidadService.search(filterAb6315s00, searchAb6315s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Especialidad filterAb6315s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EspecialidadController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6315s00s");
		this.especialidadService.removeMultiple(filterAb6315s00, jqGridRequestDto, false);
		EspecialidadController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6315s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Especialidad>> jerarquia(
			@RequestJsonBody(param = "filter") Especialidad filterAb6315s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EspecialidadController.logger.info("[POST - jerarquia] : Obtener Ab6315s00s jerarquia");
		return this.especialidadService.jerarquia(filterAb6315s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6315s00
	 *            Ab6315s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6315s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Especialidad>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Especialidad filterAb6315s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EspecialidadController.logger.info("[POST - jerarquia] : Obtener Ab6315s00s jerarquia - Hijos");
		return this.especialidadService.jerarquiaChildren(filterAb6315s00, jqGridRequestDto);
	}

}
