package com.ejie.ab63.control;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import java.util.Vector;

import javax.annotation.Resource;

import org.apache.http.HttpRequest;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.comun.utilidades.config.Config;
import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.model.inicio.InitFormEst;
import com.ejie.ab63.model.plantillas.ParametrosConfig;
import com.ejie.ab63.model.util.ErrorResultAjaxOperation;
import com.ejie.ab63.model.util.ResultAjaxOperation;
import com.ejie.ab63.model.util.SuccessResultAjaxOperation;
import com.ejie.ab63.service.AgenciaDataService;
import com.ejie.ab63.service.EstablecimientoService;
import com.ejie.ab63.service.plantillas.ParametrosConfigService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;
import com.ejie.x38.reports.ReportData;
import com.ejie.x38.security.UserCredentials;

/**
 * Ab6301s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/establecimientos")

public class EstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(EstablecimientoController.class);

	private final String CONTROLADOR = "establecimientos";

	@Autowired
	private EstablecimientoService establecimientoService;

	@Autowired
	private AgenciaDataService agenciaDataService;

	@Resource
	private ReloadableResourceBundleMessageSource appMessageSource;

	@Autowired
	private ParametrosConfigService parametrosConfigService;
	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEstablecimiento
	 *            Integer
	 * @return Ab6301s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.GET)
	public @ResponseBody Establecimiento get(@PathVariable Integer idEstablecimiento) {
		Establecimiento filter = new Establecimiento();
		filter.setIdEstablecimiento(idEstablecimiento);
		filter = this.establecimientoService.find(filter);
		EstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6301s00 por PK");
		return filter;
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEstablecimiento
	 *            Integer
	 * @return Ab6301s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.POST) // GET
	public ModelAndView getEstablecimiento(Model model, @PathVariable Integer idEstablecimiento,
			@ModelAttribute(value = "initFormEst") InitFormEst initFormEst) {
		Establecimiento filter = new Establecimiento();

		filter.setIdEstablecimiento(idEstablecimiento);
		filter = this.establecimientoService.find(filter);

		if (filter != null && filter.getDatosDirecciones() != null
				&& filter.getDatosDirecciones().getIdDireccion() == 0) {
			model.addAttribute("NO_DIRECCION", "NO_DIRECCION");
		}

		ParametrosConfig parametrosConfigFind = new ParametrosConfig();
		parametrosConfigFind.setDescripcion(Constantes.ACTIVADA_PUBLICACION_AA80T);
		ParametrosConfig parametrosConfig = this.parametrosConfigService.find(parametrosConfigFind);

		if (parametrosConfig.getValor() == 1) {
			model.addAttribute("ACTIVAR_PUBLICACION", "1");
		}

		if (filter != null && filter.getDatosDirecciones() != null && filter.getDatosDirecciones().getIdPais() == 0) {
			filter.getDatosDirecciones().setIdPais((long) Constantes.ID_NORA_ESP);
		}

		if (filter != null && filter.getTipoEstablecimiento() != null) {
			initFormEst.setTipoEstablecimiento(filter.getTipoEstablecimiento().getIdTipoEstablecimiento());
		}

		model.addAttribute("filter", filter);
		EstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6301s00 por PK");
		// obtenemos el tipo establecimiento para la pestaa
		String tipoEstablecimiento = filter.getTipoEstablecimiento().getIdTipoEstablecimiento();
		preparePestanas(model, tipoEstablecimiento);

		return new ModelAndView("datosEstablecimiento", "model", model);
	}

	@RequestMapping(value = "/relacionado/{idEstablecimiento}", method = RequestMethod.GET)
	public ModelAndView getEstablecimientoFromDatosEspecificosAAVV(Model model, @PathVariable Integer idEstablecimiento,
			@ModelAttribute(value = "initFormEst") InitFormEst initFormEst) {
		Establecimiento filter = new Establecimiento();

		filter.setIdEstablecimiento(idEstablecimiento);
		filter = this.establecimientoService.find(filter);

		if (filter != null && filter.getDatosDirecciones() != null
				&& filter.getDatosDirecciones().getIdDireccion() == 0) {
			model.addAttribute("NO_DIRECCION", "NO_DIRECCION");
		}

		ParametrosConfig parametrosConfigFind = new ParametrosConfig();
		parametrosConfigFind.setDescripcion(Constantes.ACTIVADA_PUBLICACION_AA80T);
		ParametrosConfig parametrosConfig = this.parametrosConfigService.find(parametrosConfigFind);

		if (parametrosConfig.getValor() == 1) {
			model.addAttribute("ACTIVAR_PUBLICACION", "1");
		}

		if (filter != null && filter.getDatosDirecciones() != null && filter.getDatosDirecciones().getIdPais() == 0) {
			filter.getDatosDirecciones().setIdPais((long) Constantes.ID_NORA_ESP);
		}

		if (filter != null && filter.getTipoEstablecimiento() != null) {
			initFormEst.setTipoEstablecimiento(filter.getTipoEstablecimiento().getIdTipoEstablecimiento());
		}

		model.addAttribute("filter", filter);
		EstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6301s00 por PK");
		// obtenemos el tipo establecimiento para la pestaa
		String tipoEstablecimiento = filter.getTipoEstablecimiento().getIdTipoEstablecimiento();
		preparePestanas(model, tipoEstablecimiento);

		return new ModelAndView("datosEstablecimiento", "model", model);
	}

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idEstablecimiento
	 *            Integer
	 * @return Ab6301s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/maint/{identificador}", method = RequestMethod.GET)
	public ModelAndView accessEstablecimiento(Model model, @ModelAttribute("initFormEst") InitFormEst initFormEst,
			@PathVariable("identificador") String identificador) {
		Establecimiento filter = new Establecimiento();
		filter.setIdentificadorEstablecimiento(identificador);
		filter.setOnlyTitularIfExists(true);
		filter = this.establecimientoService.findByIdenticadorEstablecimiento(filter);
		model.addAttribute("filter", filter);
		EstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6301s00 por PK");
		// obtenemos el tipo establecimiento para la pestaa
		String tipoEstablecimiento = filter.getTipoEstablecimiento().getIdTipoEstablecimiento();
		preparePestanas(model, tipoEstablecimiento);

		initFormEst.setIdentificadorEstablecimiento(identificador);
		initFormEst.setIdEstablecimiento(filter.getIdEstablecimiento().toString());
		initFormEst.setTipoEstablecimiento(tipoEstablecimiento);

		ParametrosConfig parametrosConfigFind = new ParametrosConfig();
		parametrosConfigFind.setDescripcion(Constantes.ACTIVADA_PUBLICACION_AA80T);
		ParametrosConfig parametrosConfig = this.parametrosConfigService.find(parametrosConfigFind);

		if (parametrosConfig.getValor() == 1) {
			model.addAttribute("ACTIVAR_PUBLICACION", "1");
		}

		model.addAttribute("initFormEst", initFormEst);
		return new ModelAndView("datosEstablecimiento", "model", model);
	}

	/* PREPARE PESTANAS */

	private void preparePestanas(Model model, String tipoEstablecimiento) {
		model.addAttribute("nombreControlador", CONTROLADOR);
		model.addAttribute("currentPage", Constantes.PESTANA_DATOS_ESTABLECIMIENTO);
		model.addAttribute("datosEstablecimiento", Constantes.PESTANA_DATOS_ESTABLECIMIENTO);
		model.addAttribute("interesados", Constantes.PESTANA_INTERESADOS);
		model.addAttribute("datosEspecificos", Constantes.PESTANA_DATOS_ESPECIFICOS);
		model.addAttribute("expRelacionados", Constantes.PESTANA_EXP_RELACIONADOS);
		List<String> configs = Constantes.getmapPestanasEstablecimiento().get(tipoEstablecimiento);
		for (Iterator<String> iterator = configs.iterator(); iterator.hasNext();) {
			String configOption = (String) iterator.next();
			model.addAttribute(configOption, configOption);
		}
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6301s00
	 *            Ab6301s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6301s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Establecimiento> getAll(@ModelAttribute Establecimiento filterAb6301s00) {
		EstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6301s00 por filtro");
		return this.establecimientoService.findAll(filterAb6301s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6301s00 Bean que contiene la informacion a modificar.
	 * @return Ab6301s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Establecimiento edit(@RequestBody Establecimiento filter) {
		Establecimiento filterAux = this.establecimientoService.update(filter);
		EstablecimientoController.logger.info("[PUT] : Ab6301s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6301s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6301s00 Bean resultante del proceso de
	 *         creacion.idTipoEstablecimiento
	 */
	@RequestMapping(value = "add/{idProvinciaSolicitanteAnyadir}/{idTipoEstablecimiento}", method = RequestMethod.POST)
	public @ResponseBody Establecimiento add(Model model, @PathVariable String idProvinciaSolicitanteAnyadir,
			@PathVariable String idTipoEstablecimiento) {

		Establecimiento establecimiento = this.establecimientoService.add(idTipoEstablecimiento,
				idProvinciaSolicitanteAnyadir);
		return establecimiento;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idEstablecimiento
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6301s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Establecimiento remove(@PathVariable Integer idEstablecimiento) {
		Establecimiento filter = new Establecimiento();
		filter.setIdEstablecimiento(idEstablecimiento);
		this.establecimientoService.remove(filter);
		EstablecimientoController.logger.info("[DELETE] : Ab6301s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model,
			@RequestParam(value = "tipoRegistro", required = false) String tipoRegistro) {
		// obtener perfiles de usuario
		UserCredentials userCredentials = (UserCredentials) SecurityContextHolder.getContext().getAuthentication()
				.getCredentials();
		Vector<String> listPerfiles = userCredentials.getUserProfiles();
		String provincia = "";
		for (String perfil : listPerfiles) {
			if (Constantes.getMapaPerfilProvincia().containsKey(perfil)) {
				provincia = Constantes.getMapaPerfilProvincia().get(perfil);
			}
		}
		// aadimos perfiles de usuario
		model.addAttribute("provincia", provincia);
		Establecimiento establecimiento = new Establecimiento();
		if (tipoRegistro == null) {
			tipoRegistro = Constantes.TIPO_REGISTRO_DEFINITIVO;
		}
		establecimiento.setTipoRegistro(tipoRegistro);
		model.addAttribute("busqREATE", establecimiento);
		model.addAttribute(new InitForm());

		// TODO PRELOAD USER INFO PARA ESTABLECER FILTROS GEOGRAFICOS
		EstablecimientoController.logger.info("[POST - View] : Establecimientos");
		return "busqREATE";

	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEditURL(Model model,
			@RequestParam(value = "tipoRegistro", required = false) String tipoRegistro) {
		EstablecimientoController.logger.info("[GET - View] : ab6301s00");
		return getFormEdit(model, tipoRegistro);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6301s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Establecimiento> filter(
			@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger.info("[POST - filter] : Obtener Ab6301s00s");
		filterAb6301s00.setOnlyTitularIfExists(true);
		return this.establecimientoService.filter(filterAb6301s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6301s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/{idEstablecimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Establecimiento> filterCabecera(
			@PathVariable("idEstablecimiento") Integer idEstablecimiento,
			@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger.info("[POST - filterCabecera] : Obtener Ab6301s00s");
		filterAb6301s00.setIdEstablecimiento(idEstablecimiento);
		return this.establecimientoService.filter(filterAb6301s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6301s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Establecimiento>> search(
			@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody(param = "search") Establecimiento searchAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger.info("[POST - search] : Buscar Ab6301s00s");
		return this.establecimientoService.search(filterAb6301s00, searchAb6301s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6301s00s");
		this.establecimientoService.removeMultiple(filterAb6301s00, jqGridRequestDto, false);
		EstablecimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6301s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Establecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6301s00s jerarquia");
		return this.establecimientoService.jerarquia(filterAb6301s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6301s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Establecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Establecimiento filterAb6301s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		EstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6301s00s jerarquia - Hijos");
		return this.establecimientoService.jerarquiaChildren(filterAb6301s00, jqGridRequestDto);
	}

	/**
	 * Guarda los datos del formulario formDatosEspecificos
	 * 
	 * @param model
	 * @param establecimiento
	 * @return
	 */
	@RequestMapping(value = "/save", method = RequestMethod.POST)
	public @ResponseBody ResultAjaxOperation saveDatosEmpresa(
			@ModelAttribute("establecimiento") Establecimiento establecimiento) {

		EstablecimientoController.logger.info("saveDatosEmpresa");

		try {

			this.establecimientoService.updateDatosEmpresa(establecimiento);

		} catch (Exception e) {

			EstablecimientoController.logger.info("saveDatosEmpresa " + e.getMessage());

			if (Constantes.ERROR_CIE_INEXISTENTE.equals(e.getMessage())) {
				return new ErrorResultAjaxOperation(Constantes.ERROR_CIE_INEXISTENTE);
			} else if (Constantes.ERROR_ORIGEN_OFICINA_SUCURSALPV_NO_COINCIDE_PPAL.equals(e.getMessage())) {
				return new ErrorResultAjaxOperation(Constantes.ERROR_ORIGEN_OFICINA_SUCURSALPV_NO_COINCIDE_PPAL);
			} else {
				return new ErrorResultAjaxOperation(Constantes.ERROR_GENERICO_GUARDADO);
			}
		}

		return new SuccessResultAjaxOperation("success");

	}

	@RequestMapping(value = "/xlsReport", method = RequestMethod.POST)
	protected ModelAndView getExcelBusqEstablecimientos(@ModelAttribute("tblBusqREATE") Establecimiento establecimiento,
			@ModelAttribute JQGridRequestDto jqGridRequestDto, ModelMap modelMap,
			@RequestParam(value = "columns", required = false) String columns, HttpRequest request) {

		EstablecimientoController.logger.info("[POST - getExcelBusqEstablecimientos] :");

		Locale locale = LocaleContextHolder.getLocale();
		jqGridRequestDto.setRows(1000000000000000L);

		establecimiento.setOnlyTitularIfExists(true);
		List<Establecimiento> establecimientos = this.establecimientoService.findAllLikeExcelBusqREATE(establecimiento,
				null, false);

		modelMap.put("fileName", "reate");

		List<Object> reportData = new ArrayList<Object>();
		// Hoja 1
		ReportData<Establecimiento> usuarioExcelDataAll = new ReportData<Establecimiento>();
		// nombre hoja
		usuarioExcelDataAll.setSheetName("REATE");
		// cabeceras hoja
		usuarioExcelDataAll.setHeaderNames(ReportData.parseColumns(columns));
		// datos hoja
		usuarioExcelDataAll.setModelData(establecimientos);
		reportData.add(usuarioExcelDataAll);

		modelMap.put("reportData", reportData);

		return new ModelAndView("xlsxReport", modelMap);
		/*
		 * if (request.getServletPath().indexOf("xlsReport") != -1) { return new
		 * ModelAndView("xlsReport", modelMap); } else { return new
		 * ModelAndView("xlsxReport", modelMap); }
		 */

	}

	@RequestMapping(value = "/checkRefCatastral", method = RequestMethod.POST)
	public @ResponseBody ResultAjaxOperation checkRefCatastral(
			@ModelAttribute("establecimiento") Establecimiento establecimiento) {

		EstablecimientoController.logger.info("checkRefCatastral");
		Long resultado;

		try {

			resultado = this.establecimientoService.checkRefCatastral(establecimiento);

		} catch (Exception e) {

			EstablecimientoController.logger.info("checkRefCatastral " + e.getMessage());

			return new ErrorResultAjaxOperation("error");

		}

		return new SuccessResultAjaxOperation(Long.toString(resultado));
	}

	@RequestMapping(value = "/getDatosOficinaPpalAAVV/{numCie}", method = RequestMethod.POST)
	public @ResponseBody ResultAjaxOperation getDatosOficinaPpalAAVV(@PathVariable("numCie") String numCie) {

		EstablecimientoController.logger.info("getDatosOficinaPpalAAVV");
		Map<String, String> resultado;

		try {

			resultado = this.establecimientoService.getDatosOficinaPpalAAVV(numCie);

		} catch (Exception e) {

			EstablecimientoController.logger.info("getDatosOficinaPpalAAVV " + e.getMessage());

			return new ErrorResultAjaxOperation("errorGetDatosOficinaPpalAAVV");

		}

		SuccessResultAjaxOperation successResultAjaxOperation = new SuccessResultAjaxOperation(
				"okGetDatosOficinaPpalAAVV");

		successResultAjaxOperation.setData(resultado);

		return successResultAjaxOperation;
	}

	@RequestMapping(value = "/getDireccionExtranjeraOficinaPpalAAVV/{idTercero}", method = RequestMethod.POST)
	public @ResponseBody ResultAjaxOperation getDireccionExtranjeraOficinaPpalAAVV(
			@PathVariable("idTercero") Integer idTercero) {

		EstablecimientoController.logger.info("getDireccionExtranjeraOficinaPpalAAVV");
		Map<String, String> resultado;

		try {

			resultado = this.establecimientoService.getDireccionExtranjeraOficinaPpalAAVV(idTercero);

		} catch (Exception e) {

			EstablecimientoController.logger.info("getDireccionExtranjeraOficinaPpalAAVV " + e.getMessage());

			return new ErrorResultAjaxOperation("errorGetDireccionExtranjeraOficinaPpalAAVV");

		}

		SuccessResultAjaxOperation successResultAjaxOperation = new SuccessResultAjaxOperation(
				"okGetDireccionExtranjeraOficinaPpalAAVV");

		successResultAjaxOperation.setData(resultado);

		return successResultAjaxOperation;
	}

	@RequestMapping(value = "/refreshDirExtOfiPpal/{idDireccionExt}", method = RequestMethod.DELETE)
	public @ResponseBody ResultAjaxOperation refreshDirExtOfiPpal(
			@PathVariable("idDireccionExt") Integer idDireccionExt) {

		EstablecimientoController.logger.info("refreshDirExtOfiPpal");
		Integer resultado = 0;

		try {

			resultado = this.establecimientoService.deleteDireccionExtranjeraOfiPpal(idDireccionExt);

		} catch (Exception e) {

			EstablecimientoController.logger.info("refreshDirExtOfiPpal " + e.getMessage());

			return new ErrorResultAjaxOperation("errorGetDireccionExtranjeraOficinaPpalAAVV");

		}

		return new SuccessResultAjaxOperation(String.valueOf(resultado));
	}

	@RequestMapping(value = "/comprobarPrimeraSucursal/{idOficinaPpal}/{idEstablecimiento}", method = RequestMethod.GET)
	public @ResponseBody ResultAjaxOperation comprobarPrimeraSucursal(
			@PathVariable("idOficinaPpal") Integer idOficinaPpal,
			@PathVariable("idEstablecimiento") Integer idEstablecimiento) {

		EstablecimientoController.logger.info("comprobarPrimeraSucursal");
		Integer resultado = 0;

		try {

			resultado = this.agenciaDataService.comprobarPrimeraSucursal(idOficinaPpal, idEstablecimiento);

		} catch (Exception e) {

			EstablecimientoController.logger.info("comprobarPrimeraSucursal " + e.getMessage());

			return new ErrorResultAjaxOperation("errorComprobarPrimeraSucursal");

		}

		return new SuccessResultAjaxOperation(String.valueOf(resultado));
	}
}
