package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.FactorCompensatorio;
import com.ejie.ab63.service.FactorCompensatorioService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6319s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/factorCompensatorio")

public class FactorCompensatorioController {

	private static final Logger logger = LoggerFactory.getLogger(FactorCompensatorioController.class);

	@Autowired
	private FactorCompensatorioService factorCompensatorioService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idFactorCompensatorio
	 *            Integer
	 * @return Ab6319s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFactorComp}", method = RequestMethod.GET)
	public @ResponseBody FactorCompensatorio get(@PathVariable Integer idFactorComp) {
		FactorCompensatorio filter = new FactorCompensatorio();
		filter.setIdFactorComp(idFactorComp);
		filter = this.factorCompensatorioService.find(filter);
		FactorCompensatorioController.logger.info("[GET - findBy_PK] : Obtener Ab6319s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6319s00
	 *            Ab6319s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6319s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<FactorCompensatorio> getAll(@ModelAttribute FactorCompensatorio filterAb6319s00) {
		FactorCompensatorioController.logger.info("[GET - find_ALL] : Obtener Ab6319s00 por filtro");
		return this.factorCompensatorioService.findAll(filterAb6319s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6319s00 Bean que contiene la informacion a modificar.
	 * @return Ab6319s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody FactorCompensatorio edit(@RequestBody FactorCompensatorio filter) {
		FactorCompensatorio filterAux = this.factorCompensatorioService.update(filter);
		FactorCompensatorioController.logger.info("[PUT] : Ab6319s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6319s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6319s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody FactorCompensatorio add(@RequestBody FactorCompensatorio filter) {

		FactorCompensatorio filterAux = this.factorCompensatorioService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idFactorCompensatorio
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6319s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idFactorComp}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody FactorCompensatorio remove(@PathVariable Integer idFactorComp) {
		FactorCompensatorio filter = new FactorCompensatorio();
		filter.setIdFactorComp(idFactorComp);
		this.factorCompensatorioService.remove(filter);
		FactorCompensatorioController.logger.info("[DELETE] : Ab6319s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		FactorCompensatorioController.logger.info("[GET - View] : ab6319s00");
		return "ab6319s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6319s00
	 *            Ab6319s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableRequestDto<Ab6319s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<FactorCompensatorio> filter(
			@RequestJsonBody(param = "filter") FactorCompensatorio filterAb6319s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FactorCompensatorioController.logger.info("[POST - filter] : Obtener Ab6319s00s");
		return this.factorCompensatorioService.filter(filterAb6319s00, tableRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6319s00
	 *            Ab6319s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6319s00
	 *            Ab6319s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6319s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<FactorCompensatorio>> search(
			@RequestJsonBody(param = "filter") FactorCompensatorio filterAb6319s00,
			@RequestJsonBody(param = "search") FactorCompensatorio searchAb6319s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FactorCompensatorioController.logger.info("[POST - search] : Buscar Ab6319s00s");
		return this.factorCompensatorioService.search(filterAb6319s00, searchAb6319s00, tableRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6319s00
	 *            Ab6319s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") FactorCompensatorio filterAb6319s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FactorCompensatorioController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6319s00s");
		this.factorCompensatorioService.removeMultiple(filterAb6319s00, tableRequestDto, false);
		FactorCompensatorioController.logger.info("All entities correctly deleted!");

		return tableRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

}
