package com.ejie.ab63.control;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.FianzaEstablecimiento;
import com.ejie.ab63.service.FianzaEstablecimientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6337s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/fianzaEstablecimiento")

public class FianzaEstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(FianzaEstablecimientoController.class);

	@Autowired
	private FianzaEstablecimientoService fianzaEstablecimientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idFianzasEstab
	 *            Integer
	 * @return Ab6337s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFianzasEstab}", method = RequestMethod.GET)
	public @ResponseBody FianzaEstablecimiento get(@PathVariable Integer idFianzasEstab) {
		FianzaEstablecimiento filter = new FianzaEstablecimiento();
		filter.setIdFianzasEstab(idFianzasEstab);
		filter = this.fianzaEstablecimientoService.find(filter);
		FianzaEstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6337s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6337s00
	 *            Ab6337s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6337s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<FianzaEstablecimiento> getAll(@ModelAttribute FianzaEstablecimiento filterAb6337s00) {
		FianzaEstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6337s00 por filtro");
		return this.fianzaEstablecimientoService.findAll(filterAb6337s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6337s00 Bean que contiene la informacion a modificar.
	 * @return Ab6337s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody FianzaEstablecimiento edit(@RequestBody FianzaEstablecimiento filter) {
		FianzaEstablecimiento filterAux = this.fianzaEstablecimientoService.update(filter);
		FianzaEstablecimientoController.logger.info("[PUT] : Ab6337s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6337s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6337s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody FianzaEstablecimiento add(@RequestBody FianzaEstablecimiento filter) {
		FianzaEstablecimiento filterAux = this.fianzaEstablecimientoService.add(filter);
		FianzaEstablecimientoController.logger.info("[POST] : Ab6337s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idFianzasEstab
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6337s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idFianzasEstab}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody FianzaEstablecimiento remove(@PathVariable Integer idFianzasEstab) {
		FianzaEstablecimiento filter = new FianzaEstablecimiento();
		filter.setIdFianzasEstab(idFianzasEstab);
		this.fianzaEstablecimientoService.remove(filter);
		FianzaEstablecimientoController.logger.info("[DELETE] : Ab6337s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		FianzaEstablecimientoController.logger.info("[GET - View] : ab6337s00");
		return "ab6337s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<Ab6337s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<FianzaEstablecimiento> filter(
			@RequestJsonBody(param = "filter") FianzaEstablecimiento filterAb6337s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FianzaEstablecimientoController.logger.info("[POST - filter] : Obtener Ab6337s00s");

		// Se filtra por numCie, si es vaco (caso que no debera darse) se
		// devuelve una lista vaca
		if (null != filterAb6337s00 && null != filterAb6337s00.getFranquicia()
				&& StringUtils.isNotBlank(filterAb6337s00.getFranquicia().getNumCie())) {
			return this.fianzaEstablecimientoService.filter(filterAb6337s00, tableRequestDto, false);
		} else {
			return new TableResponseDto<FianzaEstablecimiento>(tableRequestDto, (long) 0,
					new ArrayList<FianzaEstablecimiento>());
		}

	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6337s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<FianzaEstablecimiento>> search(
			@RequestJsonBody(param = "filter") FianzaEstablecimiento filterAb6337s00,
			@RequestJsonBody(param = "search") FianzaEstablecimiento searchAb6337s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FianzaEstablecimientoController.logger.info("[POST - search] : Buscar Ab6337s00s");
		return this.fianzaEstablecimientoService.search(filterAb6337s00, searchAb6337s00, tableRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") FianzaEstablecimiento filterAb6337s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FianzaEstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6337s00s");
		this.fianzaEstablecimientoService.removeMultiple(filterAb6337s00, tableRequestDto, false);
		FianzaEstablecimientoController.logger.info("All entities correctly deleted!");

		return tableRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6337s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<FianzaEstablecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") FianzaEstablecimiento filterAb6337s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FianzaEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6337s00s jerarquia");
		return this.fianzaEstablecimientoService.jerarquia(filterAb6337s00, tableRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6337s00
	 *            Ab6337s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6337s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<FianzaEstablecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") FianzaEstablecimiento filterAb6337s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		FianzaEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6337s00s jerarquia - Hijos");
		return this.fianzaEstablecimientoService.jerarquiaChildren(filterAb6337s00, tableRequestDto);
	}

	@RequestMapping(value = "/{flag}", method = RequestMethod.POST)
	public @ResponseBody List<BigDecimal> getFianzasByEstablecimiento(@PathVariable Integer flag,
			@ModelAttribute("establecimiento") Establecimiento establecimiento) {
		FianzaEstablecimiento filter = new FianzaEstablecimiento();
		// Franquicia franquicia = new Franquicia(idEstablecimiento);
		filter.setFranquicia(establecimiento.getFranquicia());
		List<BigDecimal> total = this.fianzaEstablecimientoService.calcularFianzas(filter,
				establecimiento.getGrupo().getIdGrupo(), flag);
		FianzaEstablecimientoController.logger.info("[getFianzasByEstablecimiento: " + total);
		return total;
	}

}
