package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.HabitacionAlojamiento;
import com.ejie.ab63.service.HabitacionAlojamientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6324s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/habitacionAlojamiento")

public class HabitacionAlojamientoController {

	private static final Logger logger = LoggerFactory.getLogger(HabitacionAlojamientoController.class);

	@Autowired
	private HabitacionAlojamientoService habitacionAlojamientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idHabitacionAlo
	 *            Integer
	 * @return Ab6324s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idHabitacionAlo}", method = RequestMethod.GET)
	public @ResponseBody HabitacionAlojamiento get(@PathVariable Integer idHabitacionAlo) {
		HabitacionAlojamiento filter = new HabitacionAlojamiento();
		filter.setIdHabitacionAlo(idHabitacionAlo);
		filter = this.habitacionAlojamientoService.find(filter);
		HabitacionAlojamientoController.logger.info("[GET - findBy_PK] : Obtener Ab6324s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6324s00
	 *            Ab6324s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6324s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<HabitacionAlojamiento> getAll(@ModelAttribute HabitacionAlojamiento filterAb6324s00) {
		HabitacionAlojamientoController.logger.info("[GET - find_ALL] : Obtener Ab6324s00 por filtro");
		return this.habitacionAlojamientoService.findAll(filterAb6324s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6324s00 Bean que contiene la informacion a modificar.
	 * @return Ab6324s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody HabitacionAlojamiento edit(@RequestBody HabitacionAlojamiento filter) {
		HabitacionAlojamiento filterAux = this.habitacionAlojamientoService.update(filter);
		HabitacionAlojamientoController.logger.info("[PUT] : Ab6324s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6324s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6324s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody HabitacionAlojamiento add(@RequestBody HabitacionAlojamiento filter) {
		// HabitacionAlojamiento filterAux =
		// this.habitacionAlojamientoService.add(filter);
		// HabitacionAlojamientoController.logger.info("[POST] : Ab6324s00
		// insertado correctamente");
		HabitacionAlojamiento filterAux = this.habitacionAlojamientoService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idHabitacionAlo
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6324s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idHabitacionAlo}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody HabitacionAlojamiento remove(@PathVariable Integer idHabitacionAlo) {
		HabitacionAlojamiento filter = new HabitacionAlojamiento();
		filter.setIdHabitacionAlo(idHabitacionAlo);
		this.habitacionAlojamientoService.remove(filter);
		HabitacionAlojamientoController.logger.info("[DELETE] : Ab6324s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		HabitacionAlojamientoController.logger.info("[GET - View] : ab6324s00");
		return "ab6324s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6324s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<HabitacionAlojamiento> filter(
			@RequestJsonBody(param = "filter") HabitacionAlojamiento filterAb6324s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionAlojamientoController.logger.info("[POST - filter] : Obtener Ab6324s00s");
		return this.habitacionAlojamientoService.filter(filterAb6324s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6324s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<HabitacionAlojamiento>> search(
			@RequestJsonBody(param = "filter") HabitacionAlojamiento filterAb6324s00,
			@RequestJsonBody(param = "search") HabitacionAlojamiento searchAb6324s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionAlojamientoController.logger.info("[POST - search] : Buscar Ab6324s00s");
		return this.habitacionAlojamientoService.search(filterAb6324s00, searchAb6324s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") HabitacionAlojamiento filterAb6324s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionAlojamientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6324s00s");
		this.habitacionAlojamientoService.removeMultiple(filterAb6324s00, jqGridRequestDto, false);
		HabitacionAlojamientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6324s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>> jerarquia(
			@RequestJsonBody(param = "filter") HabitacionAlojamiento filterAb6324s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionAlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6324s00s jerarquia");
		return this.habitacionAlojamientoService.jerarquia(filterAb6324s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6324s00
	 *            Ab6324s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6324s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<HabitacionAlojamiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") HabitacionAlojamiento filterAb6324s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionAlojamientoController.logger.info("[POST - jerarquia] : Obtener Ab6324s00s jerarquia - Hijos");
		return this.habitacionAlojamientoService.jerarquiaChildren(filterAb6324s00, jqGridRequestDto);
	}

}
