package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Habitacion;
import com.ejie.ab63.service.HabitacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6322s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/habitacion")

public class HabitacionController {

	private static final Logger logger = LoggerFactory.getLogger(HabitacionController.class);

	@Autowired
	private HabitacionService habitacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idHabitacion
	 *            Integer
	 * @return Ab6322s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idHabitacion}", method = RequestMethod.GET)
	public @ResponseBody Habitacion get(@PathVariable Integer idHabitacion) {
		Habitacion filter = new Habitacion();
		filter.setIdHabitacion(idHabitacion);
		filter = this.habitacionService.find(filter);
		HabitacionController.logger.info("[GET - findBy_PK] : Obtener Ab6322s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6322s00
	 *            Ab6322s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6322s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Habitacion> getAll(@ModelAttribute Habitacion filterAb6322s00) {
		HabitacionController.logger.info("[GET - find_ALL] : Obtener Ab6322s00 por filtro");
		return this.habitacionService.findAll(filterAb6322s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6322s00 Bean que contiene la informacion a modificar.
	 * @return Ab6322s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Habitacion edit(@RequestBody Habitacion filter) {
		Habitacion filterAux = this.habitacionService.update(filter);
		HabitacionController.logger.info("[PUT] : Ab6322s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6322s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6322s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Habitacion add(@RequestBody Habitacion filter) {
		// Habitacion filterAux = this.habitacionService.add(filter);
		// HabitacionController.logger.info("[POST] : Ab6322s00 insertado
		// correctamente");
		Habitacion filterAux = this.habitacionService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idHabitacion
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6322s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Habitacion remove(@PathVariable Integer idEstablecimiento,
			@RequestBody Habitacion habitacion) {
		// Habitacion filter = new Habitacion();
		// filter.setIdHabitacion(idHabitacion);
		this.habitacionService.remove(habitacion, idEstablecimiento);
		HabitacionController.logger.info("[DELETE] : Ab6322s00 borrado correctamente");
		return habitacion;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		HabitacionController.logger.info("[GET - View] : ab6322s00");
		return "ab6322s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<Ab6322s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<Habitacion> filter(
			@RequestJsonBody(param = "filter") Habitacion filterAb6322s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		HabitacionController.logger.info("[POST - filter] : Obtener Ab6322s00s");
		return this.habitacionService.filter(filterAb6322s00, tableRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6322s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Habitacion>> search(
			@RequestJsonBody(param = "filter") Habitacion filterAb6322s00,
			@RequestJsonBody(param = "search") Habitacion searchAb6322s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		HabitacionController.logger.info("[POST - search] : Buscar Ab6322s00s");
		return this.habitacionService.search(filterAb6322s00, searchAb6322s00, tableRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Habitacion filterAb6322s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		HabitacionController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6322s00s");
		this.habitacionService.removeMultiple(filterAb6322s00, tableRequestDto, false);
		HabitacionController.logger.info("All entities correctly deleted!");

		return tableRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6322s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Habitacion>> jerarquia(
			@RequestJsonBody(param = "filter") Habitacion filterAb6322s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		HabitacionController.logger.info("[POST - jerarquia] : Obtener Ab6322s00s jerarquia");
		return this.habitacionService.jerarquia(filterAb6322s00, tableRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6322s00
	 *            Ab6322s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6322s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<Habitacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Habitacion filterAb6322s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		HabitacionController.logger.info("[POST - jerarquia] : Obtener Ab6322s00s jerarquia - Hijos");
		return this.habitacionService.jerarquiaChildren(filterAb6322s00, tableRequestDto);
	}

}
