package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.HabitacionVivienda;
import com.ejie.ab63.service.HabitacionViviendaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6341s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/habitacionVivienda")

public class HabitacionViviendaController {

	private static final Logger logger = LoggerFactory.getLogger(HabitacionViviendaController.class);

	@Autowired
	private HabitacionViviendaService habitacionViviendaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idHabVivienda
	 *            String
	 * @return Ab6341s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idHabVivienda}", method = RequestMethod.GET)
	public @ResponseBody HabitacionVivienda get(@PathVariable String idHabVivienda) {
		HabitacionVivienda filter = new HabitacionVivienda();
		filter.setIdHabVivienda(idHabVivienda);
		filter = this.habitacionViviendaService.find(filter);
		HabitacionViviendaController.logger.info("[GET - findBy_PK] : Obtener Ab6341s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6341s00
	 *            Ab6341s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6341s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<HabitacionVivienda> getAll(@ModelAttribute HabitacionVivienda filterAb6341s00) {
		HabitacionViviendaController.logger.info("[GET - find_ALL] : Obtener Ab6341s00 por filtro");
		return this.habitacionViviendaService.findAll(filterAb6341s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6341s00 Bean que contiene la informacion a modificar.
	 * @return Ab6341s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody HabitacionVivienda edit(@RequestBody HabitacionVivienda filter) {
		HabitacionVivienda filterAux = this.habitacionViviendaService.update(filter);
		HabitacionViviendaController.logger.info("[PUT] : Ab6341s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6341s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6341s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody HabitacionVivienda add(@RequestBody HabitacionVivienda filter) {
		HabitacionVivienda filterAux = this.habitacionViviendaService.add(filter);
		HabitacionViviendaController.logger.info("[POST] : Ab6341s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idHabVivienda
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6341s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idHabVivienda}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody HabitacionVivienda remove(@PathVariable String idHabVivienda) {
		HabitacionVivienda filter = new HabitacionVivienda();
		filter.setIdHabVivienda(idHabVivienda);
		this.habitacionViviendaService.remove(filter);
		HabitacionViviendaController.logger.info("[DELETE] : Ab6341s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		HabitacionViviendaController.logger.info("[GET - View] : ab6341s00");
		return "ab6341s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6341s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<HabitacionVivienda> filter(
			@RequestJsonBody(param = "filter") HabitacionVivienda filterAb6341s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionViviendaController.logger.info("[POST - filter] : Obtener Ab6341s00s");
		return this.habitacionViviendaService.filter(filterAb6341s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6341s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<HabitacionVivienda>> search(
			@RequestJsonBody(param = "filter") HabitacionVivienda filterAb6341s00,
			@RequestJsonBody(param = "search") HabitacionVivienda searchAb6341s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionViviendaController.logger.info("[POST - search] : Buscar Ab6341s00s");
		return this.habitacionViviendaService.search(filterAb6341s00, searchAb6341s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") HabitacionVivienda filterAb6341s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionViviendaController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6341s00s");
		this.habitacionViviendaService.removeMultiple(filterAb6341s00, jqGridRequestDto, false);
		HabitacionViviendaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6341s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<HabitacionVivienda>> jerarquia(
			@RequestJsonBody(param = "filter") HabitacionVivienda filterAb6341s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionViviendaController.logger.info("[POST - jerarquia] : Obtener Ab6341s00s jerarquia");
		return this.habitacionViviendaService.jerarquia(filterAb6341s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6341s00
	 *            Ab6341s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6341s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<HabitacionVivienda>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") HabitacionVivienda filterAb6341s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		HabitacionViviendaController.logger.info("[POST - jerarquia] : Obtener Ab6341s00s jerarquia - Hijos");
		return this.habitacionViviendaService.jerarquiaChildren(filterAb6341s00, jqGridRequestDto);
	}

}
