package com.ejie.ab63.control;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Modalidad;
import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.ModalidadService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6314s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/modalidad")

public class ModalidadController {

	private static final Logger logger = LoggerFactory.getLogger(ModalidadController.class);

	@Autowired
	private ModalidadService modalidadService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idModalidad
	 *            String
	 * @return Ab6314s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idModalidad}", method = RequestMethod.GET)
	public @ResponseBody Modalidad get(@PathVariable String idModalidad) {
		Modalidad filter = new Modalidad();
		filter.setIdModalidad(idModalidad);
		filter = this.modalidadService.find(filter);
		ModalidadController.logger.info("[GET - findBy_PK] : Obtener Ab6314s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6314s00
	 *            Ab6314s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6314s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Modalidad> getAll(@ModelAttribute Modalidad filterAb6314s00,
			@RequestParam(value = "tipoEst", required = false) String tipoEst) {
		ModalidadController.logger.info("[GET - find_ALL] : Obtener Ab6314s00 por filtro");
		if (StringUtils.isNotBlank(tipoEst)) {
			TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
			tipoEstablecimiento.setIdTipoEstablecimiento(tipoEst);
			filterAb6314s00.setTipoEstablecimiento(tipoEstablecimiento);
		}
		filterAb6314s00.setBaja(0);
		return this.modalidadService.findAll(filterAb6314s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6314s00 Bean que contiene la informacion a modificar.
	 * @return Ab6314s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Modalidad edit(@RequestBody Modalidad filter) {
		Modalidad filterAux = this.modalidadService.update(filter);
		ModalidadController.logger.info("[PUT] : Ab6314s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6314s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6314s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Modalidad add(@RequestBody Modalidad filter) {
		Modalidad filterAux = this.modalidadService.add(filter);
		ModalidadController.logger.info("[POST] : Ab6314s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idModalidad
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6314s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idModalidad}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Modalidad remove(@PathVariable String idModalidad) {
		Modalidad filter = new Modalidad();
		filter.setIdModalidad(idModalidad);
		this.modalidadService.remove(filter);
		ModalidadController.logger.info("[DELETE] : Ab6314s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ModalidadController.logger.info("[GET - View] : ab6314s00");
		model.addAttribute("initForm", new InitForm());
		return "modalidades";
	}

	/**
	 * METODO CREADO POST PARA EL CAMBIO DE IDIOMA Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		ModalidadController.logger.info("[GET - View] : ab6314s00");
		model.addAttribute("initForm", new InitForm());
		return "modalidades";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6314s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Modalidad> filter(
			@RequestJsonBody(param = "filter") Modalidad filterAb6314s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadController.logger.info("[POST - filter] : Obtener Ab6314s00s");
		return this.modalidadService.filter(filterAb6314s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6314s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Modalidad>> search(
			@RequestJsonBody(param = "filter") Modalidad filterAb6314s00,
			@RequestJsonBody(param = "search") Modalidad searchAb6314s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadController.logger.info("[POST - search] : Buscar Ab6314s00s");
		return this.modalidadService.search(filterAb6314s00, searchAb6314s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Modalidad filterAb6314s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6314s00s");
		this.modalidadService.removeMultiple(filterAb6314s00, jqGridRequestDto, false);
		ModalidadController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6314s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Modalidad>> jerarquia(
			@RequestJsonBody(param = "filter") Modalidad filterAb6314s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadController.logger.info("[POST - jerarquia] : Obtener Ab6314s00s jerarquia");
		return this.modalidadService.jerarquia(filterAb6314s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6314s00
	 *            Ab6314s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6314s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Modalidad>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Modalidad filterAb6314s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ModalidadController.logger.info("[POST - jerarquia] : Obtener Ab6314s00s jerarquia - Hijos");
		return this.modalidadService.jerarquiaChildren(filterAb6314s00, jqGridRequestDto);
	}

}
