package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.OtrasDependenciasVivienda;
import com.ejie.ab63.service.OtrasDependenciasViviendaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6342s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/otrasDependenciasVivienda")

public class OtrasDependenciasViviendaController {

	private static final Logger logger = LoggerFactory.getLogger(OtrasDependenciasViviendaController.class);

	@Autowired
	private OtrasDependenciasViviendaService otrasDependenciasViviendaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idOtrasdepViviendas
	 *            String
	 * @return Ab6342s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idOtrasdepViviendas}", method = RequestMethod.GET)
	public @ResponseBody OtrasDependenciasVivienda get(@PathVariable String idOtrasdepViviendas) {
		OtrasDependenciasVivienda filter = new OtrasDependenciasVivienda();
		filter.setIdOtrasdepViviendas(idOtrasdepViviendas);
		filter = this.otrasDependenciasViviendaService.find(filter);
		OtrasDependenciasViviendaController.logger.info("[GET - findBy_PK] : Obtener Ab6342s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6342s00
	 *            Ab6342s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6342s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<OtrasDependenciasVivienda> getAll(
			@ModelAttribute OtrasDependenciasVivienda filterAb6342s00) {
		OtrasDependenciasViviendaController.logger.info("[GET - find_ALL] : Obtener Ab6342s00 por filtro");
		return this.otrasDependenciasViviendaService.findAll(filterAb6342s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6342s00 Bean que contiene la informacion a modificar.
	 * @return Ab6342s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody OtrasDependenciasVivienda edit(@RequestBody OtrasDependenciasVivienda filter) {
		OtrasDependenciasVivienda filterAux = this.otrasDependenciasViviendaService.update(filter);
		OtrasDependenciasViviendaController.logger.info("[PUT] : Ab6342s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6342s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6342s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody OtrasDependenciasVivienda add(@RequestBody OtrasDependenciasVivienda filter) {
		OtrasDependenciasVivienda filterAux = this.otrasDependenciasViviendaService.add(filter);
		OtrasDependenciasViviendaController.logger.info("[POST] : Ab6342s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idOtrasdepViviendas
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6342s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idOtrasdepViviendas}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody OtrasDependenciasVivienda remove(@PathVariable String idOtrasdepViviendas) {
		OtrasDependenciasVivienda filter = new OtrasDependenciasVivienda();
		filter.setIdOtrasdepViviendas(idOtrasdepViviendas);
		this.otrasDependenciasViviendaService.remove(filter);
		OtrasDependenciasViviendaController.logger.info("[DELETE] : Ab6342s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		OtrasDependenciasViviendaController.logger.info("[GET - View] : ab6342s00");
		return "ab6342s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6342s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<OtrasDependenciasVivienda> filter(
			@RequestJsonBody(param = "filter") OtrasDependenciasVivienda filterAb6342s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasDependenciasViviendaController.logger.info("[POST - filter] : Obtener Ab6342s00s");
		return this.otrasDependenciasViviendaService.filter(filterAb6342s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6342s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<OtrasDependenciasVivienda>> search(
			@RequestJsonBody(param = "filter") OtrasDependenciasVivienda filterAb6342s00,
			@RequestJsonBody(param = "search") OtrasDependenciasVivienda searchAb6342s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasDependenciasViviendaController.logger.info("[POST - search] : Buscar Ab6342s00s");
		return this.otrasDependenciasViviendaService.search(filterAb6342s00, searchAb6342s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") OtrasDependenciasVivienda filterAb6342s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasDependenciasViviendaController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6342s00s");
		this.otrasDependenciasViviendaService.removeMultiple(filterAb6342s00, jqGridRequestDto, false);
		OtrasDependenciasViviendaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6342s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrasDependenciasVivienda>> jerarquia(
			@RequestJsonBody(param = "filter") OtrasDependenciasVivienda filterAb6342s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasDependenciasViviendaController.logger.info("[POST - jerarquia] : Obtener Ab6342s00s jerarquia");
		return this.otrasDependenciasViviendaService.jerarquia(filterAb6342s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6342s00
	 *            Ab6342s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6342s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<OtrasDependenciasVivienda>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") OtrasDependenciasVivienda filterAb6342s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		OtrasDependenciasViviendaController.logger.info("[POST - jerarquia] : Obtener Ab6342s00s jerarquia - Hijos");
		return this.otrasDependenciasViviendaService.jerarquiaChildren(filterAb6342s00, jqGridRequestDto);
	}

}
