package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.EstablecimientoData;
import com.ejie.ab63.model.Parcela;
import com.ejie.ab63.service.ParcelaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6334s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/parcela")

public class ParcelaController {

	private static final Logger logger = LoggerFactory.getLogger(ParcelaController.class);

	@Autowired
	private ParcelaService parcelaService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idParcela
	 *            Long
	 * @return Ab6334s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idParcela}", method = RequestMethod.GET)
	public @ResponseBody Parcela get(@PathVariable Long idParcela) {
		Parcela filter = new Parcela();
		filter.setIdParcela(idParcela);
		filter = this.parcelaService.find(filter);
		ParcelaController.logger.info("[GET - findBy_PK] : Obtener Ab6334s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6334s00
	 *            Ab6334s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6334s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Parcela> getAll(@ModelAttribute Parcela filterAb6334s00) {
		ParcelaController.logger.info("[GET - find_ALL] : Obtener Ab6334s00 por filtro");
		return this.parcelaService.findAll(filterAb6334s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6334s00 Bean que contiene la informacion a modificar.
	 * @return Ab6334s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Parcela edit(@RequestBody Parcela filter) {
		Parcela filterAux = this.parcelaService.update(filter);
		ParcelaController.logger.info("[PUT] : Ab6334s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6334s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6334s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Parcela add(@RequestBody Parcela filter) {
		Parcela filterAux = this.parcelaService.save(filter);
		ParcelaController.logger.info("[POST] : Ab6334s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idParcela
	 *            Long Identificador del objeto que se desea eliminar.
	 * @return Ab6334s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idParcela}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Parcela remove(@PathVariable Long idParcela) {
		Parcela filter = new Parcela();
		filter.setIdParcela(idParcela);
		this.parcelaService.remove(filter);
		ParcelaController.logger.info("[DELETE] : Ab6334s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ParcelaController.logger.info("[GET - View] : ab6334s00");
		return "ab6334s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6334s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Parcela> filter(@RequestJsonBody(param = "filter") Parcela filterAb6334s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParcelaController.logger.info("[POST - filter] : Obtener Ab6334s00s");
		return this.parcelaService.filter(filterAb6334s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6334s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Parcela>> search(@RequestJsonBody(param = "filter") Parcela filterAb6334s00,
			@RequestJsonBody(param = "search") Parcela searchAb6334s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParcelaController.logger.info("[POST - search] : Buscar Ab6334s00s");
		return this.parcelaService.search(filterAb6334s00, searchAb6334s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Parcela filterAb6334s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParcelaController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6334s00s");
		this.parcelaService.removeMultiple(filterAb6334s00, jqGridRequestDto, false);
		ParcelaController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6334s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Parcela>> jerarquia(
			@RequestJsonBody(param = "filter") Parcela filterAb6334s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParcelaController.logger.info("[POST - jerarquia] : Obtener Ab6334s00s jerarquia");
		return this.parcelaService.jerarquia(filterAb6334s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6334s00
	 *            Ab6334s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6334s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Parcela>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Parcela filterAb6334s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		ParcelaController.logger.info("[POST - jerarquia] : Obtener Ab6334s00s jerarquia - Hijos");
		return this.parcelaService.jerarquiaChildren(filterAb6334s00, jqGridRequestDto);
	}

	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.POST)
	public @ResponseBody Long getTotalPlazasParcelas(@PathVariable Integer idEstablecimiento) {
		ParcelaController.logger.info("[POST - jerarquia] : Obtener Ab6334s00s jerarquia - Hijos");
		Parcela parcela = new Parcela();
		EstablecimientoData establecimientoData = new EstablecimientoData(idEstablecimiento);
		parcela.setEstablecimientoData(establecimientoData);

		return this.parcelaService.getTotalPlazasParcelas(parcela);
	}

}
