package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.Recurso;
import com.ejie.ab63.service.RecursoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6300s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/recurso")

public class RecursoController {

	private static final Logger logger = LoggerFactory.getLogger(RecursoController.class);

	@Autowired
	private RecursoService recursoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idRecurso
	 *            String
	 * @return Ab6300s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idRecurso}", method = RequestMethod.GET)
	public @ResponseBody Recurso get(@PathVariable String idRecurso) {
		Recurso filter = new Recurso();
		filter.setIdRecurso(idRecurso);
		filter = this.recursoService.find(filter);
		RecursoController.logger.info("[GET - findBy_PK] : Obtener Ab6300s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6300s00
	 *            Ab6300s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6300s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<Recurso> getAll(@ModelAttribute Recurso filterAb6300s00) {
		RecursoController.logger.info("[GET - find_ALL] : Obtener Ab6300s00 por filtro");
		return this.recursoService.findAll(filterAb6300s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6300s00 Bean que contiene la informacion a modificar.
	 * @return Ab6300s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody Recurso edit(@RequestBody Recurso filter) {
		Recurso filterAux = this.recursoService.update(filter);
		RecursoController.logger.info("[PUT] : Ab6300s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6300s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6300s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody Recurso add(@RequestBody Recurso filter) {
		Recurso filterAux = this.recursoService.add(filter);
		RecursoController.logger.info("[POST] : Ab6300s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idRecurso
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6300s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idRecurso}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody Recurso remove(@PathVariable String idRecurso) {
		Recurso filter = new Recurso();
		filter.setIdRecurso(idRecurso);
		this.recursoService.remove(filter);
		RecursoController.logger.info("[DELETE] : Ab6300s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		RecursoController.logger.info("[GET - View] : ab6300s00");
		return "ab6300s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6300s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<Recurso> filter(@RequestJsonBody(param = "filter") Recurso filterAb6300s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RecursoController.logger.info("[POST - filter] : Obtener Ab6300s00s");
		return this.recursoService.filter(filterAb6300s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6300s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<Recurso>> search(@RequestJsonBody(param = "filter") Recurso filterAb6300s00,
			@RequestJsonBody(param = "search") Recurso searchAb6300s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RecursoController.logger.info("[POST - search] : Buscar Ab6300s00s");
		return this.recursoService.search(filterAb6300s00, searchAb6300s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") Recurso filterAb6300s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RecursoController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6300s00s");
		this.recursoService.removeMultiple(filterAb6300s00, jqGridRequestDto, false);
		RecursoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6300s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Recurso>> jerarquia(
			@RequestJsonBody(param = "filter") Recurso filterAb6300s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RecursoController.logger.info("[POST - jerarquia] : Obtener Ab6300s00s jerarquia");
		return this.recursoService.jerarquia(filterAb6300s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6300s00
	 *            Ab6300s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6300s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<Recurso>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") Recurso filterAb6300s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		RecursoController.logger.info("[POST - jerarquia] : Obtener Ab6300s00s jerarquia - Hijos");
		return this.recursoService.jerarquiaChildren(filterAb6300s00, jqGridRequestDto);
	}

}
