package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.SalonComedor;
import com.ejie.ab63.service.SalonComedorService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6327s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/salonComedor")

public class SalonComedorController {

	private static final Logger logger = LoggerFactory.getLogger(SalonComedorController.class);

	@Autowired
	private SalonComedorService salonComedorService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idSalonComedor
	 *            Integer
	 * @return Ab6327s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idSalonComedor}", method = RequestMethod.GET)
	public @ResponseBody SalonComedor get(@PathVariable Integer idSalonComedor) {
		SalonComedor filter = new SalonComedor();
		filter.setIdSalonComedor(idSalonComedor);
		filter = this.salonComedorService.find(filter);
		SalonComedorController.logger.info("[GET - findBy_PK] : Obtener Ab6327s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6327s00
	 *            Ab6327s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6327s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<SalonComedor> getAll(@ModelAttribute SalonComedor filterAb6327s00) {
		SalonComedorController.logger.info("[GET - find_ALL] : Obtener Ab6327s00 por filtro");
		return this.salonComedorService.findAll(filterAb6327s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6327s00 Bean que contiene la informacion a modificar.
	 * @return Ab6327s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody SalonComedor edit(@RequestBody SalonComedor filter) {
		SalonComedor filterAux = this.salonComedorService.update(filter);
		SalonComedorController.logger.info("[PUT] : Ab6327s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6327s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6327s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody SalonComedor add(@RequestBody SalonComedor filter) {
		// SalonComedor filterAux = this.salonComedorService.add(filter);
		// SalonComedorController.logger.info("[POST] : Ab6327s00 insertado
		// correctamente");
		SalonComedor filterAux = this.salonComedorService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idSalonComedor
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6327s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody SalonComedor remove(@PathVariable Integer idEstablecimiento,
			@RequestBody SalonComedor salonComedor) {
		// SalonComedor filter = new SalonComedor();
		// filter.setIdSalonComedor(idSalonComedor);
		this.salonComedorService.remove(salonComedor, idEstablecimiento);
		SalonComedorController.logger.info("[DELETE] : Ab6327s00 borrado correctamente");
		return salonComedor;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		SalonComedorController.logger.info("[GET - View] : ab6327s00");
		return "ab6327s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6327s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<SalonComedor> filter(
			@RequestJsonBody(param = "filter") SalonComedor filterAb6327s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SalonComedorController.logger.info("[POST - filter] : Obtener Ab6327s00s");

		return this.salonComedorService.filter(filterAb6327s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6327s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<SalonComedor>> search(
			@RequestJsonBody(param = "filter") SalonComedor filterAb6327s00,
			@RequestJsonBody(param = "search") SalonComedor searchAb6327s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SalonComedorController.logger.info("[POST - search] : Buscar Ab6327s00s");
		return this.salonComedorService.search(filterAb6327s00, searchAb6327s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") SalonComedor filterAb6327s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SalonComedorController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6327s00s");
		this.salonComedorService.removeMultiple(filterAb6327s00, jqGridRequestDto, false);
		SalonComedorController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6327s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<SalonComedor>> jerarquia(
			@RequestJsonBody(param = "filter") SalonComedor filterAb6327s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SalonComedorController.logger.info("[POST - jerarquia] : Obtener Ab6327s00s jerarquia");
		return this.salonComedorService.jerarquia(filterAb6327s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6327s00
	 *            Ab6327s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6327s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<SalonComedor>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") SalonComedor filterAb6327s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		SalonComedorController.logger.info("[POST - jerarquia] : Obtener Ab6327s00s jerarquia - Hijos");
		return this.salonComedorService.jerarquiaChildren(filterAb6327s00, jqGridRequestDto);
	}

}
