package com.ejie.ab63.control;

import java.util.Iterator;
import java.util.List;
import java.util.Properties;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.comun.utilidades.config.Config;
import com.ejie.ab63.model.Establecimiento;
import com.ejie.ab63.model.TercerosEstablecimiento;
import com.ejie.ab63.model.inicio.InitFormEst;
import com.ejie.ab63.model.plantillas.ParametrosConfig;
import com.ejie.ab63.model.terceros.DatosDirecciones;
import com.ejie.ab63.model.terceros.DatosTerceros;
import com.ejie.ab63.model.terceros.TiposDireccion;
import com.ejie.ab63.service.EstablecimientoService;
import com.ejie.ab63.service.TercerosEstablecimientoService;
import com.ejie.ab63.service.plantillas.ParametrosConfigService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6339s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tercerosEstablecimiento")

public class TercerosEstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(TercerosEstablecimientoController.class);

	private final String CONTROLADOR = "tercerosEstablecimiento";

	@Autowired
	private TercerosEstablecimientoService tercerosEstablecimientoService;
	@Autowired
	private EstablecimientoService establecimientoService;
	@Autowired
	private ParametrosConfigService parametrosConfigService;
	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTercerosEstab
	 *            Integer
	 * @return Ab6339s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTercerosEstab}", method = RequestMethod.GET)
	public @ResponseBody TercerosEstablecimiento get(@PathVariable Integer idTercerosEstab) {
		TercerosEstablecimiento filter = new TercerosEstablecimiento();
		filter.setIdTercerosEstab(idTercerosEstab);
		filter = this.tercerosEstablecimientoService.find(filter);
		TercerosEstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6339s00 por PK");
		return filter;
	}

	@RequestMapping(value = "/{idEstablecimiento}/{idTercerosEstab}", method = RequestMethod.GET)
	public @ResponseBody TercerosEstablecimiento getTercero(
			@PathVariable("idEstablecimiento") Integer idEstablecimiento, @PathVariable Integer idTercerosEstab) {
		TercerosEstablecimientoController.logger.info("[POST - getTercero] : Obtener Ab6339s00s");

		Establecimiento establecimiento = new Establecimiento();

		DatosDirecciones datosDirecciones = new DatosDirecciones();

		datosDirecciones.setTiposDireccion(new TiposDireccion((long) Constantes.ID_DIRECCION_NOTIF_POSTAL));

		establecimiento.setDatosDirecciones(datosDirecciones);

		establecimiento.setIdEstablecimiento(idEstablecimiento);

		TercerosEstablecimiento filter = new TercerosEstablecimiento();
		filter.setIdTercerosEstab(idTercerosEstab);
		filter.setEstablecimiento(establecimiento);

		return this.tercerosEstablecimientoService.findByTipoDireccionFilter(filter);
		// return this.tercerosEstablecimientoService.find(filter);
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6339s00
	 *            Ab6339s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6339s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TercerosEstablecimiento> getAll(@ModelAttribute TercerosEstablecimiento filterAb6339s00) {
		TercerosEstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6339s00 por filtro");
		return this.tercerosEstablecimientoService.findAll(filterAb6339s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6339s00 Bean que contiene la informacion a modificar.
	 * @return Ab6339s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.PUT)
	public @ResponseBody TercerosEstablecimiento edit(@PathVariable String idEstablecimiento,
			@RequestBody TercerosEstablecimiento filter) {

		TercerosEstablecimientoController.logger.info("[PUT] : edit");

		// Comprobamos que exista idDireccion
		if (filter.getEstablecimiento() != null && filter.getEstablecimiento().getDatosDirecciones() != null) {

			if (filter.getEstablecimiento().getDatosDirecciones().getIdDireccion() != 0) {
				TercerosEstablecimientoController.logger.info("[PUT] : update");

				filter = this.tercerosEstablecimientoService.update(filter);

			} else {

				TercerosEstablecimientoController.logger.info("[PUT] : updateAux");
				filter = this.tercerosEstablecimientoService.updateTerceroWithOutDireccion(filter);

			}
		}

		return filter;
	}

	// prueba snts

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6339s00 Bean que contiene la informacion a modificar.
	 * @return Ab6339s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(value = "/{idEstablecimiento}", method = RequestMethod.POST)
	public @ResponseBody TercerosEstablecimiento addTercero(@PathVariable Integer idEstablecimiento,
			@RequestBody TercerosEstablecimiento filter) {

		TercerosEstablecimientoController.logger.info("[POST] : addTercero");

		filter.getEstablecimiento().setIdEstablecimiento(idEstablecimiento);
		// filter = this.tercerosEstablecimientoService.add(filter);
		filter = this.tercerosEstablecimientoService.altaTerceros(filter);

		return filter;
	}
	// prueba snts

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6339s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6339s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TercerosEstablecimiento add(@RequestBody TercerosEstablecimiento filter) {
		TercerosEstablecimiento filterAux = this.tercerosEstablecimientoService.add(filter);
		TercerosEstablecimientoController.logger.info("[POST] : Ab6339s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTercerosEstab
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6339s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idTercerosEstab}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TercerosEstablecimiento remove(@PathVariable Integer idTercerosEstab) {
		TercerosEstablecimiento filter = new TercerosEstablecimiento();
		filter.setIdTercerosEstab(idTercerosEstab);
		this.tercerosEstablecimientoService.remove(filter);
		TercerosEstablecimientoController.logger.info("[DELETE] : Ab6339s00 borrado correctamente");
		return filter;
	}

	@RequestMapping(value = "/{idEstablecimiento}/{idTercerosEstab}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TercerosEstablecimiento delete(@PathVariable("idEstablecimiento") Integer idEstablecimiento,
			@PathVariable Integer idTercerosEstab) {

		TercerosEstablecimientoController.logger.info("[DELETE - delete] : Obtener Ab6339s00s");

		TercerosEstablecimiento tercero;
		TercerosEstablecimiento filter = new TercerosEstablecimiento(idTercerosEstab);
		filter.setEstablecimiento(new Establecimiento(idEstablecimiento));

		tercero = this.tercerosEstablecimientoService.getTerceroByIdTercero(filter);

		if (null != tercero && null != tercero.getEstablecimiento()
				&& null != tercero.getEstablecimiento().getTipoEstablecimiento()) {

			if (Constantes.AGENCIA_VIAJE
					.equals(tercero.getEstablecimiento().getTipoEstablecimiento().getIdTipoEstablecimiento())) {

				tercero = this.tercerosEstablecimientoService.getTerceroByIdTerceroAAVV(filter);
			}
		}

		this.tercerosEstablecimientoService.remove(tercero);

		return tercero;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEdit(Model model, @ModelAttribute(value = "initFormEst") InitFormEst initFormEst) {
		model.addAttribute("interesados", new DatosTerceros());
		TercerosEstablecimientoController.logger.info("[GET - View] : ab6339s00");

		// obtenemos el tipo establecimiento para la pestaa
		Integer idEst = Integer.parseInt(initFormEst.getIdEstablecimiento());
		Establecimiento filter = new Establecimiento();

		ParametrosConfig parametrosConfigFind = new ParametrosConfig();
		parametrosConfigFind.setDescripcion(Constantes.ACTIVADA_PUBLICACION_AA80T);
		ParametrosConfig parametrosConfig = this.parametrosConfigService.find(parametrosConfigFind);

		if (parametrosConfig.getValor() == 1) {
			model.addAttribute("ACTIVAR_PUBLICACION", "1");
		}

		filter.setIdEstablecimiento(idEst);
		filter = this.establecimientoService.find(filter);

		String tipoEstablecimiento = filter.getTipoEstablecimiento().getIdTipoEstablecimiento();

		preparePestanas(model, tipoEstablecimiento);

		if (StringUtils.isNotBlank(tipoEstablecimiento) && Constantes.AGENCIA_VIAJE.equals(tipoEstablecimiento)
				&& null != filter.getAgenciaData()) {
			initFormEst.setNumCie(filter.getAgenciaData().getNumCie());
		}

		if (null != filter && null != filter.getModalidad()) {
			initFormEst.setModalidad(filter.getModalidad().getIdModalidad());
		}

		return "interesados";
	}

	/* PREPARE PESTANAS */

	private void preparePestanas(Model model, String tipoEstablecimiento) {
		model.addAttribute("nombreControlador", CONTROLADOR);
		model.addAttribute("currentPage", Constantes.PESTANA_INTERESADOS);
		model.addAttribute("datosEstablecimiento", Constantes.PESTANA_DATOS_ESTABLECIMIENTO);
		model.addAttribute("interesados", Constantes.PESTANA_INTERESADOS);
		model.addAttribute("datosEspecificos", Constantes.PESTANA_DATOS_ESPECIFICOS);
		model.addAttribute("expRelacionados", Constantes.PESTANA_EXP_RELACIONADOS);
		List<String> configs = Constantes.getmapPestanasEstablecimiento().get(tipoEstablecimiento);
		for (Iterator<String> iterator = configs.iterator(); iterator.hasNext();) {
			String configOption = (String) iterator.next();
			model.addAttribute(configOption, configOption);
		}
	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	/*
	 * @RequestMapping(value = "/maint", method = RequestMethod.GET) public
	 * String getFormEdit(Model model) {
	 * TercerosEstablecimientoController.logger.info("[GET - View] : ab6339s00"
	 * );
	 * 
	 * return "ab6339s00"; }
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6339s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TercerosEstablecimiento> filter(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TercerosEstablecimientoController.logger.info("[POST - filter] : Obtener Ab6339s00s");
		return this.tercerosEstablecimientoService.filter(filterAb6339s00, jqGridRequestDto, false);
	}

	@RequestMapping(value = "/{idEstablecimiento}/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TercerosEstablecimiento> filterTablaInteresados(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto,
			@PathVariable("idEstablecimiento") Integer idEstablecimiento) {
		TercerosEstablecimientoController.logger.info("[POST - filterTablaInteresados] : Obtener Ab6339s00s");

		Establecimiento establecimiento = new Establecimiento();

		DatosDirecciones datosDirecciones = new DatosDirecciones();

		datosDirecciones.setTiposDireccion(new TiposDireccion((long) Constantes.ID_DIRECCION_NOTIF_POSTAL));

		establecimiento.setDatosDirecciones(datosDirecciones);

		establecimiento.setIdEstablecimiento(idEstablecimiento);
		filterAb6339s00.setEstablecimiento(establecimiento);

		return this.tercerosEstablecimientoService.filterByTipoDireccion(filterAb6339s00, jqGridRequestDto, false);
		// return this.tercerosEstablecimientoService.filter(filterAb6339s00,
		// jqGridRequestDto, false);

		// PermisosXLNETS.getUserConnected();
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6339s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TercerosEstablecimiento>> search(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody(param = "search") TercerosEstablecimiento searchAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TercerosEstablecimientoController.logger.info("[POST - search] : Buscar Ab6339s00s");
		return this.tercerosEstablecimientoService.search(filterAb6339s00, searchAb6339s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TercerosEstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6339s00s");
		this.tercerosEstablecimientoService.removeMultiple(filterAb6339s00, jqGridRequestDto, false);
		TercerosEstablecimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6339s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TercerosEstablecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TercerosEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6339s00s jerarquia");
		return this.tercerosEstablecimientoService.jerarquia(filterAb6339s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6339s00
	 *            Ab6339s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6339s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TercerosEstablecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TercerosEstablecimiento filterAb6339s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TercerosEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6339s00s jerarquia - Hijos");
		return this.tercerosEstablecimientoService.jerarquiaChildren(filterAb6339s00, jqGridRequestDto);
	}

}
