package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.TipoAseo;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.TipoAseoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6316s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tipoAseo")

public class TipoAseoController {

	private static final Logger logger = LoggerFactory.getLogger(TipoAseoController.class);

	@Autowired
	private TipoAseoService tipoAseoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoAseo
	 *            String
	 * @return Ab6316s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoAseo}", method = RequestMethod.GET)
	public @ResponseBody TipoAseo get(@PathVariable String idTipoAseo) {
		TipoAseo filter = new TipoAseo();
		filter.setIdTipoAseo(idTipoAseo);
		filter = this.tipoAseoService.find(filter);
		TipoAseoController.logger.info("[GET - findBy_PK] : Obtener Ab6316s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6316s00
	 *            Ab6316s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6316s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TipoAseo> getAll(@ModelAttribute TipoAseo filterAb6316s00) {
		TipoAseoController.logger.info("[GET - find_ALL] : Obtener Ab6316s00 por filtro");
		return this.tipoAseoService.findAll(filterAb6316s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6316s00 Bean que contiene la informacion a modificar.
	 * @return Ab6316s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TipoAseo edit(@RequestBody TipoAseo filter) {
		TipoAseo filterAux = this.tipoAseoService.update(filter);
		TipoAseoController.logger.info("[PUT] : Ab6316s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6316s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6316s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TipoAseo add(@RequestBody TipoAseo filter) {
		TipoAseo filterAux = this.tipoAseoService.add(filter);
		TipoAseoController.logger.info("[POST] : Ab6316s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoAseo
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6316s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoAseo}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TipoAseo remove(@PathVariable String idTipoAseo) {
		TipoAseo filter = new TipoAseo();
		filter.setIdTipoAseo(idTipoAseo);
		this.tipoAseoService.remove(filter);
		TipoAseoController.logger.info("[DELETE] : Ab6316s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TipoAseoController.logger.info("[GET - View] : filter");
		model.addAttribute("initForm", new InitForm());
		return "tiposAseo";
	}

	/**
	 * METODO CREADO POST PARA EL TRADUCTOR Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		TipoAseoController.logger.info("[GET - View] : filter");
		model.addAttribute("initForm", new InitForm());
		return "tiposAseo";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6316s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TipoAseo> filter(@RequestJsonBody(param = "filter") TipoAseo filterAb6316s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoAseoController.logger.info("[POST - filter] : Obtener Ab6316s00s");
		return this.tipoAseoService.filter(filterAb6316s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6316s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TipoAseo>> search(@RequestJsonBody(param = "filter") TipoAseo filterAb6316s00,
			@RequestJsonBody(param = "search") TipoAseo searchAb6316s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoAseoController.logger.info("[POST - search] : Buscar Ab6316s00s");
		return this.tipoAseoService.search(filterAb6316s00, searchAb6316s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TipoAseo filterAb6316s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoAseoController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6316s00s");
		this.tipoAseoService.removeMultiple(filterAb6316s00, jqGridRequestDto, false);
		TipoAseoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6316s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoAseo>> jerarquia(
			@RequestJsonBody(param = "filter") TipoAseo filterAb6316s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoAseoController.logger.info("[POST - jerarquia] : Obtener Ab6316s00s jerarquia");
		return this.tipoAseoService.jerarquia(filterAb6316s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6316s00
	 *            Ab6316s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6316s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoAseo>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TipoAseo filterAb6316s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoAseoController.logger.info("[POST - jerarquia] : Obtener Ab6316s00s jerarquia - Hijos");
		return this.tipoAseoService.jerarquiaChildren(filterAb6316s00, jqGridRequestDto);
	}

}
