package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.TipoEstablecimiento;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.TipoEstablecimientoService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6311s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tipoEstablecimiento")

public class TipoEstablecimientoController {

	private static final Logger logger = LoggerFactory.getLogger(TipoEstablecimientoController.class);

	@Autowired
	private TipoEstablecimientoService tipoEstablecimientoService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoEstablecimiento
	 *            String
	 * @return Ab6311s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoEstablecimiento}", method = RequestMethod.GET)
	public @ResponseBody TipoEstablecimiento get(@PathVariable String idTipoEstablecimiento) {
		TipoEstablecimiento filter = new TipoEstablecimiento();
		filter.setIdTipoEstablecimiento(idTipoEstablecimiento);
		filter = this.tipoEstablecimientoService.find(filter);
		TipoEstablecimientoController.logger.info("[GET - findBy_PK] : Obtener Ab6311s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filter
	 *            Ab6311s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6311s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TipoEstablecimiento> getAll(@ModelAttribute TipoEstablecimiento filter) {
		TipoEstablecimientoController.logger.info("[GET - find_ALL] : Obtener Ab6311s00 por filtro");
		filter.setBaja(0);
		return this.tipoEstablecimientoService.findAll(filter, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6311s00 Bean que contiene la informacion a modificar.
	 * @return Ab6311s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TipoEstablecimiento edit(@RequestBody TipoEstablecimiento filter) {
		TipoEstablecimiento filterAux = this.tipoEstablecimientoService.update(filter);
		TipoEstablecimientoController.logger.info("[PUT] : Ab6311s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6311s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6311s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TipoEstablecimiento add(@RequestBody TipoEstablecimiento filter) {
		TipoEstablecimiento filterAux = this.tipoEstablecimientoService.add(filter);
		TipoEstablecimientoController.logger.info("[POST] : Ab6311s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoEstablecimiento
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6311s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoEstablecimiento}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TipoEstablecimiento remove(@PathVariable String idTipoEstablecimiento) {
		TipoEstablecimiento filter = new TipoEstablecimiento();
		filter.setIdTipoEstablecimiento(idTipoEstablecimiento);
		// this.tipoEstablecimientoService.remove(filter);
		TipoEstablecimientoController.logger.info("[DELETE] : Ab6311s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TipoEstablecimientoController.logger.info("[GET - View] : ab6311s00");
		TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
		model.addAttribute("busqTipoEstablecimiento", tipoEstablecimiento);
		model.addAttribute("initForm", new InitForm());
		return "tiposEstablecimiento";
	}

	/**
	 * METODO CREADO POST PARA EL CAMBIO DE DIDIOMA Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		TipoEstablecimientoController.logger.info("[GET - View] : ab6311s00");
		TipoEstablecimiento tipoEstablecimiento = new TipoEstablecimiento();
		model.addAttribute("busqTipoEstablecimiento", tipoEstablecimiento);
		model.addAttribute("initForm", new InitForm());
		return "tiposEstablecimiento";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6311s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody com.ejie.x38.dto.TableResponseDto<TipoEstablecimiento> filter(
			@RequestJsonBody(param = "filter") TipoEstablecimiento filterAb6311s00,
			@RequestJsonBody TableRequestDto jqGridRequestDto) {
		TipoEstablecimientoController.logger.info("[POST - filter] : Obtener Ab6311s00s");
		return this.tipoEstablecimientoService.filter(filterAb6311s00, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6311s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TipoEstablecimiento>> search(
			@RequestJsonBody(param = "filter") TipoEstablecimiento filterAb6311s00,
			@RequestJsonBody(param = "search") TipoEstablecimiento searchAb6311s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoEstablecimientoController.logger.info("[POST - search] : Buscar Ab6311s00s");
		return this.tipoEstablecimientoService.search(filterAb6311s00, searchAb6311s00, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") TipoEstablecimiento filterAb6311s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoEstablecimientoController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6311s00s");
		this.tipoEstablecimientoService.removeMultiple(filterAb6311s00, jqGridRequestDto, false);
		TipoEstablecimientoController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6311s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>> jerarquia(
			@RequestJsonBody(param = "filter") TipoEstablecimiento filterAb6311s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6311s00s jerarquia");
		return this.tipoEstablecimientoService.jerarquia(filterAb6311s00, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6311s00
	 *            Ab6311s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6311s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoEstablecimiento>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TipoEstablecimiento filterAb6311s00,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoEstablecimientoController.logger.info("[POST - jerarquia] : Obtener Ab6311s00s jerarquia - Hijos");
		return this.tipoEstablecimientoService.jerarquiaChildren(filterAb6311s00, jqGridRequestDto);
	}

}
