package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.TipoFranquicia;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.TipoFranquiciaService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6336s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tipoFranquicia")

public class TipoFranquiciaController {

	private static final Logger logger = LoggerFactory.getLogger(TipoFranquiciaController.class);

	@Autowired
	private TipoFranquiciaService ab6336s00Service;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idFranquicia
	 *            String
	 * @return Ab6336s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idFranquicia}", method = RequestMethod.GET)
	public @ResponseBody TipoFranquicia get(@PathVariable Long idFranquicia) {
		TipoFranquicia tipoFranquicia = new TipoFranquicia();
		tipoFranquicia.setIdFranquicia(idFranquicia);
		tipoFranquicia = this.ab6336s00Service.find(tipoFranquicia);
		TipoFranquiciaController.logger.info("[GET - findBy_PK] : Obtener Ab6336s00 por PK");
		return tipoFranquicia;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6336s00
	 *            Ab6336s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6336s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TipoFranquicia> getAll(@ModelAttribute TipoFranquicia filterAb6336s00) {
		TipoFranquiciaController.logger.info("[GET - find_ALL] : Obtener Ab6336s00 por filtro");
		return this.ab6336s00Service.findAll(filterAb6336s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param tipoFranquicia
	 *            Ab6336s00 Bean que contiene la informacion a modificar.
	 * @return Ab6336s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TipoFranquicia edit(@RequestBody TipoFranquicia tipoFranquicia) {
		TipoFranquicia ab6336s00Aux = this.ab6336s00Service.update(tipoFranquicia);
		TipoFranquiciaController.logger.info("[PUT] : Ab6336s00 actualizado correctamente");
		return ab6336s00Aux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param tipoFranquicia
	 *            Ab6336s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6336s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TipoFranquicia add(@RequestBody TipoFranquicia tipoFranquicia) {
		TipoFranquicia ab6336s00Aux = this.ab6336s00Service.add(tipoFranquicia);
		TipoFranquiciaController.logger.info("[POST] : Ab6336s00 insertado correctamente");
		return ab6336s00Aux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idFranquicia
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6336s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idFranquicia}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TipoFranquicia remove(@PathVariable Long idFranquicia) {
		TipoFranquicia tipoFranquicia = new TipoFranquicia();
		tipoFranquicia.setIdFranquicia(idFranquicia);
		this.ab6336s00Service.remove(tipoFranquicia);
		TipoFranquiciaController.logger.info("[DELETE] : Ab6336s00 borrado correctamente");
		return tipoFranquicia;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TipoFranquiciaController.logger.info("[GET - View] : tipoFranquicia");
		model.addAttribute("initForm", new InitForm());
		return "tipoFranquicia";
	}

	/**
	 * METODO CREADO POST PARA EL TRADUCTOR Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		TipoFranquiciaController.logger.info("[GET - View] : filter");
		model.addAttribute("initForm", new InitForm());
		return "tipoFranquicia";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<Ab6336s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<TipoFranquicia> filter(
			@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger.info("[POST - filter] : Obtener Ab6336s00s");
		return this.ab6336s00Service.filter(filterAb6336s00, tableRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6336s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TipoFranquicia>> search(
			@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody(param = "search") TipoFranquicia searchAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger.info("[POST - search] : Buscar Ab6336s00s");
		return this.ab6336s00Service.search(filterAb6336s00, searchAb6336s00, tableRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6336s00s");
		this.ab6336s00Service.removeMultiple(filterAb6336s00, tableRequestDto, false);
		TipoFranquiciaController.logger.info("All entities correctly deleted!");

		return tableRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6336s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<TipoFranquicia>> jerarquia(
			@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger.info("[POST - jerarquia] : Obtener Ab6336s00s jerarquia");
		return this.ab6336s00Service.jerarquia(filterAb6336s00, tableRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterAb6336s00
	 *            Ab6336s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param tableRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableResponseDto<JerarquiaDto<Ab6336s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<JerarquiaDto<TipoFranquicia>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger.info("[POST - jerarquia] : Obtener Ab6336s00s jerarquia - Hijos");
		return this.ab6336s00Service.jerarquiaChildren(filterAb6336s00, tableRequestDto);
	}

	/**
	 * EXPORTERS
	 */

	@RequestMapping(value = "/clipboardReport", method = RequestMethod.POST)
	protected @ResponseBody List<TipoFranquicia> getClipboardReport(
			@RequestJsonBody(param = "filter") TipoFranquicia filterAb6336s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		TipoFranquiciaController.logger.info("[POST - clipboardReport] : : Copiar multiples usuarios");
		return this.ab6336s00Service.getMultiple(filterAb6336s00, tableRequestDto, false);
	}

}
