package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.TipoHabitacion;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.service.TipoHabitacionService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6317s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/tipoHabitacion")

public class TipoHabitacionController {

	private static final Logger logger = LoggerFactory.getLogger(TipoHabitacionController.class);

	@Autowired
	private TipoHabitacionService tipoHabitacionService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idTipoHabitacion
	 *            String
	 * @return Ab6317s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idTipoHabitacion}", method = RequestMethod.GET)
	public @ResponseBody TipoHabitacion get(@PathVariable String idTipoHabitacion) {
		TipoHabitacion filter = new TipoHabitacion();
		filter.setIdTipoHabitacion(idTipoHabitacion);
		filter = this.tipoHabitacionService.find(filter);
		TipoHabitacionController.logger.info("[GET - findBy_PK] : Obtener Ab6317s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filter
	 *            Ab6317s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6317s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<TipoHabitacion> getAll(@ModelAttribute TipoHabitacion filter) {
		TipoHabitacionController.logger.info("[GET - find_ALL] : Obtener Ab6317s00 por filtro");
		return this.tipoHabitacionService.findAll(filter, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6317s00 Bean que contiene la informacion a modificar.
	 * @return Ab6317s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody TipoHabitacion edit(@RequestBody TipoHabitacion filter) {
		TipoHabitacion filterAux = this.tipoHabitacionService.update(filter);
		TipoHabitacionController.logger.info("[PUT] : Ab6317s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6317s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6317s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody TipoHabitacion add(@RequestBody TipoHabitacion filter) {
		TipoHabitacion filterAux = this.tipoHabitacionService.add(filter);
		TipoHabitacionController.logger.info("[POST] : Ab6317s00 insertado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTipoHabitacion
	 *            String Identificador del objeto que se desea eliminar.
	 * @return Ab6317s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idTipoHabitacion}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody TipoHabitacion remove(@PathVariable String idTipoHabitacion) {
		TipoHabitacion filter = new TipoHabitacion();
		filter.setIdTipoHabitacion(idTipoHabitacion);
		this.tipoHabitacionService.remove(filter);
		TipoHabitacionController.logger.info("[DELETE] : Ab6317s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		TipoHabitacionController.logger.info("[GET - View] : ab6317s00");
		model.addAttribute("initForm", new InitForm());
		return "tiposHab";
	}

	/**
	 * METODO CREADO POST PARA EL CAMBIO DE IDIOMA Metodo de presentacion del
	 * RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public String getFormEditPOST(Model model) {
		TipoHabitacionController.logger.info("[GET - View] : ab6317s00");
		model.addAttribute("initForm", new InitForm());
		return "tiposHab";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filter
	 *            Ab6317s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6317s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<TipoHabitacion> filter(
			@RequestJsonBody(param = "filter") TipoHabitacion filter,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoHabitacionController.logger.info("[POST - filter] : Obtener Ab6317s00s");
		return this.tipoHabitacionService.filter(filter, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filter
	 *            Ab6317s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param search
	 *            Ab6317s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6317s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<TipoHabitacion>> search(
			@RequestJsonBody(param = "filter") TipoHabitacion filter,
			@RequestJsonBody(param = "search") TipoHabitacion search,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoHabitacionController.logger.info("[POST - search] : Buscar Ab6317s00s");
		return this.tipoHabitacionService.search(filter, search, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filter
	 *            Ab6317s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") TipoHabitacion filter,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoHabitacionController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6317s00s");
		this.tipoHabitacionService.removeMultiple(filter, jqGridRequestDto, false);
		TipoHabitacionController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filter
	 *            Ab6317s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6317s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoHabitacion>> jerarquia(
			@RequestJsonBody(param = "filter") TipoHabitacion filter,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoHabitacionController.logger.info("[POST - jerarquia] : Obtener Ab6317s00s jerarquia");
		return this.tipoHabitacionService.jerarquia(filter, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filter
	 *            Ab6317s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<Ab6317s00>> Dto que contiene el
	 *         resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<TipoHabitacion>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") TipoHabitacion filter,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		TipoHabitacionController.logger.info("[POST - jerarquia] : Obtener Ab6317s00s jerarquia - Hijos");
		return this.tipoHabitacionService.jerarquiaChildren(filter, jqGridRequestDto);
	}

}
