package com.ejie.ab63.control;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.ZonaOcio;
import com.ejie.ab63.service.ZonaOcioService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.TableRequestDto;
import com.ejie.x38.dto.TableResponseDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * Ab6333s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/zonaOcio")

public class ZonaOcioController {

	private static final Logger logger = LoggerFactory.getLogger(ZonaOcioController.class);

	@Autowired
	private ZonaOcioService zonaOcioService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Operacion CRUD Read. Devuelve el bean correspondiente al identificador
	 * indicado.
	 * 
	 * @param idZonaOcio
	 *            Integer
	 * @return Ab6333s00 Objeto correspondiente al identificador indicado.
	 */
	@RequestMapping(value = "/{idZonaOcio}", method = RequestMethod.GET)
	public @ResponseBody ZonaOcio get(@PathVariable Integer idZonaOcio) {
		ZonaOcio filter = new ZonaOcio();
		filter.setIdZonaOcio(idZonaOcio);
		filter = this.zonaOcioService.find(filter);
		ZonaOcioController.logger.info("[GET - findBy_PK] : Obtener Ab6333s00 por PK");
		return filter;
	}

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterAb6333s00
	 *            Ab6333s00 Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<Ab6333s00> Lista de objetos correspondientes a la busqueda
	 *         realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<ZonaOcio> getAll(@ModelAttribute ZonaOcio filterAb6333s00) {
		ZonaOcioController.logger.info("[GET - find_ALL] : Obtener Ab6333s00 por filtro");
		return this.zonaOcioService.findAll(filterAb6333s00, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param filter
	 *            Ab6333s00 Bean que contiene la informacion a modificar.
	 * @return Ab6333s00 Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody ZonaOcio edit(@RequestBody ZonaOcio filter) {
		ZonaOcio filterAux = this.zonaOcioService.update(filter);
		ZonaOcioController.logger.info("[PUT] : Ab6333s00 actualizado correctamente");
		return filterAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param filter
	 *            Ab6333s00 Bean que contiene la informacion con la que se va a
	 *            crear el nuevo registro.
	 * @return Ab6333s00 Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody ZonaOcio add(@RequestBody ZonaOcio filter) {

		ZonaOcio filterAux = this.zonaOcioService.save(filter);
		return filterAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idZonaOcio
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return Ab6333s00 Bean eliminado.
	 */
	@RequestMapping(value = "/{idZonaOcio}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody ZonaOcio remove(@PathVariable Integer idZonaOcio) {
		ZonaOcio filter = new ZonaOcio();
		filter.setIdZonaOcio(idZonaOcio);
		this.zonaOcioService.remove(filter);
		ZonaOcioController.logger.info("[DELETE] : Ab6333s00 borrado correctamente");
		return filter;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		ZonaOcioController.logger.info("[GET - View] : ab6333s00");
		return "ab6333s00";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6333s00
	 *            Ab6333s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return TableRequestDto<Ab6333s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody TableResponseDto<ZonaOcio> filter(@RequestJsonBody(param = "filter") ZonaOcio filterAb6333s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		ZonaOcioController.logger.info("[POST - filter] : Obtener Ab6333s00s");
		return this.zonaOcioService.filter(filterAb6333s00, tableRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterAb6333s00
	 *            Ab6333s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchAb6333s00
	 *            Ab6333s00 Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<Ab6333s00> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<ZonaOcio>> search(@RequestJsonBody(param = "filter") ZonaOcio filterAb6333s00,
			@RequestJsonBody(param = "search") ZonaOcio searchAb6333s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		ZonaOcioController.logger.info("[POST - search] : Buscar Ab6333s00s");
		return this.zonaOcioService.search(filterAb6333s00, searchAb6333s00, tableRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterAb6333s00
	 *            Ab6333s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(@RequestJsonBody(param = "filter") ZonaOcio filterAb6333s00,
			@RequestJsonBody TableRequestDto tableRequestDto) {
		ZonaOcioController.logger.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples Ab6333s00s");
		this.zonaOcioService.removeMultiple(filterAb6333s00, tableRequestDto, false);
		ZonaOcioController.logger.info("All entities correctly deleted!");

		return tableRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

}
