package com.ejie.ab63.control.expedientes;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.ejie.ab63.comun.Constantes;
import com.ejie.ab63.model.InfoExpedienteEstablecimiento;
import com.ejie.ab63.model.expedientes.Expedientes;
import com.ejie.ab63.model.inicio.InitForm;
import com.ejie.ab63.model.terceros.DatosTerceros;
import com.ejie.ab63.model.terceros.RelExpTer;
import com.ejie.ab63.model.usuario.Usuario;
import com.ejie.ab63.model.util.ResultAjaxOperation;
import com.ejie.ab63.service.expedientes.ExpedientesService;
import com.ejie.ab63.service.procedimientos.ProcedureActions;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;

/**
 * Ab6301s00Controller  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/fichaExpediente/asociarEstablecimiento")
public class AsociarEstablecimientoController extends ExpedienteBaseContoller {

	private static final Logger logger = LoggerFactory.getLogger(AsociarEstablecimientoController.class);

	@Override
	protected String getCurrentPage() {
		return Constantes.PESTANA_ASOCIAR_ESTABLECIMIENTO;
	}

	@Override
	protected String getTilesPage() {
		return "asociarEstablecimiento";
	}

	@Override
	protected void setCurrentPageModel(Model model, InitForm initForm) {
		String nombreExpediente = initForm.getFolderNumber() + " - " + initForm.getTituloExpediente();
		RelExpTer relExp = new RelExpTer();
		relExp.setIdExpediente(initForm.getIdExpediente());
		List<RelExpTer> relExpTers = this.getRelExpTerService().findAll(relExp, null);
		String dni = "";
		String dniRepresentante = "";
		for (int i = 0; i < relExpTers.size(); i++) {
			RelExpTer temp = relExpTers.get(i);
			if (Constantes.SOLICITANTE == temp.getTiposTercero().getIdTipoTercero()
					&& temp.getDatosTerceros().getTipoParticipante() == Constantes.PARTICIPANTE_TITULAR) {
				DatosTerceros datos = temp.getDatosTerceros();
				dni = datos.getDocumento();

			} else if (Constantes.SOLICITANTE == temp.getTiposTercero().getIdTipoTercero()
					&& temp.getDatosTerceros().getTipoParticipante() == Constantes.PARTICIPANTE_REPRESENTANTE) {
				DatosTerceros datos = temp.getDatosTerceros();
				dniRepresentante = datos.getDocumento();
			}
		}
		String folderNumber = initForm.getFolderNumber();
		List<Expedientes> expedientes = this.getExpedientesService().findExpediente(folderNumber);
		Expedientes expediente = new Expedientes();
		for (Expedientes expedientes2 : expedientes) {
			expediente = expedientes2;
		}

		// pasarle el expediente me devuelve si esta cerrado o no
		ExpedientesService expedientesService = this.getExpedientesService();
		boolean expCerrado = expedientesService.checkIsClosed(expediente);

		// aadirlo al modelo el atributo que m indique si esta cerrrado para en
		// el jsp deshabilitar el boton 3161
		model.addAttribute("expCerrado", expCerrado);
		model.addAttribute("dniTitular", dni);
		model.addAttribute("dniRepresentante", dniRepresentante);
		model.addAttribute("nombreExpediente", nombreExpediente);

		model.addAttribute("filterTitular", new InfoExpedienteEstablecimiento());
		model.addAttribute("filterRepresentante", new InfoExpedienteEstablecimiento());
		model.addAttribute("filterUbicacion", new InfoExpedienteEstablecimiento());
	}

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 * @throws Exception
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.POST)
	public ModelAndView getFormEdit(Model model, @ModelAttribute("initForm") InitForm initForm, Usuario usuario)
			throws Exception {
		AsociarEstablecimientoController.logger.info("[GET - View] : ab6301s00");

		return mostrar(model, initForm, usuario);
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterAb6301s00
	 *            Ab6301s00 Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<Ab6301s00> Dto que contiene el resultado del
	 *         filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<InfoExpedienteEstablecimiento> filter(
			@RequestJsonBody(param = "filter") InfoExpedienteEstablecimiento filterEstablecimiento,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		AsociarEstablecimientoController.logger.info("[POST - filter] : Obtener establecimientos");
		ArrayList<String> exclude = new ArrayList<String>();
		exclude.add(Constantes.PROCEDIMIENTO_INICIO_ACTIVIDAD);
		filterEstablecimiento.setExcludes(exclude);

		if (Constantes.TIPO_BUSQUEDA_ESTABLECIMIENTOS_TITULAR.equals(filterEstablecimiento.getTipoBusqueda())) {
			return this.getExpedientesService().findExpedientesEstablecimientosByDniTitular(filterEstablecimiento,
					jqGridRequestDto);
		} else if (Constantes.TIPO_BUSQUEDA_ESTABLECIMIENTOS_REPRESENTANTE
				.equals(filterEstablecimiento.getTipoBusqueda())) {
			return this.getExpedientesService().findExpedientesEstablecimientosByDniRepresentante(filterEstablecimiento,
					jqGridRequestDto);
		} else {
			return this.getExpedientesService().findExpedientesEstablecimientosByUbicacion(filterEstablecimiento,
					jqGridRequestDto);
		}
	}

	/**
	 * 
	 * @param idExpediente
	 * @param initForm
	 * @param identificadorEstAnterior
	 * @param listExpedientes
	 * @return
	 */
	@RequestMapping(value = "/asociar/{idExpediente}", method = RequestMethod.POST)
	public @ResponseBody ResultAjaxOperation asociarEstablecimientos(HttpServletRequest request,
			@PathVariable("idExpediente") Integer idExpediente, @ModelAttribute("initForm") InitForm initForm,
			@RequestParam(value = "listExpedientes", required = true) List<String> listExpedientes) {
		AsociarEstablecimientoController.logger.info("[POST - asociar]:");
		ProcedureActions procedureActions = getProcedureActions(initForm);
		return this.getExpedientesService().procesarAsociar(request, initForm, procedureActions, listExpedientes);

	}

}
