package com.ejie.ab63.control.terceros;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import com.ejie.ab63.model.terceros.DatosTerceros;
import com.ejie.ab63.service.terceros.DatosTercerosService;
import com.ejie.x38.control.bind.annotation.RequestJsonBody;
import com.ejie.x38.dto.JQGridRequestDto;
import com.ejie.x38.dto.JQGridResponseDto;
import com.ejie.x38.dto.JerarquiaDto;
import com.ejie.x38.dto.TableRowDto;

/**
 * DatosTercerosController  
 * 
 *  
 */

@Controller
@RequestMapping(value = "/datosterceros")

public class DatosTercerosController {

	private static final Logger logger = LoggerFactory.getLogger(DatosTercerosController.class);

	@Autowired
	private DatosTercerosService datosTercerosService;

	/*
	 * OPERACIONES CRUD (Create, Read, Update, Delete)
	 * 
	 */

	/**
	 * Devuelve una lista de beans correspondientes a los valores de filtrados
	 * indicados en el objeto pasado como parametro.
	 *
	 * @param filterDatosTerceros
	 *            DatosTerceros Objeto que contiene los parametros de filtrado
	 *            utilizados en la busqueda.
	 * @return List<DatosTerceros> Lista de objetos correspondientes a la
	 *         busqueda realizada.
	 */
	@RequestMapping(method = RequestMethod.GET)
	public @ResponseBody List<DatosTerceros> getAll(@ModelAttribute DatosTerceros filterDatosTerceros) {
		DatosTercerosController.logger.info("[GET - find_ALL] : Obtener DatosTerceros por filtro");
		return this.datosTercerosService.findAll(filterDatosTerceros, null);
	}

	/**
	 * Operacion CRUD Edit. Modificacion del bean indicado.
	 *
	 * @param datosTerceros
	 *            DatosTerceros Bean que contiene la informacion a modificar.
	 * @return DatosTerceros Bean resultante de la modificacion.
	 */
	@RequestMapping(method = RequestMethod.PUT)
	public @ResponseBody DatosTerceros edit(@RequestBody DatosTerceros datosTerceros) {
		DatosTerceros datosTercerosAux = this.datosTercerosService.update(datosTerceros);
		DatosTercerosController.logger.info("[PUT] : DatosTerceros actualizado correctamente");
		return datosTercerosAux;
	}

	/**
	 * Operacion CRUD Create. Creacion de un nuevo registro a partir del bean
	 * indicado.
	 *
	 * @param datosTerceros
	 *            DatosTerceros Bean que contiene la informacion con la que se
	 *            va a crear el nuevo registro.
	 * @return DatosTerceros Bean resultante del proceso de creacion.
	 */
	@RequestMapping(method = RequestMethod.POST)
	public @ResponseBody DatosTerceros add(@RequestBody DatosTerceros datosTerceros) {
		DatosTerceros datosTercerosAux = this.datosTercerosService.add(datosTerceros);
		DatosTercerosController.logger.info("[POST] : DatosTerceros insertado correctamente");
		return datosTercerosAux;
	}

	/**
	 * Operacion CRUD Delete. Borrado del registro correspondiente al
	 * identificador especificado.
	 *
	 * @param idTercero
	 *            Integer Identificador del objeto que se desea eliminar.
	 * @return DatosTerceros Bean eliminado.
	 */
	@RequestMapping(value = "/{idTercero}", method = RequestMethod.DELETE)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody DatosTerceros remove(@PathVariable Integer idTercero) {
		DatosTerceros datosTerceros = new DatosTerceros();
		datosTerceros.setIdTercero(idTercero);
		this.datosTercerosService.remove(idTercero);
		DatosTercerosController.logger.info("[DELETE] : DatosTerceros borrado correctamente");
		return datosTerceros;
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE
	 * 
	 */

	/**
	 * Metodo de presentacion del RUP_TABLE.
	 * 
	 * @param model
	 *            Model
	 * @return String
	 */
	@RequestMapping(value = "/maint", method = RequestMethod.GET)
	public String getFormEdit(Model model) {
		DatosTercerosController.logger.info("[GET - View] : datosterceros");
		return "datosterceros";
	}

	/**
	 * Operacion de filtrado del componente RUP_TABLE.
	 * 
	 * @param filterDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<DatosTerceros> Dto que contiene el resultado
	 *         del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<DatosTerceros> filter(
			@RequestJsonBody(param = "filter") DatosTerceros filterDatosTerceros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DatosTercerosController.logger.info("[POST - filter] : Obtener DatosTerceross");
		return this.datosTercerosService.filter(filterDatosTerceros, jqGridRequestDto, false);
	}

	/**
	 * Operacion de busqueda del componente RUP_TABLE.
	 * 
	 * @param filterDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param searchDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de busqueda a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la búsqueda.
	 * @return TableRowDto<DatosTerceros> Dto que contiene el resultado de la
	 *         busqueda realizada por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/search", method = RequestMethod.POST)
	public @ResponseBody List<TableRowDto<DatosTerceros>> search(
			@RequestJsonBody(param = "filter") DatosTerceros filterDatosTerceros,
			@RequestJsonBody(param = "search") DatosTerceros searchDatosTerceros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DatosTercerosController.logger.info("[POST - search] : Buscar DatosTerceross");
		return this.datosTercerosService.search(filterDatosTerceros, searchDatosTerceros, jqGridRequestDto, false);
	}

	/**
	 * Borrado multiple de registros
	 * 
	 * @param filterDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en la busqueda.
	 * @return List<String> Lista de los identificadores de los registros
	 *         eliminados.
	 * 
	 */
	@RequestMapping(value = "/deleteAll", method = RequestMethod.POST)
	@ResponseStatus(value = HttpStatus.OK)
	public @ResponseBody List<String> removeMultiple(
			@RequestJsonBody(param = "filter") DatosTerceros filterDatosTerceros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DatosTercerosController.logger
				.info("[POST - search] : [POST - removeMultiple] : Eliminar multiples DatosTerceross");
		this.datosTercerosService.removeMultiple(filterDatosTerceros, jqGridRequestDto, false);
		DatosTercerosController.logger.info("All entities correctly deleted!");

		return jqGridRequestDto.getMultiselection().getSelectedIds();
	}

	/*
	 * METODOS COMPONENTE RUP_TABLE - JERARQUIA
	 */

	/**
	 * Operacion de filtrado del componente RUP_TABLE para presentar los
	 * registros mediante visualizacion jerarquica.
	 * 
	 * @param filterDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquia/filter", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquia(
			@RequestJsonBody(param = "filter") DatosTerceros filterDatosTerceros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DatosTercerosController.logger.info("[POST - jerarquia] : Obtener DatosTerceross jerarquia");
		return this.datosTercerosService.jerarquia(filterDatosTerceros, jqGridRequestDto, false);
	}

	/**
	 * Recupera los hijos de los registros desplegados en la visualizacion
	 * jerarquica.
	 * 
	 * @param filterDatosTerceros
	 *            DatosTerceros Bean que contiene los parametros de filtrado a
	 *            emplear.
	 * @param jqGridRequestDto
	 *            Dto que contiene los parametros de configuracion propios del
	 *            RUP_TABLE a aplicar en el filtrado.
	 * @return JQGridResponseDto<JerarquiaDto<DatosTerceros>> Dto que contiene
	 *         el resultado del filtrado realizado por el componente RUP_TABLE.
	 */
	@RequestMapping(value = "/jerarquiaChildren", method = RequestMethod.POST)
	public @ResponseBody JQGridResponseDto<JerarquiaDto<DatosTerceros>> jerarquiaChildren(
			@RequestJsonBody(param = "filter") DatosTerceros filterDatosTerceros,
			@RequestJsonBody JQGridRequestDto jqGridRequestDto) {
		DatosTercerosController.logger.info("[POST - jerarquia] : Obtener DatosTerceross jerarquia - Hijos");
		return this.datosTercerosService.jerarquiaChildren(filterDatosTerceros, jqGridRequestDto);
	}

}
